ActionBlockDeclaration class final
Reusable action-block declaration recorded on the DSL model.
- Annotations
-
- @immutable
Constructors
Properties
-
actions
→ List<
DslAction> -
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- name → String
-
final
- ownerWidgetClassName → String?
-
final
-
params
→ Map<
String, DslType> -
final
- returns → DslType?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → ActionBlockLookupScope
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited