ActionBlockTarget class abstract interface

Shared target protocol for declared or name-resolved action blocks.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
isNamedLookup bool
no setter
name String
no setter
ownerWidgetClassName String?
no setter
params Map<String, DslType>
no setter
returnName String?
no setter
returnType DslType?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope ActionBlockLookupScope
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited