ActionOutput class final

Reference to a prior action output captured with outputAs:.

Use this when a later action needs the typed output of an earlier action in the same chain.

Example:

ApiCall(
  createTask,
  outputAs: 'createdTask',
  onSuccess: (_) => [
    Navigate('TaskDetailPage', params: {
      'taskRef': DocumentReferenceOf(ActionOutput('createdTask')),
    }),
  ],
)
Inheritance
Annotations
  • @immutable

Constructors

ActionOutput(String alias)
const

Properties

alias String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String field) FieldAccess
inherited