ActionType class final

Action-typed parameter marker.

Inheritance
Annotations
  • @immutable

Constructors

ActionType({ActionCallbackKind? callbackKind, Object? defaultValue})
const

Properties

callbackKind ActionCallbackKind?
final
defaultValue Object?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
withCallbackKind(ActionCallbackKind value) ActionType
withDefault(Object? value) ActionType
override

Operators

operator ==(Object other) bool
The equality operator.
inherited