AddLocalEventHandler class final

Register a local handler action block for an app event.

All handlers are explicit action blocks in Phase 15. Local handlers may target app-, page-, or component-scoped blocks when the current scope makes the lookup unambiguous.

Inheritance
Annotations
  • @immutable

Constructors

AddLocalEventHandler(AppEventTarget event, {required ActionBlockTarget actionBlock})
const

Properties

actionBlock ActionBlockTarget
final
event AppEventTarget
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited