ApiGroupDeclaration class final

API group declaration.

Endpoints in the same group share a base URL and header set.

Annotations
  • @immutable

Constructors

ApiGroupDeclaration({required String name, required String baseUrl, Map<String, String>? headers, List<Endpoint>? endpoints})

Properties

baseUrl String
final
endpoints List<Endpoint>
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited