AppEventHandle class final

Handle returned from app.event(...).

Implemented types
Annotations
  • @immutable

Constructors

AppEventHandle({required String name, required String key, required AppEventScope scope, required StructHandle? dataStruct, bool isNamedLookup = false})
const

Properties

dataStruct StructHandle?
final
hashCode int
The hash code for this object.
no setterinherited
isNamedLookup bool
final
key String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope AppEventScope
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited