AspectRatio class final

Aspect-ratio wrapper.

Inheritance
Annotations
  • @immutable

Constructors

AspectRatio({required double ratio, DslWidget? child, String? name, Object? visible})

Properties

child DslWidget?
final
hashCode int
The hash code for this object.
no setterinherited
name String?
finalinherited
ratio double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited