AuthUser class final
Authenticated-user property lookup.
This resolves against the active auth backend configured on the app: Firebase auth or Supabase auth. Compilation fails when no auth backend is active, or when auth configuration is ambiguous.
- Inheritance
-
- Object
- DslExpression
- AuthUser
- Annotations
-
- @immutable
Constructors
- AuthUser(AuthUserField field)
-
const
Properties
- field → AuthUserField
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String field) → FieldAccess -
inherited