Avatar class final

Circular avatar rendered from text initials or a network image.

Inheritance
Annotations
  • @immutable

Constructors

Avatar({Object? text, Object? imageUrl, double size = 40, ColorToken? backgroundColor, ColorToken? textColor, String? name, Object? visible})

Properties

backgroundColor ColorToken?
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl DslExpression?
final
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final
text DslExpression?
final
textColor ColorToken?
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited