Backdrop class final

Backdrop blur wrapper.

Inheritance
Annotations
  • @immutable

Constructors

Backdrop({required DslWidget child, double blur = 10, double? blurX, double? blurY, String? name, Object? visible})

Properties

blur double
final
blurX double?
final
blurY double?
final
child DslWidget
final
hashCode int
The hash code for this object.
no setterinherited
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited