Badge class final

Small badge that decorates a child with optional content.

Inheritance
Annotations
  • @immutable

Constructors

Badge({required DslWidget child, Object? content, ColorToken? color, ColorToken? textColor, String? name, Object? visible})

Properties

child DslWidget
final
color ColorToken?
final
content DslExpression?
final
hashCode int
The hash code for this object.
no setterinherited
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor ColorToken?
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited