BarChart class final

Bar chart widget.

Inheritance
Annotations
  • @immutable

Constructors

BarChart({double barWidth = 16, bool showGrid = false, bool showLabels = true, bool showValues = false, bool horizontal = false, String? name, DslExpression? visible})
const

Properties

barWidth double
final
hashCode int
The hash code for this object.
no setterinherited
horizontal bool
final
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showGrid bool
final
showLabels bool
final
showValues bool
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited