Barcode class final
Barcode or QR-code widget.
Constructors
- Barcode(Object? data, {BarcodeKind type = BarcodeKind.qrCode, double width = 200, double height = 200, ColorToken? foregroundColor, ColorToken? backgroundColor, bool showText = false, String? name, Object? visible})
Properties
- backgroundColor → ColorToken?
-
final
- data → DslExpression
-
final
- foregroundColor → ColorToken?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- name → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showText → bool
-
final
- type → BarcodeKind
-
final
- visible → DslExpression?
-
finalinherited
- width → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited