BottomNavDeclaration class final

App-level bottom navigation configuration.

All referenced pages must already exist in the DSL app.

Annotations
  • @immutable

Constructors

BottomNavDeclaration({required Iterable<BottomNavItem> items, BottomNavStyle style = BottomNavStyle.flutter, ColorToken? backgroundColor, ColorToken? selectedColor, ColorToken? unselectedColor})

Properties

backgroundColor ColorToken?
final
hashCode int
The hash code for this object.
no setterinherited
items List<BottomNavItem>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor ColorToken?
final
style BottomNavStyle
final
unselectedColor ColorToken?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited