BottomSheetLibrary class final
Shows a bottom sheet using a library component.
Constructors
-
BottomSheetLibrary(LibraryComponentHandle component, {Map<
String, Object?> ? params, bool enableDrag = true, bool nonDismissible = false})
Properties
- component → LibraryComponentHandle
-
final
- enableDrag → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nonDismissible → bool
-
final
-
params
→ Map<
String, Object?> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited