update method
Applies a typed property patch to the selected widget.
Convenience shorthand for editor.update(selection, build).
Implementation
void update(void Function(BrownfieldWidgetPatch patch) build) {
editor.update(this, build);
}
Applies a typed property patch to the selected widget.
Convenience shorthand for editor.update(selection, build).
void update(void Function(BrownfieldWidgetPatch patch) build) {
editor.update(this, build);
}