BrownfieldStateEditor class final
Builder for page/component-local state additions in brownfield edits.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widgetClassName → String
-
final
Methods
-
ensureField(
String name, DslType type) → void - Ensures a state field exists with the requested type.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited