slot method
Selects a named structural slot from the current selection.
Implementation
BrownfieldSelection slot(String name) => root.slot(name);
Selects a named structural slot from the current selection.
BrownfieldSelection slot(String name) => root.slot(name);