Button class final
Button widget.
label can be a literal or any DSL expression that lowers to text.
Constructors
- Button(Object? label, {ButtonVariant variant = ButtonVariant.filled, String? icon, double? width, double? height, ColorToken? color, ColorToken? textColor, double? borderRadius, Object? padding, bool disabled = false, Object? onTap, String? name, Object? visible})
Properties
- borderRadius → double?
-
final
- color → ColorToken?
-
final
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- icon → String?
-
final
- label → DslExpression
-
final
- name → String?
-
finalinherited
-
onTap
→ List<
DslAction> -
final
- padding → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → ColorToken?
-
final
- variant → ButtonVariant
-
final
- visible → DslExpression?
-
finalinherited
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited