Card class final
Card container widget.
Constructors
Properties
- borderRadius → double?
-
final
- child → DslWidget?
-
final
- color → ColorToken?
-
final
- elevation → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
finalinherited
-
onTap
→ List<
DslAction> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visible → DslExpression?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited