Carousel class final

Carousel shell.

Control an existing carousel later with CarouselControl(widgetName, ...).

Inheritance
Annotations
  • @immutable

Constructors

Carousel({List<DslWidget>? children, int initialPage = 1, bool infiniteScroll = true, double viewportFraction = 0.9, bool horizontal = true, double? width, double? height, double shrinkFactor = 0.25, bool centerItems = false, bool autoPlay = false, int autoPlayAnimationDurationMillis = 800, int autoPlayIntervalMillis = 4000, bool replayAtLastItem = false, String? name, Object? visible})

Properties

autoPlay bool
final
autoPlayAnimationDurationMillis int
final
autoPlayIntervalMillis int
final
centerItems bool
final
children List<DslWidget>
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
horizontal bool
final
infiniteScroll bool
final
initialPage int
final
name String?
finalinherited
replayAtLastItem bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shrinkFactor double
final
viewportFraction double
final
visible DslExpression?
finalinherited
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited