Chip class final

Single-chip display widget backed by ChoiceChips.

Inheritance
Annotations
  • @immutable

Constructors

Chip(String label, {String? icon, bool selected = false, ColorToken? backgroundColor, ColorToken? textColor, double borderRadius = 8, bool disabled = false, Object? onTap, String? name, Object? visible})

Properties

backgroundColor ColorToken?
final
borderRadius double
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
label String
final
name String?
finalinherited
onTap List<DslAction>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final
textColor ColorToken?
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited