Colors class abstract final

Built-in color tokens used by the initial reference implementation.

These map to theme slots, so they are reuse-friendly across pages and brownfield edits.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hex(int value) HexColor

Constants

accent1 → const ColorToken
accent2 → const ColorToken
accent3 → const ColorToken
accent4 → const ColorToken
alternate → const ColorToken
error → const ColorToken
info → const ColorToken
primary → const ColorToken
primaryBackground → const ColorToken
primaryText → const ColorToken
secondary → const ColorToken
secondaryBackground → const ColorToken
secondaryText → const ColorToken
success → const ColorToken
tertiary → const ColorToken
warning → const ColorToken