Column class final

Vertical flex layout.

Inheritance
Annotations
  • @immutable

Constructors

Column({List<DslWidget>? children, MainAxis mainAxis = MainAxis.start, CrossAxis crossAxis = CrossAxis.center, double? spacing, Object? padding, bool scrollable = false, String? name, Object? visible})

Properties

children List<DslWidget>
final
crossAxis CrossAxis
final
hashCode int
The hash code for this object.
no setterinherited
mainAxis MainAxis
final
name String?
finalinherited
padding Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollable bool
final
spacing double?
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited