ComponentDeclaration class final

Component declaration.

Components are reusable widget trees instantiated through ComponentHandle.

Annotations
  • @immutable

Constructors

ComponentDeclaration({required String name, String? description, Map<String, DslType>? params, required DslWidget body, List<ActionBlockDeclaration>? actionBlocks})

Properties

actionBlocks List<ActionBlockDeclaration>
no setter
body DslWidget
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
params Map<String, DslType>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited