ComponentHandle class final

Component handle returned from App.component.

This intentionally uses noSuchMethod so the DSL can accept arbitrary named arguments without generated wrappers.

Annotations
  • @immutable

Constructors

ComponentHandle(ComponentDeclaration declaration)
const

Properties

declaration ComponentDeclaration
final
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

actionBlock(String name, {Map<String, DslType>? params, DslType? returns, Object? actions, String description = ''}) ActionBlockHandle
Declares a component-scoped action block.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited