ComponentInstance class final

Component instance placeholder produced by dynamic component-handle calls.

This is normally created indirectly by calling a component handle.

Inheritance
Annotations
  • @immutable

Constructors

ComponentInstance({required Object component, required Map<String, Object?> arguments, String? name, Object? visible})

Properties

arguments Map<String, Object?>
final
component Object
final
hashCode int
The hash code for this object.
no setterinherited
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited