ComponentSnapshot class final

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
finalinherited
kind String
finalinherited
name String
finalinherited
params List<FieldSnapshot>
finalinherited
root WidgetRef
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateFields List<FieldSnapshot>
finalinherited
widgets List<WidgetRef>
no setterinherited

Methods

findByKey(String key) WidgetSelection
inherited
findByName(String name) WidgetSelection
inherited
findByPath(String path) WidgetSelection
inherited
findByText(String text) WidgetSelection
inherited
findByType(String type) WidgetSelection
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited