ConstantDeclaration class final
App-level constant declaration.
Constants are named values that can later be referenced through
Constant(...).
- Annotations
-
- @immutable
Constructors
- ConstantDeclaration({required String name, String? description, required Object? value})
-
const
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → Object?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited