Container class final
Container-style box widget.
Use this for generic layout boxes, backgrounds, shadows, and tap handling.
Constructors
Properties
- alignment → Alignment?
-
final
- borderColor → ColorToken?
-
final
- borderRadius → double?
-
final
- borderWidth → double?
-
final
- child → DslWidget?
-
final
- color → ColorToken?
-
final
- gradient → Gradient?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- margin → Object?
-
final
- name → String?
-
finalinherited
-
onTap
→ List<
DslAction> -
final
- padding → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadow → Shadow?
-
final
- visible → DslExpression?
-
finalinherited
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited