CustomDialogLibrary class final

Shows a custom dialog using a library component.

Inheritance
Annotations
  • @immutable

Constructors

CustomDialogLibrary(LibraryComponentHandle component, {Map<String, Object?>? params, bool nonDismissible = false})

Properties

component LibraryComponentHandle
final
hashCode int
The hash code for this object.
no setterinherited
nonDismissible bool
final
params Map<String, Object?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited