CustomFunctionDeclaration class final

App-level custom function declaration recorded on the DSL model.

Annotations
  • @immutable

Constructors

CustomFunctionDeclaration({required String name, Map<String, DslType>? args, required DslType returns, required String code, String description = ''})

Properties

args Map<String, DslType>
final
code String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
returns DslType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited