CustomFunctionInvocation class final
Invocation of an app-level custom function declared through
app.customFunction(...).
- Inheritance
-
- Object
- DslExpression
- CustomFunctionInvocation
- Annotations
-
- @immutable
Constructors
-
CustomFunctionInvocation(CustomFunctionHandle handle, Map<
String, Object?> args)
Properties
-
args
→ Map<
String, DslExpression> -
final
- handle → CustomFunctionHandle
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String field) → FieldAccess -
inherited