DatePicker class final

Open a date/time picker and optionally expose the selection as an action output.

Example:

DatePicker(
  mode: DatePickerMode.date,
  outputAs: 'pickedDate',
)
Inheritance
Implemented types
Annotations
  • @immutable

Constructors

DatePicker({DatePickerMode mode = DatePickerMode.date, bool allowPast = true, bool allowFuture = true, Object? defaultDateTime, Object? minDateTime, Object? maxDateTime, bool dismissible = true, String? outputAs})

Properties

allowFuture bool
final
allowPast bool
final
defaultDateTime DslExpression?
final
dismissible bool
final
hashCode int
The hash code for this object.
no setterinherited
maxDateTime DslExpression?
final
minDateTime DslExpression?
final
mode DatePickerMode
final
outputAs String?
final
outputType DslType?
no setteroverride
outputVariableName String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited