DownloadFile class final

Download a file from a URL.

Inheritance
Annotations
  • @immutable

Constructors

DownloadFile(Object? url, {Object? filename})

Properties

filename DslExpression?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url DslExpression
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited