DrawerControl class final

Open, open-end, or close a scaffold drawer.

The page must already contain the relevant drawer surface.

Inheritance
Annotations
  • @immutable

Constructors

DrawerControl.close()
const
DrawerControl.open()
const
DrawerControl.openEnd()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
kind DrawerControlKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited