DslCompileResult class final

Result of compiling the full currently-supported DSL surface into an FFProject.

Constructors

DslCompileResult({required FFProject project, required Map<EnumHandle, FFIdentifier> enumIdentifiers, required Map<StructHandle, FFIdentifier> structIdentifiers, required Map<FirestoreCollectionHandle, FFIdentifier> collectionIdentifiers, required Map<PostgresTableHandle, FFIdentifier> tableIdentifiers, required Map<String, FFIdentifier> appStateIdentifiers, required Map<String, FFIdentifier> constantIdentifiers, required Map<CustomFunctionHandle, FFIdentifier> customFunctionIdentifiers, required Map<String, FFIdentifier> apiGroupIdentifiers, required Map<String, String> componentKeys, required Map<String, String> pageKeys})

Properties

apiGroupIdentifiers Map<String, FFIdentifier>
final
appStateIdentifiers Map<String, FFIdentifier>
final
collectionIdentifiers Map<FirestoreCollectionHandle, FFIdentifier>
final
componentKeys Map<String, String>
final
constantIdentifiers Map<String, FFIdentifier>
final
customFunctionIdentifiers Map<CustomFunctionHandle, FFIdentifier>
final
enumIdentifiers Map<EnumHandle, FFIdentifier>
final
hashCode int
The hash code for this object.
no setterinherited
pageKeys Map<String, String>
final
project FFProject
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structIdentifiers Map<StructHandle, FFIdentifier>
final
tableIdentifiers Map<PostgresTableHandle, FFIdentifier>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited