DslDeclarationCompileResult class final

Result of compiling the declaration subset of a DSL app into an FFProject.

Constructors

DslDeclarationCompileResult({required FFProject project, required Map<EnumHandle, FFIdentifier> enumIdentifiers, required Map<StructHandle, FFIdentifier> structIdentifiers, required Map<FirestoreCollectionHandle, FFIdentifier> collectionIdentifiers, required Map<PostgresTableHandle, FFIdentifier> tableIdentifiers, required Map<String, FFIdentifier> appStateIdentifiers, required Map<String, FFIdentifier> constantIdentifiers, required Map<CustomFunctionHandle, FFIdentifier> customFunctionIdentifiers, required Map<String, FFIdentifier> apiGroupIdentifiers, required Map<String, Map<String, FFIdentifier>> collectionFieldIdentifiers, required Map<String, Map<String, FFIdentifier>> tableFieldIdentifiers})

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited