DslScalarKind enum

Scalar primitives supported by the initial DSL surface.

Inheritance
Available extensions

Values

string → const DslScalarKind
integer → const DslScalarKind
doubleType → const DslScalarKind
boolean → const DslScalarKind
dateTime → const DslScalarKind
imagePath → const DslScalarKind
videoPath → const DslScalarKind
audioPath → const DslScalarKind
latLng → const DslScalarKind
color → const DslScalarKind
json → const DslScalarKind

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DslScalarKind>
A constant List of the values in this enum, in order of their declaration.