groupName property
String?
get
groupName
The owning API group name once the endpoint is attached to an app.
Implementation
String? get groupName => _groupName;
The owning API group name once the endpoint is attached to an app.
String? get groupName => _groupName;