EnumType class final

Type reference to an enum handle.

Inheritance
Annotations
  • @immutable

Constructors

EnumType(EnumHandle handle, {Object? defaultValue})
const

Properties

defaultValue Object?
finalinherited
handle EnumHandle
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
withDefault(Object? value) EnumType
override

Operators

operator ==(Object other) bool
The equality operator.
inherited