Equals class final

Equality comparison wrapper.

Inheritance
Annotations
  • @immutable

Constructors

Equals(Object? left, Object? right)

Properties

hashCode int
The hash code for this object.
no setterinherited
left DslExpression
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String field) FieldAccess
inherited