ExistingProjectComponentHandle class final

Handle for reusing a component that already exists in the current project.

Annotations
  • @immutable

Constructors

ExistingProjectComponentHandle(String name, {Map<String, DslType>? params})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
params Map<String, DslType>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited