ExistingWidgetClassTypeCompileResult class final
Result of compiling a DSL page/component state or param type against an existing project context.
Constructors
- ExistingWidgetClassTypeCompileResult({required FFDataTypeV2 type, required bool requiresStructListWorkaround, required String? serializedDefaultValue})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- requiresStructListWorkaround → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializedDefaultValue → String?
-
final
- type → FFDataTypeV2
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited