ExpandImage class final

Expands the tapped image into a full-screen viewer.

Inheritance
Annotations
  • @immutable

Constructors

ExpandImage({bool allowRotation = false, bool heroAnimation = true})
const

Properties

allowRotation bool
final
hashCode int
The hash code for this object.
no setterinherited
heroAnimation bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited