Expanded class final

Expanded layout wrapper.

Inheritance
Annotations
  • @immutable

Constructors

Expanded(DslWidget child, {int flex = 1, String? name, Object? visible})

Properties

child DslWidget
final
flex int
final
hashCode int
The hash code for this object.
no setterinherited
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited