FAB class final
Floating action button.
Constructors
- FAB({String icon = 'add', Object? label, ColorToken? backgroundColor, ColorToken? foregroundColor, Object? onTap, String? name, Object? visible})
Properties
- backgroundColor → ColorToken?
-
final
- foregroundColor → ColorToken?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String
-
final
- label → DslExpression?
-
final
- name → String?
-
finalinherited
-
onTap
→ List<
DslAction> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visible → DslExpression?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited