FieldAccess class final

Struct or document field access such as State('product')['name'].

For brownfield generator items, field access is rerun-stable when type metadata is known and falls back to name-based access when it is not.

Example:

ListView(
  source: ActionOutput('tasks'),
  itemBuilder: (item) => Text(item['title']),
)
Inheritance
Annotations
  • @immutable

Constructors

FieldAccess(DslExpression target, String field)
const

Properties

field String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target DslExpression
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String field) FieldAccess
inherited