FieldSnapshot class final

Constructors

FieldSnapshot({required String name, required String key, required String type, String? defaultValue, String? description, bool persisted = false})
const

Properties

defaultValue String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
name String
final
persisted bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited