FirebaseAuthDeclaration class final

App-level Firebase Authentication configuration.

This binds auth providers to existing sign-in and signed-in pages.

Annotations
  • @immutable

Constructors

FirebaseAuthDeclaration({required Iterable<FirebaseAuthProvider> providers, required String homePageName, required String signInPageName, bool autoCreateUserDocument = false, String? userCollectionName})

Properties

autoCreateUserDocument bool
final
hashCode int
The hash code for this object.
no setterinherited
homePageName String
final
providers List<FirebaseAuthProvider>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signInPageName String
final
userCollectionName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited