FirestoreCollectionDeclaration class final

Firestore collection declaration.

Annotations
  • @immutable

Constructors

FirestoreCollectionDeclaration({required FirestoreCollectionHandle handle, required String description})

Properties

description String
final
handle FirestoreCollectionHandle
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited