FirestoreRead class final
Firestore read action.
The read document becomes available through ActionOutput(...).
- Inheritance
- Implemented types
- Annotations
-
- @immutable
Constructors
- FirestoreRead(FirestoreCollectionHandle collection, Object? reference, {String? outputAs})
Properties
- collection → FirestoreCollectionHandle
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputAs → String?
-
final
- outputType → DslType?
-
no setteroverride
- outputVariableName → String
-
no setteroverride
- reference → DslExpression
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited