FirestoreUpdate class final
Firestore update action.
The reference expression must resolve to a document reference compatible with collection.
Constructors
-
FirestoreUpdate(Object? reference, {required FirestoreCollectionHandle collection, Map<
String, Object?> ? fields})
Properties
- collection → FirestoreCollectionHandle
-
final
-
fields
→ Map<
String, DslExpression> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reference → DslExpression
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited