FlippableCard class final

Flippable card with front and back content.

Inheritance
Annotations
  • @immutable

Constructors

FlippableCard({required DslWidget front, required DslWidget back, bool flipOnTap = true, int animationDurationMillis = 400, String? name, Object? visible})

Properties

animationDurationMillis int
final
back DslWidget
final
flipOnTap bool
final
front DslWidget
final
hashCode int
The hash code for this object.
no setterinherited
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited