Form class final

Form wrapper widget.

Combine this with form actions like ValidateForm, SetFormField, and ResetFormField, which target the form and its named child fields.

Inheritance
Annotations
  • @immutable

Constructors

Form({required DslWidget child, String? name, Object? visible})

Properties

child DslWidget
final
hashCode int
The hash code for this object.
no setterinherited
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited