GenUiCatalogComponentDeclaration class final

App-level GenUI catalog-component declaration recorded on the DSL model.

Annotations
  • @immutable

Constructors

GenUiCatalogComponentDeclaration({required String chatName, required String componentName})
const

Properties

chatName String
final
componentName String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited