GenUiChat class final

AI-native GenUI chat surface.

This lowers to FlutterFlow's GenUI chat widget. Register tools, local event listeners, catalog components, and chat chrome through the app-level app.genUi* APIs after declaring the widget.

Example:

final assistantChat = GenUiChat(
  name: 'CatalogAssistantChat',
  systemPrompt: 'You help users find the right product.',
);

app.genUiTool(
  assistantChat,
  actionBlock: suggestProductCallout,
  loadingMessage: 'Thinking...',
);
Inheritance
Implemented types
Annotations
  • @immutable

Constructors

GenUiChat({required String systemPrompt, String? thinkingMessage, String? name, Object? visible})

Properties

chatName String
no setteroverride
handle GenUiChatHandle
no setter
hashCode int
The hash code for this object.
no setterinherited
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemPrompt String
final
thinkingMessage String?
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited