GenUiChatHandle class final
Handle for referring to a named GenUI chat widget outside the widget tree.
Prefer passing the actual GenUiChat(...) widget instance when convenient.
Use this handle when the chat is referenced from a different scope.
- Implemented types
- Annotations
-
- @immutable
Constructors
- GenUiChatHandle(String chatName)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited