GenUiToolDeclaration class final

App-level GenUI tool declaration recorded on the DSL model.

Annotations
  • @immutable

Constructors

GenUiToolDeclaration({required String chatName, required ActionBlockTarget actionBlock, required String loadingMessage, String description = ''})
const

Properties

actionBlock ActionBlockTarget
final
chatName String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
loadingMessage String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited