Global class final
Global runtime-property lookup.
Use this for FlutterFlow globals such as screen size, route metadata, theme mode, current timestamp, and current device location.
- Inheritance
-
- Object
- DslExpression
- Global
- Annotations
-
- @immutable
Constructors
- Global(GlobalProperty property)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- property → GlobalProperty
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String field) → FieldAccess -
inherited