GlobalProperty enum

Supported global runtime properties exposed by FlutterFlow.

Inheritance
Available extensions

Values

currentTimestamp → const GlobalProperty
isUserLoggedIn → const GlobalProperty
currentDeviceLocation → const GlobalProperty
linkToCurrentPage → const GlobalProperty
isDarkMode → const GlobalProperty
isLightMode → const GlobalProperty
isAndroid → const GlobalProperty
isIos → const GlobalProperty
isWeb → const GlobalProperty
isDebugMode → const GlobalProperty
isKeyboardVisible → const GlobalProperty
fractionScreenWidth → const GlobalProperty
fractionScreenHeight → const GlobalProperty
screenWidth → const GlobalProperty
screenHeight → const GlobalProperty
currentEnvironment → const GlobalProperty
currentRoute → const GlobalProperty
currentRouteStack → const GlobalProperty

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GlobalProperty>
A constant List of the values in this enum, in order of their declaration.