GradientStop class final

A single color stop in a Gradient.

Annotations
  • @immutable

Constructors

GradientStop(ColorToken color, double position)

Properties

color ColorToken
final
hashCode int
The hash code for this object.
no setterinherited
position double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited