Icon class final

Icon display widget.

Use Flutter icon names such as refresh or shopping_cart.

Inheritance
Annotations
  • @immutable

Constructors

Icon(String icon, {double? size, ColorToken? color, String? name, DslExpression? visible})
const

Properties

color ColorToken?
final
hashCode int
The hash code for this object.
no setterinherited
icon String
final
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited