IconButton class final

Icon-only button widget.

Inheritance
Annotations
  • @immutable

Constructors

IconButton(String icon, {double? size, ColorToken? color, ColorToken? fillColor, double? borderRadius, Object? onTap, String? name, Object? visible})

Properties

borderRadius double?
final
color ColorToken?
final
fillColor ColorToken?
final
hashCode int
The hash code for this object.
no setterinherited
icon String
final
name String?
finalinherited
onTap List<DslAction>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited