Image class final
Image widget.
path can be a literal URL/asset path or any DSL expression resolving to one.
Constructors
Properties
- borderRadius → double?
-
final
- cached → bool
-
final
- fit → ImageFit
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- isNetwork → bool
-
final
- name → String?
-
finalinherited
- path → DslExpression
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visible → DslExpression?
-
finalinherited
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited