ItemIndex class final

Index of the current item in a ListView/GridView builder.

Obtain via item.index inside an itemBuilder callback.

Inheritance
Annotations
  • @immutable

Constructors

ItemIndex()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String field) FieldAccess
inherited