LaunchUrl class final

Launch a URL in the browser or platform handler.

Inheritance
Annotations
  • @immutable

Constructors

LaunchUrl(Object? url)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url DslExpression
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited