LibraryComponentHandle class final
Handle for reusing a component exported by an attached library dependency.
- Annotations
-
- @immutable
Constructors
Properties
- componentKey → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- libraryProjectId → String
-
final
- name → String
-
final
-
params
→ Map<
String, DslType> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited