LibraryPageHandle class final

Handle for navigating to a page exported by an attached library dependency.

Annotations
  • @immutable

Constructors

LibraryPageHandle({required String name, required String libraryProjectId, required String pageKey, Map<String, DslType>? params})

Properties

hashCode int
The hash code for this object.
no setterinherited
libraryProjectId String
final
name String
final
pageKey String
final
params Map<String, DslType>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited