LineChart class final

Line chart widget.

Inheritance
Annotations
  • @immutable

Constructors

LineChart({ColorToken? color, double lineWidth = 2, bool showGrid = false, bool showLabels = true, bool showDots = true, bool curved = false, bool filled = false, double fillOpacity = 0.3, double? minY, double? maxY, String? name, DslExpression? visible})
const

Properties

color ColorToken?
final
curved bool
final
filled bool
final
fillOpacity double
final
hashCode int
The hash code for this object.
no setterinherited
lineWidth double
final
maxY double?
final
minY double?
final
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDots bool
final
showGrid bool
final
showLabels bool
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited