ListTile class final

A tappable list row with leading/trailing icons and optional subtitle.

Inheritance
Annotations
  • @immutable

Constructors

ListTile({required Object? title, Object? subtitle, String? leadingIcon, String? trailingIcon, bool dense = false, ColorToken? color, Object? borderRadius, Object? contentPadding, Object? onTap, String? name, Object? visible})

Properties

borderRadius Object?
final
color ColorToken?
final
contentPadding Object?
final
dense bool
final
hashCode int
The hash code for this object.
no setterinherited
leadingIcon String?
final
name String?
finalinherited
onTap List<DslAction>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle DslExpression?
final
title DslExpression
final
trailingIcon String?
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited