MapWidget class final

Map widget implementation backing the public Map helper.

Inheritance
Annotations
  • @immutable

Constructors

MapWidget({double lat = 37.414, double lng = -122.077, double zoom = 11, double? width, double? height, String? name, DslExpression? visible})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double?
final
lat double
final
lng double
final
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited
width double?
final
zoom double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited