MouseCursor enum

Mouse cursors supported by MouseRegion.

Inheritance
Available extensions

Values

defer → const MouseCursor
uncontrolled → const MouseCursor
basic → const MouseCursor
click → const MouseCursor
none → const MouseCursor
forbidden → const MouseCursor
wait → const MouseCursor
progress → const MouseCursor
contextMenu → const MouseCursor
help → const MouseCursor
text → const MouseCursor
verticalText → const MouseCursor
cell → const MouseCursor
precise → const MouseCursor
move → const MouseCursor
grab → const MouseCursor
grabbing → const MouseCursor
noDrop → const MouseCursor
alias → const MouseCursor
copy → const MouseCursor
disappearing → const MouseCursor
allScroll → const MouseCursor
resizeLeftRight → const MouseCursor
resizeUpDown → const MouseCursor
resizeUpLeftDownRight → const MouseCursor
resizeUpRightDownLeft → const MouseCursor
resizeUp → const MouseCursor
resizeDown → const MouseCursor
resizeLeft → const MouseCursor
resizeRight → const MouseCursor
resizeUpLeft → const MouseCursor
resizeUpRight → const MouseCursor
resizeDownLeft → const MouseCursor
resizeDownRight → const MouseCursor
resizeColumn → const MouseCursor
resizeRow → const MouseCursor
zoomIn → const MouseCursor
zoomOut → const MouseCursor

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MouseCursor>
A constant List of the values in this enum, in order of their declaration.