PageDeclaration class final

Page declaration.

A page is a top-level route with optional params, local state, and on-load actions.

Annotations
  • @immutable

Constructors

PageDeclaration({required String name, String? description, required String route, Map<String, DslType>? params, Map<String, DslType>? state, List<DslAction>? onLoad, required DslWidget body, bool isInitial = false, List<ActionBlockDeclaration>? actionBlocks})

Properties

actionBlocks List<ActionBlockDeclaration>
no setter
body DslWidget
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
isInitial bool
final
name String
final
onLoad List<DslAction>
final
params Map<String, DslType>
final
route String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Map<String, DslType>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited