PageHandle class final
Page handle returned from App.page.
Pass this handle to navigation or shell APIs to keep page references aligned with declared DSL pages.
- Annotations
-
- @immutable
Constructors
- PageHandle(PageDeclaration declaration)
-
const
Properties
- declaration → PageDeclaration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
actionBlock(
String name, {Map< String, DslType> ? params, DslType? returns, Object? actions, String description = ''}) → ActionBlockHandle - Declares a page-scoped action block.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited