PageView class final

Swipeable page shell.

Control an existing page view later with PageViewControl(widgetName, ...).

Inheritance
Annotations
  • @immutable

Constructors

PageView({List<DslWidget>? children, int initialPage = 0, bool allowScrolling = true, bool horizontal = true, double? width, double? height, bool showIndicator = true, String? name, Object? visible})

Properties

allowScrolling bool
final
children List<DslWidget>
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
horizontal bool
final
initialPage int
final
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showIndicator bool
final
visible DslExpression?
finalinherited
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited