PageViewControl class final

Control an existing PageView by widget name:.

The named widget must already exist on the current page.

Inheritance
Annotations
  • @immutable

Constructors

PageViewControl.jumpTo(String widgetName, int index)
const
PageViewControl.next(String widgetName)
const
PageViewControl.previous(String widgetName)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int?
final
kind ViewControlKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widgetName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited