PinCode class final

Pin-code input widget.

Inheritance
Annotations
  • @immutable

Constructors

PinCode({int length = 4, bool autoFocus = false, bool obscureText = false, Object? onCompleted, String? name, Object? visible})

Properties

autoFocus bool
final
hashCode int
The hash code for this object.
no setterinherited
length int
final
name String?
finalinherited
obscureText bool
final
onCompleted List<DslAction>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited