PlaySound class final

Plays a sound from a URL.

Inheritance
Annotations
  • @immutable

Constructors

PlaySound(Object? url, {String name = 'sound', double volume = 1.0, bool awaitPlayback = false})

Properties

awaitPlayback bool
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url DslExpression
final
volume double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited