PostgresCreate class final

Postgres/Supabase insert action.

Inheritance
Implemented types
Annotations
  • @immutable

Constructors

PostgresCreate(PostgresTableHandle table, {Map<String, Object?>? fields, String? outputAs, bool? returnMatchingRows})

Properties

fields Map<String, DslExpression>
final
hashCode int
The hash code for this object.
no setterinherited
outputAs String?
final
outputType DslType?
no setteroverride
outputVariableName String
no setteroverride
returnMatchingRows bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table PostgresTableHandle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited