PostgresFilter class final
One SQL query filter.
- Annotations
-
- @immutable
Constructors
- PostgresFilter(String field, {required PostgresFilterRelation relation, Object? value, PostgresExactEquality? exactEquality})
Properties
- exactEquality → PostgresExactEquality?
-
final
- field → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- relation → PostgresFilterRelation
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → DslExpression?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited