PostgresRead class final

Postgres/Supabase read action returning one row.

Inheritance
Implemented types
Annotations
  • @immutable

Constructors

PostgresRead(PostgresTableHandle table, {PostgresQuerySpec? query, String? outputAs})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
outputAs String?
final
outputType DslType?
no setteroverride
outputVariableName String
no setteroverride
query PostgresQuerySpec?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table PostgresTableHandle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited