PostgresTableField class final

SQL table field metadata used by PostgresTableHandle.

This models one shared table declaration surface for both Supabase and generic Postgres. The active backend is chosen at the app level.

Annotations
  • @immutable

Constructors

PostgresTableField(DslType type, {String description = '', String postgresType = '', String? foreignKey, bool isPrimaryKey = false, bool isRequired = false, bool hasDefault = false})
const

Properties

description String
final
foreignKey String?
final
hasDefault bool
final
hashCode int
The hash code for this object.
no setterinherited
isPrimaryKey bool
final
isRequired bool
final
postgresType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type DslType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited