RadioGroup class final
Radio-button group.
Constructors
-
RadioGroup({required Iterable<
String> options, Object? selected, ColorToken? activeColor, bool vertical = true, Object? onChanged, String? name, Object? visible})
Properties
- activeColor → ColorToken?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
finalinherited
-
onChanged
→ List<
DslAction> -
final
-
options
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → DslExpression?
-
final
- vertical → bool
-
final
- visible → DslExpression?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited