RichText class final
Rich text composed of multiple spans.
Constructors
-
RichText({required List<
RichTextSpan> spans, TextStyleToken? style, int? maxLines, String? name, Object? visible})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLines → int?
-
final
- name → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spans
→ List<
RichTextSpan> -
final
- style → TextStyleToken?
-
final
- visible → DslExpression?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited