Scaffold class final

Top-level app scaffold.

Pages compile with a scaffold root, while components usually compile with a container root.

Inheritance
Annotations
  • @immutable

Constructors

Scaffold({AppBar? appBar, DslWidget? body, DslWidget? floatingActionButton, DslWidget? drawer, DslWidget? endDrawer, String? name, Object? visible})

Properties

appBar AppBar?
final
body DslWidget?
final
drawer DslWidget?
final
endDrawer DslWidget?
final
floatingActionButton DslWidget?
final
hashCode int
The hash code for this object.
no setterinherited
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited