ScrollTo class final

Scrolls a named scrollable widget to a percentage.

Inheritance
Annotations
  • @immutable

Constructors

ScrollTo(String widgetName, {required double percentage, int durationMillis = 300})
const

Properties

durationMillis int
final
hashCode int
The hash code for this object.
no setterinherited
percentage double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widgetName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited