SendEmail class final

Opens the platform email composer with pre-filled content.

Inheritance
Annotations
  • @immutable

Constructors

SendEmail(Object? to, {Object? subject, Object? body})

Properties

body DslExpression?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject DslExpression?
final
to DslExpression
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited