SetFormField class final

Set a form field's value by widget name:.

Inheritance
Annotations
  • @immutable

Constructors

SetFormField(String widgetName, Object? value)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value DslExpression
final
widgetName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited