SetState class final

Page-local state mutation.

SetState targets page or component local state, not app state. Use UpdateAppState when the mutation should affect global app state instead.

Inheritance
Annotations
  • @immutable

Properties

amount num?
final
field String
final
hashCode int
The hash code for this object.
no setterinherited
index DslExpression?
final
kind SetStateKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value DslExpression?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited