Shadow class final

Simple shadow token.

Annotations
  • @immutable

Constructors

Shadow({required double blur, double dx = 0, double dy = 0, double spread = 0, required ColorToken color})
const

Properties

blur double
final
color ColorToken
final
dx double
final
dy double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spread double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited