Share class final

Open the platform share sheet for a string or URL value.

Example:

Share(State('inviteLink'))
Inheritance
Annotations
  • @immutable

Constructors

Share(Object? text)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text DslExpression
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited