Slider class final

Slider input.

Inheritance
Annotations
  • @immutable

Constructors

Slider({Object? value = 0, double min = 0, double max = 100, int? divisions, ColorToken? activeColor, Object? onChanged, String? name, Object? visible})

Properties

activeColor ColorToken?
final
divisions int?
final
hashCode int
The hash code for this object.
no setterinherited
max double
final
min double
final
name String?
finalinherited
onChanged List<DslAction>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value DslExpression
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited