Spacer class final

Spacer widget, either flex-based or fixed-size.

Inheritance
Annotations
  • @immutable

Constructors

Spacer({int? flex, double? width, double? height, String? name, Object? visible})

Properties

flex int?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited