Stack class final

Overlay stack layout.

Inheritance
Annotations
  • @immutable

Constructors

Stack({List<DslWidget>? children, Alignment alignment = Alignment.center, double? width, double? height, String? name, Object? visible})

Properties

alignment Alignment
final
children List<DslWidget>
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited