State class final
Page-local state lookup.
Use this for page or component local state declared through page(..., state: ...) or brownfield state edits.
- Inheritance
-
- Object
- DslExpression
- State
- Annotations
-
- @immutable
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String field) → FieldAccess -
inherited