StickyHeader class final

Sticky header layout with a header and scrolling content.

Inheritance
Annotations
  • @immutable

Constructors

StickyHeader({required DslWidget header, required DslWidget content, bool allowOverlap = false, String? name, Object? visible})

Properties

allowOverlap bool
final
content DslWidget
final
hashCode int
The hash code for this object.
no setterinherited
final
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited