StructHandle class final
Handle returned from App.struct. It is also usable as a field type.
Constructors
Properties
- defaultValue → Object?
-
finalinherited
- description → String?
-
final
-
fields
→ Map<
String, DslType> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
withDefault(
Object? value) → StructHandle -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override