SupabaseAuthDeclaration class final

App-level Supabase Authentication configuration.

Annotations
  • @immutable

Constructors

SupabaseAuthDeclaration({required Iterable<SupabaseAuthProvider> providers, required String homePageName, required String signInPageName})

Properties

hashCode int
The hash code for this object.
no setterinherited
homePageName String
final
providers List<SupabaseAuthProvider>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signInPageName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited