SupabaseDeclaration class final

App-level Supabase project/backend declaration.

Annotations
  • @immutable

Constructors

SupabaseDeclaration({required String url, required String anonKey, String? connectedProjectId, String? connectedProjectName, String? connectedRegion, SupabaseGoogleAuthConfig? googleAuth, SupabaseAppleAuthConfig? appleAuth})
const

Properties

anonKey String
final
appleAuth SupabaseAppleAuthConfig?
final
connectedProjectId String?
final
connectedProjectName String?
final
connectedRegion String?
final
googleAuth SupabaseGoogleAuthConfig?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited