SwitchCase class final

Multi-branch conditional built on top of equality checks.

Annotations
  • @immutable

Constructors

SwitchCase(Object? value, {required Object? then})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thenActions List<DslAction>
final
value DslExpression
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited