Text class final

Text display widget.

content can be a literal or any DSL expression that lowers to string-like text output.

Inheritance
Annotations
  • @immutable

Constructors

Text(Object? content, {TextStyleToken? style, ColorToken? color, int? maxLines, TextAlign? textAlign, TextOverflow? overflow, String? name, Object? visible})

Properties

color ColorToken?
final
content DslExpression
final
hashCode int
The hash code for this object.
no setterinherited
maxLines int?
final
name String?
finalinherited
overflow TextOverflow?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyleToken?
final
textAlign TextAlign?
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited