TextCoercion class final
Explicit coercion from a text field value into another scalar type.
Prefer explicit coercions when a binding target expects int or double
and the source is text.
Example:
SetState('quantity', TextValue().asInt())
- Inheritance
-
- Object
- DslExpression
- TextCoercion
- Annotations
-
- @immutable
Constructors
- TextCoercion.double_()
-
const
- TextCoercion.int_()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → TextCoercionKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String field) → FieldAccess -
inherited