Tooltip class final

Tooltip wrapper around an existing child widget.

Inheritance
Annotations
  • @immutable

Constructors

Tooltip({required Object? message, required DslWidget child, ColorToken? backgroundColor, double? borderRadius, String? name, Object? visible})

Properties

backgroundColor ColorToken?
final
borderRadius double?
final
child DslWidget
final
hashCode int
The hash code for this object.
no setterinherited
message DslExpression
final
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited