TriggerEvent class final

Trigger a declared app event.

Use a declared AppEventHandle in greenfield DSL apps. Use AppEvent.named(...) when patching an existing project and the event is already present on the target app.

Inheritance
Annotations
  • @immutable

Constructors

TriggerEvent(AppEventTarget event, {Object? data, bool waitForCompletion = false})

Properties

data DslExpression?
final
event AppEventTarget
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
waitForCompletion bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited