UpdateAppStateMutation class final
Global app-state mutation emitted through UpdateAppState.
Constructors
- UpdateAppStateMutation.addToList(String field, Object? value)
- UpdateAppStateMutation.clear(String field)
- UpdateAppStateMutation.increment(String field, num? amount)
- UpdateAppStateMutation.insertAtIndex(String field, Object? index, Object? value)
- UpdateAppStateMutation.removeAtIndex(String field, Object? index)
- UpdateAppStateMutation.removeFromList(String field, Object? value)
- UpdateAppStateMutation.set(String field, Object? value)
- UpdateAppStateMutation.toggle(String field)
- UpdateAppStateMutation.updateItemAtIndex(String field, Object? index, Object? value)
Properties
- amount → num?
-
final
- field → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → DslExpression?
-
final
- kind → UpdateAppStateMutationKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → DslExpression?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited