VerticalDivider class final
Vertical divider widget.
Constructors
- VerticalDivider({double thickness = 1, ColorToken? color, double? indent, double? endIndent, String? name, Object? visible})
Properties
- color → ColorToken?
-
final
- endIndent → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indent → double?
-
final
- name → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thickness → double
-
final
- visible → DslExpression?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited