VideoPlayer class final
Embedded video player.
Constructors
- VideoPlayer(Object? path, {VideoSource source = VideoSource.network, bool autoPlay = false, bool looping = false, bool showControls = true, double? width, double? height, String? name, Object? visible})
Properties
- autoPlay → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- looping → bool
-
final
- name → String?
-
finalinherited
- path → DslExpression
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showControls → bool
-
final
- source → VideoSource
-
final
- visible → DslExpression?
-
finalinherited
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited