WidgetClassSnapshot class abstract
Shared read-model surface for a page or component.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- kind → String
-
final
- name → String
-
final
-
params
→ List<
FieldSnapshot> -
final
- root → WidgetRef
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stateFields
→ List<
FieldSnapshot> -
final
-
widgets
→ List<
WidgetRef> -
no setter
Methods
-
findByKey(
String key) → WidgetSelection -
findByName(
String name) → WidgetSelection -
findByPath(
String path) → WidgetSelection -
findByText(
String text) → WidgetSelection -
findByType(
String type) → WidgetSelection -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited