WidgetSelection class final

Deterministic selector result for brownfield widget lookups.

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
length int
no setter
matches List<WidgetRef>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
final
selector String
final

Methods

expectNone() → void
expectOne() WidgetRef
explainAmbiguity() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() List<Map<String, dynamic>>
toNodeKey() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited