WidgetValue class final
Current runtime value of the form widget that triggered the callback.
This is intended for widgets like Dropdown, Checkbox, and Toggle inside
their onChanged handlers.
- Inheritance
-
- Object
- DslExpression
- WidgetValue
- Annotations
-
- @immutable
Constructors
- WidgetValue()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String field) → FieldAccess -
inherited