ActionBlockDependencies class

Tracks dependencies of an action block (FFActionComponent) on other custom code entities.

Action blocks can call:

  • Custom functions (via FFFunctionCall.customFunction)
  • Custom actions (via FFAction.customAction)
  • Other action blocks (via FFAction.executeActionComponent)

Usage

final deps = ActionBlockDependencies.analyze(actionBlock);
deps.applyToGraph(graph, nodeId);

Constructors

ActionBlockDependencies.analyze(FFActionComponent actionBlock)
Analyze an action block to extract its dependencies.
factory
ActionBlockDependencies.testInstance()
Creates a test instance with all fields at defaults.
factory

Properties

actionBlockKeys Set<String>
Keys of other action blocks called by this action block.
final
appEventKeys Set<String>
Keys of app events referenced by this action block.
final
customActionKeys Set<String>
Keys of custom actions called by this action block.
final
customFunctionKeys Set<String>
Keys of custom functions called by this action block.
final
hasDependencies bool
Whether this action block has any dependencies.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usesActionBlocks bool
Whether this action block calls any other action blocks.
no setter
usesAppEvents bool
Whether this action block references any app events.
no setter
usesCustomActions bool
Whether this action block calls any custom actions.
no setter
usesCustomFunctions bool
Whether this action block calls any custom functions.
no setter

Methods

applyToGraph(ProjectGraph graph, String nodeId) → void
Apply these dependencies to the graph for the given action block node.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited