usesActionBlocks property
bool
get
usesActionBlocks
Whether this action block calls any other action blocks.
Implementation
bool get usesActionBlocks => actionBlockKeys.isNotEmpty;
Whether this action block calls any other action blocks.
bool get usesActionBlocks => actionBlockKeys.isNotEmpty;