usesAppState property
bool
get
usesAppState
Whether this widget class uses any app state variables.
Implementation
bool get usesAppState => appStateVariableKeys.isNotEmpty;
Whether this widget class uses any app state variables.
bool get usesAppState => appStateVariableKeys.isNotEmpty;