GraphBuilder class abstract final

Builds a ProjectGraph from an FFProject.

This class encapsulates the logic for creating a complete dependency graph from a project proto. The resulting graph can be used for:

  • Incremental code generation
  • Error detection
  • AI context building
  • Impact analysis

Usage

final graph = GraphBuilder.build(project);

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

build(FFProject project) ProjectGraph
Build a complete dependency graph from a project.