dependentCount property
int
get
dependentCount
The number of nodes that depend on this node (in-degree).
Implementation
int get dependentCount => importedBy.length;
The number of nodes that depend on this node (in-degree).
int get dependentCount => importedBy.length;