widgetClassKey property
For page/component nodes, the widget class key. Null for global file nodes and state variable nodes.
Implementation
final String? widgetClassKey;
For page/component nodes, the widget class key. Null for global file nodes and state variable nodes.
final String? widgetClassKey;