computeStructureHash method
Compute a structure hash that changes when widget classes are added/deleted/renamed.
Useful for detecting structural changes that require full rebuild.
Implementation
int computeStructureHash() {
final widgetClassIds = widgetClassNodeIds.toList()..sort();
var hash = 0;
for (final id in widgetClassIds) {
hash = hash ^ id.hashCode;
final node = _nodes[id];
if (node?.widgetClassKey != null) {
hash = hash ^ node!.widgetClassKey.hashCode;
}
}
return hash;
}