GraphUpdater class

Incrementally updates a ProjectGraph based on project changes.

Instead of rebuilding the entire graph when the project changes, this class applies targeted updates to keep the graph in sync.

Usage

final updater = GraphUpdater(graph);

// When project changes
updater.onWidgetClassAdded(widgetClass, project);
updater.onWidgetClassRemoved(widgetClassKey);
updater.onWidgetClassModified(widgetClass, project);

Constructors

GraphUpdater(ProjectGraph graph)

Properties

graph ProjectGraph
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onActionBlockAdded(FFActionComponent actionBlock) → void
Update the graph when an action block is added.
onActionBlockModified(FFActionComponent actionBlock) → void
Update the graph when an action block is modified.
onActionBlockRemoved(String actionBlockKey) → void
Update the graph when an action block is removed.
onAppEventAdded(FFAppEvent appEvent) → void
Update the graph when an app event is added.
onAppEventModified(FFAppEvent appEvent) → void
Update the graph when an app event is modified.
onAppEventRemoved(String appEventKey) → void
Update the graph when an app event is removed.
onAppStateVariableAdded(String varKey) → void
Update the graph when an app state variable is added.
onAppStateVariableRemoved(String varKey) → void
Update the graph when an app state variable is removed.
onWidgetClassAdded(FFWidgetClass widgetClass, FFProject project) → void
Update the graph when a widget class is added.
onWidgetClassesAdded(Iterable<FFWidgetClass> widgetClasses, FFProject project) → void
Apply multiple widget class additions at once.
onWidgetClassesRemoved(Iterable<String> widgetClassKeys) → void
Apply multiple widget class removals at once.
onWidgetClassModified(FFWidgetClass widgetClass, FFProject project) → void
Update the graph when a widget class is modified.
onWidgetClassRemoved(String widgetClassKey) → void
Update the graph when a widget class is removed.
reanalyzeAllDependencies(FFProject project) → void
Full re-analysis of all widget class dependencies.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited