protoName property
String
get
protoName
Name of this field as written in the proto definition.
Example:
message SearchRequest {
...
int32 result_per_page = 3;
}
protoName for the result_per_page field above is "result_per_page".
The name typically consist of words separated with underscores.
Implementation
String get protoName {
return _protoName ??= _unCamelCase(name);
}