GeneratedMessage class abstract
The base class for all protobuf message types.
The protoc plugin generates subclasses providing type-specific properties and methods.
Public properties and methods added here should also be added to
GeneratedMessage_reservedNames and should be unlikely to be used in a
proto file.
- Implementers
- AiGenPageExample
- AIMessage
- AIModel
- AIModelParameters
- AIModelRequestOptions
- AIModelResponseOptions
- AppMetadata
- CodegenRequest
- CodegenRequest_LibraryInfo
- CodegenResponse
- CodemagicCommonWrapper
- CollectionRules
- CopiedData
- DependencyProtoMap
- DescriptorProto
- DescriptorProto_ExtensionRange
- DescriptorProto_ReservedRange
- DocumentReferenceProto
- EnumDescriptorProto
- EnumDescriptorProto_EnumReservedRange
- EnumOptions
- EnumValueDescriptorProto
- EnumValueOptions
- ErrorMetadata
- ExtensionRangeOptions
- ExtensionRangeOptions_Declaration
- Extras
- FeatureSet
- FeatureSet_VisibilityFeature
- FeatureSetDefaults
- FeatureSetDefaults_FeatureSetEditionDefault
- FetchStripeSubscriptionResponse
- FetchStripeSubscriptionResponse_Subscriptions
- FFAccessCustomInterfaceField
- FFAccessCustomInterfaceMethod
- FFAccessDataStructField
- FFAccessDocumentField
- FFAccessGooglePlaceField
- FFAccessibilitySettings
- FFAccessPostgresRowField
- FFAccessSQLiteRowColumn
- FFAction
- FFActionComponent
- FFActionComponentKeyReference
- FFActionComponentParameterVariable
- FFActionComponentsConfig
- FFActionCondition
- FFActionInputVariable
- FFActionKeyReference
- FFActionNode
- FFActionNodeKeyReference
- FFActionOutputVariable
- FFActionReturnValue
- FFActionTrigger
- FFAdBanner
- FFAddLocalAppEventHandlerAction
- FFAdMobAction
- FFAdMobCheckConsentNotRequired
- FFAdMobLoadInterstitialAd
- FFAdMobRequestConsent
- FFAdMobSettings
- FFAdMobShowInterstitialAd
- FFAdvancedAppSettings
- FFAgent
- FFAgentDeploymentSettings
- FFAIAgentAction
- FFAIAgentRequest
- FFAiGeneratedNodeInfo
- FFAiGenSerializedIdxMapData
- FFAlertDialogAction
- FFAlgoliaConfig
- FFAlgoliaLocation
- FFAlgoliaSearch
- FFAlgoliaSearchAction
- FFAlgoliaVariable
- FFAlignment
- FFAllAppNames
- FFAllCodemagicSettings
- FFAllWebSettings
- FFAndroidAdaptiveIcon
- FFAnimatedAlignment
- FFAnimatedOpacity
- FFAnimatedPadding
- FFAnimation
- FFAnimationAction
- FFAnimationAction_FFWidgetAnimationAction
- FFAnimationState
- FFAnnotations
- FFApiCall
- FFApiCallPaginationVariable
- FFApiCallPaginationVariable_LastResponse
- FFApiCallPaginationVariable_NextPageNumber
- FFApiCallPaginationVariable_NumLoadedItems
- FFApiCallValue
- FFApiCallVariable
- FFApiConfig
- FFApiEndpoint
- FFApiEndpointSettings
- FFApiEndpointSettings_Interceptor
- FFApiGroup
- FFApiParameter
- FFApiResponseField
- FFApiValue
- FFAppBar
- FFAppConstantField
- FFAppConstants
- FFAppEvent
- FFAppNames
- FFAppState
- FFAppStateField
- FFAppStorePrivacyManifestSettings
- FFAspectRatio
- FFAudio
- FFAudioPlayer
- FFAuthAction
- FFAuthActionMessages
- FFAuthentication
- FFAuthPageInfo
- FFAuthVariable
- FFAutoPlayOptions
- FFBackend
- FFBadge
- FFBarChart
- FFBarChartBarInfo
- FFBarcode
- FFBarcodeQrcodeScanner
- FFBaseVariable
- FFBiometricVerification
- FFBlur
- FFBlurEffect
- FFBooleanValue
- FFBorder
- FFBorder_Side
- FFBorderRadius
- FFBottomSheetAction
- FFBoxDecoration
- FFBoxShadow
- FFBraintreeAction
- FFBraintreeCredentials
- FFBraintreePaymentConfig
- FFBraintreePaymentOptions
- FFBraintreeSettings
- FFBraintreeSinglePayment
- FFBreakPoints
- FFButton
- FFCalendar
- FFCallNumber
- FFCancelLocalAppEventHandlerAction
- FFCancelStreamingResponseSubscriptionAction
- FFCanvasProps
- FFCanvasSettings
- FFCard
- FFCarousel
- FFCarouselAction
- FFChart
- FFChartAxisInfo
- FFChartAxisInfo_AxisBounds
- FFChartAxisInfo_AxisLabel
- FFChartAxisInfo_AxisLabels
- FFChartData
- FFChartLabelFormatInfo
- FFChartLegendInfo
- FFChartTooltipInfo
- FFChatAction
- FFChatPage
- FFChatPreview
- FFCheckbox
- FFCheckboxGroup
- FFCheckboxListTile
- FFCheckHasField
- FFChildrenKeys
- FFChildSlotDefinition
- FFChildSlotProperties
- FFChildSlotUIProperties
- FFChipData
- FFChipStyle
- FFChoiceChips
- FFClearAIAgentMessages
- FFClearQueryCache
- FFClearSignature
- FFClearSwipeableStackAction
- FFClearTextFieldAction
- FFClearUploadedDataAction
- FFCloudFunctionSettings
- FFCodeExpression
- FFCodeFolder
- FFCodeGenerationSettings
- FFCodemagicAppStoreSettings
- FFCodemagicGooglePlayStoreSettings
- FFCodemagicSettings
- FFCodemagicSettings_BuildVersion
- FFCollection
- FFColor
- FFColorFromString
- FFColorPickerAction
- FFColorScheme
- FFColorValue
- FFColumn
- FFCombineConditions
- FFComponentDisplayWidget
- FFComponentUniqueKey
- FFCondition
- FFConditionActions
- FFConditionActions_FFTrueConditionAction
- FFConditionalBuilder
- FFConditionalExecution
- FFConditionalValue
- FFConditionalValue_ConditionValue
- FFConfirmationDialogResponse
- FFConfirmDialogAction
- FFConstantsVariable
- FFContainer
- FFCopyToClipboard
- FFCountController
- FFCountTokens
- FFCreateCustomInterfaceVariable
- FFCreateCustomInterfaceVariable_InterfaceField
- FFCreateDataStructVariable
- FFCreateDataStructVariable_StructField
- FFCreateJsonMapVariable
- FFCreateJsonMapVariable_MapEntry
- FFCreditCardForm
- FFCustomAction
- FFCustomAction_CompileInfo
- FFCustomActionCall
- FFCustomActionCall_ActionParamIdentifier
- FFCustomAuth
- FFCustomAuthFields
- FFCustomCloudFunction
- FFCustomCloudFunctionCall
- FFCustomCloudFunctionPackage
- FFCustomCloudFunctionResponseField
- FFCustomCloudFunctionsConfig
- FFCustomCloudFunctionSettings
- FFCustomCode
- FFCustomCodeCallAction
- FFCustomCodeEntity
- FFCustomCodeExpressionVariable
- FFCustomCodeFile
- FFCustomCodeFiles
- FFCustomCodeLibraries
- FFCustomCodeLibrary
- FFCustomDialogAction
- FFCustomFile
- FFCustomFile_Action
- FFCustomFile_Hook
- FFCustomFile_Parameter
- FFCustomFiles
- FFCustomFiles_Main
- FFCustomFont
- FFCustomFont_FontFileData
- FFCustomFunction
- FFCustomFunctionTest
- FFCustomIconFamily
- FFCustomIconFamily_IconInfo
- FFCustomInterface
- FFCustomInterfaceConstructor
- FFCustomInterfaceField
- FFCustomInterfaceMethodCall
- FFCustomInterfaceStaticVariable
- FFCustomWhenTestStep
- FFCustomWidget
- FFCustomWidget_RenderInfo
- FFDatabaseAction
- FFDatabaseRequest
- FFDatabaseRequestManager
- FFDatabaseRequestManagerSettings
- FFDatabaseWrite
- FFDataSchemaConfig
- FFDataStruct
- FFDataStructFieldUpdate
- FFDataStructFieldUpdate_FieldUpdates
- FFDataStructToJson
- FFDataTable
- FFDataTableAction
- FFDataTableAction_ControlPage
- FFDataTableAction_UpdateRowsPerPage
- FFDataTableAction_UpdateSort
- FFDataTableHeader
- FFDataTypeV2
- FFDatePicker
- FFDatePickerSettings
- FFDatePickerValidation
- FFDateTime
- FFDateTimeFormat
- FFDateTimeFromTimestamp
- FFDateTimeRangeEnd
- FFDateTimeRangeStart
- FFDateTimeToInteger
- FFDateTimeValue
- FFDefaultAppBar
- FFDeleteData
- FFDependency
- FFDesignTokenVariable
- FFDim
- FFDimensions
- FFDisable
- FFDisableAction
- FFDismissDialogAction
- FFDivider
- FFDocumentProperty
- FFDocumentReferenceId
- FFDocumentReferencePath
- FFDoubleValue
- FFDownloadCodeSettings
- FFDownloadFileAction
- FFDraggable
- FFDragTarget
- FFDrawer
- FFDrawerAction
- FFDropDown
- FFDropDownTesting
- FFDropDownValidation
- FFDropInOptions
- FFDynamicComponentAccess
- FFEasterEgg
- FFEditMetadata
- FFEditMetadata_RecentlyDeleted
- FFEffect
- FFEmptyListWidget
- FFEnumDefinition
- FFEnumElement
- FFEnumVariable
- FFEnvironmentSettings
- FFEnvironmentValue
- FFEnvironmentValueVariable
- FFExecuteActionComponent
- FFExecuteCallbackAction
- FFExpandable
- FFExpanded
- FFExpandImageAction
- FFFacebookSignInConfig
- FFFadeEffect
- FFFieldUpdate
- FFFirebaseAnalyticsAction
- FFFirebaseAnalyticsAction_EventParameter
- FFFirebaseAnalyticsConfig
- FFFirebaseAnalyticsConfig_AutomaticEventSettings
- FFFirebaseAppCheckConfig
- FFFirebaseAuth
- FFFirebaseAuthProvider
- FFFirebaseConfigFileInfo
- FFFirebaseCrashlyticsConfig
- FFFirebasePerformanceMonitoringConfig
- FFFirebaseRemoteConfigConfig
- FFFirebaseRemoteConfigField
- FFFirebaseRemoteConfigVariable
- FFFirebaseStorage
- FFFirestore
- FFFirestore_StorageRules
- FFFirestoreAggregation
- FFFirestoreChartData
- FFFirestoreCreate
- FFFirestoreDelete
- FFFirestoreDocument
- FFFirestoreFilter
- FFFirestoreOrderBy
- FFFirestorePagination
- FFFirestoreQuery
- FFFirestoreSchemaValidation
- FFFirestoreUpdate
- FFFirestoreVariable
- FFFirestoreWhere
- FFFirestoreWhere_NestedFilter
- FFFlex
- FFFlipEffect
- FFFlippableCard
- FFFloatingActionButton
- FFFloatingNavBarItem
- FFFloatingNavBarSettings
- FFFocusBorder
- FFFocusConfiguration
- FFFontWeightValue
- FFForm
- FFFormFieldOnValidationError
- FFFormFieldValidation
- FFFormOptionsValue
- FFFunctionCall
- FFFunctionCallValues
- FFFunctionCallValues_FFArgument
- FFGeminiAction
- FFGeminiSettings
- FFGenerateCurrentPageLink
- FFGenerateText
- FFGenerateTextFromImage
- FFGeneratorVariable
- FFGeneratorVariableVariable
- FFGenUIAppEventListenerConfig
- FFGenUIBackendConfig
- FFGenUIChatAvatarConfig
- FFGenUIChatBubbleStyling
- FFGenUIChatHeaderConfig
- FFGenUIChatInputAreaStyling
- FFGenUIChatScrollConfig
- FFGenUIChatSendButtonStyling
- FFGenUIChatStyling
- FFGenUIChatWelcomeConfig
- FFGenUIChatWidgetProperties
- FFGenUIFunctionConfig
- FFGivenTestStep
- FFGivenTestStep_EntryPage
- FFGivenTestStep_LoggedIn
- FFGlobalPropertiesVariable
- FFGoogleMap
- FFGoogleMapAction
- FFGoogleMapsApiKeys
- FFGoogleNavBarItem
- FFGoogleNavBarSettings
- FFGradient
- FFGradient_Color
- FFGridView
- FFHapticFeedbackAction
- FFHero
- FFHideSnackBarAction
- FFHtmlView
- FFIcon
- FFIconButton
- FFIconData
- FFIconDataValue
- FFIconValue
- FFIdentifier
- FFImage
- FFImport
- FFIndexInList
- FFInformationalDialogAction
- FFInputDecoration
- FFIntegerValue
- FFInteractionTestStep
- FFInteractionTestStep_DoubleTapStep
- FFInteractionTestStep_EnterTextStep
- FFInteractionTestStep_LongPressStep
- FFInteractionTestStep_ScrollUntilVisibleStep
- FFInteractionTestStep_TapStep
- FFInternationalizationSettings
- FFInternationalizationVariable
- FFItemAtCurrentIndex
- FFJsonPathDefinition
- FFJsonPathOperation
- FFJsonToDataStruct
- FFLanguage
- FFLanguageDependentText
- FFLanguageSelector
- FFLatLng
- FFLatLngValue
- FFLaunchUrlAction
- FFLibraryConfig
- FFLibraryPageRoutePath
- FFLibrarySettings
- FFLibraryValue
- FFLibraryValueVariable
- FFLineChart
- FFLineChart_LegacyAxisBounds
- FFLineChart_LegacyAxisLabel
- FFLineChart_LegacyAxisLabels
- FFLineChart_LegacyTooltipInfo
- FFLineChartLine
- FFListContains
- FFListHasValueOperation
- FFListItemAtIndex
- FFListMapOperation
- FFListMapVariable
- FFListNumItems
- FFListSortOperation
- FFListSpacing
- FFListTakeOperation
- FFListTile
- FFListUniqueOperation
- FFListView
- FFListWhereOperation
- FFLoadingIndicator
- FFLoadingWidget
- FFLoadingWidget_DefaultLoadingIndicator
- FFLocalStateClearValue
- FFLocalStateDataStructUpdate
- FFLocalStateFieldUpdate
- FFLocalStateInsertListItem
- FFLocalStateToggle
- FFLocalStateUpdate
- FFLocalStateUpdateListItem
- FFLocalStateVariable
- FFLockedLanguageSection
- FFLoopAction
- FFLoopBreakAction
- FFLoopOverList
- FFLoopOverListKeyReference
- FFLoopOverListVariable
- FFLottieAnimation
- FFLottieAnimationAction
- FFMapDocumentMarker
- FFMapDocumentMarkers
- FFMapLatLngMarker
- FFMapLatLngMarkers
- FFMapLauncherAction
- FFMarkdown
- FFMaterialThemeSettings
- FFMediaDisplay
- FFMouseRegion
- FFMoveMapCenter
- FFMultiselectWidgetAction
- FFMuxBroadcast
- FFMuxBroadcastApiAccessTokens
- FFNavBar
- FFNavBarItem
- FFNavigateAction
- FFNavigateTransition
- FFNegateBoolean
- FFNode
- FFNodeFeaturePresence
- FFNodeKeyPath
- FFNodeKeyReference
- FFNodeOutline
- FFNumberFormat
- FFNumbersList
- FFOAuthSupabaseSettings
- FFOffset
- FFOneSignalAction
- FFOneSignalAddUser
- FFOneSignalDeleteUser
- FFOneSignalSettings
- FFOneSignalUserTag
- FFOpacity
- FFOverrideSource
- FFPadding
- FFPageGroup
- FFPageRouteSettings
- FFPageView
- FFPageViewAction
- FFPageViewIndicatorOptions
- FFPaginatedDataTable
- FFParallelActions
- FFParameter
- FFParameter_NamedParameter
- FFParameter_PositionalParameter
- FFParameterPass
- FFParameterValue
- FFParamReducer
- FFParseStringAsEnum
- FFPassedParameters
- FFPaymentMessages
- FFPaymentSettings
- FFPdfViewer
- FFPermissionsSettings
- FFPermissionsSettings_PermissionMessage
- FFPermissionsSettings_UserDefinedPermission
- FFPermissionsSettings_UserDefinedPermission_PermissionNames
- FFPermissionStateVariable
- FFPieChart
- FFPieChart_FFPieChartSection
- FFPinCode
- FFPinCodeValidation
- FFPlaceholderWidget
- FFPlacePicker
- FFPlacePickerValidation
- FFPlatformSettings
- FFPlaySound
- FFPostgresAction
- FFPostgresConfig
- FFPostgresDatabase
- FFPostgresDelete
- FFPostgresField
- FFPostgresFieldUpdate
- FFPostgresFilter
- FFPostgresInsert
- FFPostgresOrderBy
- FFPostgresProjectConfig
- FFPostgresQuery
- FFPostgresQueryVariable
- FFPostgresRead
- FFPostgresSetToken
- FFPostgresTable
- FFPostgresUpdate
- FFPostgresUpdateData
- FFPredefinedJsonPathOperation
- FFPresetTexts
- FFProgressBar
- FFProject
- FFProjectError
- FFProjectError_ActionInfo
- FFProjectTest
- FFProjectTests
- FFProjectWalkthrough
- FFProjectWalkthroughs
- FFProjectWalkthroughStep
- FFProjectWalkthroughTarget
- FFProjectWarningConfig
- FFPropertyOverride
- FFPropertyParameterPass
- FFPubspecPackageInfo
- FFPullToRefreshStyle
- FFPumpAndSettleTestStep
- FFPushNotificationData
- FFPushNotificationSettings
- FFQueryLoadingWidget
- FFRadioButton
- FFRadioButtonValidation
- FFRadiusToken
- FFRandomColor
- FFRandomData
- FFRandomDate
- FFRandomDouble
- FFRandomImage
- FFRandomInteger
- FFRandomName
- FFRandomString
- FFRatingBar
- FFRazorpayAction
- FFRazorpayCredentials
- FFRazorpayPaymentSheetOptions
- FFRazorpaySettings
- FFRazorpaySinglePayment
- FFRebuildAction
- FFRefreshDatabaseRequest
- FFRefreshIndicatorWidget
- FFRequestPermissionsAction
- FFResetFormFieldAction
- FFResponseStreamMessageField
- FFResponsiveTypography
- FFResponsiveVisibility
- FFRevenueCatAction
- FFRevenueCatEntitlementResponse
- FFRevenueCatGetOfferingAttributeReducer
- FFRevenueCatGetPackageAttributeReducer
- FFRevenueCatGetPackageByIdReducer
- FFRevenueCatOperation
- FFRevenueCatPaywall
- FFRevenueCatPurchase
- FFRevenueCatRestore
- FFRevenueCatSettings
- FFRevenueCatVariable
- FFRichText
- FFRichTextSpan
- FFRiveAnimation
- FFRiveAnimationAction
- FFRotateEffect
- FFRoutingSettings
- FFRow
- FFSaturateEffect
- FFScaffold
- FFScaleEffect
- FFScreenshotInfo
- FFScreenshotNodeIdentifier
- FFScreenshotValues
- FFScreenshotValues_ScreenshotValue
- FFScrollbarTheme
- FFScrollToPercentage
- FFSearchReference
- FFSemanticProperties
- FFSemanticsAnnounceAction
- FFSendEmail
- FFSendSMS
- FFSerializedValues
- FFSetAppLanguageAction
- FFSetDarkModeSetting
- FFSetFormFieldAction
- FFSetFormFieldAction_FormFieldInfo
- FFSetStateAction
- FFSettings
- FFShaderAnimationAction
- FFShaderFill
- FFShaderParam
- FFShaderProperties
- FFShaderWrapper
- FFShadowToken
- FFShakeEffect
- FFShareAction
- FFSharing
- FFShimmerEffect
- FFShortcutInfo
- FFSignature
- FFSimpleSearchAction
- FFSimpleSearchAction_Collection
- FFSimpleSearchAction_Documents
- FFSimpleSearchAction_Strings
- FFSimpleSearchVariable
- FFSlidableActionWidget
- FFSlideEffect
- FFSlider
- FFSnackBarAction
- FFSnackBarAction_FFSnackBarSubAction
- FFSpacer
- FFSpacingToken
- FFSplashImage
- FFSQLiteColumn
- FFSQLiteConfig
- FFSQLiteDatabaseInfo
- FFSQLiteInitializationConfig
- FFSQLiteInputVariable
- FFSQLiteQueryCall
- FFSQLiteQueryCall_QueryVariable
- FFSQLiteQueryConfig
- FFSQLiteVariable
- FFStack
- FFStaggeredView
- FFStartAudioRecordAction
- FFStartPeriodic
- FFStaticMap
- FFStickyHeader
- FFStopAudioRecordAction
- FFStopPeriodic
- FFStopSound
- FFStoryboard
- FFStoryboard_Position
- FFStreamedResponseProcessorValue
- FFStringInterpolation
- FFStringValue
- FFStripeAction
- FFStripeCredentials
- FFStripePaymentSheetOptions
- FFStripeSettings
- FFStripeSinglePayment
- FFSubType
- FFSupabaseAppleAuthConfig
- FFSupabaseAuth
- FFSupabaseConfig
- FFSupabaseDatabase
- FFSupabaseEdgeFunction
- FFSupabaseEdgeFunctionCall
- FFSupabaseEdgeFunctionsConfig
- FFSupabaseGoogleAuthConfig
- FFSupabaseProjectConfig
- FFSupabaseUploadDataConfig
- FFSwipeableStack
- FFSwipeableStackAction
- FFSwitch
- FFSwitchListTile
- FFTab
- FFTabBar
- FFTabBarAction
- FFTeamResourceInfo
- FFTemplateNode
- FFTemplateNodes
- FFTerminateAction
- FFTestFinder
- FFTestFinder_ByDescendent
- FFTestFinder_ByIcon
- FFTestFinder_ByNodeKey
- FFTestFinder_BySemanticsLabel
- FFTestFinder_ByText
- FFTestFinder_ByTooltip
- FFTestFinder_ByType
- FFTestFinder_ByValueKey
- FFTestFinder_CustomFinder
- FFTestGroup
- FFTestStep
- FFText
- FFTextAlignValue
- FFTextEditor
- FFTextField
- FFTextFieldFilter
- FFTextFieldMask
- FFTextGradient
- FFTextInputValidation
- FFTextOptionsValue
- FFTextScaleSettings
- FFTextShadow
- FFTextStyle
- FFTextStyleAnimation
- FFTextStyleValue
- FFTextTranslation
- FFTheme
- FFThemeWidget
- FFThemeWidgetInfo
- FFThenTestStep
- FFThenTestStep_CustomThenStep
- FFThenTestStep_FindsNothing
- FFThenTestStep_FindsNumWidgets
- FFThenTestStep_FindsOneWidget
- FFThenTestStep_FindsWidgets
- FFThenTestStep_HasState
- FFThenTestStep_IsDisabled
- FFThenTestStep_IsEnabled
- FFThenTestStep_MatchesGoldenFile
- FFTiltEffect
- FFTimer
- FFTimerAction
- FFTimestampRange
- FFTintEffect
- FFToggleExpandableWidgetAction
- FFToggleIcon
- FFTooltip
- FFTransform
- FFTranslation
- FFTriggerActions
- FFTriggerAppEventAction
- FFTriggerPushNotification
- FFTypeCastOperation
- FFTypography
- FFTypographyStyle
- FFUpdateAppBadgeCountAction
- FFUpdateFieldValue
- FFUpdateTextScalingFactorAction
- FFUploadDataAction
- FFUploadDataMessages
- FFUploadDataSettings
- FFUploadDataSettings_AllowedTypes
- FFUploadDataSettings_Resolution
- FFUploadDataSettings_SourcePickerStyle
- FFUploadDataValidation
- FFUploadedOriginalFileName
- FFUploadMediaBlurHash
- FFUploadMediaHeight
- FFUploadMediaWidth
- FFUploadSignature
- FFValidateFormAction
- FFValue
- FFVariable
- FFVariableOperation
- FFVector2D
- FFVerticalDivider
- FFVideoPlayer
- FFVisibility
- FFWaitAction
- FFWalkthroughAction
- FFWalkthroughStart
- FFWebBuildSettings
- FFWebSettings
- FFWebView
- FFWhenTestStep
- FFWidgetBuilderParameterVariable
- FFWidgetBuilderSource
- FFWidgetBuilderUIProperties
- FFWidgetBuilderVariable
- FFWidgetClass
- FFWidgetClassModel
- FFWidgetClassOutline
- FFWidgetClassStateField
- FFWidgetClassVariable
- FFWidgetFocusStateVariable
- FFWidgetProperties
- FFWidgetStateVariable
- FFWrap
- FFYoutubePlayer
- FieldDescriptorProto
- FieldOptions
- FieldOptions_EditionDefault
- FieldOptions_FeatureSupport
- FileDescriptorProto
- FileDescriptorSet
- FileOptions
- FirebaseStorage
- FirebaseStorageRules
- FirestoreSecurityRules
- GeneratedCodeInfo
- GeneratedCodeInfo_Annotation
- ImageSize
- LastSessionUpdate
- LatLng
- ListValue
- MarketplaceItemComment
- MarketplaceItemComment_UserInfo
- MessageOptions
- MethodDescriptorProto
- MethodOptions
- MicrosoftAuthSettings
- OneofDescriptorProto
- OneofOptions
- PackageIcon
- PartitionProjectFilesRequest
- PartitionProjectFilesResponse
- ProjectLocation
- ProjectTestSettings
- RefreshIndicatorStyle
- RuleCondition
- RuleCondition_AuthenticatedUsers
- RuleCondition_Chat
- RuleCondition_Everyone
- RuleCondition_NoOne
- RuleCondition_TaggedUsers
- RuleCondition_UsersCollection
- RuleCondition_UsersPushNotifications
- ServiceDescriptorProto
- ServiceOptions
- SourceCodeInfo
- SourceCodeInfo_Location
- SslPinningConfig
- StripeCheckoutSessionInfo
- StripeCheckoutSessionInfo_LineItem
- StripeResponseAddOnInfo
- StripeResponseAddOnInfoMap
- StripeResponseSubscriptionPlan
- Struct
- TestProtoDontUse
- TestProtoDontUse_NestedMessage1
- UninterpretedOption
- UninterpretedOption_NamePart
- UserBranchPermissions
- Value
- Available extensions
Constructors
Properties
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setteroverride
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unknownFields → UnknownFieldSet
-
no setter
Methods
-
addExtension(
Extension extension, Object? value) → void - Adds an extension field value to a repeated field.
-
check(
) → void - Throws a StateError if the message has required fields without a value.
-
clear(
) → void - Clears all data that was set in this message.
-
clearExtension(
Extension extension) → void - Clears an extension field and also removes the extension.
-
clearField(
int tagNumber) → void - Clears the contents of a given field.
-
clone(
) → GeneratedMessage - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(GeneratedMessage)) → GeneratedMessage -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → GeneratedMessage - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
extensionsAreInitialized(
) → bool -
freeze(
) → GeneratedMessage - Make this message read-only.
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic - Returns the default value for the given field.
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension. -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set. -
getFieldOrNull(
int tagNumber) → dynamic - Returns the value of a field, ignoring any defaults.
-
getTagNumber(
String fieldName) → int? -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present. -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber. -
hasRequiredFields(
) → bool - Whether the message has required fields.
-
isInitialized(
) → bool - Whether all required fields in the message and embedded messages are set.
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void - Merges serialized protocol buffer data into this message.
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void - Same as mergeFromBuffer, but takes a CodedBufferReader input.
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson. -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void - Merges field values from a JSON object represented as a Dart map.
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message. -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding. -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value. -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber. -
toBuilder(
) → GeneratedMessage - Creates a writable, shallow copy of this message.
-
toDebugString(
) → String - Returns a String representation of this message.
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this. -
toString(
) → String -
Returns a String representation of this message.
override
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List - Serialize the message as the protobuf binary format.
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void - Same as writeToBuffer, but serializes to the given CodedBufferWriter.
-
writeToJson(
) → String - Returns a JSON string that encodes this message.
-
writeToJsonMap(
) → Map< String, dynamic> - Returns the JSON encoding of this message as a Dart Map.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override