PbList<E> class

A ListBase implementation used for protobuf repeated fields.

Inheritance
Available extensions

Properties

first ↔ E
The first element.
getter/setter pairinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element, or null if the iterable is empty.
no setter
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
hashCode int
The hash code for this object.
no setteroverride
indexed Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty bool
Whether this collection has no elements.
no setteroverride
isFrozen bool
no setter
isNotEmpty bool
Whether this collection has at least one element.
no setteroverride
iterator Iterator<E>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last ↔ E
The last element.
getter/setter pairinherited
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element, or null if the iterable is empty.
no setter
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length int
The number of objects in this list.
getter/setter pairoverride
nonNulls Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
reversed Iterable<E>
An Iterable of the objects in this list in reverse order.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single → E
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element of the iterable, or null.
no setter
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
toJS JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or cloning the List.
no setter
toJSIterable JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
toJSProxyOrRef JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or proxying the List.
no setter
wait Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(E element) → void
Adds value to the end of this list, extending the length by one.
override
addAll(Iterable<E> iterable) → void
Appends all objects of iterable to the end of this list.
override
any(bool test(E element)) bool
Checks whether any element of this iterable satisfies test.
inherited
asMap() Map<int, E>
An unmodifiable Map view of this list.
inherited
asNameMap() Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
cast<R>() List<R>
Returns a view of this list as a list of R instances.
inherited
clear() → void
Removes all objects from this list; the length of the list becomes zero.
override
contains(Object? element) bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → E
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The indexth element, or null if there is no such element.
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
every(bool test(E element)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> f(E element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
expandIndexed<R>(Iterable<R> expand(int index, T element)) Iterable<R>

Available on Iterable<T>, provided by the IterableExtension extension

Expands each element and index to a number of elements in a new iterable.
fillRange(int start, int end, [E? fill]) → void
Overwrites a range of elements with fillValue.
override
firstWhere(bool test(E element), {E orElse()?}) → E
The first element that satisfies the given predicate test.
inherited
firstWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element whose value and index satisfies test.
firstWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element satisfying test, or null if there are none.
fold<T>(T initialValue, T combine(T previousValue, E element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
foldIndexed<R>(R initialValue, R combine(int index, R previous, T element)) → R

Available on Iterable<T>, provided by the IterableExtension extension

Combine the elements with a value and the current index.
followedBy(Iterable<E> other) Iterable<E>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(E element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
forEachIndexed(void action(int index, T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element.
forEachIndexedWhile(bool action(int index, T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element and index as long as desired.
forEachWhile(bool action(T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element as long as desired.
freeze() → void
getRange(int start, int end) Iterable<E>
Creates an Iterable that iterates over a range of elements.
inherited
groupFoldBy<K, G>(K keyOf(T element), G combine(G? previous, T element)) Map<K, G>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements by keyOf then folds the elements in each group.
groupListsBy<K>(K keyOf(T element)) Map<K, List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements into lists by keyOf.
groupSetsBy<K>(K keyOf(T element)) Map<K, Set<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements into sets by keyOf.
indexOf(Object? element, [int start = 0]) int
The first index of element in this list.
inherited
indexWhere(bool test(E element), [int start = 0]) int
The first index in the list that satisfies the provided test.
inherited
insert(int index, E element) → void
Inserts element at position index in this list.
override
insertAll(int index, Iterable<E> iterable) → void
Inserts all objects of iterable at position index in this list.
override
isSorted(Comparator<T> compare) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are sorted by the compare ordering.
isSortedBy<K extends Comparable<K>>(K keyOf(T element)) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are sorted by their keyOf property.
isSortedByCompare<K>(K keyOf(T element), Comparator<K> compare) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are compare-sorted by their keyOf property.
join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastBy<K>(K key(T)) Map<K, T>

Available on Iterable<T>, provided by the IterableExtension extension

Associates the elements in this by the value returned by key.
lastIndexOf(Object? element, [int? start]) int
The last index of element in this list.
inherited
lastIndexWhere(bool test(E element), [int? start]) int
The last index in the list that satisfies the provided test.
inherited
lastWhere(bool test(E element), {E orElse()?}) → E
The last element that satisfies the given predicate test.
inherited
lastWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element whose index and value satisfies test.
lastWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element satisfying test, or null if there are none.
map<T>(T f(E element)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
mapIndexed<R>(R convert(int index, T element)) Iterable<R>

Available on Iterable<T>, provided by the IterableExtension extension

Maps each element and its index to a new value.
none(bool test(T element)) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether no element satisfies test.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(E combine(E previousValue, E element)) → E
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
reduceIndexed(T combine(int index, T previous, T element)) → T

Available on Iterable<T>, provided by the IterableExtension extension

Combine the elements with each other and the current index.
remove(Object? element) bool
Removes the first occurrence of value from this list.
override
removeAt(int index) → E
Removes the object at position index from this list.
override
removeLast() → E
Removes and returns the last object in this list.
override
removeRange(int start, int end) → void
Removes a range of elements from the list.
override
removeWhere(bool test(E element)) → void
Removes all objects from this list that satisfy test.
override
replaceRange(int start, int end, Iterable<E> newContents) → void
Replaces a range of elements with the elements of replacements.
override
retainWhere(bool test(E element)) → void
Removes all objects from this list that fail to satisfy test.
override
sample(int count, [Random? random]) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Selects count elements at random from this iterable.
setAll(int index, Iterable<E> iterable) → void
Overwrites elements with the objects of iterable.
override
setRange(int start, int end, Iterable<E> iterable, [int skipCount = 0]) → void
Writes some elements of iterable into a range of this list.
override
shuffle([Random? random]) → void
Shuffles the elements of this list randomly.
override
shuffled([Random? random]) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a shuffled list of the elements of the iterable.
singleWhere(bool test(E element), {E orElse()?}) → E
The single element that satisfies test.
inherited
singleWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element satisfying test.
singleWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element satisfying test.
skip(int count) Iterable<E>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(E element)) Iterable<E>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
slices(int length) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Contiguous slices of this with the given length.
sort([int compare(E a, E b)?]) → void
Sorts this list according to the order specified by the compare function.
override
sorted(Comparator<T> compare) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
sortedBy<K extends Comparable<K>>(K keyOf(T element)) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
sortedByCompare<K>(K keyOf(T element), Comparator<K> compare) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
splitAfter(bool test(T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks after some elements.
splitAfterIndexed(bool test(int index, T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks after some elements and indices.
splitBefore(bool test(T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks before some elements.
splitBeforeIndexed(bool test(int index, T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks before some elements and indices.
splitBetween(bool test(T first, T second)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks between some elements.
splitBetweenIndexed(bool test(int index, T first, T second)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks between some elements and indices.
sublist(int start, [int? end]) List<E>
Returns a new list containing the elements between start and end.
inherited
take(int count) Iterable<E>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(E element)) Iterable<E>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) List<E>
Creates a List containing the elements of this Iterable.
inherited
toSet() Set<E>
Creates a Set containing the same elements as this iterable.
inherited
toString() String
A string representation of this object.
inherited
where(bool test(E element)) Iterable<E>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereIndexed(bool test(int index, T element)) Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements whose value and index satisfies test.
whereNot(bool test(T element)) Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements that do not satisfy test.
whereNotIndexed(bool test(int index, T element)) Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements whose value and index do not satisfy test.
whereType<T>() Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator +(List<E> other) List<E>
Returns the concatenation of this list and other.
inherited
operator ==(Object other) bool
The equality operator.
override
operator [](int index) → E
The object at the given index in the list.
override
operator []=(int index, E value) → void
Sets the value at the given index in the list to value.
override