ProtobufEnum class
A base class for all proto enum types.
All proto enum classes inherit from ProtobufEnum. For example, given
the following enum defined in a proto file:
message MyMessage {
enum Color {
RED = 0;
GREEN = 1;
BLUE = 2;
};
// ...
}
the generated Dart file will include a MyMessage_Color class that extends
ProtobufEnum. It will also include a const MyMessage_Color for each of
the three values defined. Here are some examples:
MyMessage_Color.RED // => a MyMessage_Color instance
MyMessage_Color.GREEN.value // => 1
MyMessage_Color.GREEN.name // => "GREEN"
- Implementers
- AiGenPageExample_Category
- AIMessage_Role
- AiModelProvider
- AIModelRequestOptions_RequestType
- AIModelResponseOptions_ResponseType
- AssetType
- BranchAccessLevel
- CodemagicCommonWrapper_BuildType
- CopiedData_CopiedType
- DiffedEditType
- Edition
- ExtensionRangeOptions_VerificationState
- FeatureSet_EnforceNamingStyle
- FeatureSet_EnumType
- FeatureSet_FieldPresence
- FeatureSet_JsonFormat
- FeatureSet_MessageEncoding
- FeatureSet_RepeatedFieldEncoding
- FeatureSet_Utf8Validation
- FeatureSet_VisibilityFeature_DefaultSymbolVisibility
- FFAccessDocumentField_DocumentProperty
- FFAccessGooglePlaceField_GooglePlaceField
- FFAction_LegacyTrigger
- FFActionInputVariable_ActionInput
- FFActionTriggerType
- FFAdMobSettings_MaxAdContentRating
- FFAgent_FFAgentStatus
- FFAlgoliaLocation_LocationSource
- FFAnimation_Trigger
- FFAnimationAction_FFAnimationActionType
- FFAnimationAction_FFWidgetAnimationAction_ActionType
- FFApiEndpoint_BodyType
- FFApiEndpoint_CallType
- FFApiResponseField_ResponseField
- FFApiResponseType
- FFAppBar_TemplateType
- FFAppEvent_FFAppEventScope
- FFAppStorePrivacyManifestSettings_ActiveKeyboardsApi
- FFAppStorePrivacyManifestSettings_DiskSpaceApi
- FFAppStorePrivacyManifestSettings_FileTimestampApi
- FFAppStorePrivacyManifestSettings_SystemBootTimeApi
- FFAppStorePrivacyManifestSettings_UserDefaultsApi
- FFAppValuesTab
- FFAspectRatioPreset
- FFAudio_FFAudioType
- FFAudioPlayer_PlayInBackground
- FFAuthAction_ActionType
- FFAuthProvider
- FFAuthVariable_AuthProperty
- FFAxis
- FFAxisDirection
- FFBarcode_BarcodeType
- FFBarcode_BarcodeTypeCategory
- FFBaseDataType
- FFBorderRadius_BorderRadiusType
- FFBoxFit
- FFBoxShape
- FFBraintreePaymentConfig_BraintreePaymentType
- FFButton_FFButtonIconPosition
- FFCarouselAction_ActionType
- FFChart_ChartType
- FFChartData_DataSourceType
- FFChartLabelFormatInfo_LabelFormatType
- FFChatAction_ChatActionType
- FFChatPage_TimeDisplaySetting
- FFCheckboxDensity
- FFClip
- FFCodemagicGooglePlayStoreSettings_GooglePlayTrack
- FFColor_ThemeColor
- FFCombineConditions_LogicalOperator
- FFCondition_Relation
- FFConstantsVariable_ConstantValue
- FFCrossAxisAlignment
- FFCurve
- FFCustomCloudFunctionResponseField_ResponseField
- FFCustomFile_Action_Type
- FFCustomFile_Hook_Type
- FFCustomFile_Type
- FFDatabaseRequestManagerSettings_ManagerScope
- FFDataSchemaTab
- FFDataTableAction_ControlPageType
- FFDatePicker_DateTimePickerType
- FFDesignTokenVariable_TokenType
- FFDividerLineStyle
- FFDrawerAction_ActionType
- FFDynamicComponentAccess_AccessType
- FFExpandable_HeaderAlignment
- FFExpanded_ExpandedType
- FFFirebaseAppCheckConfig_AndroidProvider
- FFFirebaseAppCheckConfig_AppleProvider
- FFFirestoreAggregation_AggregationType
- FFFirestoreFilter_Relation
- FFFirestoreSchemaValidation_Mode
- FFFontWeight
- FFForm_AutovalidateMode
- FFFormFieldActionRebuildType
- FFGenUIBackendType
- FFGlobalPropertiesVariable_GlobalProperty
- FFGoogleMap_FFGoogleMapStyle
- FFGoogleMap_FFGoogleMapType
- FFGoogleMap_FFGoogleMarkerColor
- FFGoogleMap_FFMarkerIcon
- FFGoogleMap_FFMarkerType
- FFGradient_FFGradientType
- FFHapticFeedbackAction_FFFeedbackType
- FFHideSnackBarAction_HideScope
- FFImage_FFImageFormat
- FFImage_FFImageType
- FFIndicatorPosition
- FFInputDecoration_InputBorderType
- FFInternationalizationVariable_VariableType
- FFListItemAtIndex_IndexType
- FFLoadingIndicator_IndicatorType
- FFLocalStateUpdate_UpdateType
- FFLottieAnimationType
- FFMainAxisAlignment
- FFMapLauncherAction_MapType
- FFMouseRegion_FFMouseCursor
- FFMultiselectWidgetAction_ActionType
- FFMuxBroadcast_FFMuxBroadcastAudioChannel
- FFMuxBroadcast_FFMuxBroadcastLatencyMode
- FFMuxBroadcast_FFMuxBroadcastResolution
- FFNavBar_NavBarType
- FFNavigateTransition_TransitionType
- FFNumberFormat_DecimalType
- FFNumberFormat_FormatType
- FFOverrideSourceType
- FFOverrideVariableSource
- FFPadding_PaddingType
- FFPageViewAction_ActionType
- FFPermissionType
- FFPieChart_SectionLabelType
- FFPinCode_FFPinCodeFieldShape
- FFPostgresFilter_ExactEquality
- FFPostgresFilter_Relation
- FFPostgresFlavor
- FFProgressBar_FFProgressBarShape
- FFProject_LegacyNullSafety
- FFProjectError_OnTapActionIdentifier
- FFProjectWalkthroughStep_ContentAlignment
- FFProjectWalkthroughStep_FocusShape
- FFProjectWalkthroughStep_SkipAlignment
- FFPushNotificationData_Status
- FFPushNotificationData_TargetAudience
- FFRadioButton_FFRadioButtonPosition
- FFRandomName_NameType
- FFRebuildAction_UpdateType
- FFResponseStreamMessageField_ResponseField
- FFRevenueCatGetOfferingAttributeReducer_OfferingAttribute
- FFRevenueCatGetPackageAttributeReducer_PackageAttribute
- FFRevenueCatVariable_VariableType
- FFRiveSimpleAnimationType
- FFSetDarkModeSetting_DarkModeSetting
- FFSetFormFieldAction_FormFieldInfo_CursorPosition
- FFSettingsTab
- FFShaderAnimationAction_ActionType
- FFShaderAnimationMode
- FFShaderMode
- FFShaderPresetType
- FFSourceType
- FFStateVariableType
- FFStaticMap_FFStaticMapStyle
- FFStripePaymentSheetOptions_PaymentSheetTheme
- FFSwipeableStack_SwipeDirectionType
- FFSwipeableStackAction_SwipeActionType
- FFTabBar_TabBarStyle
- FFTabBarAction_ActionType
- FFText_LegacyOverflowReplacement
- FFText_OverflowReplacement
- FFText_ThemeStyle
- FFTextAlign
- FFTextField_AutoFillHints
- FFTextField_Capitalization
- FFTextField_MaxLengthEnforcement
- FFTextField_SubmitType
- FFTextGradient_FFGradientDirection
- FFTextGradient_FFGradientType
- FFTextInputType
- FFThemeSettingsTab
- FFTimer_FFTimerFormat
- FFTimer_FFTimerType
- FFTimerAction_ActionType
- FFTooltip_TriggerMode
- FFUpdateFieldValue_FieldValue
- FFUploadDataDestination
- FFUploadDataSettings_FileType
- FFUploadDataSettings_Source
- FFVariableSource
- FFVerticalDirection
- FFVideoPlayer_FFVideoType
- FFWebBuildSettings_CORSProxyStrategy
- FFWebSettings_WebOrientation
- FFWidgetProperties_PlatformType
- FFWidgetPropertyType
- FFWidgetStateVariable_ActionVariableType
- FFWidgetType
- FFWorkspaceTab
- FFWrapAlignment
- FFWrapCrossAlignment
- FieldDescriptorProto_Label
- FieldDescriptorProto_Type
- FieldOptions_CType
- FieldOptions_JSType
- FieldOptions_OptionRetention
- FieldOptions_OptionTargetType
- FileOptions_OptimizeMode
- FirestoreSecurityRules_ReadVisibility
- GeneratedCodeInfo_Annotation_Semantic
- MethodOptions_IdempotencyLevel
- NullValue
- ProjectBuildMode
- RuleCondition_TagType
- StripeBillingInterval
- StripeResponseSubscriptionPlan_StripePlanType
- StripeSubscriptionStatusEnum
- SupportedPlatform
- SymbolVisibility
- TeamAccessLevel
- TimeUnitType
Constructors
- ProtobufEnum(int value, String name)
-
Creates a new constant ProtobufEnum using
valueandname.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited