invoke<T extends GeneratedMessage> abstract method

Future<T> invoke<T extends GeneratedMessage>(
  1. ClientContext? ctx,
  2. String serviceName,
  3. String methodName,
  4. GeneratedMessage request,
  5. T emptyResponse,
)

Sends a request to a server and returns the reply.

The implementation should serialize the request as binary or JSON, as appropriate. It should merge the reply into emptyResponse and return it.

Implementation

Future<T> invoke<T extends GeneratedMessage>(
  ClientContext? ctx,
  String serviceName,
  String methodName,
  GeneratedMessage request,
  T emptyResponse,
);