isExcluded property
True if the collection should be excluded from from rule generation.
Implementation
@$pb.TagNumber(6)
$core.bool get isExcluded => $_getBF(5);
True if the collection should be excluded from from rule generation.
@$pb.TagNumber(6)
$core.bool get isExcluded => $_getBF(5);