isPublic property
True if the collection does not contain any sensitive or private data.
Implementation
@$pb.TagNumber(5)
$core.bool get isPublic => $_getBF(4);
True if the collection does not contain any sensitive or private data.
@$pb.TagNumber(5)
$core.bool get isPublic => $_getBF(4);