stripePlanInfo property

  1. @Deprecated('This field is deprecated.')
  2. @TagNumber(1)
StripeResponseSubscriptionPlan get stripePlanInfo

Can't truly be a oneof right now due to the need to return the deprecated field for outdated clients. oneof result {

Implementation

@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(1)
StripeResponseSubscriptionPlan get stripePlanInfo => $_getN(0);
  1. @Deprecated('This field is deprecated.')
  2. @TagNumber(1)
set stripePlanInfo (StripeResponseSubscriptionPlan value)

Implementation

@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(1)
set stripePlanInfo(StripeResponseSubscriptionPlan value) =>
    $_setField(1, value);