stripeSubscriptionId property
The ID of the existing Stripe subscription the checkout session is for, if it exists. No ID is provided if this is for creating a new subscription.
Implementation
@$pb.TagNumber(11)
$core.String get stripeSubscriptionId => $_getSZ(10);