StripeResponseSubscriptionPlan class
- Inheritance
-
- Object
- GeneratedMessage
- StripeResponseSubscriptionPlan
- Available extensions
Constructors
-
StripeResponseSubscriptionPlan({String? planItemId, int? planUnitAmountDollars, StripeBillingInterval? billingInterval, int? quantity, StripeResponseSubscriptionPlan_StripePlanType? planType, Timestamp? planEndDate, double? discountRate, Timestamp? freeTrialEndDate, Timestamp? currentPeriodEnd, String? currency, bool? planIsActive, @Deprecated('This field is deprecated.') bool? userHasPlan, StripeSubscriptionStatusEnum? stripeStatus, Iterable<
StripeResponseAddOnInfoMap> ? addOns, String? subscriptionId, String? teamId, String? stripePriceId, Timestamp? currentPeriodStart}) -
factory
-
StripeResponseSubscriptionPlan.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- StripeResponseSubscriptionPlan.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
-
addOns
→ PbList<
StripeResponseAddOnInfoMap> -
no setter
- billingInterval ↔ StripeBillingInterval
-
getter/setter pair
- currency ↔ String
-
getter/setter pair
- currentPeriodEnd ↔ Timestamp
-
getter/setter pair
- currentPeriodStart ↔ Timestamp
-
getter/setter pair
- discountRate ↔ double
-
getter/setter pair
- freeTrialEndDate ↔ Timestamp
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setteroverride
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - planEndDate ↔ Timestamp
-
getter/setter pair
- planIsActive ↔ bool
-
getter/setter pair
- planItemId ↔ String
-
getter/setter pair
- planType ↔ StripeResponseSubscriptionPlan_StripePlanType
-
getter/setter pair
- planUnitAmountDollars ↔ int
-
getter/setter pair
- quantity ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stripePriceId ↔ String
-
getter/setter pair
- stripeStatus ↔ StripeSubscriptionStatusEnum
-
getter/setter pair
- subscriptionId ↔ String
-
getter/setter pair
- teamId ↔ String
-
The team id that the subscription belongs to, if it is a team subscription.
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- userHasPlan ↔ bool
-
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearBillingInterval(
) → void -
clearCurrency(
) → void -
clearCurrentPeriodEnd(
) → void -
clearCurrentPeriodStart(
) → void -
clearDiscountRate(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearFreeTrialEndDate(
) → void -
clearPlanEndDate(
) → void -
clearPlanIsActive(
) → void -
clearPlanItemId(
) → void -
clearPlanType(
) → void -
clearPlanUnitAmountDollars(
) → void -
clearQuantity(
) → void -
clearStripePriceId(
) → void -
clearStripeStatus(
) → void -
clearSubscriptionId(
) → void -
clearTeamId(
) → void -
clearUserHasPlan(
) → void -
clone(
) → StripeResponseSubscriptionPlan -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(StripeResponseSubscriptionPlan)) → StripeResponseSubscriptionPlan -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → StripeResponseSubscriptionPlan -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureCurrentPeriodEnd(
) → Timestamp -
ensureCurrentPeriodStart(
) → Timestamp -
ensureFreeTrialEndDate(
) → Timestamp -
ensurePlanEndDate(
) → Timestamp -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasBillingInterval(
) → bool -
hasCurrency(
) → bool -
hasCurrentPeriodEnd(
) → bool -
hasCurrentPeriodStart(
) → bool -
hasDiscountRate(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasFreeTrialEndDate(
) → bool -
hasPlanEndDate(
) → bool -
hasPlanIsActive(
) → bool -
hasPlanItemId(
) → bool -
hasPlanType(
) → bool -
hasPlanUnitAmountDollars(
) → bool -
hasQuantity(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasStripePriceId(
) → bool -
hasStripeStatus(
) → bool -
hasSubscriptionId(
) → bool -
hasTeamId(
) → bool -
hasUserHasPlan(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited