teamId property
The team id that the subscription belongs to, if it is a team subscription.
Implementation
@$pb.TagNumber(16)
$core.String get teamId => $_getSZ(15);
The team id that the subscription belongs to, if it is a team subscription.
@$pb.TagNumber(16)
$core.String get teamId => $_getSZ(15);