AiGenPageExample_Category class
- Inheritance
-
- Object
- ProtobufEnum
- AiGenPageExample_Category
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → AiGenPageExample_Category?
Constants
- ANALYTICS → const AiGenPageExample_Category
- CALENDAR → const AiGenPageExample_Category
- CART → const AiGenPageExample_Category
- CATEGORY_UNDEFINED → const AiGenPageExample_Category
- CHECKOUT → const AiGenPageExample_Category
- CONTENT → const AiGenPageExample_Category
- DETAIL → const AiGenPageExample_Category
- ERROR → const AiGenPageExample_Category
- EVENTS → const AiGenPageExample_Category
- FEED → const AiGenPageExample_Category
- FORM → const AiGenPageExample_Category
- HELP → const AiGenPageExample_Category
- HISTORY → const AiGenPageExample_Category
- HOME → const AiGenPageExample_Category
- LIST → const AiGenPageExample_Category
- LOGIN → const AiGenPageExample_Category
- MAPS → const AiGenPageExample_Category
- MEDIA → const AiGenPageExample_Category
- MESSAGING → const AiGenPageExample_Category
- NOTIFICATIONS → const AiGenPageExample_Category
- ONBOARDING → const AiGenPageExample_Category
- PRODUCT → const AiGenPageExample_Category
- PROFILE → const AiGenPageExample_Category
- SEARCH → const AiGenPageExample_Category
- SETTINGS → const AiGenPageExample_Category
-
values
→ const List<
AiGenPageExample_Category>