FFProjectError_OnTapActionIdentifier class
- Inheritance
-
- Object
- ProtobufEnum
- FFProjectError_OnTapActionIdentifier
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFProjectError_OnTapActionIdentifier?
Constants
- CLEAR_TEXT_FIELD → const FFProjectError_OnTapActionIdentifier
- FIX_CONCENTRIC_BORDER_RADIUS → const FFProjectError_OnTapActionIdentifier
- REMOVE_OLD_SIGNATURE_FIELDS → const FFProjectError_OnTapActionIdentifier
- RESET_FORM_CLEAR_DYNAMIC_FIELDS → const FFProjectError_OnTapActionIdentifier
- RESET_FORM_CLEAR_NON_WIDGET_TYPE_FIELDS → const FFProjectError_OnTapActionIdentifier
- RESET_MISSING_FORM_FIELD → const FFProjectError_OnTapActionIdentifier
- SET_FORM_FIELD_CLEAR_KEY_PATH → const FFProjectError_OnTapActionIdentifier
- SUBCOLLECTION_DELETE → const FFProjectError_OnTapActionIdentifier
- TOGGLE_EXPANDABLE_WIDGET_CLEAR_DYNAMIC_FIELDS → const FFProjectError_OnTapActionIdentifier
- TOGGLE_EXPANDABLE_WIDGET_CLEAR_MISSING_FIELDS → const FFProjectError_OnTapActionIdentifier
- UNDEFINED → const FFProjectError_OnTapActionIdentifier
- VALIDATE_FORM_FIELD_CLEAR_KEY_PATH → const FFProjectError_OnTapActionIdentifier
-
values
→ const List<
FFProjectError_OnTapActionIdentifier>