FFWorkspaceTab class
- Inheritance
-
- Object
- ProtobufEnum
- FFWorkspaceTab
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFWorkspaceTab?
Constants
- API_CONFIG → const FFWorkspaceTab
- APP_SETTINGS → const FFWorkspaceTab
- APP_VALUES → const FFWorkspaceTab
- CUSTOM_CODE → const FFWorkspaceTab
- DATA_TYPES → const FFWorkspaceTab
- DATABASE → const FFWorkspaceTab
- MEDIA → const FFWorkspaceTab
- STORYBOARD → const FFWorkspaceTab
- TESTS → const FFWorkspaceTab
- THEME_SETTINGS → const FFWorkspaceTab
- UI_BUILDER → const FFWorkspaceTab
-
values
→ const List<
FFWorkspaceTab> - WORKSPACE_TAB_UNDEFINED → const FFWorkspaceTab