ProjectBuildMode class
- Inheritance
-
- Object
- ProtobufEnum
- ProjectBuildMode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → ProjectBuildMode?
Constants
- APK → const ProjectBuildMode
- BUILD_MODE_UNDEFINED → const ProjectBuildMode
- EXPORT → const ProjectBuildMode
- EXPORT_AS_MODULE → const ProjectBuildMode
- LOCAL_RUN → const ProjectBuildMode
- LSP → const ProjectBuildMode
- RUN_MODE → const ProjectBuildMode
- TEST_MODE → const ProjectBuildMode
-
values
→ const List<
ProjectBuildMode> - WEB_PUBLISH → const ProjectBuildMode