TeamAccessLevel class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) TeamAccessLevel?

Constants

ACCESS_LEVEL_UNDEFINED → const TeamAccessLevel
ADMIN → const TeamAccessLevel
/ Enterprise only ACLs below.
DESIGNER → const TeamAccessLevel
DEVELOPER → const TeamAccessLevel
EDITOR → const TeamAccessLevel
MANAGER → const TeamAccessLevel
Project access level for changing permissions within a project.
READ_ONLY → const TeamAccessLevel
values → const List<TeamAccessLevel>