schema/gen/flutterflow.pb library

Classes

AIMessage
AIMessage_Role
AIModel
AIModelParameters
AIModelRequestOptions
AIModelRequestOptions_RequestType
AIModelResponseOptions
AIModelResponseOptions_ResponseType
CodegenRequest
CodegenRequest_LibraryInfo
CodegenResponse
DependencyProtoMap
FFAccessCustomInterfaceField
FFAccessCustomInterfaceMethod
FFAccessDataStructField
FFAccessDocumentField
FFAccessDocumentField_DocumentProperty
FFAccessGooglePlaceField
FFAccessGooglePlaceField_GooglePlaceField
FFAccessibilitySettings
FFAccessPostgresRowField
FFAccessSQLiteRowColumn
FFAction
FFAction_LegacyTrigger
FFActionComponent
FFActionComponentKeyReference
FFActionComponentParameterVariable
FFActionComponentsConfig
FFActionCondition
FFActionInputVariable
FFActionInputVariable_ActionInput
FFActionKeyReference
FFActionNode
FFActionNodeKeyReference
FFActionOutputVariable
FFActionReturnValue
FFActionTrigger
FFActionTriggerType
FFAdBanner
FFAddLocalAppEventHandlerAction
@doc Action to add a local handler for an app event
FFAdMobAction
FFAdMobCheckConsentNotRequired
FFAdMobLoadInterstitialAd
FFAdMobRequestConsent
FFAdMobSettings
FFAdMobSettings_MaxAdContentRating
FFAdMobShowInterstitialAd
FFAdvancedAppSettings
FFAgent
FFAgent_FFAgentStatus
FFAgentDeploymentSettings
FFAIAgentAction
FFAIAgentRequest
FFAiGeneratedNodeInfo
FFAiGenSerializedIdxMapData
assorted information stored regarding how serialized idx map to nodes
FFAlertDialogAction
FFAlgoliaConfig
FFAlgoliaLocation
FFAlgoliaLocation_LocationSource
FFAlgoliaSearch
FFAlgoliaSearchAction
FFAlgoliaVariable
FFAlignment
FFAllAppNames
FFAllCodemagicSettings
FFAllWebSettings
FFAndroidAdaptiveIcon
FFAnimatedAlignment
FFAnimatedOpacity
FFAnimatedPadding
FFAnimation
FFAnimation_Trigger
FFAnimationAction
FFAnimationAction_FFAnimationActionType
FFAnimationAction_FFWidgetAnimationAction
FFAnimationAction_FFWidgetAnimationAction_ActionType
FFAnimationState
FFAnnotations
FFApiCall
FFApiCallPaginationVariable
FFApiCallPaginationVariable_LastResponse
FFApiCallPaginationVariable_NextPageNumber
FFApiCallPaginationVariable_NumLoadedItems
FFApiCallValue
FFApiCallVariable
FFApiConfig
FFApiEndpoint
FFApiEndpoint_BodyType
FFApiEndpoint_CallType
FFApiEndpointSettings
FFApiEndpointSettings_Interceptor
FFApiGroup
FFApiParameter
FFApiResponseField
FFApiResponseField_ResponseField
FFApiResponseType
FFApiValue
FFAppBar
FFAppBar_TemplateType
FFAppConstantField
FFAppConstants
FFAppEvent
  • FFAppEvent_FFAppEventScope
  • FFAppNames
    Environment specific app names including package name and display name.
    FFAppState
    FFAppStateField
    FFAppStorePrivacyManifestSettings
    FFAppStorePrivacyManifestSettings_ActiveKeyboardsApi
    FFAppStorePrivacyManifestSettings_DiskSpaceApi
    FFAppStorePrivacyManifestSettings_FileTimestampApi
    FFAppStorePrivacyManifestSettings_SystemBootTimeApi
    FFAppStorePrivacyManifestSettings_UserDefaultsApi
    FFAspectRatio
    FFAspectRatioPreset
    FFAudio
    FFAudio_FFAudioType
    FFAudioPlayer
    FFAudioPlayer_PlayInBackground
    FFAuthAction
    FFAuthAction_ActionType
    FFAuthActionMessages
    FFAuthentication
    FFAuthPageInfo
    FFAuthProvider
    FFAuthVariable
    FFAuthVariable_AuthProperty
    FFAutoPlayOptions
    FFAxis
    FFAxisDirection
    FFBackend
    FFBadge
    FFBarChart
    FFBarChartBarInfo
    FFBarcode
    FFBarcode_BarcodeType
    FFBarcode_BarcodeTypeCategory
    FFBarcodeQrcodeScanner
    FFBaseDataType
    FFBaseVariable
    FFBiometricVerification
    FFBlur
    FFBlurEffect
    FFBooleanValue
    FFBorder
    FFBorder_Side
    FFBorderRadius
    FFBorderRadius_BorderRadiusType
    FFBottomSheetAction
    FFBoxDecoration
    FFBoxFit
    FFBoxShadow
    FFBoxShape
    FFBraintreeAction
    FFBraintreeCredentials
    FFBraintreePaymentConfig
    FFBraintreePaymentConfig_BraintreePaymentType
    FFBraintreePaymentOptions
    FFBraintreeSettings
    FFBraintreeSinglePayment
    FFBreakPoints
    FFButton
    FFButton_FFButtonIconPosition
    FFCalendar
    FFCallNumber
    FFCancelLocalAppEventHandlerAction
    @doc Action to cancel a local handler for an app event
    FFCancelStreamingResponseSubscriptionAction
    FFCanvasProps
    FFCanvasSettings
    FFCard
    FFCarousel
    FFCarouselAction
    FFCarouselAction_ActionType
    FFChart
    FFChart_ChartType
    FFChartAxisInfo
    FFChartAxisInfo_AxisBounds
    FFChartAxisInfo_AxisLabel
    Axis label fields
    FFChartAxisInfo_AxisLabels
    FFChartData
    FFChartData_DataSourceType
    FFChartLabelFormatInfo
    FFChartLabelFormatInfo_LabelFormatType
    FFChartLegendInfo
    FFChartTooltipInfo
    FFChatAction
    FFChatAction_ChatActionType
    FFChatPage
    FFChatPage_TimeDisplaySetting
    FFChatPreview
    FFCheckbox
    FFCheckboxDensity
    FFCheckboxGroup
    FFCheckboxListTile
    FFCheckHasField
    FFChildrenKeys
    FFChildSlotDefinition
    Defines a child slot on a component — a named position in the widget tree where the caller provides an arbitrary widget subtree.
    FFChildSlotProperties
    Properties for a ChildSlot placeholder node in a component's widget tree.
    FFChildSlotUIProperties
    FFChipData
    FFChipStyle
    FFChoiceChips
    FFClearAIAgentMessages
    FFClearQueryCache
    FFClearSignature
    FFClearSwipeableStackAction
    FFClearTextFieldAction
    FFClearUploadedDataAction
    FFClip
    FFCloudFunctionSettings
    FFCodeExpression
    FFCodeFolder
    FFCodeGenerationSettings
    FFCodemagicAppStoreSettings
    FFCodemagicGooglePlayStoreSettings
    FFCodemagicGooglePlayStoreSettings_GooglePlayTrack
    FFCodemagicSettings
    FFCodemagicSettings_BuildVersion
    FFCollection
    Defines the schema and name for a Firestore collection.
    FFColor
    FFColor_ThemeColor
    FFColorFromString
    FFColorPickerAction
    FFColorScheme
    FFColorValue
    FFColumn
    FFCombineConditions
    FFCombineConditions_LogicalOperator
    FFComponentDisplayWidget
    FFComponentUniqueKey
    FFCondition
    FFCondition_Relation
    FFConditionActions
    FFConditionActions_FFTrueConditionAction
    FFConditionalBuilder
    FFConditionalExecution
    FFConditionalValue
    FFConditionalValue_ConditionValue
    FFConfirmationDialogResponse
    FFConfirmDialogAction
    FFConstantsVariable
    FFConstantsVariable_ConstantValue
    FFContainer
    FFCopyToClipboard
    FFCountController
    FFCountTokens
    FFCreateCustomInterfaceVariable
    FFCreateCustomInterfaceVariable_InterfaceField
    FFCreateDataStructVariable
    FFCreateDataStructVariable_StructField
    FFCreateJsonMapVariable
    FFCreateJsonMapVariable_MapEntry
    FFCreditCardForm
    FFCrossAxisAlignment
    FFCurve
    FFCustomAction
    FFCustomAction_CompileInfo
    FFCustomActionCall
    FFCustomActionCall_ActionParamIdentifier
    Each FFCustomActionCall of a given FFCustomAction needs its own way to map the CALLBACK trigger actions to itself.
    FFCustomAuth
    FFCustomAuthFields
    FFCustomCloudFunction
    FFCustomCloudFunctionCall
    FFCustomCloudFunctionPackage
    FFCustomCloudFunctionResponseField
    FFCustomCloudFunctionResponseField_ResponseField
    FFCustomCloudFunctionsConfig
    FFCustomCloudFunctionSettings
    FFCustomCode
    FFCustomCodeCallAction
    FFCustomCodeEntity
    A custom code entity could be a function, widget, or interface.
    FFCustomCodeExpressionVariable
    FFCustomCodeFile
    FFCustomCodeFiles
    FFCustomCodeLibraries
    FFCustomCodeLibrary
    FFCustomDialogAction
    FFCustomFile
    FFCustomFile_Action
    @doc A code snippet that will be substituted into a custom file.
    FFCustomFile_Action_Type
    FFCustomFile_Hook
    @doc A code snippet that will be substituted into a custom file.
    FFCustomFile_Hook_Type
    FFCustomFile_Parameter
    FFCustomFile_Type
    @doc The type of custom file.
    FFCustomFiles
    FFCustomFiles_Main
    FFCustomFont
    FFCustomFont_FontFileData
    FFCustomFunction
    FFCustomFunctionTest
    FFCustomIconFamily
    FFCustomIconFamily_IconInfo
    FFCustomInterface
    FFCustomInterfaceConstructor
    FFCustomInterfaceField
    FFCustomInterfaceMethodCall
    FFCustomInterfaceStaticVariable
    FFCustomWhenTestStep
    FFCustomWidget
    FFCustomWidget_RenderInfo
    FFDatabaseAction
    FFDatabaseRequest
    Requests can be directly associated with nodes, or can be managed by an action chain
    FFDatabaseRequestManager
    FFDatabaseRequestManagerSettings
    FFDatabaseRequestManagerSettings_ManagerScope
    Whether the request is managed / cached at the app or widget class level.
    FFDatabaseWrite
    FFDataSchemaConfig
    FFDataStruct
    Defines a data structure with one or more fields. Similar to FFCollection but not specific to Firestore.
    FFDataStructFieldUpdate
    FFDataStructFieldUpdate_FieldUpdates
    FFDataStructToJson
    FFDataTable
    Deprecated in favor of FFPaginatedDataTable
    FFDataTableAction
    FFDataTableAction_ControlPage
    FFDataTableAction_ControlPageType
    FFDataTableAction_UpdateRowsPerPage
    FFDataTableAction_UpdateSort
    FFDataTableHeader
    FFDataTypeV2
    FFDatePicker
    FFDatePicker_DateTimePickerType
    FFDatePickerSettings
    FFDatePickerValidation
    FFDateTime
    FFDateTimeFormat
    FFDateTimeFromTimestamp
    FFDateTimeRangeEnd
    FFDateTimeRangeStart
    FFDateTimeToInteger
    FFDateTimeValue
    FFDefaultAppBar
    FFDeleteData
    FFDependency
    FFDesignTokenVariable
    @doc Variable referencing a design token (spacing, radius, or shadow).
    FFDesignTokenVariable_TokenType
    FFDim
    FFDimensions
    FFDisable
    FFDisableAction
    FFDismissDialogAction
    FFDivider
    FFDividerLineStyle
    FFDocumentProperty
    FFDocumentReferenceId
    FFDocumentReferencePath
    FFDoubleValue
    FFDownloadCodeSettings
    FFDownloadFileAction
    FFDraggable
    FFDragTarget
    FFDrawer
    FFDrawerAction
    FFDrawerAction_ActionType
    FFDropDown
    FFDropDownTesting
    FFDropDownValidation
    FFDropInOptions
    FFDynamicComponentAccess
    FFDynamicComponentAccess_AccessType
    FFEasterEgg
    FFEditMetadata
    FFEditMetadata_RecentlyDeleted
    Proto tracking recently deleted objects. Should store keys of objects deleted and remove them after some time post-delete (e.g. 30 mins).
    FFEffect
    FFEmptyListWidget
    FFEnumDefinition
    FFEnumElement
    FFEnumVariable
    FFEnvironmentSettings
    FFEnvironmentValue
    FFEnvironmentValueVariable
    FFExecuteActionComponent
    FFExecuteCallbackAction
    FFExpandable
    FFExpandable_HeaderAlignment
    FFExpanded
    FFExpanded_ExpandedType
    FFExpandImageAction
    FFFacebookSignInConfig
    FFFadeEffect
    FFFieldUpdate
    FFFirebaseAnalyticsAction
    FFFirebaseAnalyticsAction_EventParameter
    FFFirebaseAnalyticsConfig
    FFFirebaseAnalyticsConfig_AutomaticEventSettings
    FFFirebaseAppCheckConfig
    FFFirebaseAppCheckConfig_AndroidProvider
    FFFirebaseAppCheckConfig_AppleProvider
    FFFirebaseAuth
    FFFirebaseAuthProvider
    FFFirebaseConfigFileInfo
    FFFirebaseCrashlyticsConfig
    FFFirebasePerformanceMonitoringConfig
    FFFirebaseRemoteConfigConfig
    FFFirebaseRemoteConfigField
    FFFirebaseRemoteConfigVariable
    FFFirebaseStorage
    FFFirestore
    Defines the Firestore configuration.
    FFFirestore_StorageRules
    FFFirestoreAggregation
    FFFirestoreAggregation_AggregationType
    FFFirestoreChartData
    FFFirestoreCreate
    FFFirestoreDelete
    FFFirestoreDocument
    FFFirestoreFilter
    FFFirestoreFilter_Relation
    TODO: Extend these with more types.
    FFFirestoreOrderBy
    FFFirestorePagination
    FFFirestoreQuery
    FFFirestoreSchemaValidation
    FFFirestoreSchemaValidation_Mode
    Using enum instead of bool in anticipation that we can have more options in how it will run.
    FFFirestoreUpdate
    FFFirestoreVariable
    FFFirestoreWhere
    FFFirestoreWhere_NestedFilter
    FFFlex
    FFFlipEffect
    FFFlippableCard
    FFFloatingActionButton
    FFFloatingNavBarItem
    FFFloatingNavBarSettings
    FFFocusBorder
    FFFocusConfiguration
    FFFontWeight
    FFFontWeightValue
    FFForm
    FFForm_AutovalidateMode
    FFFormFieldActionRebuildType
    @doc Defines the types of rebuild that can be performed, when a form field is reset or set.
    FFFormFieldOnValidationError
    FFFormFieldValidation
    FFFormOptionsValue
    @doc A message that can be set to contain either a list of values (of arbitrarty type) or a variable.
    FFFunctionCall
    FFFunctionCallValues
    FFFunctionCallValues_FFArgument
    FFGeminiAction
    FFGeminiSettings
    FFGenerateText
    FFGenerateTextFromImage
    FFGeneratorVariable
    Message that creates a local variable for this node and uses it to generate its children dynamically. The variable source can be, for instance, the database request at this node, or an array field on a Collection at an ancestor. Note: Currently the variable must be a list, and will automatically generate dynamic children. In the future we can make it more general.
    FFGeneratorVariableVariable
    FFGenUIAppEventListenerConfig
    @doc Configuration for an app event listener on a GenUI chat widget. When the specified app event fires, a context message is injected into the AI conversation. Next available tag: 4
    FFGenUIBackendConfig
    @doc Configuration for AI backend provider. Next available tag: 2
    FFGenUIBackendType
    FFGenUIChatAvatarConfig
    @doc Avatar configuration for chat participants. Next available tag: 5
    FFGenUIChatBubbleStyling
    @doc Styling for message bubbles (user or AI). Next available tag: 4
    FFGenUIChatHeaderConfig
    @doc Header configuration for the chat widget. Next available tag: 5
    FFGenUIChatInputAreaStyling
    @doc Styling for the chat input area. Next available tag: 5
    FFGenUIChatScrollConfig
    @doc Scroll behavior configuration. Next available tag: 3
    FFGenUIChatSendButtonStyling
    @doc Styling for the send button. Next available tag: 3
    FFGenUIChatStyling
    @doc Direct styling properties for the chat widget. Next available tag: 16
    FFGenUIChatWelcomeConfig
    @doc Configuration for the welcome message shown before conversation starts. Next available tag: 4
    FFGenUIChatWidgetProperties
    @doc Properties for the GenUI Chat Widget that enables AI-powered conversations. Next available tag: 10
    FFGenUIFunctionConfig
    @doc Configuration for a function exposed to GenUI AI. Allows specifying a user-friendly loading message shown during execution. Next available tag: 3
    FFGivenTestStep
    Precondition
    FFGivenTestStep_EntryPage
    FFGivenTestStep_LoggedIn
    FFGlobalPropertiesVariable
    FFGlobalPropertiesVariable_GlobalProperty
    FFGoogleMap
    FFGoogleMap_FFGoogleMapStyle
    FFGoogleMap_FFGoogleMapType
    FFGoogleMap_FFGoogleMarkerColor
    FFGoogleMap_FFMarkerIcon
    FFGoogleMap_FFMarkerType
    FFGoogleMapAction
    FFGoogleMapsApiKeys
    FFGoogleNavBarItem
    FFGoogleNavBarSettings
    FFGradient
    FFGradient_Color
    FFGradient_FFGradientType
    FFGridView
    FFHapticFeedbackAction
    FFHapticFeedbackAction_FFFeedbackType
    FFHero
    FFHideSnackBarAction
    FFHideSnackBarAction_HideScope
    FFHtmlView
    FFIcon
    FFIconButton
    FFIconData
    FFIconDataValue
    FFIconValue
    FFIdentifier
    Universal property used to identify any field name, parameter name, or any other name that a user can specify.
    FFImage
    FFImage_FFImageFormat
    FFImage_FFImageType
    FFImport
    FFIndexInList
    FFIndicatorPosition
    FFInformationalDialogAction
    FFInputDecoration
    FFInputDecoration_InputBorderType
    FFIntegerValue
    FFInteractionTestStep
    FFInteractionTestStep_DoubleTapStep
    FFInteractionTestStep_EnterTextStep
    FFInteractionTestStep_LongPressStep
    FFInteractionTestStep_ScrollUntilVisibleStep
    FFInteractionTestStep_TapStep
    FFInternationalizationSettings
    FFInternationalizationVariable
    FFInternationalizationVariable_VariableType
    FFItemAtCurrentIndex
    FFJsonPathDefinition
    FFJsonPathOperation
    FFJsonToDataStruct
    FFLanguage
    Really a locale.
    FFLanguageDependentText
    FFLanguageSelector
    FFLatLng
    FFLatLngValue
    FFLaunchUrlAction
    FFLibraryConfig
    FFLibraryPageRoutePath
    FFLibrarySettings
    FFLibraryValue
    FFLibraryValueVariable
    FFLineChart
    FFLineChart_LegacyAxisBounds
    Min/Max Axis Values
    FFLineChart_LegacyAxisLabel
    FFLineChart_LegacyAxisLabels
    FFLineChart_LegacyTooltipInfo
    Tool tip fields
    FFLineChartLine
    FFListContains
    FFListHasValueOperation
    FFListItemAtIndex
    FFListItemAtIndex_IndexType
    FFListMapOperation
    FFListMapVariable
    FFListNumItems
    FFListSortOperation
    FFListSpacing
    FFListTakeOperation
    FFListTile
    FFListUniqueOperation
    FFListView
    FFListWhereOperation
    FFLoadingIndicator
    FFLoadingIndicator_IndicatorType
    FFLoadingWidget
    FFLoadingWidget_DefaultLoadingIndicator
    FFLocalStateClearValue
    FFLocalStateDataStructUpdate
    FFLocalStateFieldUpdate
    FFLocalStateInsertListItem
    FFLocalStateToggle
    FFLocalStateUpdate
    FFLocalStateUpdate_UpdateType
    FFLocalStateUpdateListItem
    FFLocalStateVariable
    FFLockedLanguageSection
    Locked language iso codes for a specific translation section (page or component). Languages in this list are skipped when using "Translate Page" or "Translate Component".
    FFLoopAction
    FFLoopBreakAction
    FFLoopOverList
    FFLoopOverListKeyReference
    FFLoopOverListVariable
    FFLottieAnimation
    FFLottieAnimationAction
    FFLottieAnimationType
    FFMainAxisAlignment
    FFMapDocumentMarker
    FFMapDocumentMarkers
    FFMapLatLngMarker
    FFMapLatLngMarkers
    FFMapLauncherAction
    FFMapLauncherAction_MapType
    FFMarkdown
    FFMaterialThemeSettings
    FFMediaDisplay
    FFMouseRegion
    FFMouseRegion_FFMouseCursor
    FFMoveMapCenter
    FFMultiselectWidgetAction
    FFMultiselectWidgetAction_ActionType
    FFMuxBroadcast
    FFMuxBroadcast_FFMuxBroadcastAudioChannel
    FFMuxBroadcast_FFMuxBroadcastLatencyMode
    FFMuxBroadcast_FFMuxBroadcastResolution
    FFMuxBroadcastApiAccessTokens
    FFNavBar
    FFNavBar_NavBarType
    FFNavBarItem
    FFNavigateAction
    FFNavigateTransition
    FFNavigateTransition_TransitionType
    FFNegateBoolean
    FFNode
    Associated with a flutter widget in a project. next available : 34
    FFNodeFeaturePresence
    Information about the node's features in order to make error checking more efficient
    FFNodeKeyPath
    If we are accessing a variable within a component, this is the path to the nested widget. In this case the "node_key" of the variable will be the key of the component widget on the page, and these keys dictate the (possibly nested) path to the widget containing the state variable.
    FFNodeKeyReference
    FFNumberFormat
    FFNumberFormat_DecimalType
    FFNumberFormat_FormatType
    FFNumbersList
    FFOAuthSupabaseSettings
    FFOffset
    FFOneSignalAction
    FFOneSignalAddUser
    FFOneSignalDeleteUser
    FFOneSignalSettings
    FFOneSignalUserTag
    FFOpacity
    FFOverrideSource
    FFOverrideSourceType
    FFOverrideVariableSource
    TODO: Eventually add STATE as a type.
    FFPadding
    FFPadding_PaddingType
    FFPageGroup
    FFPageRouteSettings
    FFPageView
    FFPageViewAction
    FFPageViewAction_ActionType
    FFPageViewIndicatorOptions
    FFPaginatedDataTable
    FFParallelActions
    FFParameter
    FFParameter_NamedParameter
    FFParameter_PositionalParameter
    FFParameterPass
    FFParameterValue
    FFParamReducer
    Deprecated: See FFVariableOperation.
    FFParseStringAsEnum
    FFPassedParameters
    Used in certain widgets/actions, components, and custom widgets
    FFPaymentMessages
    FFPaymentSettings
    FFPdfViewer
    FFPermissionsSettings
    FFPermissionsSettings_PermissionMessage
    FFPermissionsSettings_UserDefinedPermission
    FFPermissionsSettings_UserDefinedPermission_PermissionNames
    FFPermissionStateVariable
    FFPermissionType
    FFPieChart
    FFPieChart_FFPieChartSection
    FFPieChart_SectionLabelType
    FFPinCode
    FFPinCode_FFPinCodeFieldShape
    FFPinCodeValidation
    FFPlaceholderWidget
    FFPlacePicker
    FFPlacePickerValidation
    FFPlatformSettings
    FFPlaySound
    FFPostgresAction
    FFPostgresConfig
    FFPostgresDatabase
    FFPostgresDelete
    FFPostgresField
    FFPostgresFieldUpdate
    FFPostgresFilter
    FFPostgresFilter_ExactEquality
    FFPostgresFilter_Relation
    FFPostgresFlavor
    FFPostgresInsert
    FFPostgresOrderBy
    FFPostgresProjectConfig
    FFPostgresQuery
    FFPostgresQueryVariable
    FFPostgresRead
    FFPostgresSetToken
    FFPostgresTable
    FFPostgresUpdate
    FFPostgresUpdateData
    FFPredefinedJsonPathOperation
    FFPresetTexts
    FFProgressBar
    FFProgressBar_FFProgressBarShape
    FFProject
    Next available tag: 45
    FFProject_LegacyNullSafety
    TODO: remove once null-safety migration is completed. Use enum instead of boolean to distinguish users who did not specify the value vs those who explicitly opted out.
    FFProjectTest
    FFProjectTests
    FFProjectWalkthrough
    FFProjectWalkthroughs
    FFProjectWalkthroughStep
    FFProjectWalkthroughStep_ContentAlignment
    FFProjectWalkthroughStep_FocusShape
    FFProjectWalkthroughStep_SkipAlignment
    FFProjectWalkthroughTarget
    FFPropertyOverride
    Information about properties that are not set as constants but are instead determined from a variable (e.g. by the parameters, data, etc. of a widget or its ancestors). For example, a Image path field populated by the "User.profilePic" parameter of the parent widget.
    FFPropertyParameterPass
    FFPubspecPackageInfo
    FFPullToRefreshStyle
    FFPumpAndSettleTestStep
    FFPushNotificationData
    FFPushNotificationData_Status
    FFPushNotificationData_TargetAudience
    FFPushNotificationSettings
    FFQueryLoadingWidget
    FFRadioButton
    FFRadioButton_FFRadioButtonPosition
    FFRadioButtonValidation
    FFRadiusToken
    A named border radius design token, defining a reusable BorderRadius value.
    FFRandomColor
    FFRandomData
    FFRandomDate
    FFRandomDouble
    FFRandomImage
    FFRandomInteger
    FFRandomName
    FFRandomName_NameType
    FFRandomString
    FFRatingBar
    empty_icon is currently unused, but will be in v1
    FFRazorpayAction
    FFRazorpayCredentials
    FFRazorpayPaymentSheetOptions
    FFRazorpaySettings
    FFRazorpaySinglePayment
    FFRebuildAction
    FFRebuildAction_UpdateType
    FFRefreshDatabaseRequest
    FFRefreshIndicatorWidget
    FFRequestPermissionsAction
    FFResetFormFieldAction
    FFResponseStreamMessageField
    FFResponseStreamMessageField_ResponseField
    FFResponsiveTypography
    FFResponsiveVisibility
    FFRevenueCatAction
    FFRevenueCatEntitlementResponse
    FFRevenueCatGetOfferingAttributeReducer
    FFRevenueCatGetOfferingAttributeReducer_OfferingAttribute
    FFRevenueCatGetPackageAttributeReducer
    FFRevenueCatGetPackageAttributeReducer_PackageAttribute
    FFRevenueCatGetPackageByIdReducer
    FFRevenueCatOperation
    FFRevenueCatPaywall
    FFRevenueCatPurchase
    FFRevenueCatRestore
    FFRevenueCatSettings
    FFRevenueCatVariable
    FFRevenueCatVariable_VariableType
    FFRichText
    FFRichTextSpan
    FFRiveAnimation
    FFRiveAnimationAction
    FFRiveSimpleAnimationType
    FFRotateEffect
    FFRoutingSettings
    FFRow
    FFSaturateEffect
    FFScaffold
    We assume a Scaffold is a page (may or may not be root).
    FFScaleEffect
    FFScreenshotInfo
    FFScreenshotNodeIdentifier
    Message which uniquely identifies a given rendered widget within a page when in Screenshot Mode.
    FFScreenshotValues
    FFScreenshotValues_ScreenshotValue
    FFScrollbarTheme
    FFScrollToPercentage
    FFSearchReference
    FFSemanticProperties
  • FFSemanticsAnnounceAction
    @doc Announce text to screen readers for accessibility.
    FFSendEmail
    FFSendSMS
    FFSerializedValues
    Stores a map from parameter name (namely from FFParameter identifier name) to the serialized value for that parameter.
    FFSetAppLanguageAction
    FFSetDarkModeSetting
    FFSetDarkModeSetting_DarkModeSetting
    FFSetFormFieldAction
    FFSetFormFieldAction_FormFieldInfo
    FFSetFormFieldAction_FormFieldInfo_CursorPosition
    FFSetStateAction
    FFSettings
    FFShaderAnimationAction
    FFShaderAnimationAction_ActionType
    FFShaderAnimationMode
    FFShaderFill
    FFShaderMode
    FFShaderParam
    FFShaderPresetType
    FFShaderProperties
    FFShaderWrapper
    FFShadowToken
    A named box shadow design token, defining a reusable BoxShadow value.
    FFShakeEffect
    FFShareAction
    FFSharing
    FFShimmerEffect
    FFShortcutInfo
    FFSignature
    FFSimpleSearchAction
    FFSimpleSearchAction_Collection
    FFSimpleSearchAction_Documents
    FFSimpleSearchAction_Strings
    FFSimpleSearchVariable
    FFSlidableActionWidget
    FFSlideEffect
    FFSlider
    FFSnackBarAction
    FFSnackBarAction_FFSnackBarSubAction
    FFSourceType
    FFSpacer
    FFSpacingToken
    A named spacing design token, defining a reusable EdgeInsets value.
    FFSplashImage
    FFSQLiteColumn
    FFSQLiteConfig
    FFSQLiteDatabaseInfo
    FFSQLiteInitializationConfig
    FFSQLiteInputVariable
    FFSQLiteQueryCall
    FFSQLiteQueryCall_QueryVariable
    FFSQLiteQueryConfig
    FFSQLiteVariable
    FFStack
    FFStaggeredView
    FFStartAudioRecordAction
    FFStartPeriodic
    FFStateVariableType
    FFStaticMap
    FFStaticMap_FFStaticMapStyle
    FFStickyHeader
    FFStopAudioRecordAction
    FFStopPeriodic
    FFStopSound
    FFStoryboard
    FFStoryboard_Position
    FFStreamedResponseProcessorValue
    FFStringInterpolation
    FFStringValue
    FFStripeAction
    FFStripeCredentials
    FFStripePaymentSheetOptions
    FFStripePaymentSheetOptions_PaymentSheetTheme
    FFStripeSettings
    FFStripeSinglePayment
    FFSubType
    FFSupabaseAppleAuthConfig
    FFSupabaseAuth
    FFSupabaseConfig
    FFSupabaseDatabase
    FFSupabaseEdgeFunction
    FFSupabaseEdgeFunctionCall
    FFSupabaseEdgeFunctionsConfig
    FFSupabaseGoogleAuthConfig
    FFSupabaseProjectConfig
    FFSupabaseUploadDataConfig
    FFSwipeableStack
    FFSwipeableStack_SwipeDirectionType
    FFSwipeableStackAction
    FFSwipeableStackAction_SwipeActionType
    FFSwitch
    FFSwitchListTile
    FFTab
    FFTabBar
    FFTabBar_TabBarStyle
    FFTabBarAction
    FFTabBarAction_ActionType
    FFTeamResourceInfo
    FFTemplateNode
    FFTemplateNodes
    FFTerminateAction
    FFTestFinder
    Mimics Flutter's Finder (https://api.flutter.dev/flutter/flutter_test/Finder-class.html) and CommonFinders (https://api.flutter.dev/flutter/flutter_driver/CommonFinders-class.html)
    FFTestFinder_ByDescendent
    Finds a particular widget and then does another find within that widget. This is useful in order to find components.
    FFTestFinder_ByIcon
    FFTestFinder_ByNodeKey
    Select a widget by its node key.
    FFTestFinder_BySemanticsLabel
    FFTestFinder_ByText
    FFTestFinder_ByTooltip
    FFTestFinder_ByType
    FFTestFinder_ByValueKey
    Intended to match an FFNode's ValueKey (or that of a widget in a custom widget). In the FFNode case, this may be useful to match a ValueKey set from a variable.
    FFTestFinder_CustomFinder
    FFTestGroup
    FFTestStep
    FFText
    FFText_LegacyOverflowReplacement
    FFText_OverflowReplacement
    FFText_ThemeStyle
    FFTextAlign
    FFTextAlignValue
    FFTextEditor
    Removed
    FFTextField
    FFTextField_AutoFillHints
    FFTextField_Capitalization
    FFTextField_MaxLengthEnforcement
    FFTextField_SubmitType
    FFTextFieldFilter
    FFTextFieldMask
    FFTextGradient
    FFTextGradient_FFGradientDirection
    FFTextGradient_FFGradientType
    FFTextInputType
    FFTextInputValidation
    FFTextOptionsValue
    @doc A message that can be set to either a list of text values (that can be translatable) or a variable.
    FFTextScaleSettings
    FFTextShadow
    FFTextStyle
    TODO (new types): Add messages to this type after the property migration is complete and it's easier to refactor.
    FFTextStyleAnimation
    FFTextStyleValue
    FFTextTranslation
    FFTheme
    FFThemeWidget
    FFThemeWidgetInfo
    FFThenTestStep
    Assertion Maps to classes implementing https://api.flutter.dev/flutter/package-matcher_matcher/Matcher-class.html
    FFThenTestStep_CustomThenStep
    FFThenTestStep_FindsNothing
    FFThenTestStep_FindsNumWidgets
    FFThenTestStep_FindsOneWidget
    FFThenTestStep_FindsWidgets
    FFThenTestStep_HasState
    FFThenTestStep_IsDisabled
    FFThenTestStep_IsEnabled
    FFThenTestStep_MatchesGoldenFile
    FFTiltEffect
    FFTimer
    FFTimer_FFTimerFormat
    FFTimer_FFTimerType
    FFTimerAction
    FFTimerAction_ActionType
    FFTimestampRange
    FFTintEffect
    FFToggleExpandableWidgetAction
    FFToggleIcon
    FFTooltip
    Next available tag: 25
    FFTooltip_TriggerMode
    FFTransform
    FFTranslation
    FFTriggerActions
    FFTriggerAppEventAction
    @doc Action to trigger an app event with optional data and completion handling
    FFTriggerPushNotification
    FFTypeCastOperation
    FFTypography
    FFTypographyStyle
    FFUpdateAppBadgeCountAction
    FFUpdateFieldValue
    Make sure to update firestore_update_error.dart:162 _validFirestoreSingle/ListFieldUpdateValues when changing this.
    FFUpdateFieldValue_FieldValue
    FFUpdateTextScalingFactorAction
  • FFUploadDataAction
    FFUploadDataDestination
    FFUploadDataMessages
    FFUploadDataSettings
    FFUploadDataSettings_AllowedTypes
    FFUploadDataSettings_FileType
    FFUploadDataSettings_Resolution
    FFUploadDataSettings_Source
    FFUploadDataSettings_SourcePickerStyle
    FFUploadDataValidation
    FFUploadedOriginalFileName
    @doc Operation to get the original file name of the uploaded file.
    FFUploadMediaBlurHash
    FFUploadMediaHeight
    FFUploadMediaWidth
    FFUploadSignature
    FFValidateFormAction
    FFValue
    FFVariable
    Defines a variable or function call in FlutterFlow. Each variable has a source (e.g. a Page or a Row with a backend query), a variable source (e.g. Parameters for a Page, or BackendQuery for a Row), and then a series of reducers that specify the exact variable (e.g. ".name").
    FFVariableOperation
    FFVariableSource
    FFVector2D
    FFVerticalDirection
    FFVerticalDivider
    FFVideoPlayer
    FFVideoPlayer_FFVideoType
    FFVisibility
    FFWaitAction
    FFWalkthroughAction
    FFWalkthroughStart
    FFWebBuildSettings
    FFWebBuildSettings_CORSProxyStrategy
    FFWebSettings
    FFWebSettings_WebOrientation
    FFWebView
    FFWhenTestStep
    Action Tries to mimic Flutter's WidgetTester: https://api.flutter.dev/flutter/flutter_test/WidgetTester-class.html
    FFWidgetBuilderParameterVariable
    FFWidgetBuilderSource
    FFWidgetBuilderUIProperties
    FFWidgetBuilderVariable
    FFWidgetClass
    A message that represents a Page or Component. Pages root node can only be a Scaffold, a Component's root node must be a Container.
    FFWidgetClassModel
    FFWidgetClassStateField
    FFWidgetClassVariable
    FFWidgetFocusStateVariable
    FFWidgetProperties
    FFWidgetProperties_PlatformType
    Used for widgets that may differ in style depending on the platform.
    FFWidgetPropertyType
    FFWidgetStateVariable
    FFWidgetStateVariable_ActionVariableType
    If the variable comes from an action on a widget, stores the action type.
    FFWidgetType
    FFWrap
    FFWrapAlignment
    FFWrapCrossAlignment
    FFYoutubePlayer
    Flutterflow
    MicrosoftAuthSettings
    See https://firebase.google.com/docs/auth/web/microsoft-oauth
    PackageIcon
    Icon used from a package (such as FontAwesome).
    PartitionProjectFilesRequest
    Request used to generated the partitioned project files used for merging with native dart.
    PartitionProjectFilesResponse
    Response containing the partitioned project files used for merging with native dart.
    ProjectTestSettings
    RefreshIndicatorStyle
    Default Flutter RefreshIndicator. https://api.flutter.dev/flutter/material/RefreshIndicator-class.html
    SslPinningConfig
    TimeUnitType

    Enums

    FFAccessDocumentField_Property
    FFAction_Action
    FFActionCondition_Cond
    FFActionNode_ActionType
    FFAdMobAction_Action
    FFAIAgentAction_Action
    FFAIAgentRequest_AudioInput
    FFAIAgentRequest_FileInput
    FFAIAgentRequest_ImageInput
    FFAIAgentRequest_PdfInput
    FFAIAgentRequest_VideoInput
    FFAlertDialogAction_Alert
    FFAndroidAdaptiveIcon_Background
    FFAnimationAction_Animation
    FFApiCallPaginationVariable_Type
    FFApiCallValue_Value
    FFApiParameter_Value
    FFAuthAction_ConfirmPassword
    FFAuthAction_Email
    FFAuthAction_Password
    FFAuthentication_Auth
    FFBackend_SupabaseConnection
    FFBaseVariable_Variable
    FFBooleanValue_Value
    FFChartData_Data
    FFChartLabelFormatInfo_LabelFormat
    FFChatAction_UsersValue
    FFColorValue_Value
    FFConstantsVariable_Val
    FFCustomCodeEntity_Entity
    FFCustomInterfaceMethodCall_Call
    FFCustomInterfaceMethodCall_Source
    FFCustomInterfaceStaticVariable_Call
    FFDatabaseAction_Action
    FFDatabaseRequest_Request
    FFDataStructFieldUpdate_Update
    FFDataTableAction_Action
    FFDataTypeV2_CollectionVariant
    FFDateTimeValue_Value
    FFDim_Dim
    FFDim_DimVal
    FFDoubleValue_Value
    FFDownloadFileAction_Source
    FFDynamicComponentAccess_Value
    FFEffect_Type
    FFEmptyListWidget_Widget
    FFEnumVariable_Value
    FFFieldUpdate_Value
    FFFirestoreFilter_Value
    FFFirestoreWhere_NestedFilter_Filter
    FFFontWeightValue_Value
    FFFormFieldValidation_Validation
    FFFunctionCall_Type
    FFFunctionCallValues_FFArgument_ArgumentValue
    FFGeminiAction_Action
    FFGenerateTextFromImage_Image
    FFGivenTestStep_Precondition
    FFGoogleMap_LegacyMarkerSource
    FFGoogleMap_MarkerSource
    FFGoogleMapAction_ActionType
    FFGoogleNavBarItem_Color
    FFIconDataValue_Value
    FFIconValue_Value
    FFIntegerValue_Value
    FFInteractionTestStep_Interaction
    FFLatLngValue_Value
    FFLibraryValue_ValueType
    FFLineChartLine_Fill
    FFLoadingWidget_Widget
    FFLocalStateFieldUpdate_Update
    FFLocalStateUpdate_Update
    FFLoopAction_LoopGuard
    FFMapLauncherAction_Type
    FFOneSignalAction_Action
    FFParameter_ParameterType
    FFParameter_Specifier
    FFParameterPass_Value
    FFParameterValue_Value
    FFParamReducer_Reducer
    FFPassedParameters_Name
    FFPermissionsSettings_UserDefinedPermission_Identifier
    FFPlaySound_Audio
    FFPostgresAction_Action
    FFProject_DesignSystem
    FFPropertyParameterPass_Props
    FFPullToRefreshStyle_Style
    FFRandomData_Type
    FFRevenueCatAction_Action
    FFRevenueCatOperation_Type
    FFSearchReference_Identifier
    FFSetAppLanguageAction_LanguageSource
    FFSetDarkModeSetting_SettingSource
    FFShaderParam_ParamValue
    FFSimpleSearchAction_From
    FFSQLiteInitializationConfig_Init
    FFStringValue_Value
    FFSubType_Specifier
    FFTestFinder_Finder
    FFTestStep_Step
    FFText_Decoration
    FFTextAlignValue_Value
    FFTextInputValidation_RegexValidator
    FFTextStyleValue_Value
    FFTheme_Typography
    FFThenTestStep_Step
    FFTooltip_Widget
    FFTransform_Transform
    FFTriggerPushNotification_Recipients
    FFUpdateTextScalingFactorAction_Update
    FFUploadDataAction_Config
    FFValue_Value
    FFVariable_LegacyType
    FFVariable_Type
    FFVariableOperation_Operation
    FFWalkthroughAction_Action
    FFWhenTestStep_Step
    FFWidgetBuilderSource_Source
    FFWidgetProperties_Props
    PackageIcon_Package

    Extensions

    GeneratedMessageGenericExtensions on T
    Extensions on GeneratedMessages.