fileAsset property
@doc The file asset to pass to the agent.
Implementation
@$pb.TagNumber(8)
FFVariable get fileAsset => $_getN(7);
Implementation
@$pb.TagNumber(8)
set fileAsset(FFVariable value) => $_setField(8, value);
@doc The file asset to pass to the agent.
@$pb.TagNumber(8)
FFVariable get fileAsset => $_getN(7);
@$pb.TagNumber(8)
set fileAsset(FFVariable value) => $_setField(8, value);