requestDataStructs property
@doc The request data structs to pass to the agent.
Implementation
@$pb.TagNumber(10)
$pb.PbList<FFParameter> get requestDataStructs => $_getList(9);
@doc The request data structs to pass to the agent.
@$pb.TagNumber(10)
$pb.PbList<FFParameter> get requestDataStructs => $_getList(9);