nonBlocking property
@doc When toggled off, this action will be "awaited", which means that subsequent actions will not execute until this one is complete. Enabling "Non-Blocking" removes this await, so future actions happen directly after.
Implementation
@$pb.TagNumber(80)
$core.bool get nonBlocking => $_getBF(79);