outputVariableName property
@doc The name of the output variable that will be set by this action.
Implementation
@$pb.TagNumber(27)
$core.String get outputVariableName => $_getSZ(26);
@doc The name of the output variable that will be set by this action.
@$pb.TagNumber(27)
$core.String get outputVariableName => $_getSZ(26);