actions property
@doc The action chain encapsulated by this action block.
Implementation
@$pb.TagNumber(3)
FFTriggerActions get actions => $_getN(2);
Implementation
@$pb.TagNumber(3)
set actions(FFTriggerActions value) => $_setField(3, value);
@doc The action chain encapsulated by this action block.
@$pb.TagNumber(3)
FFTriggerActions get actions => $_getN(2);
@$pb.TagNumber(3)
set actions(FFTriggerActions value) => $_setField(3, value);