actionComponents property
@doc The list of action components defined within a certain scope.
Implementation
@$pb.TagNumber(1)
$pb.PbList<FFActionComponent> get actionComponents => $_getList(0);
@doc The list of action components defined within a certain scope.
@$pb.TagNumber(1)
$pb.PbList<FFActionComponent> get actionComponents => $_getList(0);