FFActionNode class

Inheritance
Available extensions

Constructors

FFActionNode({String? key, FFAction? action, FFConditionActions? conditionActions, FFTerminateAction? terminate, FFActionNode? followUpAction, FFAnnotations? annotations, FFLoopAction? loopAction, FFLoopBreakAction? loopBreak, FFParallelActions? parallelActions})
factory
FFActionNode.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFActionNode.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

action FFAction
@doc The actual action configured by this action node.
getter/setter pair
annotations FFAnnotations
getter/setter pair
conditionActions FFConditionActions
@doc Conditions with true or false actions. If action is unset this @doc makes this action act as solely a conditional block.
getter/setter pair
followUpAction FFActionNode
@doc A subsequent action node performed after this action.
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ BuilderInfo
no setteroverride
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
key String
@doc Unique identifier for this specific action node.
getter/setter pair
loopAction FFLoopAction
@doc Loops while loop guard evaluates to true or over a list.
getter/setter pair
loopBreak FFLoopBreakAction
@doc Allows breaking out of a loop.
getter/setter pair
parallelActions FFParallelActions
@doc Allows parallel actions.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminate FFTerminateAction
@doc Demarcates a return statement, ending the action if it reaches this node. No follow_up_action can be specified in this case.
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAction() → void
clearActionType() → void
clearAnnotations() → void
clearConditionActions() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFollowUpAction() → void
clearKey() → void
clearLoopAction() → void
clearLoopBreak() → void
clearParallelActions() → void
clearTerminate() → void
clone() FFActionNode
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFActionNode)) FFActionNode
Apply updates to a copy of this message.
override
createEmptyInstance() FFActionNode
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAction() FFAction
ensureAnnotations() FFAnnotations
ensureConditionActions() FFConditionActions
ensureFollowUpAction() FFActionNode
ensureLoopAction() FFLoopAction
ensureLoopBreak() FFLoopBreakAction
ensureParallelActions() FFParallelActions
ensureTerminate() FFTerminateAction
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAction() bool
hasAnnotations() bool
hasConditionActions() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFollowUpAction() bool
hasKey() bool
hasLoopAction() bool
hasLoopBreak() bool
hasParallelActions() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasTerminate() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
whichActionType() FFActionNode_ActionType
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFActionNode
getDefault() FFActionNode