isGlobalActionComponent property
@doc whether the selected action component is global or not
Implementation
@$pb.TagNumber(3)
$core.bool get isGlobalActionComponent => $_getBF(2);
@doc whether the selected action component is global or not
@$pb.TagNumber(3)
$core.bool get isGlobalActionComponent => $_getBF(2);