maxInstances property
@doc The maximum number of instances allowed to run.
Implementation
@$pb.TagNumber(6)
$core.int get maxInstances => $_getIZ(5);
@doc The maximum number of instances allowed to run.
@$pb.TagNumber(6)
$core.int get maxInstances => $_getIZ(5);