requireAuthentication property
@doc Whether to require users to be authenticated with Firebase to execute.
Implementation
@$pb.TagNumber(4)
$core.bool get requireAuthentication => $_getBF(3);
@doc Whether to require users to be authenticated with Firebase to execute.
@$pb.TagNumber(4)
$core.bool get requireAuthentication => $_getBF(3);