useLegacyCache property
@doc If enabled, the same search query will always return the same results.
Implementation
@$pb.TagNumber(7)
$core.bool get useLegacyCache => $_getBF(6);
@doc If enabled, the same search query will always return the same results.
@$pb.TagNumber(7)
$core.bool get useLegacyCache => $_getBF(6);