animatedOpacityIsEnabled property
Not overridable @doc Whether to animate the change in opacity of the widget.
Implementation
@$pb.TagNumber(1)
$core.bool get animatedOpacityIsEnabled => $_getBF(0);
Not overridable @doc Whether to animate the change in opacity of the widget.
@$pb.TagNumber(1)
$core.bool get animatedOpacityIsEnabled => $_getBF(0);