animatedPaddingIsEnabled property
Not overridable @doc Whether to animate the change in padding of the widget.
Implementation
@$pb.TagNumber(1)
$core.bool get animatedPaddingIsEnabled => $_getBF(0);
Not overridable @doc Whether to animate the change in padding of the widget.
@$pb.TagNumber(1)
$core.bool get animatedPaddingIsEnabled => $_getBF(0);