applyInitialState property
@doc Whether to apply the initial state before animating.
Implementation
@$pb.TagNumber(14)
$core.bool get applyInitialState => $_getBF(13);
@doc Whether to apply the initial state before animating.
@$pb.TagNumber(14)
$core.bool get applyInitialState => $_getBF(13);