useSameInterval property
@doc Whether to use the same interval for all effects.
Implementation
@$pb.TagNumber(13)
$core.bool get useSameInterval => $_getBF(12);
@doc Whether to use the same interval for all effects.
@$pb.TagNumber(13)
$core.bool get useSameInterval => $_getBF(12);