privateApiMaxInstances property
@doc Set the max instances for a private api deployed as a cloud function.
Implementation
@$pb.TagNumber(15)
$core.int get privateApiMaxInstances => $_getIZ(6);
@doc Set the max instances for a private api deployed as a cloud function.
@$pb.TagNumber(15)
$core.int get privateApiMaxInstances => $_getIZ(6);