FFApiEndpoint class

Inheritance
Available extensions

Constructors

FFApiEndpoint({FFIdentifier? identifier, String? url, FFApiEndpoint_CallType? callType, Iterable<FFApiValue>? variables, @Deprecated('This field is deprecated.') FFApiResponseType? legacyResponse, @Deprecated('This field is deprecated.') Iterable<FFApiValue>? legacyHeaders, FFApiEndpoint_BodyType? bodyType, String? body, Iterable<FFJsonPathDefinition>? jsonPathDefinitions, FFEditMetadata? editMetadata, Iterable<String>? headers, FFIdentifier? groupIdentifier, FFApiEndpointSettings? endpointSettings, Iterable<FFApiParameter>? parameters, FFTeamResourceInfo? teamResourceInfo, FFParameter? responseDataStructParam})
factory
FFApiEndpoint.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFApiEndpoint.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

body String
@doc The body of the API request.
getter/setter pair
bodyType FFApiEndpoint_BodyType
@doc The type of the body of the request.
getter/setter pair
callType FFApiEndpoint_CallType
@doc The API request method.
getter/setter pair
editMetadata FFEditMetadata
getter/setter pair
endpointSettings FFApiEndpointSettings
  • getter/setter pair
    groupIdentifier FFIdentifier
    Back-reference to the API Group if this call is a member of one. @doc The unique identifier of the API Group containing the endpoint.
    getter/setter pair
    hashCode int
    Calculates a hash code based on the contents of the protobuf.
    no setterinherited
    headers PbList<String>
    Excludes any headers shared by API group.
    no setter
    identifier FFIdentifier
    @doc The unique identifier of the endpoint.
    getter/setter pair
    info_ BuilderInfo
    no setteroverride
    isFrozen bool
    Returns true if this message is marked read-only. Otherwise false.
    no setterinherited
    jsonPathDefinitions PbList<FFJsonPathDefinition>
    @doc The JSON path definitions for the response.
    no setter
    legacyHeaders PbList<FFApiValue>
    Headers are now one string, old ones are deprecated
    no setter
    legacyResponse FFApiResponseType
    Deprecated
    getter/setter pair
    parameters PbList<FFApiParameter>
    @doc Stores either query parameters or x-www-form-urlencoded parameters.
    no setter
    responseDataStructParam FFParameter
    @doc If set, the response can be parsed into the corresponding data struct. This should only be set to data struct. Just using FFParameter to allow also setting it to a list.
    getter/setter pair
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited
    teamResourceInfo FFTeamResourceInfo
  • getter/setter pair
    unknownFields UnknownFieldSet
    no setterinherited
    url String
  • getter/setter pair
    variables PbList<FFApiValue>
    @doc Variables that can be plugged in to defined parameters.
    no setter

    Methods

    addExtension(Extension extension, Object? value) → void
    Adds an extension field value to a repeated field.
    inherited
    check() → void
    Throws a StateError if the message has required fields without a value.
    inherited
    clear() → void
    Clears all data that was set in this message.
    inherited
    clearBody() → void
    clearBodyType() → void
    clearCallType() → void
    clearEditMetadata() → void
    clearEndpointSettings() → void
    clearExtension(Extension extension) → void
    Clears an extension field and also removes the extension.
    inherited
    clearField(int tagNumber) → void
    Clears the contents of a given field.
    inherited
    clearGroupIdentifier() → void
    clearIdentifier() → void
    clearLegacyResponse() → void
    clearResponseDataStructParam() → void
    clearTeamResourceInfo() → void
    clearUrl() → void
    clone() FFApiEndpoint
    Creates a deep copy of the fields in this message.
    override
    copyWith(void updates(FFApiEndpoint)) FFApiEndpoint
    Apply updates to a copy of this message.
    override
    createEmptyInstance() FFApiEndpoint
    Creates an empty instance of the same message type as this.
    override
    deepCopy() → T

    Available on T, provided by the GeneratedMessageGenericExtensions extension

    Returns a writable deep copy of this message.
    ensureEditMetadata() FFEditMetadata
    ensureEndpointSettings() FFApiEndpointSettings
    ensureGroupIdentifier() FFIdentifier
    ensureIdentifier() FFIdentifier
    ensureResponseDataStructParam() FFParameter
    ensureTeamResourceInfo() FFTeamResourceInfo
    extensionsAreInitialized() bool
    inherited
    freeze() GeneratedMessage
    Make this message read-only.
    inherited
    fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

    Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

    fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

    Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

    getDefaultForField(int tagNumber) → dynamic
    Returns the default value for the given field.
    inherited
    getExtension(Extension extension) → dynamic
    Returns the value of extension.
    inherited
    getField(int tagNumber) → dynamic
    Returns the value of the field associated with tagNumber, or the default value if it is not set.
    inherited
    getFieldOrNull(int tagNumber) → dynamic
    Returns the value of a field, ignoring any defaults.
    inherited
    getTagNumber(String fieldName) int?
    inherited
    hasBody() bool
    hasBodyType() bool
    hasCallType() bool
    hasEditMetadata() bool
    hasEndpointSettings() bool
    hasExtension(Extension extension) bool
    Returns true if a value of extension is present.
    inherited
    hasField(int tagNumber) bool
    Whether this message has a field associated with tagNumber.
    inherited
    hasGroupIdentifier() bool
    hasIdentifier() bool
    hasLegacyResponse() bool
    hasRequiredFields() bool
    Whether the message has required fields.
    inherited
    hasResponseDataStructParam() bool
    hasTeamResourceInfo() bool
    hasUrl() bool
    isInitialized() bool
    Whether all required fields in the message and embedded messages are set.
    inherited
    mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Merges serialized protocol buffer data into this message.
    inherited
    mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Same as mergeFromBuffer, but takes a CodedBufferReader input.
    inherited
    mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
    inherited
    mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Merges field values from a JSON object represented as a Dart map.
    inherited
    mergeFromMessage(GeneratedMessage other) → void
    Merges the contents of the other into this message.
    inherited
    mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
    Merges field values from json, a JSON object using proto3 encoding.
    inherited
    mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
    inherited
    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    rebuild(void updates(T)) → T

    Available on T, provided by the GeneratedMessageGenericExtensions extension

    Apply updates to a copy of this message.
    setExtension(Extension extension, Object value) → void
    Sets the value of a non-repeated extension field to value.
    inherited
    setField(int tagNumber, Object value) → void
    Sets the value of a field by its tagNumber.
    inherited
    toBuilder() GeneratedMessage
    Creates a writable, shallow copy of this message.
    inherited
    toDebugString() String
    Returns a String representation of this message.
    inherited
    toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
    Returns an Object representing Proto3 JSON serialization of this.
    inherited
    toString() String
    Returns a String representation of this message.
    inherited
    toTextFormat() String

    Available on GeneratedMessage, provided by the TextFormatExtension extension

    Returns a TextFormat String representation of this message.
    writeTextFormat(StringSink sink) → void

    Available on GeneratedMessage, provided by the TextFormatExtension extension

    Writes a TextFormat String representation of this message to sink.
    writeToBuffer() Uint8List
    Serialize the message as the protobuf binary format.
    inherited
    writeToCodedBufferWriter(CodedBufferWriter output) → void
    Same as writeToBuffer, but serializes to the given CodedBufferWriter.
    inherited
    writeToJson() String
    Returns a JSON string that encodes this message.
    inherited
    writeToJsonMap() Map<String, dynamic>
    Returns the JSON encoding of this message as a Dart Map.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited

    Static Methods

    create() FFApiEndpoint
    getDefault() FFApiEndpoint