variables property
@doc Variables that can be plugged in to defined parameters.
Implementation
@$pb.TagNumber(4)
$pb.PbList<FFApiValue> get variables => $_getList(3);
@doc Variables that can be plugged in to defined parameters.
@$pb.TagNumber(4)
$pb.PbList<FFApiValue> get variables => $_getList(3);