FFApiEndpointSettings class

Inheritance
Available extensions

Constructors

FFApiEndpointSettings({bool? noProxyForTest, bool? noProxyForWeb, String? proxyPrefixUrl, bool? isPrivateApi, bool? requireAuthentication, bool? cached, bool? decodeUtf8, bool? encodeBodyUtf8, SslPinningConfig? sslPinningConfig, bool? alwaysAllowBody, Iterable<FFApiEndpointSettings_Interceptor>? interceptors, bool? isStreamingApi, bool? escapeVariablesInRequestBody, bool? withCredentials})
factory
FFApiEndpointSettings.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFApiEndpointSettings.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

alwaysAllowBody bool
It's bad practice to have body payloads for GET and DELETE endpoints, but some users need this supported. @doc Whether to always allow body payloads, even for GET & DELETE requests.
getter/setter pair
cached bool
  • getter/setter pair
    decodeUtf8 bool
    @doc Whether to force-decode response as UTF-8. This is a common need as not all APIs return the correct header to allow Dart to natively decode as UTF-8.
    getter/setter pair
    encodeBodyUtf8 bool
    @doc Whether to encode the body as UTF-8 bytes. Some APIs (such as MongoDB) require this in order to function properly.
    getter/setter pair
    escapeVariablesInRequestBody bool
    Set to true to escape variables in the body of the request.
    getter/setter pair
    hashCode int
    Calculates a hash code based on the contents of the protobuf.
    no setterinherited
    info_ BuilderInfo
    no setteroverride
    interceptors PbList<FFApiEndpointSettings_Interceptor>
    List interceptors for this API endpoint. @doc Either the interceptor name or the action identifier must be set.
    no setter
    isFrozen bool
    Returns true if this message is marked read-only. Otherwise false.
    no setterinherited
    isPrivateApi bool
    @doc If true, will deploy a Cloud Function that will make the call @doc directly, allowing sensitive keys to be used here.
    getter/setter pair
    isStreamingApi bool
  • getter/setter pair
    noProxyForTest bool
    Not configurable if part of an API Group (will use the group's prefix). @doc If false, does not use the proxy_prefix_url in testing.
    getter/setter pair
    noProxyForWeb bool
    @doc If false, does not use the proxy_prefix_url or web, respectively.
    getter/setter pair
    proxyPrefixUrl String
    @doc The proxy URL to use for the API call. If a proxy URL is not @doc specified, uses FlutterFlow's default Heroku proxy.
    getter/setter pair
    requireAuthentication bool
    @doc Requires user to be authenticated in order to make call.
    getter/setter pair
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited
    sslPinningConfig SslPinningConfig
    @doc SSL pinning configuration.
    getter/setter pair
    unknownFields UnknownFieldSet
    no setterinherited
    withCredentials bool
    @doc Whether to include credentials (cookies, authorization headers, TLS client certificates) in the request.
    getter/setter pair

    Methods

    addExtension(Extension extension, Object? value) → void
    Adds an extension field value to a repeated field.
    inherited
    check() → void
    Throws a StateError if the message has required fields without a value.
    inherited
    clear() → void
    Clears all data that was set in this message.
    inherited
    clearAlwaysAllowBody() → void
    clearCached() → void
    clearDecodeUtf8() → void
    clearEncodeBodyUtf8() → void
    clearEscapeVariablesInRequestBody() → void
    clearExtension(Extension extension) → void
    Clears an extension field and also removes the extension.
    inherited
    clearField(int tagNumber) → void
    Clears the contents of a given field.
    inherited
    clearIsPrivateApi() → void
    clearIsStreamingApi() → void
    clearNoProxyForTest() → void
    clearNoProxyForWeb() → void
    clearProxyPrefixUrl() → void
    clearRequireAuthentication() → void
    clearSslPinningConfig() → void
    clearWithCredentials() → void
    clone() FFApiEndpointSettings
    Creates a deep copy of the fields in this message.
    override
    copyWith(void updates(FFApiEndpointSettings)) FFApiEndpointSettings
    Apply updates to a copy of this message.
    override
    createEmptyInstance() FFApiEndpointSettings
    Creates an empty instance of the same message type as this.
    override
    deepCopy() → T

    Available on T, provided by the GeneratedMessageGenericExtensions extension

    Returns a writable deep copy of this message.
    ensureSslPinningConfig() SslPinningConfig
    extensionsAreInitialized() bool
    inherited
    freeze() GeneratedMessage
    Make this message read-only.
    inherited
    fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

    Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

    fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

    Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

    getDefaultForField(int tagNumber) → dynamic
    Returns the default value for the given field.
    inherited
    getExtension(Extension extension) → dynamic
    Returns the value of extension.
    inherited
    getField(int tagNumber) → dynamic
    Returns the value of the field associated with tagNumber, or the default value if it is not set.
    inherited
    getFieldOrNull(int tagNumber) → dynamic
    Returns the value of a field, ignoring any defaults.
    inherited
    getTagNumber(String fieldName) int?
    inherited
    hasAlwaysAllowBody() bool
    hasCached() bool
    hasDecodeUtf8() bool
    hasEncodeBodyUtf8() bool
    hasEscapeVariablesInRequestBody() bool
    hasExtension(Extension extension) bool
    Returns true if a value of extension is present.
    inherited
    hasField(int tagNumber) bool
    Whether this message has a field associated with tagNumber.
    inherited
    hasIsPrivateApi() bool
    hasIsStreamingApi() bool
    hasNoProxyForTest() bool
    hasNoProxyForWeb() bool
    hasProxyPrefixUrl() bool
    hasRequireAuthentication() bool
    hasRequiredFields() bool
    Whether the message has required fields.
    inherited
    hasSslPinningConfig() bool
    hasWithCredentials() bool
    isInitialized() bool
    Whether all required fields in the message and embedded messages are set.
    inherited
    mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Merges serialized protocol buffer data into this message.
    inherited
    mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Same as mergeFromBuffer, but takes a CodedBufferReader input.
    inherited
    mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
    inherited
    mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Merges field values from a JSON object represented as a Dart map.
    inherited
    mergeFromMessage(GeneratedMessage other) → void
    Merges the contents of the other into this message.
    inherited
    mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
    Merges field values from json, a JSON object using proto3 encoding.
    inherited
    mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
    inherited
    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    rebuild(void updates(T)) → T

    Available on T, provided by the GeneratedMessageGenericExtensions extension

    Apply updates to a copy of this message.
    setExtension(Extension extension, Object value) → void
    Sets the value of a non-repeated extension field to value.
    inherited
    setField(int tagNumber, Object value) → void
    Sets the value of a field by its tagNumber.
    inherited
    toBuilder() GeneratedMessage
    Creates a writable, shallow copy of this message.
    inherited
    toDebugString() String
    Returns a String representation of this message.
    inherited
    toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
    Returns an Object representing Proto3 JSON serialization of this.
    inherited
    toString() String
    Returns a String representation of this message.
    inherited
    toTextFormat() String

    Available on GeneratedMessage, provided by the TextFormatExtension extension

    Returns a TextFormat String representation of this message.
    writeTextFormat(StringSink sink) → void

    Available on GeneratedMessage, provided by the TextFormatExtension extension

    Writes a TextFormat String representation of this message to sink.
    writeToBuffer() Uint8List
    Serialize the message as the protobuf binary format.
    inherited
    writeToCodedBufferWriter(CodedBufferWriter output) → void
    Same as writeToBuffer, but serializes to the given CodedBufferWriter.
    inherited
    writeToJson() String
    Returns a JSON string that encodes this message.
    inherited
    writeToJsonMap() Map<String, dynamic>
    Returns the JSON encoding of this message as a Dart Map.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited