cached property

  1. @TagNumber(6)
bool get cached

@doc By default, the result of the API call will not be cached. By turning this on, you can ensure that during a single run of the app, multiple calls to this endpoint with the same arguments will be cached.

Implementation

@$pb.TagNumber(6)
$core.bool get cached => $_getBF(5);
  1. @TagNumber(6)
set cached (bool value)

Implementation

@$pb.TagNumber(6)
set cached($core.bool value) => $_setBool(5, value);