decodeUtf8 property
@doc Whether to force-decode response as UTF-8. This is a common need as not all APIs return the correct header to allow Dart to natively decode as UTF-8.
Implementation
@$pb.TagNumber(7)
$core.bool get decodeUtf8 => $_getBF(6);
@doc Whether to force-decode response as UTF-8. This is a common need as not all APIs return the correct header to allow Dart to natively decode as UTF-8.
@$pb.TagNumber(7)
$core.bool get decodeUtf8 => $_getBF(6);