escapeVariablesInRequestBody property
Set to true to escape variables in the body of the request.
Implementation
@$pb.TagNumber(13)
$core.bool get escapeVariablesInRequestBody => $_getBF(12);
Set to true to escape variables in the body of the request.
@$pb.TagNumber(13)
$core.bool get escapeVariablesInRequestBody => $_getBF(12);