isPrivateApi property
@doc If true, will deploy a Cloud Function that will make the call @doc directly, allowing sensitive keys to be used here.
Implementation
@$pb.TagNumber(4)
$core.bool get isPrivateApi => $_getBF(3);
@doc If true, will deploy a Cloud Function that will make the call @doc directly, allowing sensitive keys to be used here.
@$pb.TagNumber(4)
$core.bool get isPrivateApi => $_getBF(3);