isStreamingApi property
@doc Set to true if this endpoint is configured to return responses to a stream. This will allow API calls to define callback actions to process the response stream.
Implementation
@$pb.TagNumber(12)
$core.bool get isStreamingApi => $_getBF(11);