requireAuthentication property
@doc Requires user to be authenticated in order to make call.
Implementation
@$pb.TagNumber(5)
$core.bool get requireAuthentication => $_getBF(4);
@doc Requires user to be authenticated in order to make call.
@$pb.TagNumber(5)
$core.bool get requireAuthentication => $_getBF(4);