createEmptyInstance method

  1. @override
FFApiValue createEmptyInstance()
override

Creates an empty instance of the same message type as this.

This method is useful when you have a value of type GeneratedMessage or T extends GeneratedMessage and you want a new empty message with the same message type as the value. If you know the actual message type, it's more direct to use the constructor, and this method creates the same message as the message's constructor.

Implementation

@$core.override
FFApiValue createEmptyInstance() => create();