testValue property
@doc The value to assign when testing the endpoint (within Flutterflow).
Implementation
@$pb.TagNumber(4)
$core.String get testValue => $_getSZ(3);
@doc The value to assign when testing the endpoint (within Flutterflow).
@$pb.TagNumber(4)
$core.String get testValue => $_getSZ(3);