FFAppBar class

Inheritance
Available extensions

Constructors

FFAppBar({@Deprecated('This field is deprecated.') FFText? title, bool? legacyDefaultBackButton, @Deprecated('This field is deprecated.') Int64? legacyLegacyBackgroundColor, @Deprecated('This field is deprecated.') FFIcon? legacyLeadingIcon, @Deprecated('This field is deprecated.') FFIcon? legacyTrailingIcon, @Deprecated('This field is deprecated.') double? legacyLeadingIconPadding, @Deprecated('This field is deprecated.') double? legacyTrailingIconPadding, @Deprecated('This field is deprecated.') bool? legacyShow, FFColor? legacyBackgroundColor, double? legacyElevation, bool? legacyCenterTitle, FFColor? legacyBackButtonColor, FFDim? height, FFAppBar_TemplateType? templateType, FFDim? toolbarHeight, FFDim? bottomHeight, bool? isSliver, FFDim? expandedHeight, FFDim? collapsedHeight, bool? legacyPinned, bool? floating, FFPadding? titlePadding, bool? titleInFlexibleSpaceBar, bool? legacySnap, FFBooleanValue? defaultBackButtonValue, FFColorValue? backButtonColorValue, FFColorValue? backgroundColorValue, FFDoubleValue? elevationValue, FFBooleanValue? centerTitleValue, FFBooleanValue? pinnedValue, FFBooleanValue? snapValue})
factory
FFAppBar.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFAppBar.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

backButtonColorValue FFColorValue
getter/setter pair
backgroundColorValue FFColorValue
getter/setter pair
bottomHeight FFDim
getter/setter pair
centerTitleValue FFBooleanValue
getter/setter pair
collapsedHeight FFDim
getter/setter pair
defaultBackButtonValue FFBooleanValue
getter/setter pair
elevationValue FFDoubleValue
getter/setter pair
expandedHeight FFDim
getter/setter pair
floating bool
Not overridable
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
height FFDim
getter/setter pair
info_ BuilderInfo
no setteroverride
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isSliver bool
Not overridable
getter/setter pair
legacyBackButtonColor FFColor
getter/setter pair
legacyBackgroundColor FFColor
getter/setter pair
legacyCenterTitle bool
getter/setter pair
legacyDefaultBackButton bool
getter/setter pair
legacyElevation double
getter/setter pair
legacyLeadingIcon FFIcon
getter/setter pair
legacyLeadingIconPadding double
getter/setter pair
legacyLegacyBackgroundColor ↔ Int64
getter/setter pair
legacyPinned bool
getter/setter pair
legacyShow bool
getter/setter pair
legacySnap bool
getter/setter pair
legacyTrailingIcon FFIcon
getter/setter pair
legacyTrailingIconPadding double
getter/setter pair
pinnedValue FFBooleanValue
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapValue FFBooleanValue
getter/setter pair
templateType FFAppBar_TemplateType
getter/setter pair
title FFText
getter/setter pair
titleInFlexibleSpaceBar bool
Not overridable
getter/setter pair
titlePadding FFPadding
getter/setter pair
toolbarHeight FFDim
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBackButtonColorValue() → void
clearBackgroundColorValue() → void
clearBottomHeight() → void
clearCenterTitleValue() → void
clearCollapsedHeight() → void
clearDefaultBackButtonValue() → void
clearElevationValue() → void
clearExpandedHeight() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFloating() → void
clearHeight() → void
clearIsSliver() → void
clearLegacyBackButtonColor() → void
clearLegacyBackgroundColor() → void
clearLegacyCenterTitle() → void
clearLegacyDefaultBackButton() → void
clearLegacyElevation() → void
clearLegacyLeadingIcon() → void
clearLegacyLeadingIconPadding() → void
clearLegacyLegacyBackgroundColor() → void
clearLegacyPinned() → void
clearLegacyShow() → void
clearLegacySnap() → void
clearLegacyTrailingIcon() → void
clearLegacyTrailingIconPadding() → void
clearPinnedValue() → void
clearSnapValue() → void
clearTemplateType() → void
clearTitle() → void
clearTitleInFlexibleSpaceBar() → void
clearTitlePadding() → void
clearToolbarHeight() → void
clone() FFAppBar
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFAppBar)) FFAppBar
Apply updates to a copy of this message.
override
createEmptyInstance() FFAppBar
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureBackButtonColorValue() FFColorValue
ensureBackgroundColorValue() FFColorValue
ensureBottomHeight() FFDim
ensureCenterTitleValue() FFBooleanValue
ensureCollapsedHeight() FFDim
ensureDefaultBackButtonValue() FFBooleanValue
ensureElevationValue() FFDoubleValue
ensureExpandedHeight() FFDim
ensureHeight() FFDim
ensureLegacyBackButtonColor() FFColor
ensureLegacyBackgroundColor() FFColor
ensureLegacyLeadingIcon() FFIcon
ensureLegacyTrailingIcon() FFIcon
ensurePinnedValue() FFBooleanValue
ensureSnapValue() FFBooleanValue
ensureTitle() FFText
ensureTitlePadding() FFPadding
ensureToolbarHeight() FFDim
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasBackButtonColorValue() bool
hasBackgroundColorValue() bool
hasBottomHeight() bool
hasCenterTitleValue() bool
hasCollapsedHeight() bool
hasDefaultBackButtonValue() bool
hasElevationValue() bool
hasExpandedHeight() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFloating() bool
hasHeight() bool
hasIsSliver() bool
hasLegacyBackButtonColor() bool
hasLegacyBackgroundColor() bool
hasLegacyCenterTitle() bool
hasLegacyDefaultBackButton() bool
hasLegacyElevation() bool
hasLegacyLeadingIcon() bool
hasLegacyLeadingIconPadding() bool
hasLegacyLegacyBackgroundColor() bool
hasLegacyPinned() bool
hasLegacyShow() bool
hasLegacySnap() bool
hasLegacyTrailingIcon() bool
hasLegacyTrailingIconPadding() bool
hasPinnedValue() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSnapValue() bool
hasTemplateType() bool
hasTitle() bool
hasTitleInFlexibleSpaceBar() bool
hasTitlePadding() bool
hasToolbarHeight() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFAppBar
getDefault() FFAppBar