serializedValue property

  1. @TagNumber(2)
PbList<String> get serializedValue

@doc This will be populated if there is a default value. Note that only the first value is set if parameter is not a list.

Implementation

@$pb.TagNumber(2)
$pb.PbList<$core.String> get serializedValue => $_getList(1);