fields property
@doc The list of constants defined for the project.
Implementation
@$pb.TagNumber(2)
$pb.PbList<FFAppConstantField> get fields => $_getList(1);
@doc The list of constants defined for the project.
@$pb.TagNumber(2)
$pb.PbList<FFAppConstantField> get fields => $_getList(1);