fields property
@doc The list of app state variables defined for the project.
Implementation
@$pb.TagNumber(1)
$pb.PbList<FFAppStateField> get fields => $_getList(0);
@doc The list of app state variables defined for the project.
@$pb.TagNumber(1)
$pb.PbList<FFAppStateField> get fields => $_getList(0);