securePersistedValues property
@doc Enable encrypted local storage for persisted app state fields. Note: This only secures storage - values are exposed during network requests and should not contain API keys or secrets.
Implementation
@$pb.TagNumber(3)
$core.bool get securePersistedValues => $_getBF(2);