persisted property
@doc Whether this app state variable is saved to disk so that it can be loaded when the app is restarted. Otherwise the field will be reset on restart.
Implementation
@$pb.TagNumber(2)
$core.bool get persisted => $_getBF(1);
@doc Whether this app state variable is saved to disk so that it can be loaded when the app is restarted. Otherwise the field will be reset on restart.
@$pb.TagNumber(2)
$core.bool get persisted => $_getBF(1);