serializedDefaultValue property

  1. @TagNumber(3)
PbList<String> get serializedDefaultValue

@doc This will be populated if there is a default value. Note that only the first value will be set if parameter is not a list.

Implementation

@$pb.TagNumber(3)
$pb.PbList<$core.String> get serializedDefaultValue => $_getList(2);