FFAuthAction class

Inheritance
Available extensions

Constructors

FFAuthAction({FFAuthAction_ActionType? type, FFAuthProvider? provider, @Deprecated('This field is deprecated.') String? legacyEmailFieldKey, @Deprecated('This field is deprecated.') String? legacyPasswordFieldKey, @Deprecated('This field is deprecated.') String? legacyConfirmPasswordFieldKey, @Deprecated('This field is deprecated.') String? phoneFieldKey, @Deprecated('This field is deprecated.') String? legacySmsCodeVerifyPageName, @Deprecated('This field is deprecated.') String? smsCodeFieldKey, MicrosoftAuthSettings? microsoftAuthSettings, FFVariable? phoneVariable, FFVariable? smsCodeVariable, FFPassedParameters? verifySmsCodePassedParameters, FFVariable? jwtTokenVariable, FFVariable? emailVariable, FFVariable? passwordVariable, FFVariable? confirmPasswordVariable, @Deprecated('This field is deprecated.') String? legacySmsCodeVerifyPageNodeKey, FFCustomAuthFields? customAuthFields, FFNodeKeyReference? emailFieldKeyRef, FFNodeKeyReference? passwordFieldKeyRef, FFNodeKeyReference? confirmPasswordFieldKeyRef, FFNodeKeyReference? smsCodeVerifyPageNodeKeyRef, bool? disableAutoNavigate, String? redirectUrl})
factory
FFAuthAction.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFAuthAction.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

confirmPasswordFieldKeyRef FFNodeKeyReference
@doc The key of the confirm password field widget.
getter/setter pair
confirmPasswordVariable FFVariable
@doc The variable representing the confirm password.
getter/setter pair
customAuthFields FFCustomAuthFields
@doc Token and user data properties for custom auth.
getter/setter pair
disableAutoNavigate bool
  • getter/setter pair
    emailFieldKeyRef FFNodeKeyReference
    @doc The key of the email field widget.
    getter/setter pair
    emailVariable FFVariable
    @doc The variable representing the email.
    getter/setter pair
    hashCode int
    Calculates a hash code based on the contents of the protobuf.
    no setterinherited
    info_ BuilderInfo
    no setteroverride
    isFrozen bool
    Returns true if this message is marked read-only. Otherwise false.
    no setterinherited
    jwtTokenVariable FFVariable
    @doc The variable representing the JWT token.
    getter/setter pair
    legacyConfirmPasswordFieldKey String
    getter/setter pair
    legacyEmailFieldKey String
    getter/setter pair
    legacyPasswordFieldKey String
    getter/setter pair
    legacySmsCodeVerifyPageName String
    getter/setter pair
    legacySmsCodeVerifyPageNodeKey String
    getter/setter pair
    microsoftAuthSettings MicrosoftAuthSettings
    @doc The Microsoft Authentication Settings. Set if provider is MICROSOFT.
    getter/setter pair
    passwordFieldKeyRef FFNodeKeyReference
    @doc The key of the password field widget.
    getter/setter pair
    passwordVariable FFVariable
    @doc The variable representing the password.
    getter/setter pair
    phoneFieldKey String
    ActionType: PHONE_SIGN_IN
    getter/setter pair
    phoneVariable FFVariable
    @doc The key of the phone number widget.
    getter/setter pair
    provider FFAuthProvider
    @doc The authentication provider to use.
    getter/setter pair
    redirectUrl String
    @doc Redirect URL for Supabase magic link and password reset.
    getter/setter pair
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited
    smsCodeFieldKey String
    ActionType: VERIFY_SMS_CODE
    getter/setter pair
    smsCodeVariable FFVariable
    @doc The key of the SMS code widget.
    getter/setter pair
    smsCodeVerifyPageNodeKeyRef FFNodeKeyReference
    @doc The node key of the page to navigate to for SMS code verification.
    getter/setter pair
    type FFAuthAction_ActionType
    @doc The type of authentication action to perform.
    getter/setter pair
    unknownFields UnknownFieldSet
    no setterinherited
    verifySmsCodePassedParameters FFPassedParameters
    @doc Parameters to pass when navigating to Verify SMS code page.
    getter/setter pair

    Methods

    addExtension(Extension extension, Object? value) → void
    Adds an extension field value to a repeated field.
    inherited
    check() → void
    Throws a StateError if the message has required fields without a value.
    inherited
    clear() → void
    Clears all data that was set in this message.
    inherited
    clearConfirmPassword() → void
    clearConfirmPasswordFieldKeyRef() → void
    clearConfirmPasswordVariable() → void
    clearCustomAuthFields() → void
    clearDisableAutoNavigate() → void
    clearEmail() → void
    clearEmailFieldKeyRef() → void
    clearEmailVariable() → void
    clearExtension(Extension extension) → void
    Clears an extension field and also removes the extension.
    inherited
    clearField(int tagNumber) → void
    Clears the contents of a given field.
    inherited
    clearJwtTokenVariable() → void
    clearLegacyConfirmPasswordFieldKey() → void
    clearLegacyEmailFieldKey() → void
    clearLegacyPasswordFieldKey() → void
    clearLegacySmsCodeVerifyPageName() → void
    clearLegacySmsCodeVerifyPageNodeKey() → void
    clearMicrosoftAuthSettings() → void
    clearPassword() → void
    clearPasswordFieldKeyRef() → void
    clearPasswordVariable() → void
    clearPhoneFieldKey() → void
    clearPhoneVariable() → void
    clearProvider() → void
    clearRedirectUrl() → void
    clearSmsCodeFieldKey() → void
    clearSmsCodeVariable() → void
    clearSmsCodeVerifyPageNodeKeyRef() → void
    clearType() → void
    clearVerifySmsCodePassedParameters() → void
    clone() FFAuthAction
    Creates a deep copy of the fields in this message.
    override
    copyWith(void updates(FFAuthAction)) FFAuthAction
    Apply updates to a copy of this message.
    override
    createEmptyInstance() FFAuthAction
    Creates an empty instance of the same message type as this.
    override
    deepCopy() → T

    Available on T, provided by the GeneratedMessageGenericExtensions extension

    Returns a writable deep copy of this message.
    ensureConfirmPasswordFieldKeyRef() FFNodeKeyReference
    ensureConfirmPasswordVariable() FFVariable
    ensureCustomAuthFields() FFCustomAuthFields
    ensureEmailFieldKeyRef() FFNodeKeyReference
    ensureEmailVariable() FFVariable
    ensureJwtTokenVariable() FFVariable
    ensureMicrosoftAuthSettings() MicrosoftAuthSettings
    ensurePasswordFieldKeyRef() FFNodeKeyReference
    ensurePasswordVariable() FFVariable
    ensurePhoneVariable() FFVariable
    ensureSmsCodeVariable() FFVariable
    ensureSmsCodeVerifyPageNodeKeyRef() FFNodeKeyReference
    ensureVerifySmsCodePassedParameters() FFPassedParameters
    extensionsAreInitialized() bool
    inherited
    freeze() GeneratedMessage
    Make this message read-only.
    inherited
    fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

    Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

    fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

    Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

    getDefaultForField(int tagNumber) → dynamic
    Returns the default value for the given field.
    inherited
    getExtension(Extension extension) → dynamic
    Returns the value of extension.
    inherited
    getField(int tagNumber) → dynamic
    Returns the value of the field associated with tagNumber, or the default value if it is not set.
    inherited
    getFieldOrNull(int tagNumber) → dynamic
    Returns the value of a field, ignoring any defaults.
    inherited
    getTagNumber(String fieldName) int?
    inherited
    hasConfirmPasswordFieldKeyRef() bool
    hasConfirmPasswordVariable() bool
    hasCustomAuthFields() bool
    hasDisableAutoNavigate() bool
    hasEmailFieldKeyRef() bool
    hasEmailVariable() bool
    hasExtension(Extension extension) bool
    Returns true if a value of extension is present.
    inherited
    hasField(int tagNumber) bool
    Whether this message has a field associated with tagNumber.
    inherited
    hasJwtTokenVariable() bool
    hasLegacyConfirmPasswordFieldKey() bool
    hasLegacyEmailFieldKey() bool
    hasLegacyPasswordFieldKey() bool
    hasLegacySmsCodeVerifyPageName() bool
    hasLegacySmsCodeVerifyPageNodeKey() bool
    hasMicrosoftAuthSettings() bool
    hasPasswordFieldKeyRef() bool
    hasPasswordVariable() bool
    hasPhoneFieldKey() bool
    hasPhoneVariable() bool
    hasProvider() bool
    hasRedirectUrl() bool
    hasRequiredFields() bool
    Whether the message has required fields.
    inherited
    hasSmsCodeFieldKey() bool
    hasSmsCodeVariable() bool
    hasSmsCodeVerifyPageNodeKeyRef() bool
    hasType() bool
    hasVerifySmsCodePassedParameters() bool
    isInitialized() bool
    Whether all required fields in the message and embedded messages are set.
    inherited
    mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Merges serialized protocol buffer data into this message.
    inherited
    mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Same as mergeFromBuffer, but takes a CodedBufferReader input.
    inherited
    mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
    inherited
    mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Merges field values from a JSON object represented as a Dart map.
    inherited
    mergeFromMessage(GeneratedMessage other) → void
    Merges the contents of the other into this message.
    inherited
    mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
    Merges field values from json, a JSON object using proto3 encoding.
    inherited
    mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
    inherited
    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    rebuild(void updates(T)) → T

    Available on T, provided by the GeneratedMessageGenericExtensions extension

    Apply updates to a copy of this message.
    setExtension(Extension extension, Object value) → void
    Sets the value of a non-repeated extension field to value.
    inherited
    setField(int tagNumber, Object value) → void
    Sets the value of a field by its tagNumber.
    inherited
    toBuilder() GeneratedMessage
    Creates a writable, shallow copy of this message.
    inherited
    toDebugString() String
    Returns a String representation of this message.
    inherited
    toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
    Returns an Object representing Proto3 JSON serialization of this.
    inherited
    toString() String
    Returns a String representation of this message.
    inherited
    toTextFormat() String

    Available on GeneratedMessage, provided by the TextFormatExtension extension

    Returns a TextFormat String representation of this message.
    whichConfirmPassword() FFAuthAction_ConfirmPassword
    whichEmail() FFAuthAction_Email
    whichPassword() FFAuthAction_Password
    writeTextFormat(StringSink sink) → void

    Available on GeneratedMessage, provided by the TextFormatExtension extension

    Writes a TextFormat String representation of this message to sink.
    writeToBuffer() Uint8List
    Serialize the message as the protobuf binary format.
    inherited
    writeToCodedBufferWriter(CodedBufferWriter output) → void
    Same as writeToBuffer, but serializes to the given CodedBufferWriter.
    inherited
    writeToJson() String
    Returns a JSON string that encodes this message.
    inherited
    writeToJsonMap() Map<String, dynamic>
    Returns the JSON encoding of this message as a Dart Map.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited

    Static Methods

    create() FFAuthAction
    getDefault() FFAuthAction