disableAutoNavigate property

  1. @TagNumber(23)
bool get disableAutoNavigate

@doc By default, certain auth actions will automatically navigate the user upon success. Use this flag to disable and manually manage the navigation logic.

Implementation

@$pb.TagNumber(23)
$core.bool get disableAutoNavigate => $_getBF(22);
  1. @TagNumber(23)
set disableAutoNavigate (bool value)

Implementation

@$pb.TagNumber(23)
set disableAutoNavigate($core.bool value) => $_setBool(22, value);