FFBackend class
- Inheritance
-
- Object
- GeneratedMessage
- FFBackend
- Available extensions
Constructors
-
FFBackend({Iterable<
MapEntry< ? collections, FFFirestore? firestore, FFApiConfig? apiConfig, FFAlgoliaConfig? algoliaConfig, FFFirebaseAnalyticsConfig? firebaseAnalyticsConfig, FFEditMetadata? editMetadata, FFDataSchemaConfig? dataSchemaConfig, FFFirebaseCrashlyticsConfig? firebaseCrashlyticsConfig, FFFirebaseRemoteConfigConfig? firebaseRemoteConfigConfig, FFSupabaseConfig? supabaseSelfHostedConfig, FFFirebaseAppCheckConfig? firebaseAppCheckConfig, FFPostgresConfig? postgresConfig, FFSQLiteConfig? sqliteConfig, FFFirebasePerformanceMonitoringConfig? firebasePerformanceMonitoringConfig, FFCustomCloudFunctionsConfig? customCloudFunctionsConfig, Iterable<String, FFCollection> >FFAgent> ? agents, FFOAuthSupabaseSettings? supabaseOauthConfig, FFSupabaseEdgeFunctionsConfig? supabaseEdgeFunctionsConfig}) -
factory
-
FFBackend.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFBackend.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
-
agents
→ PbList<
FFAgent> -
no setter
- algoliaConfig ↔ FFAlgoliaConfig
-
getter/setter pair
- apiConfig ↔ FFApiConfig
-
getter/setter pair
-
collections
→ PbMap<
String, FFCollection> -
All collections defined in the backend, keyed by Identifier key.
no setter
- customCloudFunctionsConfig ↔ FFCustomCloudFunctionsConfig
-
getter/setter pair
- dataSchemaConfig ↔ FFDataSchemaConfig
-
Stores the different data structure and enum types.
getter/setter pair
- editMetadata ↔ FFEditMetadata
-
Tracks updates on the collections field, each of the others have their own
edit metadata.
getter/setter pair
- firebaseAnalyticsConfig ↔ FFFirebaseAnalyticsConfig
-
getter/setter pair
- firebaseAppCheckConfig ↔ FFFirebaseAppCheckConfig
-
getter/setter pair
- firebaseCrashlyticsConfig ↔ FFFirebaseCrashlyticsConfig
-
getter/setter pair
- firebasePerformanceMonitoringConfig ↔ FFFirebasePerformanceMonitoringConfig
-
getter/setter pair
- firebaseRemoteConfigConfig ↔ FFFirebaseRemoteConfigConfig
-
getter/setter pair
- firestore ↔ FFFirestore
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setteroverride
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - postgresConfig ↔ FFPostgresConfig
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sqliteConfig ↔ FFSQLiteConfig
-
getter/setter pair
- supabaseEdgeFunctionsConfig ↔ FFSupabaseEdgeFunctionsConfig
-
@doc Global Supabase Edge Functions configuration.
getter/setter pair
- supabaseOauthConfig ↔ FFOAuthSupabaseSettings
-
@doc Per-environment OAuth Supabase settings.
getter/setter pair
- supabaseSelfHostedConfig ↔ FFSupabaseConfig
-
@doc Self-hosted Supabase configuration.
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAlgoliaConfig(
) → void -
clearApiConfig(
) → void -
clearCustomCloudFunctionsConfig(
) → void -
clearDataSchemaConfig(
) → void -
clearEditMetadata(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearFirebaseAnalyticsConfig(
) → void -
clearFirebaseAppCheckConfig(
) → void -
clearFirebaseCrashlyticsConfig(
) → void -
clearFirebasePerformanceMonitoringConfig(
) → void -
clearFirebaseRemoteConfigConfig(
) → void -
clearFirestore(
) → void -
clearPostgresConfig(
) → void -
clearSqliteConfig(
) → void -
clearSupabaseConnection(
) → void -
clearSupabaseEdgeFunctionsConfig(
) → void -
clearSupabaseOauthConfig(
) → void -
clearSupabaseSelfHostedConfig(
) → void -
clone(
) → FFBackend -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFBackend)) → FFBackend -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFBackend -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAlgoliaConfig(
) → FFAlgoliaConfig -
ensureApiConfig(
) → FFApiConfig -
ensureCustomCloudFunctionsConfig(
) → FFCustomCloudFunctionsConfig -
ensureDataSchemaConfig(
) → FFDataSchemaConfig -
ensureEditMetadata(
) → FFEditMetadata -
ensureFirebaseAnalyticsConfig(
) → FFFirebaseAnalyticsConfig -
ensureFirebaseAppCheckConfig(
) → FFFirebaseAppCheckConfig -
ensureFirebaseCrashlyticsConfig(
) → FFFirebaseCrashlyticsConfig -
ensureFirebasePerformanceMonitoringConfig(
) → FFFirebasePerformanceMonitoringConfig -
ensureFirebaseRemoteConfigConfig(
) → FFFirebaseRemoteConfigConfig -
ensureFirestore(
) → FFFirestore -
ensurePostgresConfig(
) → FFPostgresConfig -
ensureSqliteConfig(
) → FFSQLiteConfig -
ensureSupabaseEdgeFunctionsConfig(
) → FFSupabaseEdgeFunctionsConfig -
ensureSupabaseOauthConfig(
) → FFOAuthSupabaseSettings -
ensureSupabaseSelfHostedConfig(
) → FFSupabaseConfig -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAlgoliaConfig(
) → bool -
hasApiConfig(
) → bool -
hasCustomCloudFunctionsConfig(
) → bool -
hasDataSchemaConfig(
) → bool -
hasEditMetadata(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasFirebaseAnalyticsConfig(
) → bool -
hasFirebaseAppCheckConfig(
) → bool -
hasFirebaseCrashlyticsConfig(
) → bool -
hasFirebasePerformanceMonitoringConfig(
) → bool -
hasFirebaseRemoteConfigConfig(
) → bool -
hasFirestore(
) → bool -
hasPostgresConfig(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSqliteConfig(
) → bool -
hasSupabaseEdgeFunctionsConfig(
) → bool -
hasSupabaseOauthConfig(
) → bool -
hasSupabaseSelfHostedConfig(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
whichSupabaseConnection(
) → FFBackend_SupabaseConnection -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → FFBackend -
getDefault(
) → FFBackend