collections property
All collections defined in the backend, keyed by Identifier key.
Implementation
@$pb.TagNumber(1)
$pb.PbMap<$core.String, FFCollection> get collections => $_getMap(0);
All collections defined in the backend, keyed by Identifier key.
@$pb.TagNumber(1)
$pb.PbMap<$core.String, FFCollection> get collections => $_getMap(0);