legacyPositionStart property
Whether to place at the start or end position (not overridable).
Implementation
@$pb.TagNumber(7)
$core.bool get legacyPositionStart => $_getBF(6);
Whether to place at the start or end position (not overridable).
@$pb.TagNumber(7)
$core.bool get legacyPositionStart => $_getBF(6);