FFBaseVariable class

Inheritance
Available extensions

Constructors

FFBaseVariable({FFAuthVariable? auth, FFFirestoreVariable? firestore, FFGlobalPropertiesVariable? globalProperties, FFLocalStateVariable? localState, FFGeneratorVariableVariable? generatorVariable, FFWidgetClassVariable? widgetClass, FFApiCallVariable? apiCall, FFWidgetStateVariable? widgetState, FFAlgoliaVariable? algolia, FFSimpleSearchVariable? simpleSearch, FFActionOutputVariable? actionOutput, FFRevenueCatVariable? revenueCat, FFInternationalizationVariable? internationalization, FFRandomData? randomData, FFListMapVariable? listMap, FFPermissionStateVariable? permissionState, FFApiCallPaginationVariable? apiCallPagination, FFFirebaseRemoteConfigVariable? firebaseRemoteConfig, FFConstantsVariable? constants, FFPostgresQueryVariable? postgresQuery, FFSQLiteVariable? sqlite, FFCreateDataStructVariable? createDataStruct, FFActionComponentParameterVariable? actionComponentParameter, FFActionInputVariable? actionInput, FFWidgetFocusStateVariable? widgetFocusState, FFEnumVariable? enumVariable, FFCreateJsonMapVariable? createJsonMap, FFWidgetBuilderVariable? widgetBuilder, FFEnvironmentValueVariable? environmentValue, FFWidgetBuilderParameterVariable? widgetBuilderParameter, FFLibraryValueVariable? libraryValue, FFCreateCustomInterfaceVariable? createCustomInterface, FFLoopOverListVariable? loopOverList, FFCustomCodeExpressionVariable? customCodeExpression, FFCustomInterfaceStaticVariable? customInterfaceStatic, FFDesignTokenVariable? designToken})
factory
FFBaseVariable.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFBaseVariable.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

actionComponentParameter FFActionComponentParameterVariable
getter/setter pair
actionInput FFActionInputVariable
getter/setter pair
actionOutput FFActionOutputVariable
getter/setter pair
algolia FFAlgoliaVariable
getter/setter pair
apiCall FFApiCallVariable
getter/setter pair
apiCallPagination FFApiCallPaginationVariable
getter/setter pair
auth FFAuthVariable
getter/setter pair
constants FFConstantsVariable
getter/setter pair
createCustomInterface FFCreateCustomInterfaceVariable
getter/setter pair
createDataStruct FFCreateDataStructVariable
getter/setter pair
createJsonMap FFCreateJsonMapVariable
getter/setter pair
customCodeExpression FFCustomCodeExpressionVariable
getter/setter pair
customInterfaceStatic FFCustomInterfaceStaticVariable
getter/setter pair
designToken FFDesignTokenVariable
getter/setter pair
enumVariable FFEnumVariable
getter/setter pair
environmentValue FFEnvironmentValueVariable
@doc Variable starting with an environment value.
getter/setter pair
firebaseRemoteConfig FFFirebaseRemoteConfigVariable
getter/setter pair
firestore FFFirestoreVariable
getter/setter pair
generatorVariable FFGeneratorVariableVariable
getter/setter pair
globalProperties FFGlobalPropertiesVariable
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ BuilderInfo
no setteroverride
internationalization FFInternationalizationVariable
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
libraryValue FFLibraryValueVariable
@doc The list of library values that can be used in the variable.
getter/setter pair
listMap FFListMapVariable
getter/setter pair
localState FFLocalStateVariable
getter/setter pair
loopOverList FFLoopOverListVariable
getter/setter pair
permissionState FFPermissionStateVariable
getter/setter pair
postgresQuery FFPostgresQueryVariable
getter/setter pair
randomData FFRandomData
getter/setter pair
revenueCat FFRevenueCatVariable
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simpleSearch FFSimpleSearchVariable
getter/setter pair
sqlite FFSQLiteVariable
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
widgetBuilder FFWidgetBuilderVariable
@doc Variable starting with a widget builder.
getter/setter pair
widgetBuilderParameter FFWidgetBuilderParameterVariable
@doc Variable starting with a widget builder parameter.
getter/setter pair
widgetClass FFWidgetClassVariable
getter/setter pair
widgetFocusState FFWidgetFocusStateVariable
getter/setter pair
widgetState FFWidgetStateVariable
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearActionComponentParameter() → void
clearActionInput() → void
clearActionOutput() → void
clearAlgolia() → void
clearApiCall() → void
clearApiCallPagination() → void
clearAuth() → void
clearConstants() → void
clearCreateCustomInterface() → void
clearCreateDataStruct() → void
clearCreateJsonMap() → void
clearCustomCodeExpression() → void
clearCustomInterfaceStatic() → void
clearDesignToken() → void
clearEnumVariable() → void
clearEnvironmentValue() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFirebaseRemoteConfig() → void
clearFirestore() → void
clearGeneratorVariable() → void
clearGlobalProperties() → void
clearInternationalization() → void
clearLibraryValue() → void
clearListMap() → void
clearLocalState() → void
clearLoopOverList() → void
clearPermissionState() → void
clearPostgresQuery() → void
clearRandomData() → void
clearRevenueCat() → void
clearSimpleSearch() → void
clearSqlite() → void
clearVariable() → void
clearWidgetBuilder() → void
clearWidgetBuilderParameter() → void
clearWidgetClass() → void
clearWidgetFocusState() → void
clearWidgetState() → void
clone() FFBaseVariable
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFBaseVariable)) FFBaseVariable
Apply updates to a copy of this message.
override
createEmptyInstance() FFBaseVariable
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureActionComponentParameter() FFActionComponentParameterVariable
ensureActionInput() FFActionInputVariable
ensureActionOutput() FFActionOutputVariable
ensureAlgolia() FFAlgoliaVariable
ensureApiCall() FFApiCallVariable
ensureApiCallPagination() FFApiCallPaginationVariable
ensureAuth() FFAuthVariable
ensureConstants() FFConstantsVariable
ensureCreateCustomInterface() FFCreateCustomInterfaceVariable
ensureCreateDataStruct() FFCreateDataStructVariable
ensureCreateJsonMap() FFCreateJsonMapVariable
ensureCustomCodeExpression() FFCustomCodeExpressionVariable
ensureCustomInterfaceStatic() FFCustomInterfaceStaticVariable
ensureDesignToken() FFDesignTokenVariable
ensureEnumVariable() FFEnumVariable
ensureEnvironmentValue() FFEnvironmentValueVariable
ensureFirebaseRemoteConfig() FFFirebaseRemoteConfigVariable
ensureFirestore() FFFirestoreVariable
ensureGeneratorVariable() FFGeneratorVariableVariable
ensureGlobalProperties() FFGlobalPropertiesVariable
ensureInternationalization() FFInternationalizationVariable
ensureLibraryValue() FFLibraryValueVariable
ensureListMap() FFListMapVariable
ensureLocalState() FFLocalStateVariable
ensureLoopOverList() FFLoopOverListVariable
ensurePermissionState() FFPermissionStateVariable
ensurePostgresQuery() FFPostgresQueryVariable
ensureRandomData() FFRandomData
ensureRevenueCat() FFRevenueCatVariable
ensureSimpleSearch() FFSimpleSearchVariable
ensureSqlite() FFSQLiteVariable
ensureWidgetBuilder() FFWidgetBuilderVariable
ensureWidgetBuilderParameter() FFWidgetBuilderParameterVariable
ensureWidgetClass() FFWidgetClassVariable
ensureWidgetFocusState() FFWidgetFocusStateVariable
ensureWidgetState() FFWidgetStateVariable
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasActionComponentParameter() bool
hasActionInput() bool
hasActionOutput() bool
hasAlgolia() bool
hasApiCall() bool
hasApiCallPagination() bool
hasAuth() bool
hasConstants() bool
hasCreateCustomInterface() bool
hasCreateDataStruct() bool
hasCreateJsonMap() bool
hasCustomCodeExpression() bool
hasCustomInterfaceStatic() bool
hasDesignToken() bool
hasEnumVariable() bool
hasEnvironmentValue() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFirebaseRemoteConfig() bool
hasFirestore() bool
hasGeneratorVariable() bool
hasGlobalProperties() bool
hasInternationalization() bool
hasLibraryValue() bool
hasListMap() bool
hasLocalState() bool
hasLoopOverList() bool
hasPermissionState() bool
hasPostgresQuery() bool
hasRandomData() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasRevenueCat() bool
hasSimpleSearch() bool
hasSqlite() bool
hasWidgetBuilder() bool
hasWidgetBuilderParameter() bool
hasWidgetClass() bool
hasWidgetFocusState() bool
hasWidgetState() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
whichVariable() FFBaseVariable_Variable
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFBaseVariable
getDefault() FFBaseVariable