biometricOnly property
@doc Whether to return false when biometric verification is unavailable.
Implementation
@$pb.TagNumber(1)
$core.bool get biometricOnly => $_getBF(0);
@doc Whether to return false when biometric verification is unavailable.
@$pb.TagNumber(1)
$core.bool get biometricOnly => $_getBF(0);