legacyBlur property
Whether to apply the blur, used for overriding based on a variable.
Implementation
@$pb.TagNumber(3)
$core.bool get legacyBlur => $_getBF(2);
Whether to apply the blur, used for overriding based on a variable.
@$pb.TagNumber(3)
$core.bool get legacyBlur => $_getBF(2);