inputValue property
@doc A preset boolean value that represents a static/hardcoded boolean.
Implementation
@$pb.TagNumber(1)
$core.bool get inputValue => $_getBF(0);
@doc A preset boolean value that represents a static/hardcoded boolean.
@$pb.TagNumber(1)
$core.bool get inputValue => $_getBF(0);