mostRecentInputValue property
@doc Stores the most recent boolean this value was set to in order to restore after removing a variable.
Implementation
@$pb.TagNumber(3)
$core.bool get mostRecentInputValue => $_getBF(2);
@doc Stores the most recent boolean this value was set to in order to restore after removing a variable.
@$pb.TagNumber(3)
$core.bool get mostRecentInputValue => $_getBF(2);