enableDrag property
@doc Whether the bottom sheet can be dragged up and down and dismissed.
Implementation
@$pb.TagNumber(12)
$core.bool get enableDrag => $_getBF(11);
@doc Whether the bottom sheet can be dragged up and down and dismissed.
@$pb.TagNumber(12)
$core.bool get enableDrag => $_getBF(11);