isDismiss property
@doc Whether this is a Dismiss bottom sheet action.
Implementation
@$pb.TagNumber(7)
$core.bool get isDismiss => $_getBF(6);
@doc Whether this is a Dismiss bottom sheet action.
@$pb.TagNumber(7)
$core.bool get isDismiss => $_getBF(6);