useSafeArea property
@doc Whether the bottom sheet will respect the safe area of the device.
Implementation
@$pb.TagNumber(17)
$core.bool get useSafeArea => $_getBF(15);
@doc Whether the bottom sheet will respect the safe area of the device.
@$pb.TagNumber(17)
$core.bool get useSafeArea => $_getBF(15);