currencyCode property
@doc The currency that will be used for this transaction.
Implementation
@$pb.TagNumber(3)
$core.String get currencyCode => $_getSZ(2);
@doc The currency that will be used for this transaction.
@$pb.TagNumber(3)
$core.String get currencyCode => $_getSZ(2);