shippingCost property
@doc An optional shipping cost that will be added to the total.
Implementation
@$pb.TagNumber(5)
$core.double get shippingCost => $_getN(4);
@doc An optional shipping cost that will be added to the total.
@$pb.TagNumber(5)
$core.double get shippingCost => $_getN(4);