taxRate property
@doc The tax percent rate that will be applied to the total.
Implementation
@$pb.TagNumber(4)
$core.double get taxRate => $_getN(3);
@doc The tax percent rate that will be applied to the total.
@$pb.TagNumber(4)
$core.double get taxRate => $_getN(3);