transactionName property
@doc The name that will appear on receipts and in the records.
Implementation
@$pb.TagNumber(2)
FFValue get transactionName => $_getN(1);
@doc The name that will appear on receipts and in the records.
@$pb.TagNumber(2)
FFValue get transactionName => $_getN(1);