isProduction property
@doc Whether to run the app in Sandbox or Production mode.
Implementation
@$pb.TagNumber(3)
$core.bool get isProduction => $_getBF(2);
@doc Whether to run the app in Sandbox or Production mode.
@$pb.TagNumber(3)
$core.bool get isProduction => $_getBF(2);