FFCalendar class

Inheritance
Available extensions

Constructors

FFCalendar({FFColor? legacyColor, bool? legacyWeekFormat, bool? legacyWeekStartsMonday, FFColor? legacyIconColor, FFText? titleStyle, FFText? dayOfWeekStyle, FFText? dateStyle, FFText? inactiveDateStyle, FFText? selectedDateStyle, FFDateTime? legacyInitialDate, double? legacyRowHeight, bool? legacyTwoRowHeader, FFDateTimeValue? initialDateValue, FFColorValue? colorValue, FFBooleanValue? weekFormatValue, FFBooleanValue? weekStartsMondayValue, FFColorValue? iconColorValue, FFDoubleValue? rowHeightValue, FFBooleanValue? twoRowHeaderValue})
factory
FFCalendar.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFCalendar.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

colorValue FFColorValue
getter/setter pair
dateStyle FFText
getter/setter pair
dayOfWeekStyle FFText
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
iconColorValue FFColorValue
getter/setter pair
inactiveDateStyle FFText
getter/setter pair
info_ BuilderInfo
no setteroverride
initialDateValue FFDateTimeValue
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
legacyColor FFColor
getter/setter pair
legacyIconColor FFColor
getter/setter pair
legacyInitialDate FFDateTime
getter/setter pair
legacyRowHeight double
getter/setter pair
legacyTwoRowHeader bool
getter/setter pair
legacyWeekFormat bool
getter/setter pair
legacyWeekStartsMonday bool
getter/setter pair
rowHeightValue FFDoubleValue
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDateStyle FFText
getter/setter pair
titleStyle FFText
getter/setter pair
twoRowHeaderValue FFBooleanValue
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
weekFormatValue FFBooleanValue
getter/setter pair
weekStartsMondayValue FFBooleanValue
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearColorValue() → void
clearDateStyle() → void
clearDayOfWeekStyle() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIconColorValue() → void
clearInactiveDateStyle() → void
clearInitialDateValue() → void
clearLegacyColor() → void
clearLegacyIconColor() → void
clearLegacyInitialDate() → void
clearLegacyRowHeight() → void
clearLegacyTwoRowHeader() → void
clearLegacyWeekFormat() → void
clearLegacyWeekStartsMonday() → void
clearRowHeightValue() → void
clearSelectedDateStyle() → void
clearTitleStyle() → void
clearTwoRowHeaderValue() → void
clearWeekFormatValue() → void
clearWeekStartsMondayValue() → void
clone() FFCalendar
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFCalendar)) FFCalendar
Apply updates to a copy of this message.
override
createEmptyInstance() FFCalendar
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureColorValue() FFColorValue
ensureDateStyle() FFText
ensureDayOfWeekStyle() FFText
ensureIconColorValue() FFColorValue
ensureInactiveDateStyle() FFText
ensureInitialDateValue() FFDateTimeValue
ensureLegacyColor() FFColor
ensureLegacyIconColor() FFColor
ensureLegacyInitialDate() FFDateTime
ensureRowHeightValue() FFDoubleValue
ensureSelectedDateStyle() FFText
ensureTitleStyle() FFText
ensureTwoRowHeaderValue() FFBooleanValue
ensureWeekFormatValue() FFBooleanValue
ensureWeekStartsMondayValue() FFBooleanValue
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasColorValue() bool
hasDateStyle() bool
hasDayOfWeekStyle() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasIconColorValue() bool
hasInactiveDateStyle() bool
hasInitialDateValue() bool
hasLegacyColor() bool
hasLegacyIconColor() bool
hasLegacyInitialDate() bool
hasLegacyRowHeight() bool
hasLegacyTwoRowHeader() bool
hasLegacyWeekFormat() bool
hasLegacyWeekStartsMonday() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasRowHeightValue() bool
hasSelectedDateStyle() bool
hasTitleStyle() bool
hasTwoRowHeaderValue() bool
hasWeekFormatValue() bool
hasWeekStartsMondayValue() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFCalendar
getDefault() FFCalendar