streamSubscriptionKey property
@doc A unique key to identify the stream subscription that needs to be cancelled.
Implementation
@$pb.TagNumber(1)
FFValue get streamSubscriptionKey => $_getN(0);
@doc A unique key to identify the stream subscription that needs to be cancelled.
@$pb.TagNumber(1)
FFValue get streamSubscriptionKey => $_getN(0);