FFCarousel class
- Inheritance
-
- Object
- GeneratedMessage
- FFCarousel
- Available extensions
Constructors
- FFCarousel({FFDimensions? dimensions, FFAxis? axis, int? legacyInitialPageIndex, bool? legacyWrapItemsInCenter, double? legacyViewportFraction, bool? legacyInfiniteScroll, double? legacyShrinkFactor, FFAutoPlayOptions? autoPlayOptions, FFIntegerValue? initialPageIndexValue, FFBooleanValue? wrapItemsInCenterValue, FFDoubleValue? viewportFractionValue, FFBooleanValue? infiniteScrollValue, FFDoubleValue? shrinkFactorValue})
-
factory
-
FFCarousel.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFCarousel.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- autoPlayOptions ↔ FFAutoPlayOptions
-
@doc The auto play options for the carousel animations.
getter/setter pair
- axis ↔ FFAxis
-
@doc The axis orientation.
getter/setter pair
- dimensions ↔ FFDimensions
-
@doc The dimensions of the carousel widget.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- infiniteScrollValue ↔ FFBooleanValue
-
@doc Whether to support infinite scroll.
getter/setter pair
- info_ → BuilderInfo
-
no setteroverride
- initialPageIndexValue ↔ FFIntegerValue
-
@doc The initial page index of the carousel.
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - legacyInfiniteScroll ↔ bool
-
getter/setter pair
- legacyInitialPageIndex ↔ int
-
getter/setter pair
- legacyShrinkFactor ↔ double
-
getter/setter pair
- legacyViewportFraction ↔ double
-
getter/setter pair
- legacyWrapItemsInCenter ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shrinkFactorValue ↔ FFDoubleValue
-
@doc The shrink factor of the carousel.
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- viewportFractionValue ↔ FFDoubleValue
-
@doc The fraction of the viewport that each page should occupy.
getter/setter pair
- wrapItemsInCenterValue ↔ FFBooleanValue
-
@doc Whether to wrap the items in the center.
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAutoPlayOptions(
) → void -
clearAxis(
) → void -
clearDimensions(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearInfiniteScrollValue(
) → void -
clearInitialPageIndexValue(
) → void -
clearLegacyInfiniteScroll(
) → void -
clearLegacyInitialPageIndex(
) → void -
clearLegacyShrinkFactor(
) → void -
clearLegacyViewportFraction(
) → void -
clearLegacyWrapItemsInCenter(
) → void -
clearShrinkFactorValue(
) → void -
clearViewportFractionValue(
) → void -
clearWrapItemsInCenterValue(
) → void -
clone(
) → FFCarousel -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFCarousel)) → FFCarousel -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFCarousel -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAutoPlayOptions(
) → FFAutoPlayOptions -
ensureDimensions(
) → FFDimensions -
ensureInfiniteScrollValue(
) → FFBooleanValue -
ensureInitialPageIndexValue(
) → FFIntegerValue -
ensureShrinkFactorValue(
) → FFDoubleValue -
ensureViewportFractionValue(
) → FFDoubleValue -
ensureWrapItemsInCenterValue(
) → FFBooleanValue -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAutoPlayOptions(
) → bool -
hasAxis(
) → bool -
hasDimensions(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasInfiniteScrollValue(
) → bool -
hasInitialPageIndexValue(
) → bool -
hasLegacyInfiniteScroll(
) → bool -
hasLegacyInitialPageIndex(
) → bool -
hasLegacyShrinkFactor(
) → bool -
hasLegacyViewportFraction(
) → bool -
hasLegacyWrapItemsInCenter(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasShrinkFactorValue(
) → bool -
hasViewportFractionValue(
) → bool -
hasWrapItemsInCenterValue(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → FFCarousel -
getDefault(
) → FFCarousel