FFChart class
- Inheritance
-
- Object
- GeneratedMessage
- FFChart
- Available extensions
Constructors
-
FFChart({FFChart_ChartType? chartType, FFDimensions? dimensions, FFLineChart? lineChart, Iterable<
FFChartData> ? data, FFBarChart? barChart, FFChartTooltipInfo? tooltipInfo, FFColor? legacyBackgroundColor, FFColor? legacyBorderColor, double? legacyBorderWidth, bool? legacyShowBorder, bool? legacyShowGrid, bool? legacyShowLegend, FFChartLegendInfo? legendInfo, bool? hasBeenUpdated, FFPieChart? pieChart, FFColorValue? backgroundColorValue, FFColorValue? borderColorValue, FFDoubleValue? borderWidthValue, FFBooleanValue? showBorderValue, FFBooleanValue? showGridValue, FFBooleanValue? showLegendValue, FFColorValue? gridColorValue}) -
factory
-
FFChart.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFChart.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- backgroundColorValue ↔ FFColorValue
-
getter/setter pair
- barChart ↔ FFBarChart
-
getter/setter pair
- borderColorValue ↔ FFColorValue
-
getter/setter pair
- borderWidthValue ↔ FFDoubleValue
-
getter/setter pair
- chartType ↔ FFChart_ChartType
-
getter/setter pair
-
data
→ PbList<
FFChartData> -
no setter
- dimensions ↔ FFDimensions
-
getter/setter pair
- gridColorValue ↔ FFColorValue
-
getter/setter pair
- hasBeenUpdated ↔ bool
-
not overridable
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setteroverride
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - legacyBackgroundColor ↔ FFColor
-
getter/setter pair
- legacyBorderColor ↔ FFColor
-
getter/setter pair
- legacyBorderWidth ↔ double
-
getter/setter pair
- legacyShowBorder ↔ bool
-
getter/setter pair
- legacyShowGrid ↔ bool
-
getter/setter pair
- legacyShowLegend ↔ bool
-
getter/setter pair
- legendInfo ↔ FFChartLegendInfo
-
getter/setter pair
- lineChart ↔ FFLineChart
-
getter/setter pair
- pieChart ↔ FFPieChart
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBorderValue ↔ FFBooleanValue
-
getter/setter pair
- showGridValue ↔ FFBooleanValue
-
getter/setter pair
- showLegendValue ↔ FFBooleanValue
-
Not overridable
getter/setter pair
- tooltipInfo ↔ FFChartTooltipInfo
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearBackgroundColorValue(
) → void -
clearBarChart(
) → void -
clearBorderColorValue(
) → void -
clearBorderWidthValue(
) → void -
clearChartType(
) → void -
clearDimensions(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearGridColorValue(
) → void -
clearHasBeenUpdated(
) → void -
clearLegacyBackgroundColor(
) → void -
clearLegacyBorderColor(
) → void -
clearLegacyBorderWidth(
) → void -
clearLegacyShowBorder(
) → void -
clearLegacyShowGrid(
) → void -
clearLegacyShowLegend(
) → void -
clearLegendInfo(
) → void -
clearLineChart(
) → void -
clearPieChart(
) → void -
clearShowBorderValue(
) → void -
clearShowGridValue(
) → void -
clearShowLegendValue(
) → void -
clearTooltipInfo(
) → void -
clone(
) → FFChart -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFChart)) → FFChart -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFChart -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureBackgroundColorValue(
) → FFColorValue -
ensureBarChart(
) → FFBarChart -
ensureBorderColorValue(
) → FFColorValue -
ensureBorderWidthValue(
) → FFDoubleValue -
ensureDimensions(
) → FFDimensions -
ensureGridColorValue(
) → FFColorValue -
ensureLegacyBackgroundColor(
) → FFColor -
ensureLegacyBorderColor(
) → FFColor -
ensureLegendInfo(
) → FFChartLegendInfo -
ensureLineChart(
) → FFLineChart -
ensurePieChart(
) → FFPieChart -
ensureShowBorderValue(
) → FFBooleanValue -
ensureShowGridValue(
) → FFBooleanValue -
ensureShowLegendValue(
) → FFBooleanValue -
ensureTooltipInfo(
) → FFChartTooltipInfo -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasBackgroundColorValue(
) → bool -
hasBarChart(
) → bool -
hasBorderColorValue(
) → bool -
hasBorderWidthValue(
) → bool -
hasChartType(
) → bool -
hasDimensions(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasGridColorValue(
) → bool -
hasHasBeenUpdated(
) → bool -
hasLegacyBackgroundColor(
) → bool -
hasLegacyBorderColor(
) → bool -
hasLegacyBorderWidth(
) → bool -
hasLegacyShowBorder(
) → bool -
hasLegacyShowGrid(
) → bool -
hasLegacyShowLegend(
) → bool -
hasLegendInfo(
) → bool -
hasLineChart(
) → bool -
hasPieChart(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasShowBorderValue(
) → bool -
hasShowGridValue(
) → bool -
hasShowLegendValue(
) → bool -
hasTooltipInfo(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → FFChart -
getDefault(
) → FFChart