description property
User-facing description of what this slot is for. @doc Description of what content belongs in this slot.
Implementation
@$pb.TagNumber(2)
$core.String get description => $_getSZ(1);
User-facing description of what this slot is for. @doc Description of what content belongs in this slot.
@$pb.TagNumber(2)
$core.String get description => $_getSZ(1);