required property
Whether the caller must provide content for this slot. If false and no content is provided, the default_child is used (if present), otherwise the slot renders nothing.
Implementation
@$pb.TagNumber(3)
$core.bool get required => $_getBF(2);