previewComponentRef property
Optional component to render as a preview in the component editor. Helps the component author visualize layout with realistic content.
Implementation
@$pb.TagNumber(2)
FFNodeKeyReference get previewComponentRef => $_getN(1);
Implementation
@$pb.TagNumber(2)
set previewComponentRef(FFNodeKeyReference value) => $_setField(2, value);