FFChoiceChips class

Inheritance
Available extensions

Constructors

FFChoiceChips({@Deprecated('This field is deprecated.') String? legacyInitialOption, Iterable<FFChipData>? options, FFChipStyle? selectedChipStyle, FFChipStyle? unselectedChipStyle, double? legacyChipSpacing, bool? multiselect, FFText? initialOption, @Deprecated('This field is deprecated.') Iterable<FFText>? legacyInitiallySelected, double? legacyRowSpacing, FFWrapAlignment? childAlignment, bool? legacyRequireSelection, FFDisable? disabled, FFColor? legacyDisabledColor, bool? legacyWrapped, FFDoubleValue? chipSpacingValue, FFDoubleValue? rowSpacingValue, FFBooleanValue? requireSelectionValue, FFColorValue? disabledColorValue, FFBooleanValue? wrappedValue, FFVariable? optionsVariable, FFTextOptionsValue? initiallySelected})
factory
FFChoiceChips.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFChoiceChips.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

childAlignment FFWrapAlignment
getter/setter pair
chipSpacingValue FFDoubleValue
getter/setter pair
disabled FFDisable
getter/setter pair
disabledColorValue FFColorValue
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ BuilderInfo
no setteroverride
initiallySelected FFTextOptionsValue
getter/setter pair
initialOption FFText
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
legacyChipSpacing double
getter/setter pair
legacyDisabledColor FFColor
getter/setter pair
legacyInitiallySelected PbList<FFText>
no setter
legacyInitialOption String
getter/setter pair
legacyRequireSelection bool
getter/setter pair
legacyRowSpacing double
getter/setter pair
legacyWrapped bool
/ If not wrapped, the chips will be displayed in a horizontally scrollable ListView.
getter/setter pair
multiselect bool
Not overridable
getter/setter pair
options PbList<FFChipData>
no setter
optionsVariable FFVariable
getter/setter pair
requireSelectionValue FFBooleanValue
getter/setter pair
rowSpacingValue FFDoubleValue
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedChipStyle FFChipStyle
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
unselectedChipStyle FFChipStyle
getter/setter pair
wrappedValue FFBooleanValue
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearChildAlignment() → void
clearChipSpacingValue() → void
clearDisabled() → void
clearDisabledColorValue() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearInitiallySelected() → void
clearInitialOption() → void
clearLegacyChipSpacing() → void
clearLegacyDisabledColor() → void
clearLegacyInitialOption() → void
clearLegacyRequireSelection() → void
clearLegacyRowSpacing() → void
clearLegacyWrapped() → void
clearMultiselect() → void
clearOptionsVariable() → void
clearRequireSelectionValue() → void
clearRowSpacingValue() → void
clearSelectedChipStyle() → void
clearUnselectedChipStyle() → void
clearWrappedValue() → void
clone() FFChoiceChips
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFChoiceChips)) FFChoiceChips
Apply updates to a copy of this message.
override
createEmptyInstance() FFChoiceChips
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureChipSpacingValue() FFDoubleValue
ensureDisabled() FFDisable
ensureDisabledColorValue() FFColorValue
ensureInitiallySelected() FFTextOptionsValue
ensureInitialOption() FFText
ensureLegacyDisabledColor() FFColor
ensureOptionsVariable() FFVariable
ensureRequireSelectionValue() FFBooleanValue
ensureRowSpacingValue() FFDoubleValue
ensureSelectedChipStyle() FFChipStyle
ensureUnselectedChipStyle() FFChipStyle
ensureWrappedValue() FFBooleanValue
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasChildAlignment() bool
hasChipSpacingValue() bool
hasDisabled() bool
hasDisabledColorValue() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasInitiallySelected() bool
hasInitialOption() bool
hasLegacyChipSpacing() bool
hasLegacyDisabledColor() bool
hasLegacyInitialOption() bool
hasLegacyRequireSelection() bool
hasLegacyRowSpacing() bool
hasLegacyWrapped() bool
hasMultiselect() bool
hasOptionsVariable() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasRequireSelectionValue() bool
hasRowSpacingValue() bool
hasSelectedChipStyle() bool
hasUnselectedChipStyle() bool
hasWrappedValue() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFChoiceChips
getDefault() FFChoiceChips