legacyWrapped property
/ If not wrapped, the chips will be displayed in a horizontally scrollable ListView.
Implementation
@$pb.TagNumber(14)
$core.bool get legacyWrapped => $_getBF(13);
/ If not wrapped, the chips will be displayed in a horizontally scrollable ListView.
@$pb.TagNumber(14)
$core.bool get legacyWrapped => $_getBF(13);