nodeKeyPaths property
@doc The path to the component that holds the text field.
Implementation
@$pb.TagNumber(3)
$pb.PbList<FFNodeKeyPath> get nodeKeyPaths => $_getList(2);
@doc The path to the component that holds the text field.
@$pb.TagNumber(3)
$pb.PbList<FFNodeKeyPath> get nodeKeyPaths => $_getList(2);