uploadDataName property
@doc The name of the upload data action to clear.
Implementation
@$pb.TagNumber(1)
$core.String get uploadDataName => $_getSZ(0);
@doc The name of the upload data action to clear.
@$pb.TagNumber(1)
$core.String get uploadDataName => $_getSZ(0);