fields property
@doc All the fields of the collection, keyed by Identifier key.
Implementation
@$pb.TagNumber(2)
$pb.PbMap<$core.String, FFParameter> get fields => $_getMap(1);
@doc All the fields of the collection, keyed by Identifier key.
@$pb.TagNumber(2)
$pb.PbMap<$core.String, FFParameter> get fields => $_getMap(1);