FFColorScheme class
- Inheritance
-
- Object
- GeneratedMessage
- FFColorScheme
- Available extensions
Constructors
-
FFColorScheme({FFColor? primary, FFColor? secondary, FFColor? tertiary, Iterable<
FFColor> ? customPaletteColors, bool? darkModeEnabled, FFColor? alternate, FFColor? primaryBackground, FFColor? secondaryBackground, FFColor? primaryText, FFColor? secondaryText, bool? displayDarkMode, FFColor? accent1, FFColor? accent2, FFColor? accent3, FFColor? accent4, FFColor? success, FFColor? warning, FFColor? error, FFColor? info}) -
factory
-
FFColorScheme.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFColorScheme.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- accent1 ↔ FFColor
-
getter/setter pair
- accent2 ↔ FFColor
-
getter/setter pair
- accent3 ↔ FFColor
-
getter/setter pair
- accent4 ↔ FFColor
-
getter/setter pair
- alternate ↔ FFColor
-
getter/setter pair
-
customPaletteColors
→ PbList<
FFColor> -
no setter
- darkModeEnabled ↔ bool
-
getter/setter pair
- displayDarkMode ↔ bool
-
@doc If the editor should display the project in dark mode.
This should not impact generated code anyhow, and it should not be pulled
from a design system.
getter/setter pair
- error ↔ FFColor
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info ↔ FFColor
-
getter/setter pair
- info_ → BuilderInfo
-
no setteroverride
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - primary ↔ FFColor
-
getter/setter pair
- primaryBackground ↔ FFColor
-
getter/setter pair
- primaryText ↔ FFColor
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondary ↔ FFColor
-
getter/setter pair
- secondaryBackground ↔ FFColor
-
getter/setter pair
- secondaryText ↔ FFColor
-
getter/setter pair
- success ↔ FFColor
-
getter/setter pair
- tertiary ↔ FFColor
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- warning ↔ FFColor
-
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAccent1(
) → void -
clearAccent2(
) → void -
clearAccent3(
) → void -
clearAccent4(
) → void -
clearAlternate(
) → void -
clearDarkModeEnabled(
) → void -
clearDisplayDarkMode(
) → void -
clearError(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearInfo(
) → void -
clearPrimary(
) → void -
clearPrimaryBackground(
) → void -
clearPrimaryText(
) → void -
clearSecondary(
) → void -
clearSecondaryBackground(
) → void -
clearSecondaryText(
) → void -
clearSuccess(
) → void -
clearTertiary(
) → void -
clearWarning(
) → void -
clone(
) → FFColorScheme -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFColorScheme)) → FFColorScheme -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFColorScheme -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAccent1(
) → FFColor -
ensureAccent2(
) → FFColor -
ensureAccent3(
) → FFColor -
ensureAccent4(
) → FFColor -
ensureAlternate(
) → FFColor -
ensureError(
) → FFColor -
ensureInfo(
) → FFColor -
ensurePrimary(
) → FFColor -
ensurePrimaryBackground(
) → FFColor -
ensurePrimaryText(
) → FFColor -
ensureSecondary(
) → FFColor -
ensureSecondaryBackground(
) → FFColor -
ensureSecondaryText(
) → FFColor -
ensureSuccess(
) → FFColor -
ensureTertiary(
) → FFColor -
ensureWarning(
) → FFColor -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAccent1(
) → bool -
hasAccent2(
) → bool -
hasAccent3(
) → bool -
hasAccent4(
) → bool -
hasAlternate(
) → bool -
hasDarkModeEnabled(
) → bool -
hasDisplayDarkMode(
) → bool -
hasError(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasInfo(
) → bool -
hasPrimary(
) → bool -
hasPrimaryBackground(
) → bool -
hasPrimaryText(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSecondary(
) → bool -
hasSecondaryBackground(
) → bool -
hasSecondaryText(
) → bool -
hasSuccess(
) → bool -
hasTertiary(
) → bool -
hasWarning(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → FFColorScheme -
getDefault(
) → FFColorScheme