primary property
@doc If true, the column will be scrollable even if wrapped in another scrollable widget.
Implementation
@$pb.TagNumber(5)
$core.bool get primary => $_getBF(4);
@doc If true, the column will be scrollable even if wrapped in another scrollable widget.
@$pb.TagNumber(5)
$core.bool get primary => $_getBF(4);