useIntrinsicWidth property
@doc If true, the column will be wrapped in an IntrinsicWidth widget, making all children match the width of the widest child.
Implementation
@$pb.TagNumber(8)
$core.bool get useIntrinsicWidth => $_getBF(7);
@doc If true, the column will be wrapped in an IntrinsicWidth widget, making all children match the width of the widest child.
@$pb.TagNumber(8)
$core.bool get useIntrinsicWidth => $_getBF(7);