hasMultiConditions property
@doc Whether there are multiple conditions to be evaluated. If false, only the first condition (and conditional action) will be considered.
Implementation
@$pb.TagNumber(5)
$core.bool get hasMultiConditions => $_getBF(4);
@doc Whether there are multiple conditions to be evaluated. If false, only the first condition (and conditional action) will be considered.
@$pb.TagNumber(5)
$core.bool get hasMultiConditions => $_getBF(4);