animated property
Not overridable @doc Whether the container will animate when its properties change.
Implementation
@$pb.TagNumber(7)
$core.bool get animated => $_getBF(6);
Not overridable @doc Whether the container will animate when its properties change.
@$pb.TagNumber(7)
$core.bool get animated => $_getBF(6);