clipContent property
Not overridable @doc Whether the container should be clipped to its bounds.
Implementation
@$pb.TagNumber(6)
$core.bool get clipContent => $_getBF(5);
Not overridable @doc Whether the container should be clipped to its bounds.
@$pb.TagNumber(6)
$core.bool get clipContent => $_getBF(5);