safeArea property
Not overridable @doc Whether to add indentation on the child of this container.
Implementation
@$pb.TagNumber(11)
$core.bool get safeArea => $_getBF(10);
Not overridable @doc Whether to add indentation on the child of this container.
@$pb.TagNumber(11)
$core.bool get safeArea => $_getBF(10);