parameters property
@doc The list of input parameters to the custom cloud function.
Implementation
@$pb.TagNumber(2)
$pb.PbList<FFParameter> get parameters => $_getList(1);
@doc The list of input parameters to the custom cloud function.
@$pb.TagNumber(2)
$pb.PbList<FFParameter> get parameters => $_getList(1);