memory property
@doc The memory allocated for the custom cloud function.
Implementation
@$pb.TagNumber(3)
$core.String get memory => $_getSZ(2);
@doc The memory allocated for the custom cloud function.
@$pb.TagNumber(3)
$core.String get memory => $_getSZ(2);