region property
@doc The region where the custom cloud function is deployed.
Implementation
@$pb.TagNumber(1)
$core.String get region => $_getSZ(0);
@doc The region where the custom cloud function is deployed.
@$pb.TagNumber(1)
$core.String get region => $_getSZ(0);