requireAuth property
@doc Whether to require users to be authenticated to execute.
Implementation
@$pb.TagNumber(4)
$core.bool get requireAuth => $_getBF(3);
@doc Whether to require users to be authenticated to execute.
@$pb.TagNumber(4)
$core.bool get requireAuth => $_getBF(3);