timeoutSeconds property
@doc The timeout in seconds for the custom cloud function.
Implementation
@$pb.TagNumber(2)
$core.int get timeoutSeconds => $_getIZ(1);
@doc The timeout in seconds for the custom cloud function.
@$pb.TagNumber(2)
$core.int get timeoutSeconds => $_getIZ(1);