customCodeEntities property
/ Resolved custom code entities that is available in this file
Implementation
@$pb.TagNumber(3)
$pb.PbList<FFCustomCodeEntity> get customCodeEntities => $_getList(2);
/ Resolved custom code entities that is available in this file
@$pb.TagNumber(3)
$pb.PbList<FFCustomCodeEntity> get customCodeEntities => $_getList(2);