isVisible property
/ Whether this is a library that is visible to the user.
Implementation
@$pb.TagNumber(3)
$core.bool get isVisible => $_getBF(2);
/ Whether this is a library that is visible to the user.
@$pb.TagNumber(3)
$core.bool get isVisible => $_getBF(2);