avoidOverflow property
@doc Whether to shift the dialog to avoid overflowing the screen.
Implementation
@$pb.TagNumber(12)
$core.bool get avoidOverflow => $_getBF(11);
@doc Whether to shift the dialog to avoid overflowing the screen.
@$pb.TagNumber(12)
$core.bool get avoidOverflow => $_getBF(11);