isGlobal property

  1. @TagNumber(8)
bool get isGlobal

@doc Whether to align the dialog with respect to the target widget which triggered the open dialog action.

Implementation

@$pb.TagNumber(8)
$core.bool get isGlobal => $_getBF(7);
  1. @TagNumber(8)
set isGlobal (bool value)

Implementation

@$pb.TagNumber(8)
set isGlobal($core.bool value) => $_setBool(7, value);