finalCustomActions property
@doc Custom actions called after the generated main code.
Implementation
@$pb.TagNumber(2)
$pb.PbList<FFIdentifier> get finalCustomActions => $_getList(1);
@doc Custom actions called after the generated main code.
@$pb.TagNumber(2)
$pb.PbList<FFIdentifier> get finalCustomActions => $_getList(1);