initialCustomActions property
@doc Custom actions called before the generated main code.
Implementation
@$pb.TagNumber(1)
$pb.PbList<FFIdentifier> get initialCustomActions => $_getList(0);
@doc Custom actions called before the generated main code.
@$pb.TagNumber(1)
$pb.PbList<FFIdentifier> get initialCustomActions => $_getList(0);