arguments property
@doc The list of input parameters for the custom function.
Implementation
@$pb.TagNumber(2)
$pb.PbList<FFParameter> get arguments => $_getList(1);
@doc The list of input parameters for the custom function.
@$pb.TagNumber(2)
$pb.PbList<FFParameter> get arguments => $_getList(1);