staticGetters property
/ TODO: combine static and non static entities into one list
Implementation
@$pb.TagNumber(9)
$pb.PbList<FFParameter> get staticGetters => $_getList(8);
/ TODO: combine static and non static entities into one list
@$pb.TagNumber(9)
$pb.PbList<FFParameter> get staticGetters => $_getList(8);