parameters property
@doc The list of input parameters for the custom widget.
Implementation
@$pb.TagNumber(4)
$pb.PbList<FFParameter> get parameters => $_getList(3);
@doc The list of input parameters for the custom widget.
@$pb.TagNumber(4)
$pb.PbList<FFParameter> get parameters => $_getList(3);