FFDatabaseRequest_Request enum

Inheritance
Available extensions

Values

firestore → const FFDatabaseRequest_Request
document → const FFDatabaseRequest_Request
apiCall → const FFDatabaseRequest_Request
algolia → const FFDatabaseRequest_Request
postgres → const FFDatabaseRequest_Request
sqlite → const FFDatabaseRequest_Request
notSet → const FFDatabaseRequest_Request

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FFDatabaseRequest_Request>
A constant List of the values in this enum, in order of their declaration.