FFDatePicker class

Inheritance
Available extensions

Constructors

FFDatePicker({FFDatePicker_DateTimePickerType? pickerType, bool? allowPast, FFValue? defaultDateTime, bool? allowFuture, FFValue? minDateTime, FFValue? maxDateTime, bool? useDefaultTheme, bool? useCupertinoStyle, FFText? headerDateStyle, FFColor? headerBackgroundColor, FFColor? headerForegroundColor, FFColor? pickerBackgroundColor, FFColor? pickerForegroundColor, FFColor? selectedDateTimeForegroundColor, FFColor? selectedDateTimeBackgroundColor, FFColor? actionButtonForegroundColor, FFColor? cupertinoBackgroundColor, FFText? cupertinoTextStyle, double? iconSize, bool? dismissible})
factory
FFDatePicker.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFDatePicker.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

actionButtonForegroundColor FFColor
@doc The action button foreground color.
getter/setter pair
allowFuture bool
@doc Whether to allow picking future dates.
getter/setter pair
allowPast bool
@doc Whether to allow picking past dates.
getter/setter pair
cupertinoBackgroundColor FFColor
@doc The Cupertino style Date/Time Picker background color.
getter/setter pair
cupertinoTextStyle FFText
@doc The Cupertino style Date/Time Picker text style.
getter/setter pair
defaultDateTime FFValue
@doc The initially selected Date/Time to default to.
getter/setter pair
dismissible bool
@doc Whether tapping outside the Date/Time Picker window can dismiss it.
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
headerBackgroundColor FFColor
@doc The header background color.
getter/setter pair
headerDateStyle FFText
@doc The header title style.
getter/setter pair
headerForegroundColor FFColor
@doc The header foreground color.
getter/setter pair
iconSize double
@doc The size of all icons on the date picker.
getter/setter pair
info_ BuilderInfo
no setteroverride
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
maxDateTime FFValue
@doc The latest Date/Time that can be selected.
getter/setter pair
minDateTime FFValue
@doc The earliest Date/Time that can be selected.
getter/setter pair
pickerBackgroundColor FFColor
@doc The picker background color.
getter/setter pair
pickerForegroundColor FFColor
@doc The picker foreground color.
getter/setter pair
pickerType FFDatePicker_DateTimePickerType
@doc The type of date time picker to display.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDateTimeBackgroundColor FFColor
@doc The selected Date/Time background color.
getter/setter pair
selectedDateTimeForegroundColor FFColor
@doc The selected Date/Time foreground color.
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
useCupertinoStyle bool
@doc Whether to use the Cupertino style Date/Time Picker.
getter/setter pair
useDefaultTheme bool
@doc Whether to use the Flutter's default Date/Time Picker theme.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearActionButtonForegroundColor() → void
clearAllowFuture() → void
clearAllowPast() → void
clearCupertinoBackgroundColor() → void
clearCupertinoTextStyle() → void
clearDefaultDateTime() → void
clearDismissible() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearHeaderBackgroundColor() → void
clearHeaderDateStyle() → void
clearHeaderForegroundColor() → void
clearIconSize() → void
clearMaxDateTime() → void
clearMinDateTime() → void
clearPickerBackgroundColor() → void
clearPickerForegroundColor() → void
clearPickerType() → void
clearSelectedDateTimeBackgroundColor() → void
clearSelectedDateTimeForegroundColor() → void
clearUseCupertinoStyle() → void
clearUseDefaultTheme() → void
clone() FFDatePicker
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFDatePicker)) FFDatePicker
Apply updates to a copy of this message.
override
createEmptyInstance() FFDatePicker
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureActionButtonForegroundColor() FFColor
ensureCupertinoBackgroundColor() FFColor
ensureCupertinoTextStyle() FFText
ensureDefaultDateTime() FFValue
ensureHeaderBackgroundColor() FFColor
ensureHeaderDateStyle() FFText
ensureHeaderForegroundColor() FFColor
ensureMaxDateTime() FFValue
ensureMinDateTime() FFValue
ensurePickerBackgroundColor() FFColor
ensurePickerForegroundColor() FFColor
ensureSelectedDateTimeBackgroundColor() FFColor
ensureSelectedDateTimeForegroundColor() FFColor
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasActionButtonForegroundColor() bool
hasAllowFuture() bool
hasAllowPast() bool
hasCupertinoBackgroundColor() bool
hasCupertinoTextStyle() bool
hasDefaultDateTime() bool
hasDismissible() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasHeaderBackgroundColor() bool
hasHeaderDateStyle() bool
hasHeaderForegroundColor() bool
hasIconSize() bool
hasMaxDateTime() bool
hasMinDateTime() bool
hasPickerBackgroundColor() bool
hasPickerForegroundColor() bool
hasPickerType() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSelectedDateTimeBackgroundColor() bool
hasSelectedDateTimeForegroundColor() bool
hasUseCupertinoStyle() bool
hasUseDefaultTheme() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFDatePicker
getDefault() FFDatePicker