abbreviated property
Whether to use the short format when possible with the relative format.
Implementation
@$pb.TagNumber(2)
$core.bool get abbreviated => $_getBF(1);
Whether to use the short format when possible with the relative format.
@$pb.TagNumber(2)
$core.bool get abbreviated => $_getBF(1);