commitId property
@doc The commit ID of the version of the library project in use.
Implementation
@$pb.TagNumber(5)
$core.String get commitId => $_getSZ(4);
@doc The commit ID of the version of the library project in use.
@$pb.TagNumber(5)
$core.String get commitId => $_getSZ(4);