isNested property
@doc Whether the library is a nested dependency of another library.
Implementation
@$pb.TagNumber(4)
$core.bool get isNested => $_getBF(3);
@doc Whether the library is a nested dependency of another library.
@$pb.TagNumber(4)
$core.bool get isNested => $_getBF(3);