legacyDisabled property
Similar to FFVisibility, this value can be overridden with the condition for disabling
Implementation
@$pb.TagNumber(1)
$core.bool get legacyDisabled => $_getBF(0);
Similar to FFVisibility, this value can be overridden with the condition for disabling
@$pb.TagNumber(1)
$core.bool get legacyDisabled => $_getBF(0);