inputValue property
@doc A preset double value that represents a static/hardcoded double.
Implementation
@$pb.TagNumber(1)
$core.double get inputValue => $_getN(0);
@doc A preset double value that represents a static/hardcoded double.
@$pb.TagNumber(1)
$core.double get inputValue => $_getN(0);