mostRecentInputValue property

  1. @TagNumber(3)
double get mostRecentInputValue

@doc Stores the most recent double this value was set to in order to restore after removing a variable.

Implementation

@$pb.TagNumber(3)
$core.double get mostRecentInputValue => $_getN(2);
  1. @TagNumber(3)
set mostRecentInputValue (double value)

Implementation

@$pb.TagNumber(3)
set mostRecentInputValue($core.double value) => $_setDouble(2, value);