FFDropDown class

Inheritance
Available extensions

Constructors

FFDropDown({@Deprecated('This field is deprecated.') String? legacyInitialOption, @Deprecated('This field is deprecated.') Iterable<String>? legacyOptions, FFDimensions? dimensions, FFIcon? legacyIcon, FFColor? legacyFillColor, double? legacyElevation, double? legacyBorderRadius, FFColor? legacyBorderColor, double? legacyBorderWidth, FFText? textStyle, FFPadding? margin, bool? legacyHidesUnderline, @Deprecated('This field is deprecated.') String? legacyHintText, FFText? initialOption, @Deprecated('This field is deprecated.') Iterable<FFText>? legacyOptionsLabels, FFText? hintText, @Deprecated('This field is deprecated.') Iterable<FFParameterValue>? legacyOptionsValues, bool? optionsHasKeyValues, FFParameter? valueType, FFParameterValue? legacyInitialOptionKeyValue, FFDisable? disabled, bool? isSearchable, FFText? searchHintText, FFColor? legacySearchCursorColor, bool? isMultiSelect, bool? fixPosition, FFDim? maxHeight, FFText? searchTextStyle, FFOffset? menuOffset, FFText? label, FFColorValue? fillColorValue, FFDoubleValue? elevationValue, FFDoubleValue? borderRadiusValue, FFColorValue? borderColorValue, FFDoubleValue? borderWidthValue, FFBooleanValue? hidesUnderlineValue, FFColorValue? searchCursorColorValue, FFIconValue? iconValue, FFFormOptionsValue? initialOptionKeyValue, FFFormOptionsValue? optionsLabels, FFFormOptionsValue? optionsValues, FFDropDownTesting? testing, FFColorValue? focusBorderColorValue})
factory
FFDropDown.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFDropDown.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

borderColorValue FFColorValue
getter/setter pair
borderRadiusValue FFDoubleValue
getter/setter pair
borderWidthValue FFDoubleValue
getter/setter pair
dimensions FFDimensions
getter/setter pair
disabled FFDisable
getter/setter pair
elevationValue FFDoubleValue
getter/setter pair
fillColorValue FFColorValue
getter/setter pair
fixPosition bool
Should not be overridable
getter/setter pair
focusBorderColorValue FFColorValue
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hidesUnderlineValue FFBooleanValue
getter/setter pair
hintText FFText
getter/setter pair
iconValue FFIconValue
getter/setter pair
info_ BuilderInfo
no setteroverride
initialOption FFText
getter/setter pair
initialOptionKeyValue FFFormOptionsValue
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isMultiSelect bool
Should not be overridable
getter/setter pair
isSearchable bool
Should not be overridable
getter/setter pair
label FFText
getter/setter pair
legacyBorderColor FFColor
getter/setter pair
legacyBorderRadius double
getter/setter pair
legacyBorderWidth double
getter/setter pair
legacyElevation double
getter/setter pair
legacyFillColor FFColor
getter/setter pair
legacyHidesUnderline bool
getter/setter pair
legacyHintText String
getter/setter pair
legacyIcon FFIcon
getter/setter pair
legacyInitialOption String
getter/setter pair
legacyInitialOptionKeyValue FFParameterValue
getter/setter pair
legacyOptions PbList<String>
no setter
legacyOptionsLabels PbList<FFText>
no setter
legacyOptionsValues PbList<FFParameterValue>
no setter
legacySearchCursorColor FFColor
getter/setter pair
margin FFPadding
getter/setter pair
maxHeight FFDim
getter/setter pair
getter/setter pair
optionsHasKeyValues bool
Should not be overridable
getter/setter pair
optionsLabels FFFormOptionsValue
getter/setter pair
optionsValues FFFormOptionsValue
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchCursorColorValue FFColorValue
getter/setter pair
searchHintText FFText
getter/setter pair
searchTextStyle FFText
getter/setter pair
testing FFDropDownTesting
@doc Stores some info for testing the DropDown widget.
getter/setter pair
textStyle FFText
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
valueType FFParameter
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBorderColorValue() → void
clearBorderRadiusValue() → void
clearBorderWidthValue() → void
clearDimensions() → void
clearDisabled() → void
clearElevationValue() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFillColorValue() → void
clearFixPosition() → void
clearFocusBorderColorValue() → void
clearHidesUnderlineValue() → void
clearHintText() → void
clearIconValue() → void
clearInitialOption() → void
clearInitialOptionKeyValue() → void
clearIsMultiSelect() → void
clearIsSearchable() → void
clearLabel() → void
clearLegacyBorderColor() → void
clearLegacyBorderRadius() → void
clearLegacyBorderWidth() → void
clearLegacyElevation() → void
clearLegacyFillColor() → void
clearLegacyHidesUnderline() → void
clearLegacyHintText() → void
clearLegacyIcon() → void
clearLegacyInitialOption() → void
clearLegacyInitialOptionKeyValue() → void
clearLegacySearchCursorColor() → void
clearMargin() → void
clearMaxHeight() → void
clearMenuOffset() → void
clearOptionsHasKeyValues() → void
clearOptionsLabels() → void
clearOptionsValues() → void
clearSearchCursorColorValue() → void
clearSearchHintText() → void
clearSearchTextStyle() → void
clearTesting() → void
clearTextStyle() → void
clearValueType() → void
clone() FFDropDown
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFDropDown)) FFDropDown
Apply updates to a copy of this message.
override
createEmptyInstance() FFDropDown
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureBorderColorValue() FFColorValue
ensureBorderRadiusValue() FFDoubleValue
ensureBorderWidthValue() FFDoubleValue
ensureDimensions() FFDimensions
ensureDisabled() FFDisable
ensureElevationValue() FFDoubleValue
ensureFillColorValue() FFColorValue
ensureFocusBorderColorValue() FFColorValue
ensureHidesUnderlineValue() FFBooleanValue
ensureHintText() FFText
ensureIconValue() FFIconValue
ensureInitialOption() FFText
ensureInitialOptionKeyValue() FFFormOptionsValue
ensureLabel() FFText
ensureLegacyBorderColor() FFColor
ensureLegacyFillColor() FFColor
ensureLegacyIcon() FFIcon
ensureLegacyInitialOptionKeyValue() FFParameterValue
ensureLegacySearchCursorColor() FFColor
ensureMargin() FFPadding
ensureMaxHeight() FFDim
ensureMenuOffset() FFOffset
ensureOptionsLabels() FFFormOptionsValue
ensureOptionsValues() FFFormOptionsValue
ensureSearchCursorColorValue() FFColorValue
ensureSearchHintText() FFText
ensureSearchTextStyle() FFText
ensureTesting() FFDropDownTesting
ensureTextStyle() FFText
ensureValueType() FFParameter
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasBorderColorValue() bool
hasBorderRadiusValue() bool
hasBorderWidthValue() bool
hasDimensions() bool
hasDisabled() bool
hasElevationValue() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFillColorValue() bool
hasFixPosition() bool
hasFocusBorderColorValue() bool
hasHidesUnderlineValue() bool
hasHintText() bool
hasIconValue() bool
hasInitialOption() bool
hasInitialOptionKeyValue() bool
hasIsMultiSelect() bool
hasIsSearchable() bool
hasLabel() bool
hasLegacyBorderColor() bool
hasLegacyBorderRadius() bool
hasLegacyBorderWidth() bool
hasLegacyElevation() bool
hasLegacyFillColor() bool
hasLegacyHidesUnderline() bool
hasLegacyHintText() bool
hasLegacyIcon() bool
hasLegacyInitialOption() bool
hasLegacyInitialOptionKeyValue() bool
hasLegacySearchCursorColor() bool
hasMargin() bool
hasMaxHeight() bool
hasMenuOffset() bool
hasOptionsHasKeyValues() bool
hasOptionsLabels() bool
hasOptionsValues() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSearchCursorColorValue() bool
hasSearchHintText() bool
hasSearchTextStyle() bool
hasTesting() bool
hasTextStyle() bool
hasValueType() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFDropDown
getDefault() FFDropDown