ignoreChildren property
By default, when we accept a node edit we accept it's new children as well. If this is set to true we will keep the old children on the updated node.
Implementation
@$pb.TagNumber(4)
$core.bool get ignoreChildren => $_getBF(3);