totalNumUpdates property
Tracks the lifetime number of updates on this object (currently only used for the entire project).
Implementation
@$pb.TagNumber(7)
$core.int get totalNumUpdates => $_getIZ(6);
Tracks the lifetime number of updates on this object (currently only used for the entire project).
@$pb.TagNumber(7)
$core.int get totalNumUpdates => $_getIZ(6);