key property
The key (from above) of the object deleted. If it's a node or widget class name this is the hash of the string.
Implementation
@$pb.TagNumber(1)
$core.int get key => $_getIZ(0);
The key (from above) of the object deleted. If it's a node or widget class name this is the hash of the string.
@$pb.TagNumber(1)
$core.int get key => $_getIZ(0);