environments property
@doc List of user defined environments in the project.
Implementation
@$pb.TagNumber(2)
$pb.PbList<FFIdentifier> get environments => $_getList(1);
@doc List of user defined environments in the project.
@$pb.TagNumber(2)
$pb.PbList<FFIdentifier> get environments => $_getList(1);