heroAnimation property
@doc Whether transition to the expanded image should use a hero animation.
Implementation
@$pb.TagNumber(2)
$core.bool get heroAnimation => $_getBF(1);
@doc Whether transition to the expanded image should use a hero animation.
@$pb.TagNumber(2)
$core.bool get heroAnimation => $_getBF(1);