onActionsStart property
@doc Whether to log a single event when a user triggers actions.
Implementation
@$pb.TagNumber(2)
$core.bool get onActionsStart => $_getBF(1);
@doc Whether to log a single event when a user triggers actions.
@$pb.TagNumber(2)
$core.bool get onActionsStart => $_getBF(1);