onAuth property

  1. @TagNumber(4)
bool get onAuth

@doc Whether to log an event when a user interacts with authentication in the form of signup, login, logout, reset password, or delete account.

Implementation

@$pb.TagNumber(4)
$core.bool get onAuth => $_getBF(3);
  1. @TagNumber(4)
set onAuth (bool value)

Implementation

@$pb.TagNumber(4)
set onAuth($core.bool value) => $_setBool(3, value);