onIndividualActions property
@doc Whether to log an event on each individual action that is triggered.
Implementation
@$pb.TagNumber(3)
$core.bool get onIndividualActions => $_getBF(2);
@doc Whether to log an event on each individual action that is triggered.
@$pb.TagNumber(3)
$core.bool get onIndividualActions => $_getBF(2);