FFFirestoreQuery class

Inheritance
Available extensions

Constructors

FFFirestoreQuery({FFIdentifier? collectionIdentifier, @Deprecated('This field is deprecated.') Iterable<FFFirestoreFilter>? legacyWhere, Iterable<FFFirestoreOrderBy>? orderBy, int? limit, bool? hideOnEmpty, bool? singleTimeQuery, bool? ignoreEmptyValues, FFFirestorePagination? pagination, bool? excludeCurrentUser, FFValue? parentReference, FFFirestoreAggregation? aggregation, bool? filterOnNull, FFFirestoreWhere? where})
factory
FFFirestoreQuery.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFFirestoreQuery.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

aggregation FFFirestoreAggregation
getter/setter pair
collectionIdentifier FFIdentifier
Identifier of the FFCollection whose collection we're querying. Redundant with the parameter.collection_identifier field in FFDatabaseRequest.
getter/setter pair
excludeCurrentUser bool
Whether to manually filter the current user from a Users query (instead of having to add a "!=" filter in the query).
getter/setter pair
filterOnNull bool
Do not filter when field are null.
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hideOnEmpty bool
Whether single element queries should yield an empty widget when no such document exists.
getter/setter pair
ignoreEmptyValues bool
Do not filter when fields are empty.
getter/setter pair
info_ BuilderInfo
no setteroverride
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
legacyWhere PbList<FFFirestoreFilter>
no setter
limit int
Number of elements returned (if return type is list). Ignored if pagination is enabled.
getter/setter pair
orderBy PbList<FFFirestoreOrderBy>
no setter
pagination FFFirestorePagination
Pagination/infinite scroll config.
getter/setter pair
parentReference FFValue
Parent reference if the collection is a sub-collection. If not set and the query is on a sub-collection, this becomes a collection group query.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleTimeQuery bool
If true, use Future instead of Stream Ignored if pagination is enabled.
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
where FFFirestoreWhere
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAggregation() → void
clearCollectionIdentifier() → void
clearExcludeCurrentUser() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFilterOnNull() → void
clearHideOnEmpty() → void
clearIgnoreEmptyValues() → void
clearLimit() → void
clearPagination() → void
clearParentReference() → void
clearSingleTimeQuery() → void
clearWhere() → void
clone() FFFirestoreQuery
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFFirestoreQuery)) FFFirestoreQuery
Apply updates to a copy of this message.
override
createEmptyInstance() FFFirestoreQuery
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAggregation() FFFirestoreAggregation
ensureCollectionIdentifier() FFIdentifier
ensurePagination() FFFirestorePagination
ensureParentReference() FFValue
ensureWhere() FFFirestoreWhere
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAggregation() bool
hasCollectionIdentifier() bool
hasExcludeCurrentUser() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFilterOnNull() bool
hasHideOnEmpty() bool
hasIgnoreEmptyValues() bool
hasLimit() bool
hasPagination() bool
hasParentReference() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSingleTimeQuery() bool
hasWhere() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFFirestoreQuery
getDefault() FFFirestoreQuery