excludeCurrentUser property
Whether to manually filter the current user from a Users query (instead of having to add a "!=" filter in the query).
Implementation
@$pb.TagNumber(10)
$core.bool get excludeCurrentUser => $_getBF(8);
Whether to manually filter the current user from a Users query (instead of having to add a "!=" filter in the query).
@$pb.TagNumber(10)
$core.bool get excludeCurrentUser => $_getBF(8);