hideOnEmpty property
Whether single element queries should yield an empty widget when no such document exists.
Implementation
@$pb.TagNumber(5)
$core.bool get hideOnEmpty => $_getBF(4);
Whether single element queries should yield an empty widget when no such document exists.
@$pb.TagNumber(5)
$core.bool get hideOnEmpty => $_getBF(4);