parentReference property
Parent reference if the collection is a sub-collection. If not set and the query is on a sub-collection, this becomes a collection group query.
Implementation
@$pb.TagNumber(11)
FFValue get parentReference => $_getN(9);
Parent reference if the collection is a sub-collection. If not set and the query is on a sub-collection, this becomes a collection group query.
@$pb.TagNumber(11)
FFValue get parentReference => $_getN(9);