legacyIsHorizontal property
This corresponds to a FFAxis, but I'm using a boolean instead to allow for overrides much easier Once the property refactor is done, we can consider doing that refactor
Implementation
@$pb.TagNumber(1)
$core.bool get legacyIsHorizontal => $_getBF(0);