begin property
@doc The starting value for the flip animation, where 1 flip is 180 degrees.
Implementation
@$pb.TagNumber(4)
FFValue get begin => $_getN(3);
@doc The starting value for the flip animation, where 1 flip is 180 degrees.
@$pb.TagNumber(4)
FFValue get begin => $_getN(3);