borderRadius property
@doc Defines how rounded the corners of the focus border are, helping create a consistent visual indicator for keyboard focus.
Implementation
@$pb.TagNumber(2)
FFBorderRadius get borderRadius => $_getN(1);
Implementation
@$pb.TagNumber(2)
set borderRadius(FFBorderRadius value) => $_setField(2, value);