borderWidthValue property
@doc The thickness of the focus border, important for ensuring the focus indicator is clearly visible for keyboard navigation.
Implementation
@$pb.TagNumber(4)
FFDoubleValue get borderWidthValue => $_getN(3);
Implementation
@$pb.TagNumber(4)
set borderWidthValue(FFDoubleValue value) => $_setField(4, value);