padding property
@doc The padding of the focus border, which should provide sufficient contrast to indicate keyboard focus state clearly.
Implementation
@$pb.TagNumber(5)
FFPadding get padding => $_getN(4);
@doc The padding of the focus border, which should provide sufficient contrast to indicate keyboard focus state clearly.
@$pb.TagNumber(5)
FFPadding get padding => $_getN(4);