wrapInFocusGroup property

  1. @TagNumber(1)
bool get wrapInFocusGroup

@doc Whether to wrap this widget in a FocusTraversalGroup. When enabled, this widget and its descendants will be wrapped in a FocusTraversalGroup, which allows for more granular control over how keyboard focus moves through the UI. Focus can still move between different FocusTraversalGroups based on the focus traversal order.

Implementation

@$pb.TagNumber(1)
$core.bool get wrapInFocusGroup => $_getBF(0);
  1. @TagNumber(1)
set wrapInFocusGroup (bool value)

Implementation

@$pb.TagNumber(1)
set wrapInFocusGroup($core.bool value) => $_setBool(0, value);