legacyNodeKey property
Form fields are identified by their node key and validation type.
For validations associated with actions (date picker, upload media) the node_key is the node the action is attached to.
Note that a node can have more than one validation, e.g. if the same button first triggers a date picker and then a place picker (for some reason).
Implementation
@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(1)
$core.String get legacyNodeKey => $_getSZ(0);
Implementation
@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(1)
set legacyNodeKey($core.String value) => $_setString(0, value);