action property
@doc This is used to pass in an action as an argument.
Implementation
@$pb.TagNumber(2)
FFTriggerActions get action => $_getN(1);
Implementation
@$pb.TagNumber(2)
set action(FFTriggerActions value) => $_setField(2, value);
@doc This is used to pass in an action as an argument.
@$pb.TagNumber(2)
FFTriggerActions get action => $_getN(1);
@$pb.TagNumber(2)
set action(FFTriggerActions value) => $_setField(2, value);