identifier property
A way to give this variable a name for use in the UI and generated code. We'll need to make sure this isn't duplicated anywhere within the same branch of the node tree (probably easier to just make unique within page).
Implementation
@$pb.TagNumber(1)
FFIdentifier get identifier => $_getN(0);
Implementation
@$pb.TagNumber(1)
set identifier(FFIdentifier value) => $_setField(1, value);