mapTakesGesturePreference property
@doc Whether the map takes gesture preference, such as when the map is within a scrollable Widget.
Implementation
@$pb.TagNumber(33)
FFBooleanValue get mapTakesGesturePreference => $_getN(32);
Implementation
@$pb.TagNumber(33)
set mapTakesGesturePreference(FFBooleanValue value) => $_setField(33, value);