showZoomControls property
Should not be overridable @doc Whether to show the zoom controls on the map.
Implementation
@$pb.TagNumber(10)
$core.bool get showZoomControls => $_getBF(9);
Should not be overridable @doc Whether to show the zoom controls on the map.
@$pb.TagNumber(10)
$core.bool get showZoomControls => $_getBF(9);