updatePageOnMapMove property
Should not be overridable @doc Whether to update page when map is moved.
Implementation
@$pb.TagNumber(16)
$core.bool get updatePageOnMapMove => $_getBF(15);
Should not be overridable @doc Whether to update page when map is moved.
@$pb.TagNumber(16)
$core.bool get updatePageOnMapMove => $_getBF(15);