FFIconButton class

Inheritance
Available extensions

Constructors

FFIconButton({FFIcon? legacyIcon, @Deprecated('This field is deprecated.') double? legacyIconSize, @Deprecated('This field is deprecated.') double? elevation, FFColor? legacyFillColor, @Deprecated('This field is deprecated.') double? legacyButtonSize, double? legacyBorderRadius, FFColor? legacyBorderColor, double? legacyBorderWidth, bool? legacyShowLoadingIndicator, FFDisable? disabled, FFColor? legacyDisabledColor, FFColor? legacyDisabledIconColor, bool? hasHoverStyle, FFColor? legacyHoverColor, FFColor? legacyHoverIconColor, FFDim? buttonSize, FFColorValue? fillColorValue, FFDoubleValue? borderRadiusValue, FFColorValue? borderColorValue, FFDoubleValue? borderWidthValue, FFBooleanValue? showLoadingIndicatorValue, FFColorValue? disabledColorValue, FFColorValue? disabledIconColorValue, FFColorValue? hoverColorValue, FFColorValue? hoverIconColorValue, FFIconValue? iconValue, FFColorValue? hoverBorderColorValue})
factory
FFIconButton.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFIconButton.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

borderColorValue FFColorValue
getter/setter pair
borderRadiusValue FFDoubleValue
getter/setter pair
borderWidthValue FFDoubleValue
getter/setter pair
buttonSize FFDim
getter/setter pair
disabled FFDisable
getter/setter pair
disabledColorValue FFColorValue
getter/setter pair
disabledIconColorValue FFColorValue
getter/setter pair
elevation double
getter/setter pair
fillColorValue FFColorValue
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hasHoverStyle bool
Not overridable
getter/setter pair
hoverBorderColorValue FFColorValue
getter/setter pair
hoverColorValue FFColorValue
getter/setter pair
hoverIconColorValue FFColorValue
getter/setter pair
iconValue FFIconValue
getter/setter pair
info_ BuilderInfo
no setteroverride
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
legacyBorderColor FFColor
getter/setter pair
legacyBorderRadius double
getter/setter pair
legacyBorderWidth double
getter/setter pair
legacyButtonSize double
getter/setter pair
legacyDisabledColor FFColor
getter/setter pair
legacyDisabledIconColor FFColor
getter/setter pair
legacyFillColor FFColor
getter/setter pair
legacyHoverColor FFColor
getter/setter pair
legacyHoverIconColor FFColor
getter/setter pair
legacyIcon FFIcon
getter/setter pair
legacyIconSize double
getter/setter pair
legacyShowLoadingIndicator bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLoadingIndicatorValue FFBooleanValue
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBorderColorValue() → void
clearBorderRadiusValue() → void
clearBorderWidthValue() → void
clearButtonSize() → void
clearDisabled() → void
clearDisabledColorValue() → void
clearDisabledIconColorValue() → void
clearElevation() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFillColorValue() → void
clearHasHoverStyle() → void
clearHoverBorderColorValue() → void
clearHoverColorValue() → void
clearHoverIconColorValue() → void
clearIconValue() → void
clearLegacyBorderColor() → void
clearLegacyBorderRadius() → void
clearLegacyBorderWidth() → void
clearLegacyButtonSize() → void
clearLegacyDisabledColor() → void
clearLegacyDisabledIconColor() → void
clearLegacyFillColor() → void
clearLegacyHoverColor() → void
clearLegacyHoverIconColor() → void
clearLegacyIcon() → void
clearLegacyIconSize() → void
clearLegacyShowLoadingIndicator() → void
clearShowLoadingIndicatorValue() → void
clone() FFIconButton
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFIconButton)) FFIconButton
Apply updates to a copy of this message.
override
createEmptyInstance() FFIconButton
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureBorderColorValue() FFColorValue
ensureBorderRadiusValue() FFDoubleValue
ensureBorderWidthValue() FFDoubleValue
ensureButtonSize() FFDim
ensureDisabled() FFDisable
ensureDisabledColorValue() FFColorValue
ensureDisabledIconColorValue() FFColorValue
ensureFillColorValue() FFColorValue
ensureHoverBorderColorValue() FFColorValue
ensureHoverColorValue() FFColorValue
ensureHoverIconColorValue() FFColorValue
ensureIconValue() FFIconValue
ensureLegacyBorderColor() FFColor
ensureLegacyDisabledColor() FFColor
ensureLegacyDisabledIconColor() FFColor
ensureLegacyFillColor() FFColor
ensureLegacyHoverColor() FFColor
ensureLegacyHoverIconColor() FFColor
ensureLegacyIcon() FFIcon
ensureShowLoadingIndicatorValue() FFBooleanValue
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasBorderColorValue() bool
hasBorderRadiusValue() bool
hasBorderWidthValue() bool
hasButtonSize() bool
hasDisabled() bool
hasDisabledColorValue() bool
hasDisabledIconColorValue() bool
hasElevation() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFillColorValue() bool
hasHasHoverStyle() bool
hasHoverBorderColorValue() bool
hasHoverColorValue() bool
hasHoverIconColorValue() bool
hasIconValue() bool
hasLegacyBorderColor() bool
hasLegacyBorderRadius() bool
hasLegacyBorderWidth() bool
hasLegacyButtonSize() bool
hasLegacyDisabledColor() bool
hasLegacyDisabledIconColor() bool
hasLegacyFillColor() bool
hasLegacyHoverColor() bool
hasLegacyHoverIconColor() bool
hasLegacyIcon() bool
hasLegacyIconSize() bool
hasLegacyShowLoadingIndicator() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasShowLoadingIndicatorValue() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFIconButton
getDefault() FFIconButton