inputValue property
@doc A preset icon value that represents a static/hardcoded icon.
Implementation
@$pb.TagNumber(1)
FFIcon get inputValue => $_getN(0);
@doc A preset icon value that represents a static/hardcoded icon.
@$pb.TagNumber(1)
FFIcon get inputValue => $_getN(0);