useBlurHash property
use_blur_hash not used as a variable in image codegen
Implementation
@$pb.TagNumber(11)
$core.bool get useBlurHash => $_getBF(10);
use_blur_hash not used as a variable in image codegen
@$pb.TagNumber(11)
$core.bool get useBlurHash => $_getBF(10);