FFInputDecoration class

Inheritance
Available extensions

Constructors

FFInputDecoration({FFInputDecoration_InputBorderType? inputBorderType, @Deprecated('This field is deprecated.') Int64? legacyColor, double? legacyBorderWidth, FFBorderRadius? borderRadius, @Deprecated('This field is deprecated.') String? legacyHintText, @Deprecated('This field is deprecated.') String? legacyLabelText, FFColor? legacyBorderColor, bool? legacyDense, FFPadding? contentPadding, FFColor? legacyFillColor, bool? legacyFilled, FFText? hintStyle, FFText? labelStyle, FFColor? legacyErrorBorderColor, FFText? labelText, FFText? hintText, FFColor? legacyFocusBorderColor, FFText? errorTextStyle, bool? legacyAlignLabelWithHint, FFText? counterStyle, FFColorValue? borderColorValue, FFBooleanValue? filledValue, FFColorValue? fillColorValue, FFDoubleValue? borderWidthValue, FFBooleanValue? denseValue, FFColorValue? errorBorderColorValue, FFColorValue? focusBorderColorValue, FFBooleanValue? alignLabelWithHintValue, FFColor? legacyHoverColor, FFColorValue? hoverColorValue})
factory
FFInputDecoration.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFInputDecoration.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

alignLabelWithHintValue FFBooleanValue
getter/setter pair
borderColorValue FFColorValue
getter/setter pair
borderRadius FFBorderRadius
getter/setter pair
borderWidthValue FFDoubleValue
getter/setter pair
contentPadding FFPadding
getter/setter pair
counterStyle FFText
getter/setter pair
denseValue FFBooleanValue
getter/setter pair
errorBorderColorValue FFColorValue
getter/setter pair
errorTextStyle FFText
getter/setter pair
fillColorValue FFColorValue
getter/setter pair
filledValue FFBooleanValue
getter/setter pair
focusBorderColorValue FFColorValue
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hintStyle FFText
getter/setter pair
hintText FFText
getter/setter pair
hoverColorValue FFColorValue
getter/setter pair
info_ BuilderInfo
no setteroverride
inputBorderType FFInputDecoration_InputBorderType
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
labelStyle FFText
getter/setter pair
labelText FFText
getter/setter pair
legacyAlignLabelWithHint bool
getter/setter pair
legacyBorderColor FFColor
getter/setter pair
legacyBorderWidth double
getter/setter pair
legacyColor ↔ Int64
getter/setter pair
legacyDense bool
getter/setter pair
legacyErrorBorderColor FFColor
getter/setter pair
legacyFillColor FFColor
getter/setter pair
legacyFilled bool
getter/setter pair
legacyFocusBorderColor FFColor
getter/setter pair
legacyHintText String
getter/setter pair
legacyHoverColor FFColor
getter/setter pair
legacyLabelText String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknownFields UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAlignLabelWithHintValue() → void
clearBorderColorValue() → void
clearBorderRadius() → void
clearBorderWidthValue() → void
clearContentPadding() → void
clearCounterStyle() → void
clearDenseValue() → void
clearErrorBorderColorValue() → void
clearErrorTextStyle() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFillColorValue() → void
clearFilledValue() → void
clearFocusBorderColorValue() → void
clearHintStyle() → void
clearHintText() → void
clearHoverColorValue() → void
clearInputBorderType() → void
clearLabelStyle() → void
clearLabelText() → void
clearLegacyAlignLabelWithHint() → void
clearLegacyBorderColor() → void
clearLegacyBorderWidth() → void
clearLegacyColor() → void
clearLegacyDense() → void
clearLegacyErrorBorderColor() → void
clearLegacyFillColor() → void
clearLegacyFilled() → void
clearLegacyFocusBorderColor() → void
clearLegacyHintText() → void
clearLegacyHoverColor() → void
clearLegacyLabelText() → void
clone() FFInputDecoration
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFInputDecoration)) FFInputDecoration
Apply updates to a copy of this message.
override
createEmptyInstance() FFInputDecoration
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAlignLabelWithHintValue() FFBooleanValue
ensureBorderColorValue() FFColorValue
ensureBorderRadius() FFBorderRadius
ensureBorderWidthValue() FFDoubleValue
ensureContentPadding() FFPadding
ensureCounterStyle() FFText
ensureDenseValue() FFBooleanValue
ensureErrorBorderColorValue() FFColorValue
ensureErrorTextStyle() FFText
ensureFillColorValue() FFColorValue
ensureFilledValue() FFBooleanValue
ensureFocusBorderColorValue() FFColorValue
ensureHintStyle() FFText
ensureHintText() FFText
ensureHoverColorValue() FFColorValue
ensureLabelStyle() FFText
ensureLabelText() FFText
ensureLegacyBorderColor() FFColor
ensureLegacyErrorBorderColor() FFColor
ensureLegacyFillColor() FFColor
ensureLegacyFocusBorderColor() FFColor
ensureLegacyHoverColor() FFColor
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAlignLabelWithHintValue() bool
hasBorderColorValue() bool
hasBorderRadius() bool
hasBorderWidthValue() bool
hasContentPadding() bool
hasCounterStyle() bool
hasDenseValue() bool
hasErrorBorderColorValue() bool
hasErrorTextStyle() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFillColorValue() bool
hasFilledValue() bool
hasFocusBorderColorValue() bool
hasHintStyle() bool
hasHintText() bool
hasHoverColorValue() bool
hasInputBorderType() bool
hasLabelStyle() bool
hasLabelText() bool
hasLegacyAlignLabelWithHint() bool
hasLegacyBorderColor() bool
hasLegacyBorderWidth() bool
hasLegacyColor() bool
hasLegacyDense() bool
hasLegacyErrorBorderColor() bool
hasLegacyFillColor() bool
hasLegacyFilled() bool
hasLegacyFocusBorderColor() bool
hasLegacyHintText() bool
hasLegacyHoverColor() bool
hasLegacyLabelText() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited