inputValue property
@doc A preset integer value that represents a static/hardcoded integer.
Implementation
@$pb.TagNumber(1)
$core.int get inputValue => $_getIZ(0);
@doc A preset integer value that represents a static/hardcoded integer.
@$pb.TagNumber(1)
$core.int get inputValue => $_getIZ(0);