mostRecentInputValue property
@doc Stores the most recent integer this value was set to in order to restore after removing a variable.
Implementation
@$pb.TagNumber(3)
$core.int get mostRecentInputValue => $_getIZ(2);
@doc Stores the most recent integer this value was set to in order to restore after removing a variable.
@$pb.TagNumber(3)
$core.int get mostRecentInputValue => $_getIZ(2);