unfocus property
@doc Whether to unfocus the text field after entering text.
Implementation
@$pb.TagNumber(2)
$core.bool get unfocus => $_getBF(1);
@doc Whether to unfocus the text field after entering text.
@$pb.TagNumber(2)
$core.bool get unfocus => $_getBF(1);