persistLanguageSelection property
@doc Whether to store the user's language selection in local storage so that it persists when they next open the app.
Implementation
@$pb.TagNumber(8)
$core.bool get persistLanguageSelection => $_getBF(7);
@doc Whether to store the user's language selection in local storage so that it persists when they next open the app.
@$pb.TagNumber(8)
$core.bool get persistLanguageSelection => $_getBF(7);