FFLanguageSelector class

Inheritance
Available extensions

Constructors

FFLanguageSelector({FFDimensions? dimensions, FFColor? legacyBackgroundColor, FFColor? legacyBorderColor, double? legacyBorderRadius, FFText? textStyle, bool? legacyHideFlags, double? legacyFlagSize, double? legacyFlagTextGap, FFColor? legacyDropdownIconColor, FFColor? legacyDropdownColor, FFColorValue? backgroundColorValue, FFColorValue? borderColorValue, FFDoubleValue? borderRadiusValue, FFBooleanValue? hideFlagsValue, FFDoubleValue? flagSizeValue, FFDoubleValue? flagTextGapValue, FFColorValue? dropdownIconColorValue, FFColorValue? dropdownColorValue})
factory
FFLanguageSelector.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFLanguageSelector.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

backgroundColorValue FFColorValue
getter/setter pair
borderColorValue FFColorValue
getter/setter pair
borderRadiusValue FFDoubleValue
getter/setter pair
dimensions FFDimensions
getter/setter pair
getter/setter pair
getter/setter pair
flagSizeValue FFDoubleValue
getter/setter pair
flagTextGapValue FFDoubleValue
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hideFlagsValue FFBooleanValue
getter/setter pair
info_ BuilderInfo
no setteroverride
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
legacyBackgroundColor FFColor
getter/setter pair
legacyBorderColor FFColor
getter/setter pair
legacyBorderRadius double
getter/setter pair
legacyDropdownColor FFColor
getter/setter pair
legacyDropdownIconColor FFColor
getter/setter pair
legacyFlagSize double
getter/setter pair
legacyFlagTextGap double
getter/setter pair
legacyHideFlags bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle FFText
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBackgroundColorValue() → void
clearBorderColorValue() → void
clearBorderRadiusValue() → void
clearDimensions() → void
clearDropdownColorValue() → void
clearDropdownIconColorValue() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFlagSizeValue() → void
clearFlagTextGapValue() → void
clearHideFlagsValue() → void
clearLegacyBackgroundColor() → void
clearLegacyBorderColor() → void
clearLegacyBorderRadius() → void
clearLegacyDropdownColor() → void
clearLegacyDropdownIconColor() → void
clearLegacyFlagSize() → void
clearLegacyFlagTextGap() → void
clearLegacyHideFlags() → void
clearTextStyle() → void
clone() FFLanguageSelector
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFLanguageSelector)) FFLanguageSelector
Apply updates to a copy of this message.
override
createEmptyInstance() FFLanguageSelector
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureBackgroundColorValue() FFColorValue
ensureBorderColorValue() FFColorValue
ensureBorderRadiusValue() FFDoubleValue
ensureDimensions() FFDimensions
ensureDropdownColorValue() FFColorValue
ensureDropdownIconColorValue() FFColorValue
ensureFlagSizeValue() FFDoubleValue
ensureFlagTextGapValue() FFDoubleValue
ensureHideFlagsValue() FFBooleanValue
ensureLegacyBackgroundColor() FFColor
ensureLegacyBorderColor() FFColor
ensureLegacyDropdownColor() FFColor
ensureLegacyDropdownIconColor() FFColor
ensureTextStyle() FFText
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasBackgroundColorValue() bool
hasBorderColorValue() bool
hasBorderRadiusValue() bool
hasDimensions() bool
hasDropdownColorValue() bool
hasDropdownIconColorValue() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFlagSizeValue() bool
hasFlagTextGapValue() bool
hasHideFlagsValue() bool
hasLegacyBackgroundColor() bool
hasLegacyBorderColor() bool
hasLegacyBorderRadius() bool
hasLegacyDropdownColor() bool
hasLegacyDropdownIconColor() bool
hasLegacyFlagSize() bool
hasLegacyFlagTextGap() bool
hasLegacyHideFlags() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasTextStyle() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited