mostRecentInputValue property
@doc Stores the most recent LatLng this value was set to in order to restore after removing a variable.
Implementation
@$pb.TagNumber(3)
FFLatLng get mostRecentInputValue => $_getN(2);
@doc Stores the most recent LatLng this value was set to in order to restore after removing a variable.
@$pb.TagNumber(3)
FFLatLng get mostRecentInputValue => $_getN(2);