routeOverrides property
@doc This configuration allows the main project to set path overrides for @doc library pages
Implementation
@$pb.TagNumber(2)
$pb.PbList<FFLibraryPageRoutePath> get routeOverrides => $_getList(1);
@doc This configuration allows the main project to set path overrides for @doc library pages
@$pb.TagNumber(2)
$pb.PbList<FFLibraryPageRoutePath> get routeOverrides => $_getList(1);