pageKey property
@doc The page to navigate to when the route is accessed.
Implementation
@$pb.TagNumber(1)
$core.String get pageKey => $_getSZ(0);
@doc The page to navigate to when the route is accessed.
@$pb.TagNumber(1)
$core.String get pageKey => $_getSZ(0);