routePath property
@doc The route_path to use in the main project for this page
Implementation
@$pb.TagNumber(2)
FFValue get routePath => $_getN(1);
@doc The route_path to use in the main project for this page
@$pb.TagNumber(2)
FFValue get routePath => $_getN(1);