libraryParameters property
The parameters that are set when a project is published as a library @doc The list of library values that are set in a library project
Implementation
@$pb.TagNumber(1)
$pb.PbList<FFParameter> get libraryParameters => $_getList(0);