FFLineChart class
- Inheritance
-
- Object
- GeneratedMessage
- FFLineChart
- Available extensions
Constructors
-
FFLineChart({Iterable<
FFLineChartLine> ? lines, @Deprecated('This field is deprecated.') FFColor? legacyBackgroundColor, @Deprecated('This field is deprecated.') FFColor? legacyBorderColor, @Deprecated('This field is deprecated.') bool? legacyShowGrid, @Deprecated('This field is deprecated.') FFLineChart_LegacyAxisLabels? legacyAxisLabels, @Deprecated('This field is deprecated.') FFLineChart_LegacyTooltipInfo? legacyTooltipInfo, @Deprecated('This field is deprecated.') FFLineChart_LegacyAxisBounds? legacyAxisBounds, @Deprecated('This field is deprecated.') double? legacyBorderWidth, @Deprecated('This field is deprecated.') bool? legacyShowBorder, FFChartAxisInfo? axisInfo, Iterable<String> ? xLabels, FFVariable? xLabelsValue, Iterable<String> ? yLabels, FFVariable? yLabelsValue}) -
factory
-
FFLineChart.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFLineChart.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- axisInfo ↔ FFChartAxisInfo
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setteroverride
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - legacyAxisBounds ↔ FFLineChart_LegacyAxisBounds
-
getter/setter pair
- legacyAxisLabels ↔ FFLineChart_LegacyAxisLabels
-
getter/setter pair
- legacyBackgroundColor ↔ FFColor
-
Basic properties
getter/setter pair
- legacyBorderColor ↔ FFColor
-
getter/setter pair
- legacyBorderWidth ↔ double
-
getter/setter pair
- legacyShowBorder ↔ bool
-
getter/setter pair
- legacyShowGrid ↔ bool
-
getter/setter pair
- legacyTooltipInfo ↔ FFLineChart_LegacyTooltipInfo
-
getter/setter pair
-
lines
→ PbList<
FFLineChartLine> -
Data fields
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unknownFields → UnknownFieldSet
-
no setterinherited
-
xLabels
→ PbList<
String> -
Custom string labels for the X-axis (e.g. time labels like "8AM", "11AM").
When set, these replace the default numeric axis labels.
no setter
- xLabelsValue ↔ FFVariable
-
Variable-backed X-axis labels. Stores either a literal list expression
(e.g. "
'8AM', '11AM', '2PM'") or a variable reference (Listgetter/setter pair -
yLabels
→ PbList<
String> -
Custom string labels for the Y-axis (e.g. "Low", "Medium", "High").
When set, these replace the default numeric axis labels.
no setter
- yLabelsValue ↔ FFVariable
-
Variable-backed Y-axis labels. Stores either a literal list expression
(e.g. "
'Low', 'Medium', 'High'") or a variable reference (Listgetter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAxisInfo(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearLegacyAxisBounds(
) → void -
clearLegacyAxisLabels(
) → void -
clearLegacyBackgroundColor(
) → void -
clearLegacyBorderColor(
) → void -
clearLegacyBorderWidth(
) → void -
clearLegacyShowBorder(
) → void -
clearLegacyShowGrid(
) → void -
clearLegacyTooltipInfo(
) → void -
clearXLabelsValue(
) → void -
clearYLabelsValue(
) → void -
clone(
) → FFLineChart -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFLineChart)) → FFLineChart -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFLineChart -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAxisInfo(
) → FFChartAxisInfo -
ensureLegacyAxisBounds(
) → FFLineChart_LegacyAxisBounds -
ensureLegacyAxisLabels(
) → FFLineChart_LegacyAxisLabels -
ensureLegacyBackgroundColor(
) → FFColor -
ensureLegacyBorderColor(
) → FFColor -
ensureLegacyTooltipInfo(
) → FFLineChart_LegacyTooltipInfo -
ensureXLabelsValue(
) → FFVariable -
ensureYLabelsValue(
) → FFVariable -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAxisInfo(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasLegacyAxisBounds(
) → bool -
hasLegacyAxisLabels(
) → bool -
hasLegacyBackgroundColor(
) → bool -
hasLegacyBorderColor(
) → bool -
hasLegacyBorderWidth(
) → bool -
hasLegacyShowBorder(
) → bool -
hasLegacyShowGrid(
) → bool -
hasLegacyTooltipInfo(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasXLabelsValue(
) → bool -
hasYLabelsValue(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → FFLineChart -
getDefault(
) → FFLineChart