index property
@doc The element at this index will be accessed, if the type is SPECIFIED.
Implementation
@$pb.TagNumber(2)
FFValue get index => $_getN(1);
@doc The element at this index will be accessed, if the type is SPECIFIED.
@$pb.TagNumber(2)
FFValue get index => $_getN(1);