applyStartEndSpace property

  1. @TagNumber(2)
bool get applyStartEndSpace

@doc If true, the spacing value will also be applied to the start and end of the list.

Implementation

@$pb.TagNumber(2)
$core.bool get applyStartEndSpace => $_getBF(1);
  1. @TagNumber(2)
set applyStartEndSpace (bool value)

Implementation

@$pb.TagNumber(2)
set applyStartEndSpace($core.bool value) => $_setBool(1, value);