primary property
@doc If true, the column will be scrollable even if wrapped in another scrollable widget.
Implementation
@$pb.TagNumber(3)
$core.bool get primary => $_getBF(2);
@doc If true, the column will be scrollable even if wrapped in another scrollable widget.
@$pb.TagNumber(3)
$core.bool get primary => $_getBF(2);