reorderable property
@doc Whether to allow reordering of items in the list.
Implementation
@$pb.TagNumber(6)
$core.bool get reorderable => $_getBF(5);
@doc Whether to allow reordering of items in the list.
@$pb.TagNumber(6)
$core.bool get reorderable => $_getBF(5);