shrinkWrapValue property
@doc If true, the list view will shrink wrap its contents. Otherwise, it will expand to fill the available space.
Implementation
@$pb.TagNumber(7)
FFBooleanValue get shrinkWrapValue => $_getN(6);
Implementation
@$pb.TagNumber(7)
set shrinkWrapValue(FFBooleanValue value) => $_setField(7, value);