fieldUpdates property
@doc The updates to apply to the data type's fields.
Implementation
@$pb.TagNumber(1)
$pb.PbList<FFLocalStateFieldUpdate> get fieldUpdates => $_getList(0);
@doc The updates to apply to the data type's fields.
@$pb.TagNumber(1)
$pb.PbList<FFLocalStateFieldUpdate> get fieldUpdates => $_getList(0);