FFLocalStateFieldUpdate class
- Inheritance
-
- Object
- GeneratedMessage
- FFLocalStateFieldUpdate
- Available extensions
Constructors
- FFLocalStateFieldUpdate({FFIdentifier? fieldIdentifier, FFValue? setValue, FFLocalStateClearValue? clearValue, FFValue? increment, FFValue? addToList, FFValue? removeFromList, FFValue? removeFromListAtIndex, FFLocalStateUpdateListItem? updateItemAtIndex, FFLocalStateDataStructUpdate? dataStructUpdate, FFLocalStateInsertListItem? insertAtIndex, FFLocalStateToggle? toggle})
-
factory
-
FFLocalStateFieldUpdate.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFLocalStateFieldUpdate.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- addToList ↔ FFValue
-
@doc Add this value to the list.
getter/setter pair
- clearValue ↔ FFLocalStateClearValue
-
@doc Clear the field.
getter/setter pair
- dataStructUpdate ↔ FFLocalStateDataStructUpdate
-
@doc Update the data type field.
getter/setter pair
- fieldIdentifier ↔ FFIdentifier
-
@doc The identifier of the local state field to update.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- increment ↔ FFValue
-
@doc Increment the field by this value.
getter/setter pair
- info_ → BuilderInfo
-
no setteroverride
- insertAtIndex ↔ FFLocalStateInsertListItem
-
@doc Insert the value at the specified index in the list.
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - removeFromList ↔ FFValue
-
@doc Remove this value from the list.
getter/setter pair
- removeFromListAtIndex ↔ FFValue
-
@doc Remove the value at this index from the list.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setValue ↔ FFValue
-
@doc Set the field to this value.
getter/setter pair
- toggle ↔ FFLocalStateToggle
-
@doc Toggle the field.
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- updateItemAtIndex ↔ FFLocalStateUpdateListItem
-
@doc Update the value of an item at the specified index.
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAddToList(
) → void -
clearClearValue(
) → void -
clearDataStructUpdate(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearFieldIdentifier(
) → void -
clearIncrement(
) → void -
clearInsertAtIndex(
) → void -
clearRemoveFromList(
) → void -
clearRemoveFromListAtIndex(
) → void -
clearSetValue(
) → void -
clearToggle(
) → void -
clearUpdate(
) → void -
clearUpdateItemAtIndex(
) → void -
clone(
) → FFLocalStateFieldUpdate -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFLocalStateFieldUpdate)) → FFLocalStateFieldUpdate -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFLocalStateFieldUpdate -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAddToList(
) → FFValue -
ensureClearValue(
) → FFLocalStateClearValue -
ensureDataStructUpdate(
) → FFLocalStateDataStructUpdate -
ensureFieldIdentifier(
) → FFIdentifier -
ensureIncrement(
) → FFValue -
ensureInsertAtIndex(
) → FFLocalStateInsertListItem -
ensureRemoveFromList(
) → FFValue -
ensureRemoveFromListAtIndex(
) → FFValue -
ensureSetValue(
) → FFValue -
ensureToggle(
) → FFLocalStateToggle -
ensureUpdateItemAtIndex(
) → FFLocalStateUpdateListItem -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAddToList(
) → bool -
hasClearValue(
) → bool -
hasDataStructUpdate(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasFieldIdentifier(
) → bool -
hasIncrement(
) → bool -
hasInsertAtIndex(
) → bool -
hasRemoveFromList(
) → bool -
hasRemoveFromListAtIndex(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSetValue(
) → bool -
hasToggle(
) → bool -
hasUpdateItemAtIndex(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
whichUpdate(
) → FFLocalStateFieldUpdate_Update -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited