updates property
@doc The updates to make to the local state.
Implementation
@$pb.TagNumber(8)
$pb.PbList<FFLocalStateFieldUpdate> get updates => $_getList(7);
@doc The updates to make to the local state.
@$pb.TagNumber(8)
$pb.PbList<FFLocalStateFieldUpdate> get updates => $_getList(7);