animationStatus property
It looks like this is not used in code generation.
Implementation
@$pb.TagNumber(8)
$core.bool get animationStatus => $_getBF(7);
It looks like this is not used in code generation.
@$pb.TagNumber(8)
$core.bool get animationStatus => $_getBF(7);