originalFrameRate property
Should not be overridable @doc Actual frame rate of the Lottie animation (fps). Derived from the Lottie file.
Implementation
@$pb.TagNumber(9)
$core.double get originalFrameRate => $_getN(8);
Should not be overridable @doc Actual frame rate of the Lottie animation (fps). Derived from the Lottie file.
@$pb.TagNumber(9)
$core.double get originalFrameRate => $_getN(8);