usingUpdatedDimensions property

  1. @TagNumber(12)
bool get usingUpdatedDimensions

@doc Whether the Lottie animation widget is using the updated dimensions.

Old lottie widgets were using only the pixel width/height for web and ignoring cases where it's set as a percentage of screen. New widgets, or those that have had their width/height edited will use the correct value.

Implementation

@$pb.TagNumber(12)
$core.bool get usingUpdatedDimensions => $_getBF(10);
  1. @TagNumber(12)
set usingUpdatedDimensions (bool value)

Implementation

@$pb.TagNumber(12)
set usingUpdatedDimensions($core.bool value) => $_setBool(10, value);