FFMuxBroadcast class
- Inheritance
-
- Object
- GeneratedMessage
- FFMuxBroadcast
- Available extensions
Constructors
- FFMuxBroadcast({FFDimensions? dimensions, FFBorderRadius? borderRadius, FFMuxBroadcast_FFMuxBroadcastResolution? broadcastResolution, FFMuxBroadcast_FFMuxBroadcastAudioChannel? audioChannel, FFText? liveText, FFColor? legacyLiveTextBackgroundColor, FFText? durationTextStyle, FFColor? legacyDurationTextBackgroundColor, FFButton? startButtonOptions, FFIcon? legacyStopButtonIcon, FFColor? legacyStopButtonBackgroundColor, FFIcon? legacyRotateButtonIcon, FFColor? legacyRotateButtonBackgroundColor, bool? isStreamingView, FFIcon? legacyLiveIcon, FFBorderRadius? liveContainerBorderRadius, FFBorderRadius? durationContainerBorderRadius, FFMuxBroadcast_FFMuxBroadcastLatencyMode? latencyMode, FFColorValue? liveTextBackgroundColorValue, FFColorValue? durationTextBackgroundColorValue, FFColorValue? stopButtonBackgroundColorValue, FFColorValue? rotateButtonBackgroundColorValue, FFIconValue? stopButtonIconValue, FFIconValue? rotateButtonIconValue, FFIconValue? liveIconValue})
-
factory
-
FFMuxBroadcast.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFMuxBroadcast.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- audioChannel ↔ FFMuxBroadcast_FFMuxBroadcastAudioChannel
-
getter/setter pair
- borderRadius ↔ FFBorderRadius
-
@doc The border radius to be applied on the broadcast view.
getter/setter pair
- broadcastResolution ↔ FFMuxBroadcast_FFMuxBroadcastResolution
-
getter/setter pair
- dimensions ↔ FFDimensions
-
@doc The dimensions of the broadcast view.
getter/setter pair
- durationContainerBorderRadius ↔ FFBorderRadius
-
@doc The border radius of the duration container view.
getter/setter pair
- durationTextBackgroundColorValue ↔ FFColorValue
-
@doc The background color of the duration text.
getter/setter pair
- durationTextStyle ↔ FFText
-
@doc The text style of the duration text.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setteroverride
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - isStreamingView ↔ bool
-
not overridable
@doc Whether to show the broadcast view in the UI Builder.
getter/setter pair
- latencyMode ↔ FFMuxBroadcast_FFMuxBroadcastLatencyMode
-
getter/setter pair
- legacyDurationTextBackgroundColor ↔ FFColor
-
getter/setter pair
- legacyLiveIcon ↔ FFIcon
-
getter/setter pair
- legacyLiveTextBackgroundColor ↔ FFColor
-
getter/setter pair
- legacyRotateButtonBackgroundColor ↔ FFColor
-
getter/setter pair
- legacyRotateButtonIcon ↔ FFIcon
-
getter/setter pair
- legacyStopButtonBackgroundColor ↔ FFColor
-
getter/setter pair
- legacyStopButtonIcon ↔ FFIcon
-
getter/setter pair
- liveContainerBorderRadius ↔ FFBorderRadius
-
@doc The border radius of the live container view.
getter/setter pair
- liveIconValue ↔ FFIconValue
-
@doc The icon to show when the broadcast is live (leading the Live text).
getter/setter pair
- liveText ↔ FFText
-
@doc The text style of the live text.
getter/setter pair
- liveTextBackgroundColorValue ↔ FFColorValue
-
@doc The background color of the live text.
getter/setter pair
- rotateButtonBackgroundColorValue ↔ FFColorValue
-
@doc The background color of the rotate camera button.
getter/setter pair
- rotateButtonIconValue ↔ FFIconValue
-
@doc The rotate camera button icon.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startButtonOptions ↔ FFButton
-
@doc The start broadcast button styling.
getter/setter pair
- stopButtonBackgroundColorValue ↔ FFColorValue
-
@doc The background color of the stop broadcast button.
getter/setter pair
- stopButtonIconValue ↔ FFIconValue
-
@doc The stop broadcast button icon.
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAudioChannel(
) → void -
clearBorderRadius(
) → void -
clearBroadcastResolution(
) → void -
clearDimensions(
) → void -
clearDurationContainerBorderRadius(
) → void -
clearDurationTextBackgroundColorValue(
) → void -
clearDurationTextStyle(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearIsStreamingView(
) → void -
clearLatencyMode(
) → void -
clearLegacyDurationTextBackgroundColor(
) → void -
clearLegacyLiveIcon(
) → void -
clearLegacyLiveTextBackgroundColor(
) → void -
clearLegacyRotateButtonBackgroundColor(
) → void -
clearLegacyRotateButtonIcon(
) → void -
clearLegacyStopButtonBackgroundColor(
) → void -
clearLegacyStopButtonIcon(
) → void -
clearLiveContainerBorderRadius(
) → void -
clearLiveIconValue(
) → void -
clearLiveText(
) → void -
clearLiveTextBackgroundColorValue(
) → void -
clearRotateButtonBackgroundColorValue(
) → void -
clearRotateButtonIconValue(
) → void -
clearStartButtonOptions(
) → void -
clearStopButtonBackgroundColorValue(
) → void -
clearStopButtonIconValue(
) → void -
clone(
) → FFMuxBroadcast -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFMuxBroadcast)) → FFMuxBroadcast -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFMuxBroadcast -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureBorderRadius(
) → FFBorderRadius -
ensureDimensions(
) → FFDimensions -
ensureDurationContainerBorderRadius(
) → FFBorderRadius -
ensureDurationTextBackgroundColorValue(
) → FFColorValue -
ensureDurationTextStyle(
) → FFText -
ensureLegacyDurationTextBackgroundColor(
) → FFColor -
ensureLegacyLiveIcon(
) → FFIcon -
ensureLegacyLiveTextBackgroundColor(
) → FFColor -
ensureLegacyRotateButtonBackgroundColor(
) → FFColor -
ensureLegacyRotateButtonIcon(
) → FFIcon -
ensureLegacyStopButtonBackgroundColor(
) → FFColor -
ensureLegacyStopButtonIcon(
) → FFIcon -
ensureLiveContainerBorderRadius(
) → FFBorderRadius -
ensureLiveIconValue(
) → FFIconValue -
ensureLiveText(
) → FFText -
ensureLiveTextBackgroundColorValue(
) → FFColorValue -
ensureRotateButtonBackgroundColorValue(
) → FFColorValue -
ensureRotateButtonIconValue(
) → FFIconValue -
ensureStartButtonOptions(
) → FFButton -
ensureStopButtonBackgroundColorValue(
) → FFColorValue -
ensureStopButtonIconValue(
) → FFIconValue -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAudioChannel(
) → bool -
hasBorderRadius(
) → bool -
hasBroadcastResolution(
) → bool -
hasDimensions(
) → bool -
hasDurationContainerBorderRadius(
) → bool -
hasDurationTextBackgroundColorValue(
) → bool -
hasDurationTextStyle(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasIsStreamingView(
) → bool -
hasLatencyMode(
) → bool -
hasLegacyDurationTextBackgroundColor(
) → bool -
hasLegacyLiveIcon(
) → bool -
hasLegacyLiveTextBackgroundColor(
) → bool -
hasLegacyRotateButtonBackgroundColor(
) → bool -
hasLegacyRotateButtonIcon(
) → bool -
hasLegacyStopButtonBackgroundColor(
) → bool -
hasLegacyStopButtonIcon(
) → bool -
hasLiveContainerBorderRadius(
) → bool -
hasLiveIconValue(
) → bool -
hasLiveText(
) → bool -
hasLiveTextBackgroundColorValue(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasRotateButtonBackgroundColorValue(
) → bool -
hasRotateButtonIconValue(
) → bool -
hasStartButtonOptions(
) → bool -
hasStopButtonBackgroundColorValue(
) → bool -
hasStopButtonIconValue(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → FFMuxBroadcast -
getDefault(
) → FFMuxBroadcast