isStreamingView property
not overridable @doc Whether to show the broadcast view in the UI Builder.
Implementation
@$pb.TagNumber(14)
$core.bool get isStreamingView => $_getBF(13);
not overridable @doc Whether to show the broadcast view in the UI Builder.
@$pb.TagNumber(14)
$core.bool get isStreamingView => $_getBF(13);