replaceRoute property
@doc Whether to replace the current route during navigation. i.e. whether to use Navigator.pushReplacement.
Implementation
@$pb.TagNumber(8)
$core.bool get replaceRoute => $_getBF(7);
@doc Whether to replace the current route during navigation. i.e. whether to use Navigator.pushReplacement.
@$pb.TagNumber(8)
$core.bool get replaceRoute => $_getBF(7);