FFNode class

Associated with a flutter widget in a project. next available : 34

Inheritance
Available extensions

Constructors

FFNode({String? key, Iterable<FFNode>? children, FFWidgetType? type, FFWidgetProperties? props, @Deprecated('This field is deprecated.') bool? showDefaultChildren, String? name, @Deprecated('This field is deprecated.') Iterable<FFAction>? legacyActions, @Deprecated('This field is deprecated.') String? legacyFfWidgetClass, FFDatabaseRequest? databaseRequest, Iterable<MapEntry<String, FFChildrenKeys>>? childPropertyMap, FFPassedParameters? parameterValues, FFGeneratorVariable? generatorVariable, bool? isDummyRoot, Iterable<FFAnimation>? animations, @Deprecated('This field is deprecated.') String? customWidgetName, Iterable<FFTriggerActions>? triggerActions, FFEditMetadata? editMetadata, bool? enforceCustomWidgetDimensions, FFAnnotations? annotations, FFComponentUniqueKey? dynamicComponentKey, @Deprecated('This field is deprecated.') String? legacyComponentClassKey, FFThemeWidgetInfo? themeWidgetInfo, FFValue? valueKey, FFNodeKeyReference? componentClassKeyRef, FFAiGeneratedNodeInfo? aiGeneratedNodeInfo, FFNodeFeaturePresence? featurePresence, FFIdentifier? customWidgetIdentifier, @Deprecated('This field is deprecated.') FFNodeKeyReference? legacyWidgetBuilderKeyRef, FFWidgetBuilderUIProperties? widgetBuilderUiProperties, FFIdentifier? widgetBuilderIdentifier, FFFocusConfiguration? focusConfig, FFFocusBorder? focusBorder, FFBooleanValue? widgetDisabledCondition})
factory
FFNode.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFNode.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

aiGeneratedNodeInfo FFAiGeneratedNodeInfo
Data about AI Page Gen, if the node was generated using that
getter/setter pair
animations PbList<FFAnimation>
@doc Animations applied to this widget.
no setter
annotations FFAnnotations
getter/setter pair
childPropertyMap PbMap<String, FFChildrenKeys>
A map used to keep track of what child is used where for widgets that have non "child" or "children" descendents (e.g. Scaffold). An example mapping for Scaffold would be {"body": "Column_asfsf", "drawer": "Drawer_4asf34"}.
no setter
children PbList<FFNode>
For single child widgets, only the first element should be set.
no setter
componentClassKeyRef FFNodeKeyReference
getter/setter pair
customWidgetIdentifier FFIdentifier
getter/setter pair
customWidgetName String
Same as ff_widget_class but for custom widgets.
getter/setter pair
databaseRequest FFDatabaseRequest
getter/setter pair
dynamicComponentKey FFComponentUniqueKey
Describes a unique key for a dynamic component widget for state management.
getter/setter pair
editMetadata FFEditMetadata
getter/setter pair
enforceCustomWidgetDimensions bool
getter/setter pair
featurePresence FFNodeFeaturePresence
Information about the node's features in order to make error checking more efficient. Honestly not an ideal system but otherwise it's difficult to track all instances of a feature being used when error checking while remaining efficient.
getter/setter pair
focusBorder FFFocusBorder
@doc Configuration for the focus border appearance when this widget has keyboard focus
getter/setter pair
focusConfig FFFocusConfiguration
@doc Configuration for focus traversal and focus groups
getter/setter pair
generatorVariable FFGeneratorVariable
Represents the variable (if present) from which we generate our children. This field is automatically populated if a multi-child node has a multi-value database request (e.g. a ListView with a database_request that returns a list of User documents).
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ BuilderInfo
no setteroverride
isComponent bool

Available on FFNode, provided by the SchemaFFNodeExtensions extension

no setter
isDummyRoot bool
Whether this is a placeholder for a Custom Component or Custom Widget.
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isPage bool

Available on FFNode, provided by the SchemaFFNodeExtensions extension

no setter
isWidgetClass bool

Available on FFNode, provided by the SchemaFFNodeExtensions extension

no setter
key String
getter/setter pair
legacyActions PbList<FFAction>
no setter
legacyComponentClassKey String
getter/setter pair
legacyFfWidgetClass String
Populated if this widget is a FFWidgetClass. In this case, neither children nor props.props should be specified.
getter/setter pair
legacyWidgetBuilderKeyRef FFNodeKeyReference
Specifies which widget builder parameter of the containing widget class this node is referencing.
getter/setter pair
name String
getter/setter pair
parameterValues FFPassedParameters
Parameters passed to widget class (either component or custom widget).
getter/setter pair
props FFWidgetProperties
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDefaultChildren bool
getter/setter pair
themeWidgetInfo FFThemeWidgetInfo
Whether this widget inherits some user defined theming
getter/setter pair
triggerActions PbList<FFTriggerActions>
Actions that are triggered by this widget.
no setter
type FFWidgetType
TODO: refactor to use child_nodes instead of house keeping between children and child_property_map. Use extension called FFnode#children to avoid rewriting code that flattens. children -> children_old for deprecation. map<string, FFNodes> child_nodes = 11;
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
valueKey FFValue
getter/setter pair
widgetBuilderIdentifier FFIdentifier
@doc Identifier to determine the widget builder that this node is referencing.
getter/setter pair
widgetBuilderUiProperties FFWidgetBuilderUIProperties
@doc UI properties of placeholder for the widget builder
getter/setter pair
widgetDisabledCondition FFBooleanValue
@doc When this condition is true, the widget is excluded from keyboard focus traversal and the focus border will not appear.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAiGeneratedNodeInfo() → void
clearAnnotations() → void
clearComponentClassKeyRef() → void
clearCustomWidgetIdentifier() → void
clearCustomWidgetName() → void
clearDatabaseRequest() → void
clearDynamicComponentKey() → void
clearEditMetadata() → void
clearEnforceCustomWidgetDimensions() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFeaturePresence() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFocusBorder() → void
clearFocusConfig() → void
clearGeneratorVariable() → void
clearIsDummyRoot() → void
clearKey() → void
clearLegacyComponentClassKey() → void
clearLegacyFfWidgetClass() → void
clearLegacyWidgetBuilderKeyRef() → void
clearName() → void
clearParameterValues() → void
clearProps() → void
clearShowDefaultChildren() → void
clearThemeWidgetInfo() → void
clearType() → void
clearValueKey() → void
clearWidgetBuilderIdentifier() → void
clearWidgetBuilderUiProperties() → void
clearWidgetDisabledCondition() → void
clone() FFNode
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFNode)) FFNode
Apply updates to a copy of this message.
override
createEmptyInstance() FFNode
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAiGeneratedNodeInfo() FFAiGeneratedNodeInfo
ensureAnnotations() FFAnnotations
ensureComponentClassKeyRef() FFNodeKeyReference
ensureCustomWidgetIdentifier() FFIdentifier
ensureDatabaseRequest() FFDatabaseRequest
ensureDynamicComponentKey() FFComponentUniqueKey
ensureEditMetadata() FFEditMetadata
ensureFeaturePresence() FFNodeFeaturePresence
ensureFocusBorder() FFFocusBorder
ensureFocusConfig() FFFocusConfiguration
ensureGeneratorVariable() FFGeneratorVariable
ensureLegacyWidgetBuilderKeyRef() FFNodeKeyReference
ensureParameterValues() FFPassedParameters
ensureProps() FFWidgetProperties
ensureThemeWidgetInfo() FFThemeWidgetInfo
ensureValueKey() FFValue
ensureWidgetBuilderIdentifier() FFIdentifier
ensureWidgetBuilderUiProperties() FFWidgetBuilderUIProperties
ensureWidgetDisabledCondition() FFBooleanValue
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAiGeneratedNodeInfo() bool
hasAnnotations() bool
hasComponentClassKeyRef() bool
hasCustomWidgetIdentifier() bool
hasCustomWidgetName() bool
hasDatabaseRequest() bool
hasDynamicComponentKey() bool
hasEditMetadata() bool
hasEnforceCustomWidgetDimensions() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasFeaturePresence() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFocusBorder() bool
hasFocusConfig() bool
hasGeneratorVariable() bool
hasIsDummyRoot() bool
hasKey() bool
hasLegacyComponentClassKey() bool
hasLegacyFfWidgetClass() bool
hasLegacyWidgetBuilderKeyRef() bool
hasName() bool
hasParameterValues() bool
hasProps() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasShowDefaultChildren() bool
hasThemeWidgetInfo() bool
hasType() bool
hasValueKey() bool
hasWidgetBuilderIdentifier() bool
hasWidgetBuilderUiProperties() bool
hasWidgetDisabledCondition() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFNode
getDefault() FFNode