childPropertyMap property
A map used to keep track of what child is used where for widgets that have non "child" or "children" descendents (e.g. Scaffold). An example mapping for Scaffold would be {"body": "Column_asfsf", "drawer": "Drawer_4asf34"}.
Implementation
@$pb.TagNumber(11)
$pb.PbMap<$core.String, FFChildrenKeys> get childPropertyMap => $_getMap(9);