keyPath property
@doc The list of keys that represent the path to the nested component.
Implementation
@$pb.TagNumber(6)
$pb.PbList<FFNodeKeyReference> get keyPath => $_getList(1);
@doc The list of keys that represent the path to the nested component.
@$pb.TagNumber(6)
$pb.PbList<FFNodeKeyReference> get keyPath => $_getList(1);