copyWith method

  1. @Deprecated('See https://github.com/google/protobuf.dart/issues/998.')
FFOneSignalSettings copyWith(
  1. void updates(
    1. FFOneSignalSettings
    )
)
override

Apply updates to a copy of this message.

Makes a writable shallow copy of this message, applies the updates to it, and marks the copy read-only before returning it.

Implementation

@$core.Deprecated('See https://github.com/google/protobuf.dart/issues/998.')
FFOneSignalSettings copyWith(void Function(FFOneSignalSettings) updates) =>
    super.copyWith((message) => updates(message as FFOneSignalSettings))
        as FFOneSignalSettings;