FFPageViewIndicatorOptions class
- Inheritance
-
- Object
- GeneratedMessage
- FFPageViewIndicatorOptions
- Available extensions
Constructors
- FFPageViewIndicatorOptions({bool? hasIndicator, FFAlignment? alignment, FFPadding? indicatorPadding, double? expansionFactor, double? legacySpacing, double? legacyBorderRadius, double? legacyDotWidth, double? legacyDotHeight, FFColor? legacyInactiveColor, FFColor? legacyActiveColor, bool? outline, FFDoubleValue? spacingValue, FFDoubleValue? borderRadiusValue, FFDoubleValue? dotWidthValue, FFDoubleValue? dotHeightValue, FFColorValue? inactiveColorValue, FFColorValue? activeColorValue})
-
factory
-
FFPageViewIndicatorOptions.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFPageViewIndicatorOptions.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- activeColorValue ↔ FFColorValue
-
getter/setter pair
- alignment ↔ FFAlignment
-
getter/setter pair
- borderRadiusValue ↔ FFDoubleValue
-
getter/setter pair
- dotHeightValue ↔ FFDoubleValue
-
getter/setter pair
- dotWidthValue ↔ FFDoubleValue
-
getter/setter pair
- expansionFactor ↔ double
-
Should not be overridable - it controls which animation is used.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- hasIndicator ↔ bool
-
Should not be overridable - it controls all the other options.
getter/setter pair
- inactiveColorValue ↔ FFColorValue
-
getter/setter pair
- indicatorPadding ↔ FFPadding
-
getter/setter pair
- info_ → BuilderInfo
-
no setteroverride
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - legacyActiveColor ↔ FFColor
-
getter/setter pair
- legacyBorderRadius ↔ double
-
getter/setter pair
- legacyDotHeight ↔ double
-
getter/setter pair
- legacyDotWidth ↔ double
-
getter/setter pair
- legacyInactiveColor ↔ FFColor
-
getter/setter pair
- legacySpacing ↔ double
-
getter/setter pair
- outline ↔ bool
-
Should not be overridable - it controls the paint style.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacingValue ↔ FFDoubleValue
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearActiveColorValue(
) → void -
clearAlignment(
) → void -
clearBorderRadiusValue(
) → void -
clearDotHeightValue(
) → void -
clearDotWidthValue(
) → void -
clearExpansionFactor(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearHasIndicator(
) → void -
clearInactiveColorValue(
) → void -
clearIndicatorPadding(
) → void -
clearLegacyActiveColor(
) → void -
clearLegacyBorderRadius(
) → void -
clearLegacyDotHeight(
) → void -
clearLegacyDotWidth(
) → void -
clearLegacyInactiveColor(
) → void -
clearLegacySpacing(
) → void -
clearOutline(
) → void -
clearSpacingValue(
) → void -
clone(
) → FFPageViewIndicatorOptions -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFPageViewIndicatorOptions)) → FFPageViewIndicatorOptions -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFPageViewIndicatorOptions -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureActiveColorValue(
) → FFColorValue -
ensureAlignment(
) → FFAlignment -
ensureBorderRadiusValue(
) → FFDoubleValue -
ensureDotHeightValue(
) → FFDoubleValue -
ensureDotWidthValue(
) → FFDoubleValue -
ensureInactiveColorValue(
) → FFColorValue -
ensureIndicatorPadding(
) → FFPadding -
ensureLegacyActiveColor(
) → FFColor -
ensureLegacyInactiveColor(
) → FFColor -
ensureSpacingValue(
) → FFDoubleValue -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasActiveColorValue(
) → bool -
hasAlignment(
) → bool -
hasBorderRadiusValue(
) → bool -
hasDotHeightValue(
) → bool -
hasDotWidthValue(
) → bool -
hasExpansionFactor(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasHasIndicator(
) → bool -
hasInactiveColorValue(
) → bool -
hasIndicatorPadding(
) → bool -
hasLegacyActiveColor(
) → bool -
hasLegacyBorderRadius(
) → bool -
hasLegacyDotHeight(
) → bool -
hasLegacyDotWidth(
) → bool -
hasLegacyInactiveColor(
) → bool -
hasLegacySpacing(
) → bool -
hasOutline(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSpacingValue(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited