FFParameter class

Inheritance
Available extensions

Constructors

FFParameter({FFIdentifier? identifier, FFBaseDataType? legacyType, FFIdentifier? legacyCollectionIdentifier, bool? legacyIsList, FFParameterValue? defaultValue, FFWidgetPropertyType? legacyWidgetPropertyType, Iterable<FFBaseDataType>? allowedDestinationTypes, bool? legacyNonNullable, FFIdentifier? legacyDataStructIdentifier, FFIdentifier? legacyTableIdentifier, FFIdentifier? legacySqliteQueryIdentifier, FFIdentifier? legacyEnumIdentifier, Iterable<FFParameter>? legacyActionParams, FFDataTypeV2? dataType, String? description, FFParameter_PositionalParameter? positionalParameter, FFParameter_NamedParameter? namedParameter})
factory
FFParameter.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFParameter.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

allowedDestinationTypes PbList<FFBaseDataType>
For simple types (Integer, String, etc.) an optional default value for the parameter. The data types this parameter can be used as. For instance, a TextField parameter (which is by default a String) may be used as a Double or Integer in some cases.
no setter
dataType FFDataTypeV2
getter/setter pair
defaultValue FFParameterValue
getter/setter pair
description String
@doc The user-defined description of the parameter.
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
identifier FFIdentifier
By convention, the identifier name is prefixed with the identifier of the containing field (e.g. the containing Collection or Widget Class).
getter/setter pair
info_ BuilderInfo
no setteroverride
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isList bool

Available on FFParameter, provided by the SchemaFFParameterExtensions extension

getter/setter pair
legacyActionParams PbList<FFParameter>
no setter
legacyCollectionIdentifier FFIdentifier
If the data type is DocumentReference or Document, contains the key of the collection to know the Collection type of this parameter.
getter/setter pair
legacyDataStructIdentifier FFIdentifier
If the data type is DataStruct, contains the key of the structure to know the data structure type.
getter/setter pair
legacyEnumIdentifier FFIdentifier
If the data type is an Enum, contains the key of the enum.
getter/setter pair
legacyIsList bool
Whether this is a single value or list of the specified data type.
getter/setter pair
legacyNonNullable bool
Whether this parameter is specified as non-nullable. By default all parameters are assumed to be nullable unless otherwise specified (or if it is implicit based on whatever module is using it).
getter/setter pair
legacySqliteQueryIdentifier FFIdentifier
If the data type is SQLiteRow, contains the key of the SQLite query to know the type of this parameter.
getter/setter pair
legacyTableIdentifier FFIdentifier
If the data type is PostgresRow, contains the key of the table to know the table type of this parameter.
getter/setter pair
legacyType FFBaseDataType
Legacy fields
getter/setter pair
legacyWidgetPropertyType FFWidgetPropertyType
The widget property (if type is FFBaseDataType.WidgetProperty). TODO: Factor this so that FFBaseDataType is instead a oneof (and widget property as well as collection_identifier live under there).
getter/setter pair
namedParameter FFParameter_NamedParameter
getter/setter pair
positionalParameter FFParameter_PositionalParameter
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknownFields UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearDataType() → void
clearDefaultValue() → void
clearDescription() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIdentifier() → void
clearLegacyCollectionIdentifier() → void
clearLegacyDataStructIdentifier() → void
clearLegacyEnumIdentifier() → void
clearLegacyIsList() → void
clearLegacyNonNullable() → void
clearLegacySqliteQueryIdentifier() → void
clearLegacyTableIdentifier() → void
clearLegacyType() → void
clearLegacyWidgetPropertyType() → void
clearNamedParameter() → void
clearParameterType() → void
clearPositionalParameter() → void
clearSpecifier() → void
clone() FFParameter
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFParameter)) FFParameter
Apply updates to a copy of this message.
override
createEmptyInstance() FFParameter
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureDataType() FFDataTypeV2
ensureDefaultValue() FFParameterValue
ensureIdentifier() FFIdentifier
ensureLegacyCollectionIdentifier() FFIdentifier
ensureLegacyDataStructIdentifier() FFIdentifier
ensureLegacyEnumIdentifier() FFIdentifier
ensureLegacySqliteQueryIdentifier() FFIdentifier
ensureLegacyTableIdentifier() FFIdentifier
ensureNamedParameter() FFParameter_NamedParameter
ensurePositionalParameter() FFParameter_PositionalParameter
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasDataType() bool
hasDefaultValue() bool
hasDescription() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasIdentifier() bool
hasLegacyCollectionIdentifier() bool
hasLegacyDataStructIdentifier() bool
hasLegacyEnumIdentifier() bool
hasLegacyIsList() bool
hasLegacyNonNullable() bool
hasLegacySqliteQueryIdentifier() bool
hasLegacyTableIdentifier() bool
hasLegacyType() bool
hasLegacyWidgetPropertyType() bool
hasNamedParameter() bool
hasPositionalParameter() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
whichParameterType() FFParameter_ParameterType
whichSpecifier() FFParameter_Specifier
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFParameter
getDefault() FFParameter