legacyCollectionIdentifier property
If the data type is DocumentReference or Document, contains the key of the collection to know the Collection type of this parameter.
Implementation
@$pb.TagNumber(3)
FFIdentifier get legacyCollectionIdentifier => $_getN(2);
Implementation
@$pb.TagNumber(3)
set legacyCollectionIdentifier(FFIdentifier value) => $_setField(3, value);