legacyIsList property
Whether this is a single value or list of the specified data type.
Implementation
@$pb.TagNumber(4)
$core.bool get legacyIsList => $_getBF(3);
Whether this is a single value or list of the specified data type.
@$pb.TagNumber(4)
$core.bool get legacyIsList => $_getBF(3);