legacyNonNullable property

  1. @TagNumber(8)
bool get legacyNonNullable

Whether this parameter is specified as non-nullable. By default all parameters are assumed to be nullable unless otherwise specified (or if it is implicit based on whatever module is using it).

Implementation

@$pb.TagNumber(8)
$core.bool get legacyNonNullable => $_getBF(7);
  1. @TagNumber(8)
set legacyNonNullable (bool value)

Implementation

@$pb.TagNumber(8)
set legacyNonNullable($core.bool value) => $_setBool(7, value);