action property
@doc This is used to pass in an action as an argument.
Implementation
@$pb.TagNumber(7)
FFTriggerActions get action => $_getN(6);
Implementation
@$pb.TagNumber(7)
set action(FFTriggerActions value) => $_setField(7, value);
@doc This is used to pass in an action as an argument.
@$pb.TagNumber(7)
FFTriggerActions get action => $_getN(6);
@$pb.TagNumber(7)
set action(FFTriggerActions value) => $_setField(7, value);