updateContainingClassOnSetState property

  1. @TagNumber(4)
bool get updateContainingClassOnSetState

Only applicable to components. Determines whether or not to update the containing page or component when this component updates its state.

Implementation

@$pb.TagNumber(4)
$core.bool get updateContainingClassOnSetState => $_getBF(3);
  1. @TagNumber(4)
set updateContainingClassOnSetState (bool value)

Implementation

@$pb.TagNumber(4)
set updateContainingClassOnSetState($core.bool value) => $_setBool(3, value);