awaitPlayback property
@doc Whether to wait for the sound to finish playing before starting other @doc actions.
Implementation
@$pb.TagNumber(4)
$core.bool get awaitPlayback => $_getBF(3);
@doc Whether to wait for the sound to finish playing before starting other @doc actions.
@$pb.TagNumber(4)
$core.bool get awaitPlayback => $_getBF(3);