isPrimaryKey property
@doc Whether this field is the primary key of the table.
Implementation
@$pb.TagNumber(3)
$core.bool get isPrimaryKey => $_getBF(2);
@doc Whether this field is the primary key of the table.
@$pb.TagNumber(3)
$core.bool get isPrimaryKey => $_getBF(2);