hideOnEmpty property
@doc if true, hide the widget when the query returns no results.
Implementation
@$pb.TagNumber(5)
$core.bool get hideOnEmpty => $_getBF(4);
@doc if true, hide the widget when the query returns no results.
@$pb.TagNumber(5)
$core.bool get hideOnEmpty => $_getBF(4);