isSingleRow property
@doc if true, this query returns a single row.
Implementation
@$pb.TagNumber(4)
$core.bool get isSingleRow => $_getBF(3);
@doc if true, this query returns a single row.
@$pb.TagNumber(4)
$core.bool get isSingleRow => $_getBF(3);