isStreamingSupabaseQuery property
@doc If true, returns query results as a stream that updates in real time. If false, returns the one-time query results.
Implementation
@$pb.TagNumber(6)
$core.bool get isStreamingSupabaseQuery => $_getBF(5);
@doc If true, returns query results as a stream that updates in real time. If false, returns the one-time query results.
@$pb.TagNumber(6)
$core.bool get isStreamingSupabaseQuery => $_getBF(5);