FFProject class

Next available tag: 45

Inheritance
Available extensions

Constructors

FFProject({String? name, FFTheme? theme, FFNavBar? navBar, FFAuthPageInfo? authPageInfo, FFAuthentication? authentication, @Deprecated('This field is deprecated.') String? legacyPackageName, Iterable<MapEntry<String, FFWidgetClass>>? widgetClasses, @Deprecated('This field is deprecated.') Iterable<String>? legacyPages, FFBackend? backend, FFSettings? appSettings, FFRoutingSettings? routingSettings, @Deprecated('This field is deprecated.') int? legacyInitialPageIndex, FFCustomCode? customCode, FFAppState? appState, @Deprecated('This field is deprecated.') Iterable<FFPageGroup>? legacyPageGroups, int? updateProjectVersion, FFEditMetadata? editMetadata, FFEditMetadata? widgetClassMetadata, @Deprecated('This field is deprecated.') FFProject_LegacyNullSafety? legacyNullSafety, String? marketplaceSourceItemId, bool? isMarketplaceProject, @Deprecated('This field is deprecated.') bool? legacyVisibleToTeam, FFTeamResourceInfo? legacyDesignSystem, FFTemplateNodes? templates, @Deprecated('This field is deprecated.') String? legacyDisplayName, @Deprecated('This field is deprecated.') Iterable<String>? legacyComponents, FFCodeGenerationSettings? codeGenerationSettings, FFStoryboard? storyboard, Iterable<String>? pageKeys, Iterable<String>? componentKeys, FFDefaultAppBar? defaultAppBar, FFProjectTests? tests, FFScreenshotInfo? screenshotInfo, Iterable<int>? dismissedWarningKeys, FFAppConstants? appConstants, FFProjectWalkthroughs? walkthroughs, Iterable<FFDependency>? dependencies, FFNodeKeyReference? initialPageKeyRef, FFAllAppNames? allAppNames, String? designSystemLibraryProjectId, String? description, Iterable<FFLibraryConfig>? libraryConfigurations, Iterable<FFAppEvent>? appEvents})
factory
FFProject.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFProject.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

allAppNames FFAllAppNames
@doc All app names keyed by environment key.
getter/setter pair
appConstants FFAppConstants
getter/setter pair
appEvents PbList<FFAppEvent>
@doc App events for the project (event bus communication primitive).
no setter
appSettings FFSettings
getter/setter pair
appState FFAppState
@doc Encapsulates global variables that hold the current state of the app.
getter/setter pair
authentication FFAuthentication
getter/setter pair
authPageInfo FFAuthPageInfo
getter/setter pair
backend FFBackend
getter/setter pair
codeGenerationSettings FFCodeGenerationSettings
getter/setter pair
componentKeys PbList<String>
TODO (victoria): surface to users once YAML format is supported.
no setter
currentSupabaseConfig FFSupabaseConfig

Available on FFProject, provided by the SchemaProjectPostgresExtensions extension

no setter
currentSupabaseOAuthConfig FFSupabaseConfig

Available on FFProject, provided by the SchemaProjectPostgresExtensions extension

no setter
customCode FFCustomCode
getter/setter pair
defaultAppBar FFDefaultAppBar
getter/setter pair
dependencies PbList<FFDependency>
@doc The list of flutterflow libraries that are added as project dependencies
no setter
description String
@doc The description of the project, surfaced in the generated pubspec.
getter/setter pair
designSystemLibraryProjectId String
@doc The project ID of the design system library project. The design system library project must be included in the project's dependencies.
getter/setter pair
dismissedWarningKeys PbList<int>
no setter
editMetadata FFEditMetadata
Tracks updates to name, package_name, pages, page_groups, and deleted WidgetClasses.
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ BuilderInfo
no setteroverride
initialPageKeyRef FFNodeKeyReference
Need initial page stored for codegen
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isMarketplaceProject bool
getter/setter pair
legacyComponents PbList<String>
Component names in the order in which they appear
no setter
legacyDesignSystem FFTeamResourceInfo
@doc The project ID of the design system library project.
getter/setter pair
legacyDisplayName String
getter/setter pair
legacyInitialPageIndex int
getter/setter pair
legacyNullSafety FFProject_LegacyNullSafety
getter/setter pair
legacyPackageName String
getter/setter pair
legacyPageGroups PbList<FFPageGroup>
no setter
legacyPages PbList<String>
All pages are FFWidgetClasses, and by default are used as the old FFNode pages was used. Should be transitioned when loading the project proto (by default with empty params, same name and page_source_name as the original FFNode).
no setter
legacyVisibleToTeam bool
getter/setter pair
libraryConfigurations PbList<FFLibraryConfig>
@doc Library configuration settings for the project
no setter
marketplaceSourceItemId String
Marketplace fields
getter/setter pair
name String
getter/setter pair
getter/setter pair
pageKeys PbList<String>
TODO (victoria): surface to users once YAML format is supported.
no setter
postgresFlavor FFPostgresFlavor

Available on FFProject, provided by the SchemaProjectPostgresExtensions extension

no setter
routingSettings FFRoutingSettings
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshotInfo FFScreenshotInfo
getter/setter pair
storyboard FFStoryboard
getter/setter pair
supabaseConnectionMode FFBackend_SupabaseConnection

Available on FFProject, provided by the SchemaProjectPostgresExtensions extension

no setter
supabaseEdgeFunctionsConfig FFSupabaseEdgeFunctionsConfig

Available on FFProject, provided by the SchemaProjectPostgresExtensions extension

no setter
templates FFTemplateNodes
getter/setter pair
tests FFProjectTests
@doc Tests for the project.
getter/setter pair
theme FFTheme
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
updateProjectVersion int
getter/setter pair
walkthroughs FFProjectWalkthroughs
getter/setter pair
widgetClasses PbMap<String, FFWidgetClass>
Widget classes keyed by node key.
no setter
widgetClassMetadata FFEditMetadata
Tracks adds and deletes for widget classes.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAllAppNames() → void
clearAppConstants() → void
clearAppSettings() → void
clearAppState() → void
clearAuthentication() → void
clearAuthPageInfo() → void
clearBackend() → void
clearCodeGenerationSettings() → void
clearCustomCode() → void
clearDefaultAppBar() → void
clearDescription() → void
clearDesignSystem() → void
clearDesignSystemLibraryProjectId() → void
clearEditMetadata() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearInitialPageKeyRef() → void
clearIsMarketplaceProject() → void
clearLegacyDesignSystem() → void
clearLegacyDisplayName() → void
clearLegacyInitialPageIndex() → void
clearLegacyNullSafety() → void
clearLegacyPackageName() → void
clearLegacyVisibleToTeam() → void
clearMarketplaceSourceItemId() → void
clearName() → void
clearNavBar() → void
clearRoutingSettings() → void
clearScreenshotInfo() → void
clearStoryboard() → void
clearTemplates() → void
clearTests() → void
clearTheme() → void
clearUpdateProjectVersion() → void
clearWalkthroughs() → void
clearWidgetClassMetadata() → void
clone() FFProject
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFProject)) FFProject
Apply updates to a copy of this message.
override
createEmptyInstance() FFProject
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAllAppNames() FFAllAppNames
ensureAppConstants() FFAppConstants
ensureAppSettings() FFSettings
ensureAppState() FFAppState
ensureAuthentication() FFAuthentication
ensureAuthPageInfo() FFAuthPageInfo
ensureBackend() FFBackend
ensureCodeGenerationSettings() FFCodeGenerationSettings
ensureCurrentSupabaseOAuthConfig() FFSupabaseConfig

Available on FFProject, provided by the SchemaProjectPostgresExtensions extension

ensureCustomCode() FFCustomCode
ensureDefaultAppBar() FFDefaultAppBar
ensureEditMetadata() FFEditMetadata
ensureInitialPageKeyRef() FFNodeKeyReference
ensureLegacyDesignSystem() FFTeamResourceInfo
ensureNavBar() FFNavBar
ensureRoutingSettings() FFRoutingSettings
ensureScreenshotInfo() FFScreenshotInfo
ensureStoryboard() FFStoryboard
ensureTemplates() FFTemplateNodes
ensureTests() FFProjectTests
ensureTheme() FFTheme
ensureWalkthroughs() FFProjectWalkthroughs
ensureWidgetClassMetadata() FFEditMetadata
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getComponent(String key) FFWidgetClass?

Available on FFProject, provided by the SchemaProjectExtensions extension

getComponents() List<FFWidgetClass>

Available on FFProject, provided by the SchemaProjectExtensions extension

getComponentsMap() Map<String, FFWidgetClass>

Available on FFProject, provided by the SchemaProjectExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getPages() List<FFWidgetClass>

Available on FFProject, provided by the SchemaProjectExtensions extension

getSerializedCompressedBufferString() String

Available on FFProject, provided by the SchemaProjectSerializationExtensions extension

getTagNumber(String fieldName) int?
inherited
getWidgetClassByName(String? name) FFWidgetClass?

Available on FFProject, provided by the SchemaProjectExtensions extension

hasAllAppNames() bool
hasAppConstants() bool
hasAppSettings() bool
hasAppState() bool
hasAuthentication() bool
hasAuthPageInfo() bool
hasBackend() bool
hasCodeGenerationSettings() bool
hasCustomCode() bool
hasDefaultAppBar() bool
hasDescription() bool
hasDesignSystemLibraryProjectId() bool
hasEditMetadata() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasInitialPageKeyRef() bool
hasIsMarketplaceProject() bool
hasLegacyDesignSystem() bool
hasLegacyDisplayName() bool
hasLegacyInitialPageIndex() bool
hasLegacyNullSafety() bool
hasLegacyPackageName() bool
hasLegacyVisibleToTeam() bool
hasMarketplaceSourceItemId() bool
hasName() bool
hasNavBar() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasRoutingSettings() bool
hasScreenshotInfo() bool
hasStoryboard() bool
hasTemplates() bool
hasTests() bool
hasTheme() bool
hasUpdateProjectVersion() bool
hasWalkthroughs() bool
hasWidgetClassMetadata() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
page(int index) FFWidgetClass?

Available on FFProject, provided by the SchemaProjectExtensions extension

rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
whichDesignSystem() FFProject_DesignSystem
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFProject
getDefault() FFProject