description property
@doc The description of the project, surfaced in the generated pubspec.
Implementation
@$pb.TagNumber(43)
$core.String get description => $_getSZ(40);
@doc The description of the project, surfaced in the generated pubspec.
@$pb.TagNumber(43)
$core.String get description => $_getSZ(40);