legacyComponents property
Component names in the order in which they appear
Implementation
@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(28)
$pb.PbList<$core.String> get legacyComponents => $_getList(25);
Component names in the order in which they appear
@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(28)
$pb.PbList<$core.String> get legacyComponents => $_getList(25);