legacyPages property
All pages are FFWidgetClasses, and by default are used as the old FFNode pages was used. Should be transitioned when loading the project proto (by default with empty params, same name and page_source_name as the original FFNode).
Implementation
@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(9)
$pb.PbList<$core.String> get legacyPages => $_getList(7);