walkthroughs property
@doc App walkthroughs that guide users through the app.
Implementation
@$pb.TagNumber(1)
$pb.PbList<FFProjectWalkthrough> get walkthroughs => $_getList(0);
@doc App walkthroughs that guide users through the app.
@$pb.TagNumber(1)
$pb.PbList<FFProjectWalkthrough> get walkthroughs => $_getList(0);