numBatches property
@doc Number of batches to run function to get scheduled push notifications.
Implementation
@$pb.TagNumber(6)
$core.int get numBatches => $_getIZ(5);
@doc Number of batches to run function to get scheduled push notifications.
@$pb.TagNumber(6)
$core.int get numBatches => $_getIZ(5);