schedulerIntervalMinutes property
@doc Frequency we want to run function to get scheduled push notifications.
Implementation
@$pb.TagNumber(5)
$core.int get schedulerIntervalMinutes => $_getIZ(4);
@doc Frequency we want to run function to get scheduled push notifications.
@$pb.TagNumber(5)
$core.int get schedulerIntervalMinutes => $_getIZ(4);