FFRadioButton class

Inheritance
Available extensions

Constructors

FFRadioButton({@Deprecated('This field is deprecated.') Iterable<String>? legacyOptions, FFDimensions? dimensions, FFColor? legacyRadioButtonColor, double? legacyOptionHeight, FFText? textStyle, FFPadding? textPadding, FFRadioButton_FFRadioButtonPosition? buttonPosition, FFAxis? direction, bool? legacyToggleable, FFWrapAlignment? horizontalAlignment, FFWrapCrossAlignment? verticalAlignment, FFColor? legacyInactiveRadioButtonColor, FFText? selectedTextStyle, bool? selectedStyleIsDifferent, @Deprecated('This field is deprecated.') String? legacyInitialValue, FFText? initialValue, @Deprecated('This field is deprecated.') Iterable<FFText>? legacyOption, FFDisable? disabled, FFDim? optionWidth, FFColorValue? radioButtonColorValue, FFDoubleValue? optionHeightValue, FFTextOptionsValue? options, FFBooleanValue? toggleableValue, FFColorValue? inactiveRadioButtonColorValue, FFDoubleValue? optionSpacingValue})
factory
FFRadioButton.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFRadioButton.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

buttonPosition FFRadioButton_FFRadioButtonPosition
getter/setter pair
dimensions FFDimensions
getter/setter pair
direction FFAxis
getter/setter pair
disabled FFDisable
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
horizontalAlignment FFWrapAlignment
getter/setter pair
inactiveRadioButtonColorValue FFColorValue
getter/setter pair
info_ BuilderInfo
no setteroverride
initialValue FFText
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
legacyInactiveRadioButtonColor FFColor
getter/setter pair
legacyInitialValue String
getter/setter pair
legacyOption PbList<FFText>
no setter
legacyOptionHeight double
getter/setter pair
legacyOptions PbList<String>
no setter
legacyRadioButtonColor FFColor
getter/setter pair
legacyToggleable bool
getter/setter pair
optionHeightValue FFDoubleValue
getter/setter pair
options FFTextOptionsValue
getter/setter pair
optionSpacingValue FFDoubleValue
  • getter/setter pair
    optionWidth FFDim
    getter/setter pair
    radioButtonColorValue FFColorValue
    getter/setter pair
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited
    selectedStyleIsDifferent bool
    Should not be overridable
    getter/setter pair
    selectedTextStyle FFText
    getter/setter pair
    textPadding FFPadding
    getter/setter pair
    textStyle FFText
    getter/setter pair
    toggleableValue FFBooleanValue
    getter/setter pair
    unknownFields UnknownFieldSet
    no setterinherited
    verticalAlignment FFWrapCrossAlignment
    getter/setter pair

    Methods

    addExtension(Extension extension, Object? value) → void
    Adds an extension field value to a repeated field.
    inherited
    check() → void
    Throws a StateError if the message has required fields without a value.
    inherited
    clear() → void
    Clears all data that was set in this message.
    inherited
    clearButtonPosition() → void
    clearDimensions() → void
    clearDirection() → void
    clearDisabled() → void
    clearExtension(Extension extension) → void
    Clears an extension field and also removes the extension.
    inherited
    clearField(int tagNumber) → void
    Clears the contents of a given field.
    inherited
    clearHorizontalAlignment() → void
    clearInactiveRadioButtonColorValue() → void
    clearInitialValue() → void
    clearLegacyInactiveRadioButtonColor() → void
    clearLegacyInitialValue() → void
    clearLegacyOptionHeight() → void
    clearLegacyRadioButtonColor() → void
    clearLegacyToggleable() → void
    clearOptionHeightValue() → void
    clearOptions() → void
    clearOptionSpacingValue() → void
    clearOptionWidth() → void
    clearRadioButtonColorValue() → void
    clearSelectedStyleIsDifferent() → void
    clearSelectedTextStyle() → void
    clearTextPadding() → void
    clearTextStyle() → void
    clearToggleableValue() → void
    clearVerticalAlignment() → void
    clone() FFRadioButton
    Creates a deep copy of the fields in this message.
    override
    copyWith(void updates(FFRadioButton)) FFRadioButton
    Apply updates to a copy of this message.
    override
    createEmptyInstance() FFRadioButton
    Creates an empty instance of the same message type as this.
    override
    deepCopy() → T

    Available on T, provided by the GeneratedMessageGenericExtensions extension

    Returns a writable deep copy of this message.
    ensureDimensions() FFDimensions
    ensureDisabled() FFDisable
    ensureInactiveRadioButtonColorValue() FFColorValue
    ensureInitialValue() FFText
    ensureLegacyInactiveRadioButtonColor() FFColor
    ensureLegacyRadioButtonColor() FFColor
    ensureOptionHeightValue() FFDoubleValue
    ensureOptions() FFTextOptionsValue
    ensureOptionSpacingValue() FFDoubleValue
    ensureOptionWidth() FFDim
    ensureRadioButtonColorValue() FFColorValue
    ensureSelectedTextStyle() FFText
    ensureTextPadding() FFPadding
    ensureTextStyle() FFText
    ensureToggleableValue() FFBooleanValue
    extensionsAreInitialized() bool
    inherited
    freeze() GeneratedMessage
    Make this message read-only.
    inherited
    fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

    Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

    fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

    Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

    getDefaultForField(int tagNumber) → dynamic
    Returns the default value for the given field.
    inherited
    getExtension(Extension extension) → dynamic
    Returns the value of extension.
    inherited
    getField(int tagNumber) → dynamic
    Returns the value of the field associated with tagNumber, or the default value if it is not set.
    inherited
    getFieldOrNull(int tagNumber) → dynamic
    Returns the value of a field, ignoring any defaults.
    inherited
    getTagNumber(String fieldName) int?
    inherited
    hasButtonPosition() bool
    hasDimensions() bool
    hasDirection() bool
    hasDisabled() bool
    hasExtension(Extension extension) bool
    Returns true if a value of extension is present.
    inherited
    hasField(int tagNumber) bool
    Whether this message has a field associated with tagNumber.
    inherited
    hasHorizontalAlignment() bool
    hasInactiveRadioButtonColorValue() bool
    hasInitialValue() bool
    hasLegacyInactiveRadioButtonColor() bool
    hasLegacyInitialValue() bool
    hasLegacyOptionHeight() bool
    hasLegacyRadioButtonColor() bool
    hasLegacyToggleable() bool
    hasOptionHeightValue() bool
    hasOptions() bool
    hasOptionSpacingValue() bool
    hasOptionWidth() bool
    hasRadioButtonColorValue() bool
    hasRequiredFields() bool
    Whether the message has required fields.
    inherited
    hasSelectedStyleIsDifferent() bool
    hasSelectedTextStyle() bool
    hasTextPadding() bool
    hasTextStyle() bool
    hasToggleableValue() bool
    hasVerticalAlignment() bool
    isInitialized() bool
    Whether all required fields in the message and embedded messages are set.
    inherited
    mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Merges serialized protocol buffer data into this message.
    inherited
    mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Same as mergeFromBuffer, but takes a CodedBufferReader input.
    inherited
    mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
    inherited
    mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
    Merges field values from a JSON object represented as a Dart map.
    inherited
    mergeFromMessage(GeneratedMessage other) → void
    Merges the contents of the other into this message.
    inherited
    mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
    Merges field values from json, a JSON object using proto3 encoding.
    inherited
    mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
    inherited
    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    rebuild(void updates(T)) → T

    Available on T, provided by the GeneratedMessageGenericExtensions extension

    Apply updates to a copy of this message.
    setExtension(Extension extension, Object value) → void
    Sets the value of a non-repeated extension field to value.
    inherited
    setField(int tagNumber, Object value) → void
    Sets the value of a field by its tagNumber.
    inherited
    toBuilder() GeneratedMessage
    Creates a writable, shallow copy of this message.
    inherited
    toDebugString() String
    Returns a String representation of this message.
    inherited
    toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
    Returns an Object representing Proto3 JSON serialization of this.
    inherited
    toString() String
    Returns a String representation of this message.
    inherited
    toTextFormat() String

    Available on GeneratedMessage, provided by the TextFormatExtension extension

    Returns a TextFormat String representation of this message.
    writeTextFormat(StringSink sink) → void

    Available on GeneratedMessage, provided by the TextFormatExtension extension

    Writes a TextFormat String representation of this message to sink.
    writeToBuffer() Uint8List
    Serialize the message as the protobuf binary format.
    inherited
    writeToCodedBufferWriter(CodedBufferWriter output) → void
    Same as writeToBuffer, but serializes to the given CodedBufferWriter.
    inherited
    writeToJson() String
    Returns a JSON string that encodes this message.
    inherited
    writeToJsonMap() Map<String, dynamic>
    Returns the JSON encoding of this message as a Dart Map.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited

    Static Methods

    create() FFRadioButton
    getDefault() FFRadioButton