isProduction property
@doc Whether to run the app in Test or Production mode.
Implementation
@$pb.TagNumber(4)
$core.bool get isProduction => $_getBF(3);
@doc Whether to run the app in Test or Production mode.
@$pb.TagNumber(4)
$core.bool get isProduction => $_getBF(3);