amount property
@doc The total cost of this payment, in the currency's smallest unit.
Implementation
@$pb.TagNumber(1)
FFValue get amount => $_getN(0);
@doc The total cost of this payment, in the currency's smallest unit.
@$pb.TagNumber(1)
FFValue get amount => $_getN(0);