currencyCode property
@doc The currency that will be used for this transaction.
Implementation
@$pb.TagNumber(2)
FFValue get currencyCode => $_getN(1);
@doc The currency that will be used for this transaction.
@$pb.TagNumber(2)
FFValue get currencyCode => $_getN(1);