maxWaitTimeMs property
@doc Max wait time used to end this action if the refreshed request does @doc not complete or takes a ridiculously long time.
Implementation
@$pb.TagNumber(4)
$core.int get maxWaitTimeMs => $_getIZ(3);
@doc Max wait time used to end this action if the refreshed request does @doc not complete or takes a ridiculously long time.
@$pb.TagNumber(4)
$core.int get maxWaitTimeMs => $_getIZ(3);