waitForResult property
@doc Whether to wait for the results of the refreshed request before moving @doc on to other actions.
Implementation
@$pb.TagNumber(2)
$core.bool get waitForResult => $_getBF(1);
@doc Whether to wait for the results of the refreshed request before moving @doc on to other actions.
@$pb.TagNumber(2)
$core.bool get waitForResult => $_getBF(1);