loadDataAfterAppLaunch property

  1. @TagNumber(5)
bool get loadDataAfterAppLaunch

@doc Whether or not to immediately load all plan, purchase, and offering data before the app launches, or instead allow it to load slightly after.

Implementation

@$pb.TagNumber(5)
$core.bool get loadDataAfterAppLaunch => $_getBF(4);
  1. @TagNumber(5)
set loadDataAfterAppLaunch (bool value)

Implementation

@$pb.TagNumber(5)
set loadDataAfterAppLaunch($core.bool value) => $_setBool(4, value);