begin property
@doc The starting value for the rotate animation, where 1 turn is 360 degrees. It can be a positive or negative double value.
Implementation
@$pb.TagNumber(3)
FFValue get begin => $_getN(2);
@doc The starting value for the rotate animation, where 1 turn is 360 degrees. It can be a positive or negative double value.
@$pb.TagNumber(3)
FFValue get begin => $_getN(2);