end property
@doc The ending value for the rotate animation, where 1 turn is 360 degrees. It can be a positive or negative double value.
Implementation
@$pb.TagNumber(4)
FFValue get end => $_getN(3);
@doc The ending value for the rotate animation, where 1 turn is 360 degrees. It can be a positive or negative double value.
@$pb.TagNumber(4)
FFValue get end => $_getN(3);