useIntrinsicHeight property
@doc If true, the row will be wrapped in an IntrinsicHeight widget, making all children match the height of the tallest child.
Implementation
@$pb.TagNumber(7)
$core.bool get useIntrinsicHeight => $_getBF(6);
@doc If true, the row will be wrapped in an IntrinsicHeight widget, making all children match the height of the tallest child.
@$pb.TagNumber(7)
$core.bool get useIntrinsicHeight => $_getBF(6);