beginDx property
@doc The horizontal starting value for the scale animation, where 1 is the original size.
Implementation
@$pb.TagNumber(5)
FFValue get beginDx => $_getN(4);
@doc The horizontal starting value for the scale animation, where 1 is the original size.
@$pb.TagNumber(5)
FFValue get beginDx => $_getN(4);