beginDy property
@doc The vertical starting value for the scale animation, where 1 is the original size.
Implementation
@$pb.TagNumber(7)
FFValue get beginDy => $_getN(6);
@doc The vertical starting value for the scale animation, where 1 is the original size.
@$pb.TagNumber(7)
FFValue get beginDy => $_getN(6);