endDx property
@doc The horizontal ending value for the scale animation, where 1 is the original size.
Implementation
@$pb.TagNumber(6)
FFValue get endDx => $_getN(5);
@doc The horizontal ending value for the scale animation, where 1 is the original size.
@$pb.TagNumber(6)
FFValue get endDx => $_getN(5);