endDy property
@doc The vertical ending value for the scale animation, where 1 is the original size.
Implementation
@$pb.TagNumber(8)
FFValue get endDy => $_getN(7);
@doc The vertical ending value for the scale animation, where 1 is the original size.
@$pb.TagNumber(8)
FFValue get endDy => $_getN(7);