generateAll property
@doc Whether to generate screenshots for all pages in the app.
Implementation
@$pb.TagNumber(3)
$core.bool get generateAll => $_getBF(2);
@doc Whether to generate screenshots for all pages in the app.
@$pb.TagNumber(3)
$core.bool get generateAll => $_getBF(2);