FFSearchReference_Identifier enum

Inheritance
Available extensions

Values

appState → const FFSearchReference_Identifier
appConstant → const FFSearchReference_Identifier
apiEndpoint → const FFSearchReference_Identifier
customFunction → const FFSearchReference_Identifier
customWidget → const FFSearchReference_Identifier
customAction → const FFSearchReference_Identifier
widgetClass → const FFSearchReference_Identifier
widgetClassState → const FFSearchReference_Identifier
widgetClassParameter → const FFSearchReference_Identifier
notSet → const FFSearchReference_Identifier

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FFSearchReference_Identifier>
A constant List of the values in this enum, in order of their declaration.