FFSemanticProperties class
@doc Additional semantic properties of the node. Semantic actions callbacks are handled as FFActionTriggerType on the Node.
- Inheritance
-
- Object
- GeneratedMessage
- FFSemanticProperties
- Available extensions
Constructors
- FFSemanticProperties({FFBooleanValue? isContainer, FFBooleanValue? isImage, FFBooleanValue? isButton, FFBooleanValue? isHeader, FFBooleanValue? explicitChildNodes, FFBooleanValue? excludeSemantics, FFStringValue? hintText, FFStringValue? tooltipText, FFDoubleValue? ordinalSortKey, FFBooleanValue? isLiveRegion, FFStringValue? valueText, FFBooleanValue? enabled, FFBooleanValue? onTap, FFBooleanValue? checked, FFBooleanValue? selected, FFBooleanValue? toggled, FFBooleanValue? link, FFBooleanValue? textField, FFBooleanValue? slider, FFStringValue? increasedValue, FFStringValue? decreasedValue, FFBooleanValue? keyboardKey, FFBooleanValue? readOnly, FFBooleanValue? obscured, FFBooleanValue? multiline, FFBooleanValue? focusable, FFBooleanValue? focused, FFBooleanValue? namesRoute, FFBooleanValue? scopesRoute, FFBooleanValue? inMutuallyExclusiveGroup, FFBooleanValue? blockUserActions, FFBooleanValue? mixed, FFStringValue? linkUrl, FFIntegerValue? headingLevel, FFIntegerValue? maxValueLength, FFIntegerValue? currentValueLength, FFStringValue? identifier, FFStringValue? onTapHint, FFStringValue? onLongPressHint, FFStringValue? passwordVisibilityIconLabel})
-
factory
-
FFSemanticProperties.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFSemanticProperties.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- blockUserActions ↔ FFBooleanValue
-
@doc Whether to block user actions for this semantics node.
getter/setter pair
- checked ↔ FFBooleanValue
-
@doc Whether this subtree represents a checkbox or similar widget with a "checked" state.
getter/setter pair
- currentValueLength ↔ FFIntegerValue
-
@doc The current number of characters entered into an editable text field.
getter/setter pair
- decreasedValue ↔ FFStringValue
-
@doc The value that
valuewill become after a decrease action.getter/setter pair - enabled ↔ FFBooleanValue
-
@doc Whether this subtree represents something that can be in an enabled or disabled state.
getter/setter pair
- excludeSemantics ↔ FFBooleanValue
-
@doc Whether to remove this widget from the semantics tree entirely.
getter/setter pair
- explicitChildNodes ↔ FFBooleanValue
-
@doc Whether descendants can add semantic information to this node rather than merging with it.
getter/setter pair
- focusable ↔ FFBooleanValue
-
@doc Whether the node is able to hold input focus.
getter/setter pair
- focused ↔ FFBooleanValue
-
@doc Whether the node currently holds input focus.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- headingLevel ↔ FFIntegerValue
-
@doc The heading level in the document structure.
getter/setter pair
-
@doc Whether the node is considered hidden.
getter/setter pair
- hintText ↔ FFStringValue
-
@doc Additional context shown when this widget has focus, helping explain its behavior.
getter/setter pair
- identifier ↔ FFStringValue
-
@doc Provides an identifier for the semantics node in the native accessibility hierarchy.
getter/setter pair
- increasedValue ↔ FFStringValue
-
@doc The value that
valuewill become after an increase action.getter/setter pair - info_ → BuilderInfo
-
no setteroverride
- inMutuallyExclusiveGroup ↔ FFBooleanValue
-
@doc Whether the node is in a mutually exclusive group.
getter/setter pair
- isButton ↔ FFBooleanValue
-
@doc Whether this widget is a button for screen readers, indicating it is tappable.
getter/setter pair
- isContainer ↔ FFBooleanValue
-
@doc Whether this widget introduces a new node in the semantics tree rather than merging with parent.
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - isHeader ↔ FFBooleanValue
-
@doc Whether this widget is a header/heading for screen readers, helping structure content.
getter/setter pair
- isImage ↔ FFBooleanValue
-
@doc Whether this widget is an image for screen readers, helping identify visual content.
getter/setter pair
- isLiveRegion ↔ FFBooleanValue
-
@doc Whether widget content changes dynamically and should be announced when changed.
getter/setter pair
- keyboardKey ↔ FFBooleanValue
-
@doc Whether this subtree represents a keyboard key.
getter/setter pair
- link ↔ FFBooleanValue
-
@doc Whether this subtree represents a link.
getter/setter pair
- linkUrl ↔ FFStringValue
-
@doc The URL that this node links to. Stored as text and parsed to Uri in codegen.
getter/setter pair
- maxValueLength ↔ FFIntegerValue
-
@doc The maximum number of characters that can be entered into an editable text field.
getter/setter pair
- mixed ↔ FFBooleanValue
-
@doc Whether this subtree represents a mixed/indeterminate state (e.g., tri-state checkbox).
getter/setter pair
- multiline ↔ FFBooleanValue
-
@doc Whether the value is coming from a field that supports multiline text editing.
getter/setter pair
- namesRoute ↔ FFBooleanValue
-
@doc Whether the node contains the semantic label for a route.
getter/setter pair
- obscured ↔ FFBooleanValue
-
@doc Whether value should be obscured.
getter/setter pair
- onLongPressHint ↔ FFStringValue
-
@doc Description of what happens when users long press this widget.
getter/setter pair
- onTap ↔ FFBooleanValue
-
@doc Expose a tap semantics action (no-op). Enables screen readers to trigger a tap.
getter/setter pair
- onTapHint ↔ FFStringValue
-
@doc Description of what happens when users tap this widget.
getter/setter pair
- ordinalSortKey ↔ FFDoubleValue
-
@doc Orders the widget in the screen reader navigation, lower numbers announced first.
getter/setter pair
- passwordVisibilityIconLabel ↔ FFStringValue
-
@doc Semantic label for the password visibility toggle icon. Only applicable when password field is enabled and keyboard traversal is allowed in a TextField.
getter/setter pair
- readOnly ↔ FFBooleanValue
-
@doc Whether the node is read-only.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopesRoute ↔ FFBooleanValue
-
@doc Whether the node corresponds to the root of a subtree for which a route name should be announced.
getter/setter pair
- selected ↔ FFBooleanValue
-
@doc Whether this subtree represents something that can be selected or unselected.
getter/setter pair
- slider ↔ FFBooleanValue
-
@doc Whether this subtree represents a slider.
getter/setter pair
- textField ↔ FFBooleanValue
-
@doc Whether this subtree represents a text field.
getter/setter pair
- toggled ↔ FFBooleanValue
-
@doc Whether this subtree represents a toggle switch in the "on" state.
getter/setter pair
- tooltipText ↔ FFStringValue
-
@doc Accessibility label for screen readers to describe the widget.
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- valueText ↔ FFStringValue
-
@doc Provides a textual description of the value of the widget.
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearBlockUserActions(
) → void -
clearChecked(
) → void -
clearCurrentValueLength(
) → void -
clearDecreasedValue(
) → void -
clearEnabled(
) → void -
clearExcludeSemantics(
) → void -
clearExplicitChildNodes(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearFocusable(
) → void -
clearFocused(
) → void -
clearHeadingLevel(
) → void -
clearHidden(
) → void -
clearHintText(
) → void -
clearIdentifier(
) → void -
clearIncreasedValue(
) → void -
clearInMutuallyExclusiveGroup(
) → void -
clearIsButton(
) → void -
clearIsContainer(
) → void -
clearIsHeader(
) → void -
clearIsImage(
) → void -
clearIsLiveRegion(
) → void -
clearKeyboardKey(
) → void -
clearLink(
) → void -
clearLinkUrl(
) → void -
clearMaxValueLength(
) → void -
clearMixed(
) → void -
clearMultiline(
) → void -
clearNamesRoute(
) → void -
clearObscured(
) → void -
clearOnLongPressHint(
) → void -
clearOnTap(
) → void -
clearOnTapHint(
) → void -
clearOrdinalSortKey(
) → void -
clearPasswordVisibilityIconLabel(
) → void -
clearReadOnly(
) → void -
clearScopesRoute(
) → void -
clearSelected(
) → void -
clearSlider(
) → void -
clearTextField(
) → void -
clearToggled(
) → void -
clearTooltipText(
) → void -
clearValueText(
) → void -
clone(
) → FFSemanticProperties -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFSemanticProperties)) → FFSemanticProperties -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFSemanticProperties -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureBlockUserActions(
) → FFBooleanValue -
ensureChecked(
) → FFBooleanValue -
ensureCurrentValueLength(
) → FFIntegerValue -
ensureDecreasedValue(
) → FFStringValue -
ensureEnabled(
) → FFBooleanValue -
ensureExcludeSemantics(
) → FFBooleanValue -
ensureExplicitChildNodes(
) → FFBooleanValue -
ensureFocusable(
) → FFBooleanValue -
ensureFocused(
) → FFBooleanValue -
ensureHeadingLevel(
) → FFIntegerValue -
ensureHidden(
) → FFBooleanValue -
ensureHintText(
) → FFStringValue -
ensureIdentifier(
) → FFStringValue -
ensureIncreasedValue(
) → FFStringValue -
ensureInMutuallyExclusiveGroup(
) → FFBooleanValue -
ensureIsButton(
) → FFBooleanValue -
ensureIsContainer(
) → FFBooleanValue -
ensureIsHeader(
) → FFBooleanValue -
ensureIsImage(
) → FFBooleanValue -
ensureIsLiveRegion(
) → FFBooleanValue -
ensureKeyboardKey(
) → FFBooleanValue -
ensureLink(
) → FFBooleanValue -
ensureLinkUrl(
) → FFStringValue -
ensureMaxValueLength(
) → FFIntegerValue -
ensureMixed(
) → FFBooleanValue -
ensureMultiline(
) → FFBooleanValue -
ensureNamesRoute(
) → FFBooleanValue -
ensureObscured(
) → FFBooleanValue -
ensureOnLongPressHint(
) → FFStringValue -
ensureOnTap(
) → FFBooleanValue -
ensureOnTapHint(
) → FFStringValue -
ensureOrdinalSortKey(
) → FFDoubleValue -
ensurePasswordVisibilityIconLabel(
) → FFStringValue -
ensureReadOnly(
) → FFBooleanValue -
ensureScopesRoute(
) → FFBooleanValue -
ensureSelected(
) → FFBooleanValue -
ensureSlider(
) → FFBooleanValue -
ensureTextField(
) → FFBooleanValue -
ensureToggled(
) → FFBooleanValue -
ensureTooltipText(
) → FFStringValue -
ensureValueText(
) → FFStringValue -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasBlockUserActions(
) → bool -
hasChecked(
) → bool -
hasCurrentValueLength(
) → bool -
hasDecreasedValue(
) → bool -
hasEnabled(
) → bool -
hasExcludeSemantics(
) → bool -
hasExplicitChildNodes(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasFocusable(
) → bool -
hasFocused(
) → bool -
hasHeadingLevel(
) → bool -
hasHidden(
) → bool -
hasHintText(
) → bool -
hasIdentifier(
) → bool -
hasIncreasedValue(
) → bool -
hasInMutuallyExclusiveGroup(
) → bool -
hasIsButton(
) → bool -
hasIsContainer(
) → bool -
hasIsHeader(
) → bool -
hasIsImage(
) → bool -
hasIsLiveRegion(
) → bool -
hasKeyboardKey(
) → bool -
hasLink(
) → bool -
hasLinkUrl(
) → bool -
hasMaxValueLength(
) → bool -
hasMixed(
) → bool -
hasMultiline(
) → bool -
hasNamesRoute(
) → bool -
hasObscured(
) → bool -
hasOnLongPressHint(
) → bool -
hasOnTap(
) → bool -
hasOnTapHint(
) → bool -
hasOrdinalSortKey(
) → bool -
hasPasswordVisibilityIconLabel(
) → bool -
hasReadOnly(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasScopesRoute(
) → bool -
hasSelected(
) → bool -
hasSlider(
) → bool -
hasTextField(
) → bool -
hasToggled(
) → bool -
hasTooltipText(
) → bool -
hasValueText(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited