scopesRoute property
@doc Whether the node corresponds to the root of a subtree for which a route name should be announced.
Implementation
@$pb.TagNumber(30)
FFBooleanValue get scopesRoute => $_getN(29);
Implementation
@$pb.TagNumber(30)
set scopesRoute(FFBooleanValue value) => $_setField(30, value);