isRtlText property
@doc Whether the announcement text should be read right-to-left
Implementation
@$pb.TagNumber(2)
FFValue get isRtlText => $_getN(1);
@doc Whether the announcement text should be read right-to-left
@$pb.TagNumber(2)
FFValue get isRtlText => $_getN(1);