variable property
@doc The variable representing the setting to set the app to.
Implementation
@$pb.TagNumber(2)
FFVariable get variable => $_getN(1);
Implementation
@$pb.TagNumber(2)
set variable(FFVariable value) => $_setField(2, value);
@doc The variable representing the setting to set the app to.
@$pb.TagNumber(2)
FFVariable get variable => $_getN(1);
@$pb.TagNumber(2)
set variable(FFVariable value) => $_setField(2, value);