hz property
@doc Frequency of the shake animation.
Indicates approximately how many times to repeat the shake per second.
Implementation
@$pb.TagNumber(5)
FFValue get hz => $_getN(4);
@doc Frequency of the shake animation.
Indicates approximately how many times to repeat the shake per second.
@$pb.TagNumber(5)
FFValue get hz => $_getN(4);