offsetDy property
@doc Vertical offset of the shake animation.
Positive and negative double values are allowed. Negative values indicate the shake will start from the opposite side.
Implementation
@$pb.TagNumber(7)
FFValue get offsetDy => $_getN(6);
@doc Vertical offset of the shake animation.
Positive and negative double values are allowed. Negative values indicate the shake will start from the opposite side.
@$pb.TagNumber(7)
FFValue get offsetDy => $_getN(6);