keyboardKeys property

  1. @TagNumber(1)
PbList<Int64> get keyboardKeys

@doc A list of ints corresponding to the key codes of keyboard keys that are tied to the shortcut. These values are from LogicalKeyboardKey's _knownLogicalKeys.

Implementation

@$pb.TagNumber(1)
$pb.PbList<$fixnum.Int64> get keyboardKeys => $_getList(0);