beginDx property
@doc The horizontal starting value for the slide animation (pixels).
Implementation
@$pb.TagNumber(5)
FFValue get beginDx => $_getN(4);
@doc The horizontal starting value for the slide animation (pixels).
@$pb.TagNumber(5)
FFValue get beginDx => $_getN(4);