beginDy property
@doc The vertical starting value for the slide animation (pixels).
Implementation
@$pb.TagNumber(6)
FFValue get beginDy => $_getN(5);
@doc The vertical starting value for the slide animation (pixels).
@$pb.TagNumber(6)
FFValue get beginDy => $_getN(5);