endDx property
@doc The horizontal ending value for the slide animation (pixels).
Implementation
@$pb.TagNumber(7)
FFValue get endDx => $_getN(6);
@doc The horizontal ending value for the slide animation (pixels).
@$pb.TagNumber(7)
FFValue get endDx => $_getN(6);