playSoundName property
@doc The name of the sound action to stop.
Implementation
@$pb.TagNumber(1)
$core.String get playSoundName => $_getSZ(0);
@doc The name of the sound action to stop.
@$pb.TagNumber(1)
$core.String get playSoundName => $_getSZ(0);