onCloseAction property

  1. @TagNumber(3)
FFTriggerActions get onCloseAction

@doc The action that will be triggered when a streaming API endpoint closes the connection to the app. No more events will be sent after this action is triggered.

Implementation

@$pb.TagNumber(3)
FFTriggerActions get onCloseAction => $_getN(2);
  1. @TagNumber(3)
set onCloseAction (FFTriggerActions value)

Implementation

@$pb.TagNumber(3)
set onCloseAction(FFTriggerActions value) => $_setField(3, value);