onErrorAction property

  1. @TagNumber(2)
FFTriggerActions get onErrorAction

@doc Reference to the action that will process errors from a streaming API. This action will process an individual error sent from the backend.

Implementation

@$pb.TagNumber(2)
FFTriggerActions get onErrorAction => $_getN(1);
  1. @TagNumber(2)
set onErrorAction (FFTriggerActions value)

Implementation

@$pb.TagNumber(2)
set onErrorAction(FFTriggerActions value) => $_setField(2, value);