streamSubscriptionKey property

  1. @TagNumber(4)
FFValue get streamSubscriptionKey

@doc A unique key to identify this stream subscription. This can be used to cancel the subscription later.

Implementation

@$pb.TagNumber(4)
FFValue get streamSubscriptionKey => $_getN(3);
  1. @TagNumber(4)
set streamSubscriptionKey (FFValue value)

Implementation

@$pb.TagNumber(4)
set streamSubscriptionKey(FFValue value) => $_setField(4, value);