inputValue property
@doc A preset string value that represents a static/hardcoded string.
Implementation
@$pb.TagNumber(1)
$core.String get inputValue => $_getSZ(0);
@doc A preset string value that represents a static/hardcoded string.
@$pb.TagNumber(1)
$core.String get inputValue => $_getSZ(0);