mostRecentInputValue property
@doc Stores the most recent string this value was set to in order to restore after removing a variable.
Implementation
@$pb.TagNumber(3)
$core.String get mostRecentInputValue => $_getSZ(2);
@doc Stores the most recent string this value was set to in order to restore after removing a variable.
@$pb.TagNumber(3)
$core.String get mostRecentInputValue => $_getSZ(2);