isProduction property
@doc Whether to run the app in Test or Production mode.
Implementation
@$pb.TagNumber(6)
$core.bool get isProduction => $_getBF(5);
@doc Whether to run the app in Test or Production mode.
@$pb.TagNumber(6)
$core.bool get isProduction => $_getBF(5);