merchantName property
@doc A display name for the merchant that the user will see for payments.
Implementation
@$pb.TagNumber(3)
$core.String get merchantName => $_getSZ(2);
@doc A display name for the merchant that the user will see for payments.
@$pb.TagNumber(3)
$core.String get merchantName => $_getSZ(2);