parameters property
@doc The list of input parameters to the Edge Function.
Implementation
@$pb.TagNumber(7)
$pb.PbList<FFParameter> get parameters => $_getList(6);
@doc The list of input parameters to the Edge Function.
@$pb.TagNumber(7)
$pb.PbList<FFParameter> get parameters => $_getList(6);