FFSwitchListTile class

Inheritance
Available extensions

Constructors

FFSwitchListTile({bool? legacyInitialValue, FFText? title, FFText? subtitle, bool? legacyDense, FFPadding? contentPadding, FFColor? legacyTileColor, FFBorderRadius? borderRadius, FFColor? legacyActiveColor, FFColor? legacyActiveTrackColor, bool? leading, FFDisable? disabled, FFColor? legacyDisabledActiveColor, FFColor? legacyDisabledActiveTrackColor, FFBooleanValue? initialValueValue, FFBooleanValue? denseValue, FFColorValue? tileColorValue, FFColorValue? activeColorValue, FFColorValue? activeTrackColorValue, FFColorValue? disabledActiveColorValue, FFColorValue? disabledActiveTrackColorValue})
factory
FFSwitchListTile.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFSwitchListTile.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

activeColorValue FFColorValue
getter/setter pair
activeTrackColorValue FFColorValue
getter/setter pair
borderRadius FFBorderRadius
getter/setter pair
contentPadding FFPadding
getter/setter pair
denseValue FFBooleanValue
getter/setter pair
disabled FFDisable
getter/setter pair
disabledActiveColorValue FFColorValue
getter/setter pair
disabledActiveTrackColorValue FFColorValue
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ BuilderInfo
no setteroverride
initialValueValue FFBooleanValue
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
leading bool
Should not be overridable
getter/setter pair
legacyActiveColor FFColor
getter/setter pair
legacyActiveTrackColor FFColor
getter/setter pair
legacyDense bool
getter/setter pair
legacyDisabledActiveColor FFColor
getter/setter pair
legacyDisabledActiveTrackColor FFColor
getter/setter pair
legacyInitialValue bool
getter/setter pair
legacyTileColor FFColor
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle FFText
getter/setter pair
tileColorValue FFColorValue
getter/setter pair
title FFText
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearActiveColorValue() → void
clearActiveTrackColorValue() → void
clearBorderRadius() → void
clearContentPadding() → void
clearDenseValue() → void
clearDisabled() → void
clearDisabledActiveColorValue() → void
clearDisabledActiveTrackColorValue() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearInitialValueValue() → void
clearLeading() → void
clearLegacyActiveColor() → void
clearLegacyActiveTrackColor() → void
clearLegacyDense() → void
clearLegacyDisabledActiveColor() → void
clearLegacyDisabledActiveTrackColor() → void
clearLegacyInitialValue() → void
clearLegacyTileColor() → void
clearSubtitle() → void
clearTileColorValue() → void
clearTitle() → void
clone() FFSwitchListTile
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFSwitchListTile)) FFSwitchListTile
Apply updates to a copy of this message.
override
createEmptyInstance() FFSwitchListTile
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureActiveColorValue() FFColorValue
ensureActiveTrackColorValue() FFColorValue
ensureBorderRadius() FFBorderRadius
ensureContentPadding() FFPadding
ensureDenseValue() FFBooleanValue
ensureDisabled() FFDisable
ensureDisabledActiveColorValue() FFColorValue
ensureDisabledActiveTrackColorValue() FFColorValue
ensureInitialValueValue() FFBooleanValue
ensureLegacyActiveColor() FFColor
ensureLegacyActiveTrackColor() FFColor
ensureLegacyDisabledActiveColor() FFColor
ensureLegacyDisabledActiveTrackColor() FFColor
ensureLegacyTileColor() FFColor
ensureSubtitle() FFText
ensureTileColorValue() FFColorValue
ensureTitle() FFText
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasActiveColorValue() bool
hasActiveTrackColorValue() bool
hasBorderRadius() bool
hasContentPadding() bool
hasDenseValue() bool
hasDisabled() bool
hasDisabledActiveColorValue() bool
hasDisabledActiveTrackColorValue() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasInitialValueValue() bool
hasLeading() bool
hasLegacyActiveColor() bool
hasLegacyActiveTrackColor() bool
hasLegacyDense() bool
hasLegacyDisabledActiveColor() bool
hasLegacyDisabledActiveTrackColor() bool
hasLegacyInitialValue() bool
hasLegacyTileColor() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSubtitle() bool
hasTileColorValue() bool
hasTitle() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFSwitchListTile
getDefault() FFSwitchListTile