FFTestFinder_Finder enum

Inheritance
Available extensions

Values

byNodeKey → const FFTestFinder_Finder
byValueKey → const FFTestFinder_Finder
byType → const FFTestFinder_Finder
byTooltip → const FFTestFinder_Finder
bySemanticsLabel → const FFTestFinder_Finder
byText → const FFTestFinder_Finder
byDescendent → const FFTestFinder_Finder
custom → const FFTestFinder_Finder
byIcon → const FFTestFinder_Finder
notSet → const FFTestFinder_Finder

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FFTestFinder_Finder>
A constant List of the values in this enum, in order of their declaration.