FFText class

Inheritance
Available extensions

Constructors

FFText({String? legacyText, double? legacyFontSize, String? fontFamily, @Deprecated('This field is deprecated.') Int64? legacyColorVal, FFFontWeight? legacyFontWeight, FFTextAlign? legacyTextAlign, FFColor? legacyColor, FFText_ThemeStyle? themeStyle, bool? legacyItalic, bool? autoSize, int? legacyLegacyOverriddenTextMaxChars, FFText_LegacyOverflowReplacement? legacyOverflowReplacement, bool? isCustomFont, double? legacyHeight, FFIdentifier? translationIdentifier, bool? underline, bool? strikethrough, int? legacyMaxLines, double? legacyLetterSpacing, FFTextGradient? gradient, bool? selectable, FFValue? variableColor, double? legacyMinFontSize, FFTextStyleAnimation? animation, Iterable<FFTextShadow>? shadows, FFStringValue? textValue, FFDoubleValue? fontSizeValue, FFColorValue? colorValue, FFBooleanValue? italicValue, FFDoubleValue? minFontSizeValue, FFDoubleValue? heightValue, FFIntegerValue? maxLinesValue, FFDoubleValue? letterSpacingValue, FFIntegerValue? legacyOverriddenTextMaxCharsValue, FFTextStyleValue? textStyle, FFFontWeightValue? fontWeightValue, FFTextAlignValue? textAlignValue, String? figmaFontName, String? customStyleName, FFText_OverflowReplacement? overflowReplacement})
factory
FFText.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFText.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

animation FFTextStyleAnimation
getter/setter pair
autoSize bool
not overridable
getter/setter pair
colorValue FFColorValue
getter/setter pair
customStyleName String
Name of the custom style for this text
getter/setter pair
figmaFontName String
Store mapping from FFText to Figma text style if the font was imported from Figma
getter/setter pair
fontFamily String
not overridable
getter/setter pair
fontSizeValue FFDoubleValue
getter/setter pair
fontWeightValue FFFontWeightValue
getter/setter pair
gradient FFTextGradient
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
heightValue FFDoubleValue
getter/setter pair
info_ BuilderInfo
no setteroverride
isCustomFont bool
not overridable
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
italicValue FFBooleanValue
getter/setter pair
legacyColor FFColor
getter/setter pair
legacyColorVal ↔ Int64
getter/setter pair
legacyFontSize double
getter/setter pair
legacyFontWeight FFFontWeight
getter/setter pair
legacyHeight double
TextStyle#height.
getter/setter pair
legacyItalic bool
getter/setter pair
legacyLegacyOverriddenTextMaxChars int
getter/setter pair
legacyLetterSpacing double
getter/setter pair
legacyMaxLines int
getter/setter pair
legacyMinFontSize double
Only used if auto_size is true.
getter/setter pair
legacyOverflowReplacement FFText_LegacyOverflowReplacement
getter/setter pair
legacyOverriddenTextMaxCharsValue FFIntegerValue
getter/setter pair
legacyText String
getter/setter pair
legacyTextAlign FFTextAlign
getter/setter pair
letterSpacingValue FFDoubleValue
getter/setter pair
maxLinesValue FFIntegerValue
getter/setter pair
minFontSizeValue FFDoubleValue
getter/setter pair
overflowReplacement FFText_OverflowReplacement
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectable bool
not overridable
getter/setter pair
shadows PbList<FFTextShadow>
no setter
strikethrough bool
getter/setter pair
textAlignValue FFTextAlignValue
getter/setter pair
textStyle FFTextStyleValue
TODO (new types): The correct refactor is to create an FFTextStyle message, and a FFTextStyleValue message and migrate existing fields into it and add the value message here. However, as we are in the middle of the properties refactor this is not possible without fully migrating. We will temporarily store a variable for the text style instead, and down the line after the migration do this refactor including only the non-legacy fields.
getter/setter pair
textValue FFStringValue
getter/setter pair
themeStyle FFText_ThemeStyle
getter/setter pair
translationIdentifier FFIdentifier
getter/setter pair
underline bool
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
variableColor FFValue
TODO (new types): Migrate this value as well
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAnimation() → void
clearAutoSize() → void
clearColorValue() → void
clearCustomStyleName() → void
clearDecoration() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFigmaFontName() → void
clearFontFamily() → void
clearFontSizeValue() → void
clearFontWeightValue() → void
clearGradient() → void
clearHeightValue() → void
clearIsCustomFont() → void
clearItalicValue() → void
clearLegacyColor() → void
clearLegacyColorVal() → void
clearLegacyFontSize() → void
clearLegacyFontWeight() → void
clearLegacyHeight() → void
clearLegacyItalic() → void
clearLegacyLegacyOverriddenTextMaxChars() → void
clearLegacyLetterSpacing() → void
clearLegacyMaxLines() → void
clearLegacyMinFontSize() → void
clearLegacyOverflowReplacement() → void
clearLegacyOverriddenTextMaxCharsValue() → void
clearLegacyText() → void
clearLegacyTextAlign() → void
clearLetterSpacingValue() → void
clearMaxLinesValue() → void
clearMinFontSizeValue() → void
clearOverflowReplacement() → void
clearSelectable() → void
clearStrikethrough() → void
clearTextAlignValue() → void
clearTextStyle() → void
clearTextValue() → void
clearThemeStyle() → void
clearTranslationIdentifier() → void
clearUnderline() → void
clearVariableColor() → void
clone() FFText
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFText)) FFText
Apply updates to a copy of this message.
override
createEmptyInstance() FFText
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAnimation() FFTextStyleAnimation
ensureColorValue() FFColorValue
ensureFontSizeValue() FFDoubleValue
ensureFontWeightValue() FFFontWeightValue
ensureGradient() FFTextGradient
ensureHeightValue() FFDoubleValue
ensureItalicValue() FFBooleanValue
ensureLegacyColor() FFColor
ensureLegacyOverriddenTextMaxCharsValue() FFIntegerValue
ensureLetterSpacingValue() FFDoubleValue
ensureMaxLinesValue() FFIntegerValue
ensureMinFontSizeValue() FFDoubleValue
ensureTextAlignValue() FFTextAlignValue
ensureTextStyle() FFTextStyleValue
ensureTextValue() FFStringValue
ensureTranslationIdentifier() FFIdentifier
ensureVariableColor() FFValue
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAnimation() bool
hasAutoSize() bool
hasColorValue() bool
hasCustomStyleName() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFigmaFontName() bool
hasFontFamily() bool
hasFontSizeValue() bool
hasFontWeightValue() bool
hasGradient() bool
hasHeightValue() bool
hasIsCustomFont() bool
hasItalicValue() bool
hasLegacyColor() bool
hasLegacyColorVal() bool
hasLegacyFontSize() bool
hasLegacyFontWeight() bool
hasLegacyHeight() bool
hasLegacyItalic() bool
hasLegacyLegacyOverriddenTextMaxChars() bool
hasLegacyLetterSpacing() bool
hasLegacyMaxLines() bool
hasLegacyMinFontSize() bool
hasLegacyOverflowReplacement() bool
hasLegacyOverriddenTextMaxCharsValue() bool
hasLegacyText() bool
hasLegacyTextAlign() bool
hasLetterSpacingValue() bool
hasMaxLinesValue() bool
hasMinFontSizeValue() bool
hasOverflowReplacement() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSelectable() bool
hasStrikethrough() bool
hasTextAlignValue() bool
hasTextStyle() bool
hasTextValue() bool
hasThemeStyle() bool
hasTranslationIdentifier() bool
hasUnderline() bool
hasVariableColor() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
whichDecoration() FFText_Decoration
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFText
getDefault() FFText