figmaFontName property
Store mapping from FFText to Figma text style if the font was imported from Figma
Implementation
@$pb.TagNumber(38)
$core.String get figmaFontName => $_getSZ(37);
Store mapping from FFText to Figma text style if the font was imported from Figma
@$pb.TagNumber(38)
$core.String get figmaFontName => $_getSZ(37);