textStyle property

  1. @TagNumber(35)
FFTextStyleValue get textStyle

TODO (new types): The correct refactor is to create an FFTextStyle message, and a FFTextStyleValue message and migrate existing fields into it and add the value message here. However, as we are in the middle of the properties refactor this is not possible without fully migrating. We will temporarily store a variable for the text style instead, and down the line after the migration do this refactor including only the non-legacy fields.

Implementation

@$pb.TagNumber(35)
FFTextStyleValue get textStyle => $_getN(34);
  1. @TagNumber(35)
set textStyle (FFTextStyleValue value)

Implementation

@$pb.TagNumber(35)
set textStyle(FFTextStyleValue value) => $_setField(35, value);