blockShortcutIntents property
Not overridable @doc If set, shortcuts are blocked when the text field is focused.
Implementation
@$pb.TagNumber(47)
$core.bool get blockShortcutIntents => $_getBF(46);
Not overridable @doc If set, shortcuts are blocked when the text field is focused.
@$pb.TagNumber(47)
$core.bool get blockShortcutIntents => $_getBF(46);