enableInteractiveSelection property

  1. @TagNumber(51)
FFBooleanValue get enableInteractiveSelection

@doc If set to false, this disables the ability to select text in the text field. This prevents the user from copying, cutting, or selecting text within the field. By default this is true, allowing text selection.

Implementation

@$pb.TagNumber(51)
FFBooleanValue get enableInteractiveSelection => $_getN(50);
  1. @TagNumber(51)
set enableInteractiveSelection (FFBooleanValue value)

Implementation

@$pb.TagNumber(51)
set enableInteractiveSelection(FFBooleanValue value) => $_setField(51, value);