passwordIconAllowKeyboardTraversal property
@doc Controls whether the password visibility icon can be focused during keyboard navigation. When false (default), the icon skips keyboard traversal and won't be focused. When true, the icon can be focused during keyboard navigation. By default this is false, preventing focus during keyboard traversal.
Implementation
@$pb.TagNumber(53)
FFBooleanValue get passwordIconAllowKeyboardTraversal => $_getN(52);
Implementation
@$pb.TagNumber(53)
set passwordIconAllowKeyboardTraversal(FFBooleanValue value) =>
$_setField(53, value);