FFThenTestStep class

Inheritance
Available extensions

Constructors

FFThenTestStep({FFTestFinder? target, FFThenTestStep_FindsOneWidget? findsOneWidget, FFThenTestStep_FindsNothing? findsNothing, FFThenTestStep_FindsWidgets? findsWidgets, FFThenTestStep_FindsNumWidgets? findsNumWidgets, FFThenTestStep_CustomThenStep? custom, FFThenTestStep_IsEnabled? isEnabled, FFThenTestStep_IsDisabled? isDisabled, FFThenTestStep_HasState? hasState, FFThenTestStep_MatchesGoldenFile? matchesGoldenFile})
factory
FFThenTestStep.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFThenTestStep.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

custom FFThenTestStep_CustomThenStep
@doc Custom assertion. Currently not implemented.
getter/setter pair
findsNothing FFThenTestStep_FindsNothing
@doc Asserts that the target finds nothing.
getter/setter pair
findsNumWidgets FFThenTestStep_FindsNumWidgets
@doc Asserts that the target finds a specific number of widgets.
getter/setter pair
findsOneWidget FFThenTestStep_FindsOneWidget
@doc Asserts that the target finds one widget.
getter/setter pair
findsWidgets FFThenTestStep_FindsWidgets
@doc Asserts that the target finds widgets.
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hasState FFThenTestStep_HasState
@doc Asserts that the target has a specific state.
getter/setter pair
info_ BuilderInfo
no setteroverride
isDisabled FFThenTestStep_IsDisabled
@doc Asserts that the target is disabled.
getter/setter pair
isEnabled FFThenTestStep_IsEnabled
@doc Asserts that the target is enabled.
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
matchesGoldenFile FFThenTestStep_MatchesGoldenFile
@doc Asserts that the current canvas matches a baseline image file.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target FFTestFinder
@doc Target of the assertion.
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCustom() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFindsNothing() → void
clearFindsNumWidgets() → void
clearFindsOneWidget() → void
clearFindsWidgets() → void
clearHasState() → void
clearIsDisabled() → void
clearIsEnabled() → void
clearMatchesGoldenFile() → void
clearStep() → void
clearTarget() → void
clone() FFThenTestStep
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFThenTestStep)) FFThenTestStep
Apply updates to a copy of this message.
override
createEmptyInstance() FFThenTestStep
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureCustom() FFThenTestStep_CustomThenStep
ensureFindsNothing() FFThenTestStep_FindsNothing
ensureFindsNumWidgets() FFThenTestStep_FindsNumWidgets
ensureFindsOneWidget() FFThenTestStep_FindsOneWidget
ensureFindsWidgets() FFThenTestStep_FindsWidgets
ensureHasState() FFThenTestStep_HasState
ensureIsDisabled() FFThenTestStep_IsDisabled
ensureIsEnabled() FFThenTestStep_IsEnabled
ensureMatchesGoldenFile() FFThenTestStep_MatchesGoldenFile
ensureTarget() FFTestFinder
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasCustom() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFindsNothing() bool
hasFindsNumWidgets() bool
hasFindsOneWidget() bool
hasFindsWidgets() bool
hasHasState() bool
hasIsDisabled() bool
hasIsEnabled() bool
hasMatchesGoldenFile() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasTarget() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
whichStep() FFThenTestStep_Step
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFThenTestStep
getDefault() FFThenTestStep