beginHorizontal property
@doc Horizontal starting value for the tilt animation (degrees).
Implementation
@$pb.TagNumber(6)
FFValue get beginHorizontal => $_getN(5);
@doc Horizontal starting value for the tilt animation (degrees).
@$pb.TagNumber(6)
FFValue get beginHorizontal => $_getN(5);