beginVertical property
@doc Vertical starting value for the tilt animation (degrees).
Implementation
@$pb.TagNumber(5)
FFValue get beginVertical => $_getN(4);
@doc Vertical starting value for the tilt animation (degrees).
@$pb.TagNumber(5)
FFValue get beginVertical => $_getN(4);