endHorizontal property
@doc Horizontal ending value for the tilt animation (degrees).
Implementation
@$pb.TagNumber(8)
FFValue get endHorizontal => $_getN(7);
@doc Horizontal ending value for the tilt animation (degrees).
@$pb.TagNumber(8)
FFValue get endHorizontal => $_getN(7);