endVertical property
@doc Vertical ending value for the tilt animation (degrees).
Implementation
@$pb.TagNumber(7)
FFValue get endVertical => $_getN(6);
@doc Vertical ending value for the tilt animation (degrees).
@$pb.TagNumber(7)
FFValue get endVertical => $_getN(6);