nodeKeyPaths property
@doc The path to the component that holds the expandable widget.
Implementation
@$pb.TagNumber(1)
$pb.PbList<FFNodeKeyPath> get nodeKeyPaths => $_getList(0);
@doc The path to the component that holds the expandable widget.
@$pb.TagNumber(1)
$pb.PbList<FFNodeKeyPath> get nodeKeyPaths => $_getList(0);