FFTooltip class

Next available tag: 25

Inheritance
Available extensions

Constructors

FFTooltip({FFText? message, FFPadding? innerPadding, double? legacyOffset, FFAxisDirection? preferredDirection, double? legacyBorderRadius, FFColor? legacyBackgroundColor, int? legacyElevation, double? legacyTailBaseWidth, double? legacyTailLength, int? legacyWaitDuration, int? legacyShowDuration, FFTooltip_TriggerMode? triggerMode, FFDoubleValue? offsetValue, FFDoubleValue? borderRadiusValue, FFColorValue? backgroundColorValue, FFIntegerValue? elevationValue, FFDoubleValue? tailBaseWidthValue, FFDoubleValue? tailLengthValue, FFIntegerValue? waitDurationValue, FFIntegerValue? showDurationValue, FFNodeKeyReference? componentClassNodeKeyRef, FFDimensions? componentDimensions, FFPassedParameters? componentParameters, bool? showTooltipOnFocus})
factory
FFTooltip.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFTooltip.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

backgroundColorValue FFColorValue
getter/setter pair
borderRadiusValue FFDoubleValue
getter/setter pair
componentClassNodeKeyRef FFNodeKeyReference
getter/setter pair
componentDimensions FFDimensions
getter/setter pair
componentParameters FFPassedParameters
getter/setter pair
elevationValue FFIntegerValue
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ BuilderInfo
no setteroverride
innerPadding FFPadding
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
legacyBackgroundColor FFColor
getter/setter pair
legacyBorderRadius double
getter/setter pair
legacyElevation int
getter/setter pair
legacyOffset double
getter/setter pair
legacyShowDuration int
getter/setter pair
legacyTailBaseWidth double
getter/setter pair
legacyTailLength double
getter/setter pair
legacyWaitDuration int
getter/setter pair
message FFText
getter/setter pair
offsetValue FFDoubleValue
getter/setter pair
preferredDirection FFAxisDirection
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDurationValue FFIntegerValue
getter/setter pair
showTooltipOnFocus bool
getter/setter pair
tailBaseWidthValue FFDoubleValue
getter/setter pair
tailLengthValue FFDoubleValue
getter/setter pair
triggerMode FFTooltip_TriggerMode
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
waitDurationValue FFIntegerValue
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBackgroundColorValue() → void
clearBorderRadiusValue() → void
clearComponentClassNodeKeyRef() → void
clearComponentDimensions() → void
clearComponentParameters() → void
clearElevationValue() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearInnerPadding() → void
clearLegacyBackgroundColor() → void
clearLegacyBorderRadius() → void
clearLegacyElevation() → void
clearLegacyOffset() → void
clearLegacyShowDuration() → void
clearLegacyTailBaseWidth() → void
clearLegacyTailLength() → void
clearLegacyWaitDuration() → void
clearMessage() → void
clearOffsetValue() → void
clearPreferredDirection() → void
clearShowDurationValue() → void
clearShowTooltipOnFocus() → void
clearTailBaseWidthValue() → void
clearTailLengthValue() → void
clearTriggerMode() → void
clearWaitDurationValue() → void
clearWidget() → void
clone() FFTooltip
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFTooltip)) FFTooltip
Apply updates to a copy of this message.
override
createEmptyInstance() FFTooltip
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureBackgroundColorValue() FFColorValue
ensureBorderRadiusValue() FFDoubleValue
ensureComponentClassNodeKeyRef() FFNodeKeyReference
ensureComponentDimensions() FFDimensions
ensureComponentParameters() FFPassedParameters
ensureElevationValue() FFIntegerValue
ensureInnerPadding() FFPadding
ensureLegacyBackgroundColor() FFColor
ensureMessage() FFText
ensureOffsetValue() FFDoubleValue
ensureShowDurationValue() FFIntegerValue
ensureTailBaseWidthValue() FFDoubleValue
ensureTailLengthValue() FFDoubleValue
ensureWaitDurationValue() FFIntegerValue
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasBackgroundColorValue() bool
hasBorderRadiusValue() bool
hasComponentClassNodeKeyRef() bool
hasComponentDimensions() bool
hasComponentParameters() bool
hasElevationValue() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasInnerPadding() bool
hasLegacyBackgroundColor() bool
hasLegacyBorderRadius() bool
hasLegacyElevation() bool
hasLegacyOffset() bool
hasLegacyShowDuration() bool
hasLegacyTailBaseWidth() bool
hasLegacyTailLength() bool
hasLegacyWaitDuration() bool
hasMessage() bool
hasOffsetValue() bool
hasPreferredDirection() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasShowDurationValue() bool
hasShowTooltipOnFocus() bool
hasTailBaseWidthValue() bool
hasTailLengthValue() bool
hasTriggerMode() bool
hasWaitDurationValue() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
whichWidget() FFTooltip_Widget
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFTooltip
getDefault() FFTooltip