animated property
Not overridable @doc Whether to use implicit animation for the transform.
Implementation
@$pb.TagNumber(9)
$core.bool get animated => $_getBF(8);
Not overridable @doc Whether to use implicit animation for the transform.
@$pb.TagNumber(9)
$core.bool get animated => $_getBF(8);