appEventData property
@doc The data to be associated with the event being triggered
Implementation
@$pb.TagNumber(2)
FFValue get appEventData => $_getN(1);
@doc The data to be associated with the event being triggered
@$pb.TagNumber(2)
FFValue get appEventData => $_getN(1);