debugId property
@doc Debug id if any that is to be passed to the app event
Implementation
@$pb.TagNumber(4)
FFValue get debugId => $_getN(3);
@doc Debug id if any that is to be passed to the app event
@$pb.TagNumber(4)
FFValue get debugId => $_getN(3);