value property
Variable or value to add or remove from array. TODO: Refactor this into its own proto used across FlutterFlow cause this is getting silly.
Implementation
@$pb.TagNumber(3)
FFFieldUpdate get value => $_getN(2);
Implementation
@$pb.TagNumber(3)
set value(FFFieldUpdate value) => $_setField(3, value);