increment property
@doc Increment the text scaling factor by this value.
Implementation
@$pb.TagNumber(2)
FFValue get increment => $_getN(1);
@doc Increment the text scaling factor by this value.
@$pb.TagNumber(2)
FFValue get increment => $_getN(1);