resetValue property
@doc Reset the text scaling factor value back to 1.0
Implementation
@$pb.TagNumber(3)
$core.double get resetValue => $_getN(2);
@doc Reset the text scaling factor value back to 1.0
@$pb.TagNumber(3)
$core.double get resetValue => $_getN(2);