imageQuality property
@doc The quality of the image, ranging from 0-100, where 100 is the @doc original/max quality.
Implementation
@$pb.TagNumber(6)
$core.int get imageQuality => $_getIZ(5);
@doc The quality of the image, ranging from 0-100, where 100 is the @doc original/max quality.
@$pb.TagNumber(6)
$core.int get imageQuality => $_getIZ(5);