multiUpload property
@doc Whether to allow multiple files to be uploaded.
Implementation
@$pb.TagNumber(7)
$core.bool get multiUpload => $_getBF(6);
@doc Whether to allow multiple files to be uploaded.
@$pb.TagNumber(7)
$core.bool get multiUpload => $_getBF(6);