showSnackBar property
@doc Whether to show a snack bar indicating the status of the upload.
Implementation
@$pb.TagNumber(8)
$core.bool get showSnackBar => $_getBF(7);
@doc Whether to show a snack bar indicating the status of the upload.
@$pb.TagNumber(8)
$core.bool get showSnackBar => $_getBF(7);