autoCrop property
@doc Whether to automatically crop exported images to the drawn area.
Implementation
@$pb.TagNumber(2)
$core.bool get autoCrop => $_getBF(1);
@doc Whether to automatically crop exported images to the drawn area.
@$pb.TagNumber(2)
$core.bool get autoCrop => $_getBF(1);