componentNodePath property
- @doc If we are accessing a variable from a nested component, this is the node key path to the specified widget.
Implementation
@$pb.TagNumber(12)
FFNodeKeyPath get componentNodePath => $_getN(11);
Implementation
@$pb.TagNumber(12)
set componentNodePath(FFNodeKeyPath value) => $_setField(12, value);