description property
A plain text description of what this variable is being used for, primarily for AI purposes.
Implementation
@$pb.TagNumber(19)
$core.String get description => $_getSZ(18);
A plain text description of what this variable is being used for, primarily for AI purposes.
@$pb.TagNumber(19)
$core.String get description => $_getSZ(18);