FFVariableOperation class

Inheritance
Available extensions

Constructors

FFVariableOperation({@Deprecated('This field is deprecated.') FFParameter? returnParam, FFItemAtCurrentIndex? itemAtCurrentIndex, FFIndexInList? indexInList, FFJsonPathOperation? jsonPathOperation, FFTypeCastOperation? typeCastOperation, FFListContains? listContains, FFDateTimeRangeStart? dateTimeRangeStart, FFDateTimeRangeEnd? dateTimeRangeEnd, FFDateTimeFormat? dateTimeFormat, FFListNumItems? listNumItems, FFNegateBoolean? negate, FFNumberFormat? numberFormat, FFApiResponseField? apiResponseField, FFRevenueCatOperation? revenueCat, FFListMapOperation? listMapOperation, FFAccessDocumentField? accessDocumentField, FFAccessGooglePlaceField? accessGooglePlaceField, FFAccessDataStructField? accessDataStructField, FFListWhereOperation? listWhereOperation, FFAccessPostgresRowField? accessPostgresRowField, FFListItemAtIndex? listItemAtIndex, FFUploadMediaHeight? uploadMediaHeight, FFUploadMediaWidth? uploadMediaWidth, FFDocumentReferenceId? documentReferenceId, FFDateTimeToInteger? dateTimeToInteger, FFAccessSQLiteRowColumn? accessSqliteRowColumn, FFUploadMediaBlurHash? uploadMediaBlurHash, FFCheckHasField? checkHasField, FFListTakeOperation? listTakeOperation, FFCustomCloudFunctionResponseField? customCloudFunctionResponseField, FFJsonToDataStruct? jsonToDataStruct, FFDataStructToJson? dataStructToJson, FFListSortOperation? listSortOperation, FFListHasValueOperation? listHasValueOperation, FFPredefinedJsonPathOperation? predefinedJsonPathOperation, FFListUniqueOperation? listUniqueOperation, FFResponseStreamMessageField? responseStreamMessageField, FFParseStringAsEnum? parseStringAsEnum, FFAccessCustomInterfaceField? accessCustomInterfaceField, FFAccessCustomInterfaceMethod? accessCustomInterfaceMethod, FFDocumentReferencePath? documentReferencePath, FFUploadedOriginalFileName? uploadedOriginalFileName})
factory
FFVariableOperation.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFVariableOperation.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

accessCustomInterfaceField FFAccessCustomInterfaceField
getter/setter pair
accessCustomInterfaceMethod FFAccessCustomInterfaceMethod
getter/setter pair
accessDataStructField FFAccessDataStructField
getter/setter pair
accessDocumentField FFAccessDocumentField
getter/setter pair
accessGooglePlaceField FFAccessGooglePlaceField
getter/setter pair
accessPostgresRowField FFAccessPostgresRowField
getter/setter pair
accessSqliteRowColumn FFAccessSQLiteRowColumn
getter/setter pair
apiResponseField FFApiResponseField
getter/setter pair
checkHasField FFCheckHasField
getter/setter pair
customCloudFunctionResponseField FFCustomCloudFunctionResponseField
getter/setter pair
dataStructToJson FFDataStructToJson
getter/setter pair
dateTimeFormat FFDateTimeFormat
getter/setter pair
dateTimeRangeEnd FFDateTimeRangeEnd
getter/setter pair
dateTimeRangeStart FFDateTimeRangeStart
getter/setter pair
dateTimeToInteger FFDateTimeToInteger
getter/setter pair
documentReferenceId FFDocumentReferenceId
getter/setter pair
documentReferencePath FFDocumentReferencePath
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
indexInList FFIndexInList
getter/setter pair
info_ BuilderInfo
no setteroverride
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
itemAtCurrentIndex FFItemAtCurrentIndex
getter/setter pair
jsonPathOperation FFJsonPathOperation
getter/setter pair
jsonToDataStruct FFJsonToDataStruct
getter/setter pair
listContains FFListContains
getter/setter pair
listHasValueOperation FFListHasValueOperation
getter/setter pair
listItemAtIndex FFListItemAtIndex
getter/setter pair
listMapOperation FFListMapOperation
getter/setter pair
listNumItems FFListNumItems
getter/setter pair
listSortOperation FFListSortOperation
getter/setter pair
listTakeOperation FFListTakeOperation
getter/setter pair
listUniqueOperation FFListUniqueOperation
getter/setter pair
listWhereOperation FFListWhereOperation
getter/setter pair
negate FFNegateBoolean
getter/setter pair
numberFormat FFNumberFormat
getter/setter pair
parseStringAsEnum FFParseStringAsEnum
getter/setter pair
predefinedJsonPathOperation FFPredefinedJsonPathOperation
getter/setter pair
responseStreamMessageField FFResponseStreamMessageField
getter/setter pair
returnParam FFParameter
We no longer explicitly store the type information, that should be determined based on the operation itself.
getter/setter pair
revenueCat FFRevenueCatOperation
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeCastOperation FFTypeCastOperation
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
uploadedOriginalFileName FFUploadedOriginalFileName
getter/setter pair
uploadMediaBlurHash FFUploadMediaBlurHash
getter/setter pair
uploadMediaHeight FFUploadMediaHeight
getter/setter pair
uploadMediaWidth FFUploadMediaWidth
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAccessCustomInterfaceField() → void
clearAccessCustomInterfaceMethod() → void
clearAccessDataStructField() → void
clearAccessDocumentField() → void
clearAccessGooglePlaceField() → void
clearAccessPostgresRowField() → void
clearAccessSqliteRowColumn() → void
clearApiResponseField() → void
clearCheckHasField() → void
clearCustomCloudFunctionResponseField() → void
clearDataStructToJson() → void
clearDateTimeFormat() → void
clearDateTimeRangeEnd() → void
clearDateTimeRangeStart() → void
clearDateTimeToInteger() → void
clearDocumentReferenceId() → void
clearDocumentReferencePath() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIndexInList() → void
clearItemAtCurrentIndex() → void
clearJsonPathOperation() → void
clearJsonToDataStruct() → void
clearListContains() → void
clearListHasValueOperation() → void
clearListItemAtIndex() → void
clearListMapOperation() → void
clearListNumItems() → void
clearListSortOperation() → void
clearListTakeOperation() → void
clearListUniqueOperation() → void
clearListWhereOperation() → void
clearNegate() → void
clearNumberFormat() → void
clearOperation() → void
clearParseStringAsEnum() → void
clearPredefinedJsonPathOperation() → void
clearResponseStreamMessageField() → void
clearReturnParam() → void
clearRevenueCat() → void
clearTypeCastOperation() → void
clearUploadedOriginalFileName() → void
clearUploadMediaBlurHash() → void
clearUploadMediaHeight() → void
clearUploadMediaWidth() → void
clone() FFVariableOperation
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFVariableOperation)) FFVariableOperation
Apply updates to a copy of this message.
override
createEmptyInstance() FFVariableOperation
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAccessCustomInterfaceField() FFAccessCustomInterfaceField
ensureAccessCustomInterfaceMethod() FFAccessCustomInterfaceMethod
ensureAccessDataStructField() FFAccessDataStructField
ensureAccessDocumentField() FFAccessDocumentField
ensureAccessGooglePlaceField() FFAccessGooglePlaceField
ensureAccessPostgresRowField() FFAccessPostgresRowField
ensureAccessSqliteRowColumn() FFAccessSQLiteRowColumn
ensureApiResponseField() FFApiResponseField
ensureCheckHasField() FFCheckHasField
ensureCustomCloudFunctionResponseField() FFCustomCloudFunctionResponseField
ensureDataStructToJson() FFDataStructToJson
ensureDateTimeFormat() FFDateTimeFormat
ensureDateTimeRangeEnd() FFDateTimeRangeEnd
ensureDateTimeRangeStart() FFDateTimeRangeStart
ensureDateTimeToInteger() FFDateTimeToInteger
ensureDocumentReferenceId() FFDocumentReferenceId
ensureDocumentReferencePath() FFDocumentReferencePath
ensureIndexInList() FFIndexInList
ensureItemAtCurrentIndex() FFItemAtCurrentIndex
ensureJsonPathOperation() FFJsonPathOperation
ensureJsonToDataStruct() FFJsonToDataStruct
ensureListContains() FFListContains
ensureListHasValueOperation() FFListHasValueOperation
ensureListItemAtIndex() FFListItemAtIndex
ensureListMapOperation() FFListMapOperation
ensureListNumItems() FFListNumItems
ensureListSortOperation() FFListSortOperation
ensureListTakeOperation() FFListTakeOperation
ensureListUniqueOperation() FFListUniqueOperation
ensureListWhereOperation() FFListWhereOperation
ensureNegate() FFNegateBoolean
ensureNumberFormat() FFNumberFormat
ensureParseStringAsEnum() FFParseStringAsEnum
ensurePredefinedJsonPathOperation() FFPredefinedJsonPathOperation
ensureResponseStreamMessageField() FFResponseStreamMessageField
ensureReturnParam() FFParameter
ensureRevenueCat() FFRevenueCatOperation
ensureTypeCastOperation() FFTypeCastOperation
ensureUploadedOriginalFileName() FFUploadedOriginalFileName
ensureUploadMediaBlurHash() FFUploadMediaBlurHash
ensureUploadMediaHeight() FFUploadMediaHeight
ensureUploadMediaWidth() FFUploadMediaWidth
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAccessCustomInterfaceField() bool
hasAccessCustomInterfaceMethod() bool
hasAccessDataStructField() bool
hasAccessDocumentField() bool
hasAccessGooglePlaceField() bool
hasAccessPostgresRowField() bool
hasAccessSqliteRowColumn() bool
hasApiResponseField() bool
hasCheckHasField() bool
hasCustomCloudFunctionResponseField() bool
hasDataStructToJson() bool
hasDateTimeFormat() bool
hasDateTimeRangeEnd() bool
hasDateTimeRangeStart() bool
hasDateTimeToInteger() bool
hasDocumentReferenceId() bool
hasDocumentReferencePath() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasIndexInList() bool
hasItemAtCurrentIndex() bool
hasJsonPathOperation() bool
hasJsonToDataStruct() bool
hasListContains() bool
hasListHasValueOperation() bool
hasListItemAtIndex() bool
hasListMapOperation() bool
hasListNumItems() bool
hasListSortOperation() bool
hasListTakeOperation() bool
hasListUniqueOperation() bool
hasListWhereOperation() bool
hasNegate() bool
hasNumberFormat() bool
hasParseStringAsEnum() bool
hasPredefinedJsonPathOperation() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasResponseStreamMessageField() bool
hasReturnParam() bool
hasRevenueCat() bool
hasTypeCastOperation() bool
hasUploadedOriginalFileName() bool
hasUploadMediaBlurHash() bool
hasUploadMediaHeight() bool
hasUploadMediaWidth() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
whichOperation() FFVariableOperation_Operation
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited