FFVariableOperation_Operation enum
Values
- itemAtCurrentIndex → const FFVariableOperation_Operation
- indexInList → const FFVariableOperation_Operation
- jsonPathOperation → const FFVariableOperation_Operation
- typeCastOperation → const FFVariableOperation_Operation
- listContains → const FFVariableOperation_Operation
- dateTimeRangeStart → const FFVariableOperation_Operation
- dateTimeRangeEnd → const FFVariableOperation_Operation
- dateTimeFormat → const FFVariableOperation_Operation
- listNumItems → const FFVariableOperation_Operation
- negate → const FFVariableOperation_Operation
- numberFormat → const FFVariableOperation_Operation
- apiResponseField → const FFVariableOperation_Operation
- revenueCat → const FFVariableOperation_Operation
- listMapOperation → const FFVariableOperation_Operation
- accessDocumentField → const FFVariableOperation_Operation
- accessGooglePlaceField → const FFVariableOperation_Operation
- accessDataStructField → const FFVariableOperation_Operation
- listWhereOperation → const FFVariableOperation_Operation
- accessPostgresRowField → const FFVariableOperation_Operation
- listItemAtIndex → const FFVariableOperation_Operation
- uploadMediaHeight → const FFVariableOperation_Operation
- uploadMediaWidth → const FFVariableOperation_Operation
- documentReferenceId → const FFVariableOperation_Operation
- dateTimeToInteger → const FFVariableOperation_Operation
- accessSqliteRowColumn → const FFVariableOperation_Operation
- uploadMediaBlurHash → const FFVariableOperation_Operation
- checkHasField → const FFVariableOperation_Operation
- listTakeOperation → const FFVariableOperation_Operation
- customCloudFunctionResponseField → const FFVariableOperation_Operation
- jsonToDataStruct → const FFVariableOperation_Operation
- dataStructToJson → const FFVariableOperation_Operation
- listSortOperation → const FFVariableOperation_Operation
- listHasValueOperation → const FFVariableOperation_Operation
- predefinedJsonPathOperation → const FFVariableOperation_Operation
- listUniqueOperation → const FFVariableOperation_Operation
- responseStreamMessageField → const FFVariableOperation_Operation
- parseStringAsEnum → const FFVariableOperation_Operation
- accessCustomInterfaceField → const FFVariableOperation_Operation
- accessCustomInterfaceMethod → const FFVariableOperation_Operation
- documentReferencePath → const FFVariableOperation_Operation
- uploadedOriginalFileName → const FFVariableOperation_Operation
- notSet → const FFVariableOperation_Operation
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FFVariableOperation_Operation> - A constant List of the values in this enum, in order of their declaration.