legacyVisible property
Visibility flag to be optionally overridden in order to toggle whether the widget is visible dynamically based on a variable. The value here will dictate whether the widget is being rendered in the UI builder.
Implementation
@$pb.TagNumber(1)
$core.bool get legacyVisible => $_getBF(0);