removeEmojiLibrary property
@doc whether to remove emojis from the web build
Implementation
@$pb.TagNumber(4)
$core.bool get removeEmojiLibrary => $_getBF(3);
@doc whether to remove emojis from the web build
@$pb.TagNumber(4)
$core.bool get removeEmojiLibrary => $_getBF(3);