FFWebSettings class

Inheritance
Available extensions

Constructors

FFWebSettings({String? faviconPath, String? customHeaders, FFEditMetadata? editMetadata, String? seoTitle, String? seoDescription, String? subdomain, bool? showWatermark, bool? usePerPageTitles, String? pageTitle, String? ogImagePath, bool? allowToShare, bool? allowSearchEngineIndexing, bool? allowPwa, @Deprecated('This field is deprecated.') bool? legacyUseCanvasKit, FFColor? statusBarColor, @Deprecated('This field is deprecated.') FFWebBuildSettings? legacyCanvasKitSettings, @Deprecated('This field is deprecated.') bool? legacyUseOldInitialization, @Deprecated('This field is deprecated.') bool? legacyUseFlutter3271, FFWebSettings_WebOrientation? orientation})
factory
FFWebSettings.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFWebSettings.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

allowPwa bool
@doc whether to allow PWA
getter/setter pair
allowSearchEngineIndexing bool
@doc whether to allow search engine indexing
getter/setter pair
allowToShare bool
@doc whether to allow sharing
getter/setter pair
customHeaders String
@doc custom headers for web
getter/setter pair
editMetadata FFEditMetadata
getter/setter pair
faviconPath String
@doc favicon path for web
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ BuilderInfo
no setteroverride
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
legacyCanvasKitSettings FFWebBuildSettings
getter/setter pair
legacyUseCanvasKit bool
getter/setter pair
legacyUseFlutter3271 bool
getter/setter pair
legacyUseOldInitialization bool
for using the old initialization method in flutter web, which is deprecated
getter/setter pair
ogImagePath String
@doc og image path for web
getter/setter pair
orientation FFWebSettings_WebOrientation
@doc The default orientation for web
getter/setter pair
pageTitle String
@doc Title to use for all pages if use_per_page_titles is false
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seoDescription String
@doc seo description
getter/setter pair
seoTitle String
@doc seo title
getter/setter pair
showWatermark bool
@doc whether to show watermark
getter/setter pair
statusBarColor FFColor
@doc status bar color for web
getter/setter pair
subdomain String
@doc subdomain
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
usePerPageTitles bool
@doc whether to use individual page titles
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAllowPwa() → void
clearAllowSearchEngineIndexing() → void
clearAllowToShare() → void
clearCustomHeaders() → void
clearEditMetadata() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFaviconPath() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearLegacyCanvasKitSettings() → void
clearLegacyUseCanvasKit() → void
clearLegacyUseFlutter3271() → void
clearLegacyUseOldInitialization() → void
clearOgImagePath() → void
clearOrientation() → void
clearPageTitle() → void
clearSeoDescription() → void
clearSeoTitle() → void
clearShowWatermark() → void
clearStatusBarColor() → void
clearSubdomain() → void
clearUsePerPageTitles() → void
clone() FFWebSettings
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFWebSettings)) FFWebSettings
Apply updates to a copy of this message.
override
createEmptyInstance() FFWebSettings
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureEditMetadata() FFEditMetadata
ensureLegacyCanvasKitSettings() FFWebBuildSettings
ensureStatusBarColor() FFColor
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAllowPwa() bool
hasAllowSearchEngineIndexing() bool
hasAllowToShare() bool
hasCustomHeaders() bool
hasEditMetadata() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasFaviconPath() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasLegacyCanvasKitSettings() bool
hasLegacyUseCanvasKit() bool
hasLegacyUseFlutter3271() bool
hasLegacyUseOldInitialization() bool
hasOgImagePath() bool
hasOrientation() bool
hasPageTitle() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSeoDescription() bool
hasSeoTitle() bool
hasShowWatermark() bool
hasStatusBarColor() bool
hasSubdomain() bool
hasUsePerPageTitles() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFWebSettings
getDefault() FFWebSettings