widgetBuilderParamIdentifier property
- @doc The identifier to identify the widget builder parameter in the component that is calling this widget builder.
Implementation
@$pb.TagNumber(1)
FFIdentifier get widgetBuilderParamIdentifier => $_getN(0);
Implementation
@$pb.TagNumber(1)
set widgetBuilderParamIdentifier(FFIdentifier value) => $_setField(1, value);