childSlots property
Child slots declared by this component. Each slot defines a named position where callers provide arbitrary widget content.
Implementation
@$pb.TagNumber(15)
$pb.PbList<FFChildSlotDefinition> get childSlots => $_getList(12);
Child slots declared by this component. Each slot defines a named position where callers provide arbitrary widget content.
@$pb.TagNumber(15)
$pb.PbList<FFChildSlotDefinition> get childSlots => $_getList(12);