description property
@doc The user-defined description of the widget. This is turned into Dart doc comments in the project's generated code.
Implementation
@$pb.TagNumber(2)
$core.String get description => $_getSZ(1);
@doc The user-defined description of the widget. This is turned into Dart doc comments in the project's generated code.
@$pb.TagNumber(2)
$core.String get description => $_getSZ(1);