FFYoutubePlayer class

Inheritance
Available extensions

Constructors

FFYoutubePlayer({String? legacyUrl, FFDimensions? dimensions, bool? legacyAutoPlay, bool? legacyLooping, bool? legacyMute, bool? legacyShowControls, bool? showFullScreen, bool? legacyPauseOnNavigate, bool? legacyStrictRelatedVideos, FFStringValue? urlValue, FFBooleanValue? autoPlayValue, FFBooleanValue? loopingValue, FFBooleanValue? muteValue, FFBooleanValue? showControlsValue, FFBooleanValue? pauseOnNavigateValue, FFBooleanValue? strictRelatedVideosValue})
factory
FFYoutubePlayer.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFYoutubePlayer.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

autoPlayValue FFBooleanValue
getter/setter pair
dimensions FFDimensions
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ BuilderInfo
no setteroverride
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
legacyAutoPlay bool
getter/setter pair
legacyLooping bool
getter/setter pair
legacyMute bool
getter/setter pair
legacyPauseOnNavigate bool
getter/setter pair
legacyShowControls bool
getter/setter pair
legacyStrictRelatedVideos bool
getter/setter pair
legacyUrl String
getter/setter pair
loopingValue FFBooleanValue
getter/setter pair
muteValue FFBooleanValue
getter/setter pair
pauseOnNavigateValue FFBooleanValue
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showControlsValue FFBooleanValue
getter/setter pair
showFullScreen bool
Should not be overridable - it controls a lot more than just a property.
getter/setter pair
strictRelatedVideosValue FFBooleanValue
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
urlValue FFStringValue
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAutoPlayValue() → void
clearDimensions() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearLegacyAutoPlay() → void
clearLegacyLooping() → void
clearLegacyMute() → void
clearLegacyPauseOnNavigate() → void
clearLegacyShowControls() → void
clearLegacyStrictRelatedVideos() → void
clearLegacyUrl() → void
clearLoopingValue() → void
clearMuteValue() → void
clearPauseOnNavigateValue() → void
clearShowControlsValue() → void
clearShowFullScreen() → void
clearStrictRelatedVideosValue() → void
clearUrlValue() → void
clone() FFYoutubePlayer
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFYoutubePlayer)) FFYoutubePlayer
Apply updates to a copy of this message.
override
createEmptyInstance() FFYoutubePlayer
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAutoPlayValue() FFBooleanValue
ensureDimensions() FFDimensions
ensureLoopingValue() FFBooleanValue
ensureMuteValue() FFBooleanValue
ensurePauseOnNavigateValue() FFBooleanValue
ensureShowControlsValue() FFBooleanValue
ensureStrictRelatedVideosValue() FFBooleanValue
ensureUrlValue() FFStringValue
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAutoPlayValue() bool
hasDimensions() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasLegacyAutoPlay() bool
hasLegacyLooping() bool
hasLegacyMute() bool
hasLegacyPauseOnNavigate() bool
hasLegacyShowControls() bool
hasLegacyStrictRelatedVideos() bool
hasLegacyUrl() bool
hasLoopingValue() bool
hasMuteValue() bool
hasPauseOnNavigateValue() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasShowControlsValue() bool
hasShowFullScreen() bool
hasStrictRelatedVideosValue() bool
hasUrlValue() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFYoutubePlayer
getDefault() FFYoutubePlayer