showFullScreen property
Should not be overridable - it controls a lot more than just a property.
Implementation
@$pb.TagNumber(7)
$core.bool get showFullScreen => $_getBF(6);
Should not be overridable - it controls a lot more than just a property.
@$pb.TagNumber(7)
$core.bool get showFullScreen => $_getBF(6);