FFApiResponseField_ResponseField class
- Inheritance
-
- Object
- ProtobufEnum
- FFApiResponseField_ResponseField
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFApiResponseField_ResponseField?
Constants
- DATA_STRUCT → const FFApiResponseField_ResponseField
- EXCEPTION_MESSAGE → const FFApiResponseField_ResponseField
- GET_HEADER → const FFApiResponseField_ResponseField
- JSON_BODY → const FFApiResponseField_ResponseField
- RAW_BODY_TEXT → const FFApiResponseField_ResponseField
- RESPONSE_FIELD_UNDEFINED → const FFApiResponseField_ResponseField
- STATUS_CODE → const FFApiResponseField_ResponseField
- SUCCEEDED → const FFApiResponseField_ResponseField
-
values
→ const List<
FFApiResponseField_ResponseField>