FFAppEvent_FFAppEventScope class
@doc Defines the scope of the app event - whether it's global or local.
- Inheritance
-
- Object
- ProtobufEnum
- FFAppEvent_FFAppEventScope
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFAppEvent_FFAppEventScope?
Constants
- GLOBAL → const FFAppEvent_FFAppEventScope
- @doc Event is handled globally.
- LOCAL → const FFAppEvent_FFAppEventScope
- @doc Event handling is scoped to a specific component or context.
-
values
→ const List<
FFAppEvent_FFAppEventScope>