FFAspectRatioPreset class
- Inheritance
-
- Object
- ProtobufEnum
- FFAspectRatioPreset
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFAspectRatioPreset?
Constants
- FF_ASPECT_RATIO_PRESET_1_1 → const FFAspectRatioPreset
- FF_ASPECT_RATIO_PRESET_2_3 → const FFAspectRatioPreset
- FF_ASPECT_RATIO_PRESET_3_2 → const FFAspectRatioPreset
- FF_ASPECT_RATIO_PRESET_3_4 → const FFAspectRatioPreset
- FF_ASPECT_RATIO_PRESET_4_3 → const FFAspectRatioPreset
- FF_ASPECT_RATIO_PRESET_9_16 → const FFAspectRatioPreset
- FF_ASPECT_RATIO_PRESET_16_9 → const FFAspectRatioPreset
- FF_ASPECT_RATIO_PRESET_CUSTOM → const FFAspectRatioPreset
- FF_ASPECT_RATIO_PRESET_UNDEFINED → const FFAspectRatioPreset
-
values
→ const List<
FFAspectRatioPreset>