FFAuthVariable_AuthProperty class
- Inheritance
-
- Object
- ProtobufEnum
- FFAuthVariable_AuthProperty
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFAuthVariable_AuthProperty?
Constants
- AUTH_PROPERTY_UNDEFINED → const FFAuthVariable_AuthProperty
- AUTH_TOKEN → const FFAuthVariable_AuthProperty
- Fields used for "Custom Auth"
- AUTH_TOKEN_EXPIRY_TIME → const FFAuthVariable_AuthProperty
- DISPLAY_NAME → const FFAuthVariable_AuthProperty
- EMAIL → const FFAuthVariable_AuthProperty
- EMAIL_VERIFIED → const FFAuthVariable_AuthProperty
- JWT_TOKEN → const FFAuthVariable_AuthProperty
- PHONE_NUMBER → const FFAuthVariable_AuthProperty
- PHOTO_URL → const FFAuthVariable_AuthProperty
- REFRESH_TOKEN → const FFAuthVariable_AuthProperty
- USER_ID → const FFAuthVariable_AuthProperty
- USER_REFERENCE → const FFAuthVariable_AuthProperty
- USERS_DATA_FIELD → const FFAuthVariable_AuthProperty
-
values
→ const List<
FFAuthVariable_AuthProperty>