FFConstantsVariable_ConstantValue class
- Inheritance
-
- Object
- ProtobufEnum
- FFConstantsVariable_ConstantValue
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFConstantsVariable_ConstantValue?
Constants
- BREAKPOINT_LARGE → const FFConstantsVariable_ConstantValue
- BREAKPOINT_MEDIUM → const FFConstantsVariable_ConstantValue
- BREAKPOINT_SMALL → const FFConstantsVariable_ConstantValue
- CONSTANT_VALUE_UNDEFINED → const FFConstantsVariable_ConstantValue
- EMPTY_LIST → const FFConstantsVariable_ConstantValue
- EMPTY_STRING → const FFConstantsVariable_ConstantValue
- FALSE → const FFConstantsVariable_ConstantValue
- INFINITY → const FFConstantsVariable_ConstantValue
- NULL → const FFConstantsVariable_ConstantValue
- TRUE → const FFConstantsVariable_ConstantValue
-
values
→ const List<
FFConstantsVariable_ConstantValue>