FFCustomCloudFunctionResponseField_ResponseField class
- Inheritance
-
- Object
- ProtobufEnum
- FFCustomCloudFunctionResponseField_ResponseField
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- ERROR_CODE → const FFCustomCloudFunctionResponseField_ResponseField
- JSON_BODY → const FFCustomCloudFunctionResponseField_ResponseField
- RAW_BODY_TEXT → const FFCustomCloudFunctionResponseField_ResponseField
- RAW_RETURN_TYPE → const FFCustomCloudFunctionResponseField_ResponseField
- RESPONSE_FIELD_UNDEFINED → const FFCustomCloudFunctionResponseField_ResponseField
- SUCCEEDED → const FFCustomCloudFunctionResponseField_ResponseField
-
values
→ const List<
FFCustomCloudFunctionResponseField_ResponseField>