FFExpandable_HeaderAlignment class
- Inheritance
-
- Object
- ProtobufEnum
- FFExpandable_HeaderAlignment
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFExpandable_HeaderAlignment?
Constants
- BOTTOM → const FFExpandable_HeaderAlignment
- CENTER → const FFExpandable_HeaderAlignment
- HEADER_ALIGNMENT_UNDEFINED → const FFExpandable_HeaderAlignment
- TOP → const FFExpandable_HeaderAlignment
-
values
→ const List<
FFExpandable_HeaderAlignment>