FFFirestoreSchemaValidation_Mode class
Using enum instead of bool in anticipation that we can have more options in how it will run.
- Inheritance
-
- Object
- ProtobufEnum
- FFFirestoreSchemaValidation_Mode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFFirestoreSchemaValidation_Mode?
Constants
- DISABLED → const FFFirestoreSchemaValidation_Mode
- ENABLED → const FFFirestoreSchemaValidation_Mode
- UNDEFINED → const FFFirestoreSchemaValidation_Mode
-
values
→ const List<
FFFirestoreSchemaValidation_Mode>