FFFontWeight class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) FFFontWeight?

Constants

values → const List<FFFontWeight>
w100 → const FFFontWeight
w200 → const FFFontWeight
/ Extra-light
w300 → const FFFontWeight
/ Light
w400 → const FFFontWeight
/ Normal / regular / plain
w500 → const FFFontWeight
/ Medium
w600 → const FFFontWeight
/ Semi-bold
w700 → const FFFontWeight
/ Bold
w800 → const FFFontWeight
/ Extra-bold
w900 → const FFFontWeight
/ Black, the most thick
WEIGHT_UNSET → const FFFontWeight