FFGlobalPropertiesVariable_GlobalProperty class
- Inheritance
-
- Object
- ProtobufEnum
- FFGlobalPropertiesVariable_GlobalProperty
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- CURRENT_DEVICE_LOCATION → const FFGlobalPropertiesVariable_GlobalProperty
- CURRENT_ENVIRONMENT → const FFGlobalPropertiesVariable_GlobalProperty
- CURRENT_ROUTE → const FFGlobalPropertiesVariable_GlobalProperty
- CURRENT_ROUTE_STACK → const FFGlobalPropertiesVariable_GlobalProperty
- CURRENT_TIMESTAMP → const FFGlobalPropertiesVariable_GlobalProperty
- FRACTION_SCREEN_HEIGHT → const FFGlobalPropertiesVariable_GlobalProperty
- FRACTION_SCREEN_WIDTH → const FFGlobalPropertiesVariable_GlobalProperty
- GLOBAL_PROPERTY_UNDEFINED → const FFGlobalPropertiesVariable_GlobalProperty
- IS_ANDROID → const FFGlobalPropertiesVariable_GlobalProperty
- IS_DARK_MODE → const FFGlobalPropertiesVariable_GlobalProperty
- IS_DEBUG_MODE → const FFGlobalPropertiesVariable_GlobalProperty
- IS_IOS → const FFGlobalPropertiesVariable_GlobalProperty
- IS_KEYBOARD_VISIBLE → const FFGlobalPropertiesVariable_GlobalProperty
- IS_LIGHT_MODE → const FFGlobalPropertiesVariable_GlobalProperty
- IS_USER_LOGGED_IN → const FFGlobalPropertiesVariable_GlobalProperty
- IS_WEB → const FFGlobalPropertiesVariable_GlobalProperty
- LINK_TO_CURRENT_PAGE → const FFGlobalPropertiesVariable_GlobalProperty
- SCREEN_HEIGHT → const FFGlobalPropertiesVariable_GlobalProperty
- SCREEN_WIDTH → const FFGlobalPropertiesVariable_GlobalProperty
-
values
→ const List<
FFGlobalPropertiesVariable_GlobalProperty>