FFOverrideVariableSource class
TODO: Eventually add STATE as a type.
- Inheritance
-
- Object
- ProtobufEnum
- FFOverrideVariableSource
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFOverrideVariableSource?
Constants
- AUTHENTICATED_USER → const FFOverrideVariableSource
- CURRENT_TIME → const FFOverrideVariableSource
- DATABASE_REQUEST → const FFOverrideVariableSource
- DATABASE_REQUEST_INDEX → const FFOverrideVariableSource
- OVERRIDE_WIDGET_SOURCE_TYPE_UNDEFINED → const FFOverrideVariableSource
- PARAMETER → const FFOverrideVariableSource
-
values
→ const List<
FFOverrideVariableSource>