FFProject_LegacyNullSafety class
TODO: remove once null-safety migration is completed. Use enum instead of boolean to distinguish users who did not specify the value vs those who explicitly opted out.
- Inheritance
-
- Object
- ProtobufEnum
- FFProject_LegacyNullSafety
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFProject_LegacyNullSafety?
Constants
- DISABLED → const FFProject_LegacyNullSafety
- ENABLED → const FFProject_LegacyNullSafety
- UNDEFINED → const FFProject_LegacyNullSafety
-
values
→ const List<
FFProject_LegacyNullSafety>