FFRevenueCatGetPackageAttributeReducer_PackageAttribute class
- Inheritance
-
- Object
- ProtobufEnum
- FFRevenueCatGetPackageAttributeReducer_PackageAttribute
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- DESCRIPTION → const FFRevenueCatGetPackageAttributeReducer_PackageAttribute
- PACKAGE_IDENTIFIER → const FFRevenueCatGetPackageAttributeReducer_PackageAttribute
- PRICE_STRING → const FFRevenueCatGetPackageAttributeReducer_PackageAttribute
- PRODUCT_IDENTIFIER → const FFRevenueCatGetPackageAttributeReducer_PackageAttribute
- PRODUCT_PRICE → const FFRevenueCatGetPackageAttributeReducer_PackageAttribute
- TITLE → const FFRevenueCatGetPackageAttributeReducer_PackageAttribute
- UNDEFINED → const FFRevenueCatGetPackageAttributeReducer_PackageAttribute
-
values
→ const List<
FFRevenueCatGetPackageAttributeReducer_PackageAttribute>