FFText_OverflowReplacement class
- Inheritance
-
- Object
- ProtobufEnum
- FFText_OverflowReplacement
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFText_OverflowReplacement?
Constants
- CLIP → const FFText_OverflowReplacement
- ELLIPSIS → const FFText_OverflowReplacement
- FADE → const FFText_OverflowReplacement
- OVERFLOW_REPLACEMENT_UNDEFINED → const FFText_OverflowReplacement
-
values
→ const List<
FFText_OverflowReplacement> - VISIBLE → const FFText_OverflowReplacement