FFText_ThemeStyle class
- Inheritance
-
- Object
- ProtobufEnum
- FFText_ThemeStyle
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFText_ThemeStyle?
Constants
- BODY_LARGE → const FFText_ThemeStyle
- BODY_MEDIUM → const FFText_ThemeStyle
- BODY_SMALL → const FFText_ThemeStyle
- CUSTOM → const FFText_ThemeStyle
- DISPLAY_LARGE → const FFText_ThemeStyle
- DISPLAY_MEDIUM → const FFText_ThemeStyle
- DISPLAY_SMALL → const FFText_ThemeStyle
- HEADLINE_LARGE → const FFText_ThemeStyle
- HEADLINE_MEDIUM → const FFText_ThemeStyle
- HEADLINE_SMALL → const FFText_ThemeStyle
- LABEL_LARGE → const FFText_ThemeStyle
- LABEL_MEDIUM → const FFText_ThemeStyle
- LABEL_SMALL → const FFText_ThemeStyle
- THEME_STYLE_UNDEFINED → const FFText_ThemeStyle
- TITLE_LARGE → const FFText_ThemeStyle
- TITLE_MEDIUM → const FFText_ThemeStyle
- TITLE_SMALL → const FFText_ThemeStyle
-
values
→ const List<
FFText_ThemeStyle>