FFUpdateFieldValue_FieldValue class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) FFUpdateFieldValue_FieldValue?

Constants

DECREMENT → const FFUpdateFieldValue_FieldValue
Firebase doesn't actually support decrement. We just will treat it as negative increment.
DELETE → const FFUpdateFieldValue_FieldValue
FIELD_VALUE_UNDEFINED → const FFUpdateFieldValue_FieldValue
FIRESTORE_ARRAY_REMOVE → const FFUpdateFieldValue_FieldValue
FIRESTORE_ARRAY_UNION → const FFUpdateFieldValue_FieldValue
FIRESTORE_SERVER_TIMESTAMP → const FFUpdateFieldValue_FieldValue
INCREMENT → const FFUpdateFieldValue_FieldValue
SET → const FFUpdateFieldValue_FieldValue
Set field value. Doesn't map to any Firestore FieldValue.
values → const List<FFUpdateFieldValue_FieldValue>