FFUploadDataSettings_Source class
- Inheritance
-
- Object
- ProtobufEnum
- FFUploadDataSettings_Source
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFUploadDataSettings_Source?
Constants
- CAMERA → const FFUploadDataSettings_Source
- FILES → const FFUploadDataSettings_Source
- GALLERY → const FFUploadDataSettings_Source
- GALLERY_OR_CAMERA → const FFUploadDataSettings_Source
- SOURCE_UNDEFINED → const FFUploadDataSettings_Source
- UPLOADED_MEDIA → const FFUploadDataSettings_Source
-
values
→ const List<
FFUploadDataSettings_Source>