FFWrapAlignment class
- Inheritance
-
- Object
- ProtobufEnum
- FFWrapAlignment
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → FFWrapAlignment?
Constants
-
values
→ const List<
FFWrapAlignment> - wrap_alignment_undefined → const FFWrapAlignment
- wrap_center → const FFWrapAlignment
- wrap_end → const FFWrapAlignment
- wrap_space_around → const FFWrapAlignment
- wrap_space_between → const FFWrapAlignment
- wrap_space_evenly → const FFWrapAlignment
- wrap_start → const FFWrapAlignment