deprecated property
Is this enum deprecated? Depending on the target platform, this can emit Deprecated annotations for the enum, or it will be completely ignored; in the very least, this is a formalization for deprecating enums.
Implementation
@$pb.TagNumber(3)
$core.bool get deprecated => $_getBF(1);