debugRedact property
Indicate that fields annotated with this enum value should not be printed out when using debug formats, e.g. when the field contains sensitive credentials.
Implementation
@$pb.TagNumber(3)
$core.bool get debugRedact => $_getBF(2);