fullName property
The fully-qualified name of the extension field. There must be a leading dot in front of the full name.
Implementation
@$pb.TagNumber(2)
$core.String get fullName => $_getSZ(1);
The fully-qualified name of the extension field. There must be a leading dot in front of the full name.
@$pb.TagNumber(2)
$core.String get fullName => $_getSZ(1);