repeated property
If true, indicates that the extension must be defined as repeated. Otherwise the extension must be defined as optional.
Implementation
@$pb.TagNumber(6)
$core.bool get repeated => $_getBF(4);
If true, indicates that the extension must be defined as repeated. Otherwise the extension must be defined as optional.
@$pb.TagNumber(6)
$core.bool get repeated => $_getBF(4);