unverifiedLazy property
unverified_lazy does no correctness checks on the byte stream. This should only be used where lazy with verification is prohibitive for performance reasons.
Implementation
@$pb.TagNumber(15)
$core.bool get unverifiedLazy => $_getBF(6);