annotation property

An Annotation connects some span of text in generated code to an element of its generating .proto file.

Implementation

@$pb.TagNumber(1)
$pb.PbList<GeneratedCodeInfo_Annotation> get annotation => $_getList(0);