begin property
Identifies the starting offset in bytes in the generated code that relates to the identified object.
Implementation
@$pb.TagNumber(3)
$core.int get begin => $_getIZ(2);
Identifies the starting offset in bytes in the generated code that relates to the identified object.
@$pb.TagNumber(3)
$core.int get begin => $_getIZ(2);