sourceFile property
Identifies the filesystem path to the original source .proto.
Implementation
@$pb.TagNumber(2)
$core.String get sourceFile => $_getSZ(1);
Identifies the filesystem path to the original source .proto.
@$pb.TagNumber(2)
$core.String get sourceFile => $_getSZ(1);