deprecated property
Is this message deprecated? Depending on the target platform, this can emit Deprecated annotations for the message, or it will be completely ignored; in the very least, this is a formalization for deprecating messages.
Implementation
@$pb.TagNumber(3)
$core.bool get deprecated => $_getBF(2);