body property

  1. @TagNumber(999)
FFNodeOutline get body

@doc Main body widget of a container Uses highest tag number (999) to ensure it's serialized last in JSON. This is important for maintaining correct widget tree structure.

Implementation

@$pb.TagNumber(999)
FFNodeOutline get body => $_getN(20);
  1. @TagNumber(999)
set body (FFNodeOutline value)

Implementation

@$pb.TagNumber(999)
set body(FFNodeOutline value) => $_setField(999, value);