key property
@doc Unique identifier/key for the widget, used for widget identification and state management
Implementation
@$pb.TagNumber(1)
$core.String get key => $_getSZ(0);
@doc Unique identifier/key for the widget, used for widget identification and state management
@$pb.TagNumber(1)
$core.String get key => $_getSZ(0);