ActionBlockHandle class final

Handle returned from action-block declarations.

Implemented types
Annotations
  • @immutable

Constructors

ActionBlockHandle({required String name, required String key, required ActionBlockLookupScope scope, required Map<String, DslType> params, required DslType? returnType, required String? returnName, String? ownerWidgetClassName, bool isNamedLookup = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
isNamedLookup bool
final
key String
final
name String
final
ownerWidgetClassName String?
final
params Map<String, DslType>
final
returnName String?
final
returnType DslType?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope ActionBlockLookupScope
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited