Simple protocol for actions that expose a named output.
The compiler uses these values to create action outputs that later actions
can consume through ActionOutput(...).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputAs → String?
-
no setter
- outputType → DslType?
-
no setter
- outputVariableName → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited