AppEventDeclaration class final

App-event declaration recorded on the DSL model.

Global events may declare an app-level handler action block. Local events are declared first and receive handlers later through AddLocalEventHandler(...).

Annotations
  • @immutable

Constructors

AppEventDeclaration({required String name, required String key, required AppEventScope scope, required StructHandle? dataStruct, required ActionBlockTarget? handler, String description = ''})
const

Properties

dataStruct StructHandle?
final
description String
final
handler ActionBlockTarget?
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope AppEventScope
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited