AppStateDeclaration class final
App-level state declaration.
App state is global to the generated app and survives page transitions.
- Annotations
-
- @immutable
Constructors
- AppStateDeclaration({required String name, String? description, required DslType type, required bool persisted})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited