BarcodeKind enum
Barcode types supported by Barcode.
Values
- itf16 → const BarcodeKind
- itf14 → const BarcodeKind
- ean13 → const BarcodeKind
- ean8 → const BarcodeKind
- ean5 → const BarcodeKind
- ean2 → const BarcodeKind
- isbn → const BarcodeKind
- code39 → const BarcodeKind
- code93 → const BarcodeKind
- upcA → const BarcodeKind
- upcE → const BarcodeKind
- code128 → const BarcodeKind
- gs128 → const BarcodeKind
- telepen → const BarcodeKind
- codabar → const BarcodeKind
- itf → const BarcodeKind
- rm4scc → const BarcodeKind
- qrCode → const BarcodeKind
- pdf417 → const BarcodeKind
- dataMatrix → const BarcodeKind
- aztec → const BarcodeKind
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BarcodeKind> - A constant List of the values in this enum, in order of their declaration.