BarcodeScanner class final
Opens the barcode or QR scanner and exposes the result as an action output.
- Inheritance
- Implemented types
- Annotations
-
- @immutable
Constructors
- BarcodeScanner({bool barcodeMode = false, String? outputAs})
-
const
Properties
- barcodeMode → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputAs → String?
-
final
- outputType → DslType?
-
no setteroverride
- outputVariableName → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited