BrownfieldParamEditor class final
Builder for page/component parameter additions in brownfield edits.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widgetClassName → String
-
final
Methods
-
ensureParam(
String name, DslType type, {String description = ''}) → void - Ensures a parameter exists with the requested type and description.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeParam(
String name) → void - Removes a parameter by name.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited