ensureActions method
void
ensureActions(
- BrownfieldSelection selection, {
- required FFActionTriggerType triggerType,
- required List<
DslAction> actions,
Ensures one trigger chain exists on the selected widget for triggerType.
Repeated runs update/replace the same trigger chain instead of duplicating identical actions.
Implementation
void ensureActions(
BrownfieldSelection selection, {
required FFActionTriggerType triggerType,
required List<DslAction> actions,
}) {
if (actions.isEmpty) {
throw ArgumentError('ensureActions(...) requires at least one action.');
}
_operations.add(
_TriggerSpec(
selection: selection,
triggerType: triggerType,
actions: List.unmodifiable(actions),
),
);
}