BrownfieldWidgetPatch class final
Typed Phase 5 property patch builder for an existing node.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
borderRadius(
num value) → void - Replaces border radius on supported widgets.
- Replaces button style variant on supported button widgets.
-
color(
ColorToken value) → void - Replaces the widget's dominant color with a token-aware color.
-
icon(
String name, {double? size}) → void - Replaces the icon and optional icon size on icon-like widgets.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
padding(
Object value) → void - Replaces padding on supported container-like widgets.
-
size(
{num? width, num? height}) → void - Replaces width and/or height on supported widgets.
-
spacing(
double value) → void - Sets internal spacing/gap for supported layout widgets.
-
text(
String value) → void - Replaces the widget's visible text/label when supported.
-
textFieldHint(
String value) → void - Replaces a text field's hint text.
-
textFieldLabel(
String value) → void - Replaces a text field's label text.
-
toString(
) → String -
A string representation of this object.
inherited
-
visible(
bool value) → void - Sets a literal visibility flag on the widget.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited