CarouselControl class final
Control an existing Carousel by widget name:.
Constructors
- CarouselControl.jumpTo(String widgetName, int index)
-
const
- CarouselControl.next(String widgetName)
-
const
- CarouselControl.previous(String widgetName)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int?
-
final
- kind → ViewControlKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widgetName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited