DocumentReferenceType class final
Firestore DocumentReference type tied to a specific collection.
Constructors
- DocumentReferenceType(FirestoreCollectionHandle collection, {Object? defaultValue})
-
const
Properties
- collection → FirestoreCollectionHandle
-
final
- defaultValue → Object?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
withDefault(
Object? value) → DocumentReferenceType -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override