DslAction class abstract
Base class for all DSL action nodes.
Actions are declarative. They describe what should happen when a trigger fires; the compiler is responsible for lowering them into FlutterFlow action graphs and validating any wiring constraints.
- Implementers
- AddLocalEventHandler
- ApiCall
- BarcodeScanner
- BiometricVerification
- BottomSheetLibrary
- CallNumber
- CancelLocalEventHandler
- CarouselControl
- ClearAppState
- ClearTextField
- ClearUploadedData
- ConfirmDialog
- CopyToClipboard
- CustomDialogLibrary
- DatePicker
- DeleteAccount
- DismissDialog
- DownloadFile
- DrawerControl
- ExecuteActionBlock
- ExpandImage
- FirestoreCreate
- FirestoreDelete
- FirestoreQuery
- FirestoreRead
- FirestoreUpdate
- ForEach
- HapticFeedback
- HideSnackBar
- If
- LaunchUrl
- LoginAnonymously
- LoginEmailPassword
- LoginWithApple
- LoginWithGoogle
- LoginWithPhone
- Logout
- Loop
- LoopBreak
- Navigate
- NavigateBack
- NavigateToLibraryPage
- NonBlocking
- PageViewControl
- Parallel
- ParamAction
- PlaySound
- PostgresCreate
- PostgresDelete
- PostgresQuery
- PostgresRead
- PostgresSetToken
- PostgresUpdate
- Rebuild
- RequestPermissions
- ResetFormField
- ResetPassword
- ScrollTo
- SendEmail
- SendSMS
- SetDarkMode
- SetFormField
- SetState
- Share
- ShowBottomSheet
- ShowDialog
- SignupEmailPassword
- Snackbar
- StartPeriodic
- StopPeriodic
- StopSound
- Switch
- TabBarControl
- Terminate
- TriggerEvent
- UpdateAppStateMutation
- UpdatePassword
- UploadData
- ValidateForm
- Wait
- Annotations
-
- @immutable
Constructors
- DslAction()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited