DslDeclarationCompileResult class final
Result of compiling the declaration subset of a DSL app into an FFProject.
Constructors
-
DslDeclarationCompileResult({required FFProject project, required Map<
EnumHandle, FFIdentifier> enumIdentifiers, required Map<StructHandle, FFIdentifier> structIdentifiers, required Map<FirestoreCollectionHandle, FFIdentifier> collectionIdentifiers, required Map<PostgresTableHandle, FFIdentifier> tableIdentifiers, required Map<String, FFIdentifier> appStateIdentifiers, required Map<String, FFIdentifier> constantIdentifiers, required Map<CustomFunctionHandle, FFIdentifier> customFunctionIdentifiers, required Map<String, FFIdentifier> apiGroupIdentifiers, required Map<String, Map< collectionFieldIdentifiers, required Map<String, FFIdentifier> >String, Map< tableFieldIdentifiers})String, FFIdentifier> >
Properties
-
apiGroupIdentifiers
→ Map<
String, FFIdentifier> -
final
-
appStateIdentifiers
→ Map<
String, FFIdentifier> -
final
-
collectionFieldIdentifiers
→ Map<
String, Map< String, FFIdentifier> > -
final
-
collectionIdentifiers
→ Map<
FirestoreCollectionHandle, FFIdentifier> -
final
-
constantIdentifiers
→ Map<
String, FFIdentifier> -
final
-
customFunctionIdentifiers
→ Map<
CustomFunctionHandle, FFIdentifier> -
final
-
enumIdentifiers
→ Map<
EnumHandle, FFIdentifier> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- project → FFProject
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
structIdentifiers
→ Map<
StructHandle, FFIdentifier> -
final
-
tableFieldIdentifiers
→ Map<
String, Map< String, FFIdentifier> > -
final
-
tableIdentifiers
→ Map<
PostgresTableHandle, FFIdentifier> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited