DslRunResult class final

Result of running a DSL app through the Flash pipeline.

Constructors

DslRunResult({required App app, required DslCompileResult compileResult, required String projectId, required String? commitId, required bool pushed, required bool dryRun, required List<String> taskSummaries})

Properties

app App
final
commitId String?
final
compileResult DslCompileResult
final
dryRun bool
final
hashCode int
The hash code for this object.
no setterinherited
projectId String
final
pushed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskSummaries List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited