DslWidget class abstract
Base class for every widget-level AST node.
Widgets are declarative AST nodes, not runtime Flutter widgets. The compiler lowers them into FlutterFlow widget classes later.
- Implementers
- AppBar
- AspectRatio
- Avatar
- Backdrop
- Badge
- BarChart
- Barcode
- Button
- Card
- Carousel
- Checkbox
- Chip
- Column
- ComponentInstance
- ConditionalBuilder
- Container
- Divider
- Drawer
- Dropdown
- Expandable
- Expanded
- FAB
- Flexible
- FlippableCard
- Form
- GenUiChat
- GridView
- Icon
- IconButton
- Image
- LineChart
- ListTile
- ListView
- MapWidget
- Markdown
- MouseRegion
- PageView
- PieChart
- PinCode
- ProgressBar
- RadioGroup
- RichText
- Row
- Scaffold
- Slider
- Spacer
- Stack
- StickyHeader
- TabBar
- Text
- TextField
- Toggle
- Tooltip
- Transform
- VerticalDivider
- VideoPlayer
- WebView
- Wrap
- Annotations
-
- @immutable
Constructors
- DslWidget({String? name, DslExpression? visible})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visible → DslExpression?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited