EdgeInsets class final
Edge-insets value object.
- Annotations
-
- @immutable
Constructors
- EdgeInsets.all(double? all)
-
const
- EdgeInsets.only({double? left, double? top, double? right, double? bottom})
-
const
- EdgeInsets.symmetric({double? horizontal = 0, double? vertical = 0})
-
const
Properties
- all → double?
-
final
- bottom → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontal → double?
-
final
- left → double?
-
final
- right → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → double?
-
final
- vertical → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited