Endpoint class final
Endpoint declaration used by ApiCall actions and API groups.
Constructors
-
Endpoint.get(String name, String path, {Map<
String, DslType> ? variables, DslType? response}) -
factory
-
Endpoint.post(String name, String path, {Map<
String, DslType> ? variables, Map<String, Object?> ? body, DslType? response}) -
factory
-
Endpoint.put(String name, String path, {Map<
String, DslType> ? variables, Map<String, Object?> ? body, DslType? response}) -
factory
Properties
-
body
→ Map<
String, Object?> -
final
- groupName → String?
-
The owning API group name once the endpoint is attached to an app.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → HttpMethod
-
final
- name → String
-
final
- path → String
-
final
- response → DslType?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
variables
→ Map<
String, DslType> -
final
Methods
-
attachToGroup(
String groupName) → void - Attaches this endpoint to an API group.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited