ExecuteActionBlock class final

Execute a reusable action block.

Prefer declared ActionBlockHandle values in greenfield DSL apps. Use ActionBlock.named(...) when patching an existing project and you need to invoke a block that already exists on the target app/page/component.

Inheritance
Implemented types
Annotations
  • @immutable

Constructors

ExecuteActionBlock(ActionBlockTarget target, {Map<String, Object?>? params, String? outputAs, bool shouldSetState = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
outputAs String?
final
outputType DslType?
no setteroverride
outputVariableName String
no setteroverride
params Map<String, DslExpression>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldSetState bool
final
target ActionBlockTarget
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited