Expandable class final

Expandable section with header, collapsed, and expanded slots.

Inheritance
Annotations
  • @immutable

Constructors

Expandable({required DslWidget header, required DslWidget collapsed, required DslWidget expanded, bool initiallyExpanded = false, ExpandableHeaderAlignment? headerAlignment, ColorToken? backgroundColor, bool hasIcon = true, double? iconSize, String? name, Object? visible})

Properties

backgroundColor ColorToken?
final
collapsed DslWidget
final
expanded DslWidget
final
hashCode int
The hash code for this object.
no setterinherited
hasIcon bool
final
final
headerAlignment ExpandableHeaderAlignment?
final
iconSize double?
final
initiallyExpanded bool
final
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited