FirestoreCreate class final
Firestore create action.
The created document reference is exposed as an action output and can be consumed by later actions.
Example:
FirestoreCreate(
tasksCollection,
fields: {'title': State('title')},
outputAs: 'createdTask',
)
- Inheritance
- Implemented types
- Annotations
-
- @immutable
Constructors
-
FirestoreCreate(FirestoreCollectionHandle collection, {Map<
String, Object?> ? fields, Object? parentReference, String? outputAs})
Properties
- collection → FirestoreCollectionHandle
-
final
-
fields
→ Map<
String, DslExpression> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputAs → String?
-
final
- outputType → DslType?
-
no setteroverride
- outputVariableName → String
-
no setteroverride
- parentReference → DslExpression?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited