FirestoreQuery class final
Firestore query action.
The output type is listOf(collection) so downstream bindings can treat the
result as a typed document list.
Example:
FirestoreQuery(tasksCollection, outputAs: 'tasks')
- Inheritance
- Implemented types
- Annotations
-
- @immutable
Constructors
- FirestoreQuery(FirestoreCollectionHandle collection, {int? limit, bool singleTimeQuery = true, String? outputAs})
-
const
Properties
- collection → FirestoreCollectionHandle
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
final
- outputAs → String?
-
final
- outputType → DslType?
-
no setteroverride
- outputVariableName → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singleTimeQuery → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited