ForEach class final

Execute an action body for each item in a list.

Example:

ForEach(
  ActionOutput('tasks'),
  body: (item) => [
    Snackbar(item['title']),
  ],
)
Inheritance
Annotations
  • @immutable

Constructors

ForEach(Object? source, {required Object? body, int? startIndex, int? endIndex, int? step, bool reversed = false})

Properties

bodyBuilder LoopActionBuilder
final
endIndex int?
final
hashCode int
The hash code for this object.
no setterinherited
reversed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source DslExpression
final
startIndex int?
final
step int?
final

Methods

buildBody() List<DslAction>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited