GenUiChatConfiguration class final
App-level GenUI chat configuration recorded on the DSL model.
- Annotations
-
- @immutable
Constructors
Properties
- autoScroll → bool?
-
final
- avatarAssetPath → String?
-
final
- avatarUrl → String?
-
final
- chatName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerTitle → String?
-
final
- messageSpacing → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemPrompt → String?
-
final
Methods
-
copyWith(
{String? systemPrompt, String? headerTitle, String? avatarAssetPath, String? avatarUrl, double? messageSpacing, bool? autoScroll}) → GenUiChatConfiguration -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited