GridView class final
Repeating grid widget backed by a runtime data source.
itemBuilder receives the same ItemRef contract as ListView.
Constructors
Properties
- childAspectRatio → double
-
final
- columns → int
-
final
- crossAxisSpacing → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → ItemBuilder
-
final
- mainAxisSpacing → double?
-
final
- name → String?
-
finalinherited
- padding → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → DslExpression
-
final
- visible → DslExpression?
-
finalinherited
Methods
-
buildItem(
) → DslWidget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited