ListView class final

Repeating list widget backed by a runtime data source.

source is typically an action output, app state list, or Firestore query result.

Inheritance
Annotations
  • @immutable

Constructors

ListView({required Object? source, required ItemBuilder itemBuilder, double? spacing, bool shrinkWrap = false, bool horizontal = false, Object? padding, String? name, Object? visible})

Properties

hashCode int
The hash code for this object.
no setterinherited
horizontal bool
final
itemBuilder ItemBuilder
final
name String?
finalinherited
padding Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shrinkWrap bool
final
source DslExpression
final
spacing double?
final
visible DslExpression?
finalinherited

Methods

buildItem() DslWidget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited