LoopItemRef class final
Placeholder passed into ForEach(..., body: (item) => ...).
- Inheritance
-
- Object
- DslExpression
- LoopItemRef
- Annotations
-
- @immutable
Constructors
- LoopItemRef()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → LoopItemIndex
-
The zero-based index of this item in the loop.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String field) → FieldAccess -
inherited