MouseRegion class final
Mouse-region wrapper.
Constructors
- MouseRegion({DslWidget? child, MouseCursor cursor = MouseCursor.defer, String? name, Object? visible})
Properties
- child → DslWidget?
-
final
- cursor → MouseCursor
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visible → DslExpression?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited