PieChart class final
Pie or donut chart widget.
Constructors
-
PieChart({Iterable<
ColorToken> ? colors, bool donut = false, double donutRadius = 30, double sectionRadius = 60, PieLabelType labelType = PieLabelType.value, String? name, Object? visible})
Properties
-
colors
→ List<
ColorToken> -
final
- donut → bool
-
final
- donutRadius → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelType → PieLabelType
-
final
- name → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectionRadius → double
-
final
- visible → DslExpression?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited