PostgresQuerySpec class final
Query spec shared by PostgresRead, PostgresQuery, PostgresUpdate, and PostgresDelete.
- Annotations
-
- @immutable
Constructors
-
PostgresQuerySpec({List<
PostgresFilter> ? filters, bool isOrQuery = false, List<PostgresOrderBy> ? orderBys, int? limit, bool isSingleRow = false, bool hideOnEmpty = false, bool isStreamingSupabaseQuery = false})
Properties
-
filters
→ List<
PostgresFilter> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideOnEmpty → bool
-
final
- isOrQuery → bool
-
final
- isSingleRow → bool
-
final
- isStreamingSupabaseQuery → bool
-
final
- limit → int?
-
final
-
orderBys
→ List<
PostgresOrderBy> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withSingleRow(
bool value) → PostgresQuerySpec
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited