PostgresTableHandle class final
Postgres/Supabase table handle returned from App.table.
A table handle doubles as the row type for SQL query outputs, just like a Firestore collection handle doubles as a document type.
Constructors
-
PostgresTableHandle(String name, Map<
String, PostgresTableField> fields, {String description = '', bool isView = false, Object? defaultValue})
Properties
- defaultValue → Object?
-
finalinherited
- description → String
-
final
-
fields
→ Map<
String, PostgresTableField> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isView → bool
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
withDefault(
Object? value) → PostgresTableHandle -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override