ProjectSnapshot class final
Machine-readable read model for an existing FlutterFlow project.
Constructors
- ProjectSnapshot.fromProject(FFProject project)
-
factory
Properties
-
appState
→ List<
FieldSnapshot> -
final
-
components
→ List<
ComponentSnapshot> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
pages
→ List<
PageSnapshot> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
findComponent(
String name) → ComponentSnapshot? -
findPage(
String name) → PageSnapshot? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toJsonString(
{bool pretty = true}) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited