RichTextSpan class final
Inline rich-text span.
Use name only when you need to preserve an identifiable span in snapshots or generated widget trees.
- Annotations
-
- @immutable
Constructors
- RichTextSpan(Object? text, {ColorToken? color, double? fontSize, bool bold = false, bool italic = false, bool underline = false, bool strikethrough = false, String? name})
Properties
- bold → bool
-
final
- color → ColorToken?
-
final
- fontSize → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- italic → bool
-
final
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strikethrough → bool
-
final
- text → DslExpression
-
final
- underline → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited