ShowBottomSheet class final

Show a bottom sheet using a local component.

The supplied component must be a local component handle, not a library or existing-project component handle.

Example:

ShowBottomSheet(
  taskFiltersSheet,
  params: {'selectedTab': State('tab')},
)
Inheritance
Annotations
  • @immutable

Constructors

ShowBottomSheet(ComponentHandle component, {Map<String, Object?>? params, bool enableDrag = true, bool nonDismissible = false})

Properties

component ComponentHandle
final
enableDrag bool
final
hashCode int
The hash code for this object.
no setterinherited
nonDismissible bool
final
params Map<String, Object?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited