ShowDialog class final
Show a dialog.
Use ShowDialog.message for informational dialogs, or ShowDialog.component when an existing local component should render the dialog body. Component dialogs are rerun-safe as long as the referenced component and params stay stable.
Example:
ShowDialog.message(
title: 'Delete task?',
message: 'This action cannot be undone.',
)
Constructors
-
ShowDialog.component(ComponentHandle? component, {Map<
String, Object?> ? params, bool nonDismissible = false}) - ShowDialog.message({required Object? title, required Object? message, Object? dismissText})
Properties
- component → ComponentHandle?
-
final
- dismissText → DslExpression?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → ShowDialogKind
-
final
- message → DslExpression?
-
final
- nonDismissible → bool
-
final
-
params
→ Map<
String, Object?> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → DslExpression?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited