Slider class final
Slider input.
Constructors
Properties
- activeColor → ColorToken?
-
final
- divisions → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- max → double
-
final
- min → double
-
final
- name → String?
-
finalinherited
-
onChanged
→ List<
DslAction> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → DslExpression
-
final
- visible → DslExpression?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited