Built-in typography tokens used by the initial reference implementation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bodyLarge → const TextStyleToken
- bodyMedium → const TextStyleToken
- bodySmall → const TextStyleToken
- headlineMedium → const TextStyleToken
- headlineSmall → const TextStyleToken
- labelMedium → const TextStyleToken
- labelSmall → const TextStyleToken
- titleLarge → const TextStyleToken
- titleMedium → const TextStyleToken
- titleSmall → const TextStyleToken