TabBar class final
Tabbed content shell.
Control an existing tab bar later with TabBarControl(widgetName, ...).
Constructors
-
TabBar({required List<
TabItem> tabs, TabBarStyle? style, ColorToken? indicatorColor, ColorToken? labelColor, ColorToken? unselectedLabelColor, ColorToken? backgroundColor, int? initialIndex, bool scrollable = false, String? name, Object? visible})
Properties
- backgroundColor → ColorToken?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indicatorColor → ColorToken?
-
final
- initialIndex → int?
-
final
- labelColor → ColorToken?
-
final
- name → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollable → bool
-
final
- style → TabBarStyle?
-
final
-
tabs
→ List<
TabItem> -
final
- unselectedLabelColor → ColorToken?
-
final
- visible → DslExpression?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited