TextField class final

Text entry field.

onChanged and onSubmitted can consume TextValue() as the current field value.

Inheritance
Annotations
  • @immutable

Constructors

TextField({String? label, String? hint, String? prefixIcon, String? suffixIcon, Keyboard keyboard = Keyboard.text, int? maxLines, bool obscureText = false, Object? onChanged, Object? onSubmitted, String? name, Object? visible})

Properties

hashCode int
The hash code for this object.
no setterinherited
hint String?
final
keyboard Keyboard
final
label String?
final
maxLines int?
final
name String?
finalinherited
obscureText bool
final
onChanged List<DslAction>
final
onSubmitted List<DslAction>
final
prefixIcon String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffixIcon String?
final
visible DslExpression?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited