TextValue class final
Text field runtime value.
This is only valid inside text-field trigger contexts such as onChanged
and onSubmitted.
Example:
TextField(
name: 'PriceField',
onChanged: [
SetState('price', TextValue().asDouble()),
],
)
- Inheritance
-
- Object
- DslExpression
- TextValue
- Annotations
-
- @immutable
Constructors
- TextValue()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asDouble(
) → TextCoercion -
asInt(
) → TextCoercion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String field) → FieldAccess -
inherited