UploadData class final
Upload media or files.
Use actionName when later actions need to clear or otherwise refer to the
uploaded payload. The upload result is handled through the generated upload
action semantics rather than ActionOutput(...).
Example:
UploadData(
source: UploadSource.gallery,
destination: UploadDestination.firebase,
actionName: 'profilePhotoUpload',
)
Constructors
- UploadData({UploadSource source = UploadSource.galleryOrCamera, bool allowPhoto = true, bool allowVideo = false, bool allowFile = false, UploadDestination destination = UploadDestination.localFile, String? actionName, bool multiUpload = false})
-
const
Properties
- actionName → String?
-
final
- allowFile → bool
-
final
- allowPhoto → bool
-
final
- allowVideo → bool
-
final
- destination → UploadDestination
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- multiUpload → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → UploadSource
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited