ValidateForm class final
Validate a form widget by its name:.
This targets an existing form widget in the current page/component tree.
Example:
[
ValidateForm('CreateTaskForm'),
ApiCall(createTask, params: {'title': State('title')}),
]
Constructors
- ValidateForm(String formName, {bool terminateIfFails = true})
-
const
Properties
- formName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terminateIfFails → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited