WidgetRef class final
A widget tree node in the brownfield read model.
Properties
-
children
→ List<
WidgetRef> -
final
- componentName → String?
-
final
-
descendants
→ List<
WidgetRef> -
no setter
- generator → GeneratorSnapshot?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- name → String?
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchableText → String
-
no setter
-
slots
→ Map<
String, List< WidgetRef> > -
final
- text → String?
-
final
-
triggerTypes
→ List<
String> -
final
- type → String
-
final
Methods
-
describe(
) → String -
findByKey(
String key) → WidgetSelection -
findByName(
String name) → WidgetSelection -
findByPath(
String path) → WidgetSelection -
findByText(
String text) → WidgetSelection -
findByType(
String type) → WidgetSelection -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
slot(
String name) → WidgetSelection -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited