WidgetState class final

Runtime state read from another named widget in the current page/component.

Supported properties in Phase 14 are:

  • currentIndex for TabBar, PageView, and Carousel
  • value for Toggle, Checkbox, and Dropdown
  • text for TextField
Inheritance
Annotations
  • @immutable

Constructors

WidgetState(String widgetName, WidgetStateProperty property)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
property WidgetStateProperty
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widgetName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String field) FieldAccess
inherited