applyToGraph method

void applyToGraph(
  1. ProjectGraph graph,
  2. String nodeId
)

Apply these dependencies to the graph for the given action block node.

Creates granular dependency nodes as needed and adds edges from the action block to its dependencies.

Implementation

void applyToGraph(ProjectGraph graph, String nodeId) {
  _linkToNodes(
    graph,
    nodeId,
    customFunctionKeys,
    NodeIds.customFunction,
    DependencyNodeType.customFunction,
  );
  _linkToNodes(
    graph,
    nodeId,
    customActionKeys,
    NodeIds.customAction,
    DependencyNodeType.customAction,
  );
  _linkToNodes(
    graph,
    nodeId,
    actionBlockKeys,
    NodeIds.actionBlock,
    DependencyNodeType.actionBlock,
  );
  _linkToNodes(
    graph,
    nodeId,
    appEventKeys,
    NodeIds.appEvent,
    DependencyNodeType.appEvent,
  );
}