Global file node IDs - constants for well-known global nodes.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
globalNodeTypes
→ const Map<
String, DependencyNodeType> - Mapping of global node IDs to their types.
- kActionBlocksNodeId → const String
- kAppStateNodeId → const String
- kCustomCodeNodeId → const String
- kDataSchemaNodeId → const String
- kIndexNodeId → const String
- kMainNodeId → const String
- kRoutingNodeId → const String
- kThemeNodeId → const String