isGranularDependencyNodeId static method

bool isGranularDependencyNodeId(
  1. String nodeId
)

Check if a node ID represents any granular dependency type. This includes API calls, action blocks, custom functions, custom widgets, custom actions, data structs, enums, Firestore collections, Supabase tables, asset dependencies, and field-level dependencies (data struct fields, action block params).

Implementation

static bool isGranularDependencyNodeId(String nodeId) =>
    _granularSchemes.any((scheme) => scheme.matches(nodeId)) ||
    _compoundGranularSchemes.any((scheme) => scheme.matches(nodeId));