schema/gen/common.pb library

Classes

AiGenPageExample
AiGenPageExample_Category
AiModelProvider
AppMetadata
AssetType
BranchAccessLevel
Access levels describing the extent a user can access/modify a branch.
CodemagicCommonWrapper
Codemagic BuildType needed to be moved to common.proto, however the enum values are globally scoped and can't be changed. This is a dummy wrapper to allow the same values to be used.
CodemagicCommonWrapper_BuildType
CollectionRules
CopiedData
CopiedData_CopiedType
DiffedEditType
When updating DiffedEditType, make sure to also update:
DocumentReferenceProto
ErrorMetadata
Extras
FetchStripeSubscriptionResponse
FetchStripeSubscriptionResponse_Subscriptions
FFAppValuesTab
FFDataSchemaTab
FFProjectError
FFProjectError_ActionInfo
FFProjectError_OnTapActionIdentifier
FFProjectWarningConfig
FFSettingsTab
FFThemeSettingsTab
FFWorkspaceTab
FirebaseStorage
FirebaseStorageRules
FirestoreSecurityRules
FirestoreSecurityRules_ReadVisibility
ImageSize
LastSessionUpdate
Information related to the most recently applied update from a session.
LatLng
MarketplaceItemComment
MarketplaceItemComment_UserInfo
ProjectBuildMode
ProjectLocation
RuleCondition
RuleCondition_AuthenticatedUsers
RuleCondition_Chat
RuleCondition_Everyone
RuleCondition_NoOne
RuleCondition_TaggedUsers
RuleCondition_TagType
RuleCondition_UsersCollection
RuleCondition_UsersPushNotifications
StripeBillingInterval
StripeCheckoutSessionInfo
StripeCheckoutSessionInfo_LineItem
StripeResponseAddOnInfo
StripeResponseAddOnInfoMap
StripeResponseSubscriptionPlan
StripeResponseSubscriptionPlan_StripePlanType
StripeSubscriptionStatusEnum
SupportedPlatform
TeamAccessLevel
UserBranchPermissions

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.