stripePlanInfo property
- @Deprecated('This field is deprecated.')
- @TagNumber(1)
Can't truly be a oneof right now due to the need to return the deprecated field for outdated clients. oneof result {
Implementation
@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(1)
StripeResponseSubscriptionPlan get stripePlanInfo => $_getN(0);
- @Deprecated('This field is deprecated.')
- @TagNumber(1)
Implementation
@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(1)
set stripePlanInfo(StripeResponseSubscriptionPlan value) =>
$_setField(1, value);