FFAIAgentRequest class
- Inheritance
-
- Object
- GeneratedMessage
- FFAIAgentRequest
- Available extensions
Constructors
-
FFAIAgentRequest({@Deprecated('This field is deprecated.') FFAgent? legacyAgent, @Deprecated('This field is deprecated.') String? conversationId, FFStringValue? textInput, FFVariable? imageNetworkUrl, FFVariable? uploadedImageFile, FFVariable? audioAsset, FFVariable? audioNetworkUrl, FFVariable? fileAsset, FFVariable? fileUrl, Iterable<
FFParameter> ? requestDataStructs, FFVariable? videoAsset, FFVariable? videoNetworkUrl, FFIdentifier? agentId, FFStringValue? conversationIdValue, FFVariable? pdfNetworkUrl, FFVariable? uploadedPdfFile}) -
factory
-
FFAIAgentRequest.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFAIAgentRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- agentId ↔ FFIdentifier
-
@doc The identifier of the chosen FFAgent agent to call.
getter/setter pair
- audioAsset ↔ FFVariable
-
@doc The audio asset to pass to the agent.
getter/setter pair
- audioNetworkUrl ↔ FFVariable
-
@doc The audio URL to pass to the agent.
getter/setter pair
- conversationId ↔ String
-
@doc A unique user provided identifier of that particular AI agent session.
getter/setter pair
- conversationIdValue ↔ FFStringValue
-
@doc A unique user provided identifier of that particular AI agent session.
getter/setter pair
- fileAsset ↔ FFVariable
-
@doc The file asset to pass to the agent.
getter/setter pair
- fileUrl ↔ FFVariable
-
@doc The file URL to pass to the agent.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- imageNetworkUrl ↔ FFVariable
-
@doc The image URL to pass to the agent.
getter/setter pair
- info_ → BuilderInfo
-
no setteroverride
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - legacyAgent ↔ FFAgent
-
@doc The chosen agent to call.
getter/setter pair
- pdfNetworkUrl ↔ FFVariable
-
@doc The PDF network URL to pass to the agent.
getter/setter pair
-
requestDataStructs
→ PbList<
FFParameter> -
@doc The request data structs to pass to the agent.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textInput ↔ FFStringValue
-
@doc The text input to pass to the agent.
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- uploadedImageFile ↔ FFVariable
-
@doc The image asset to pass to the agent.
getter/setter pair
- uploadedPdfFile ↔ FFVariable
-
@doc The PDF asset to pass to the agent.
getter/setter pair
- videoAsset ↔ FFVariable
-
@doc The video asset to pass to the agent.
getter/setter pair
- videoNetworkUrl ↔ FFVariable
-
@doc The video URL to pass to the agent.
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAgentId(
) → void -
clearAudioAsset(
) → void -
clearAudioInput(
) → void -
clearAudioNetworkUrl(
) → void -
clearConversationId(
) → void -
clearConversationIdValue(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearFileAsset(
) → void -
clearFileInput(
) → void -
clearFileUrl(
) → void -
clearImageInput(
) → void -
clearImageNetworkUrl(
) → void -
clearLegacyAgent(
) → void -
clearPdfInput(
) → void -
clearPdfNetworkUrl(
) → void -
clearTextInput(
) → void -
clearUploadedImageFile(
) → void -
clearUploadedPdfFile(
) → void -
clearVideoAsset(
) → void -
clearVideoInput(
) → void -
clearVideoNetworkUrl(
) → void -
clone(
) → FFAIAgentRequest -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFAIAgentRequest)) → FFAIAgentRequest -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFAIAgentRequest -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAgentId(
) → FFIdentifier -
ensureAudioAsset(
) → FFVariable -
ensureAudioNetworkUrl(
) → FFVariable -
ensureConversationIdValue(
) → FFStringValue -
ensureFileAsset(
) → FFVariable -
ensureFileUrl(
) → FFVariable -
ensureImageNetworkUrl(
) → FFVariable -
ensureLegacyAgent(
) → FFAgent -
ensurePdfNetworkUrl(
) → FFVariable -
ensureTextInput(
) → FFStringValue -
ensureUploadedImageFile(
) → FFVariable -
ensureUploadedPdfFile(
) → FFVariable -
ensureVideoAsset(
) → FFVariable -
ensureVideoNetworkUrl(
) → FFVariable -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAgentId(
) → bool -
hasAudioAsset(
) → bool -
hasAudioNetworkUrl(
) → bool -
hasConversationId(
) → bool -
hasConversationIdValue(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasFileAsset(
) → bool -
hasFileUrl(
) → bool -
hasImageNetworkUrl(
) → bool -
hasLegacyAgent(
) → bool -
hasPdfNetworkUrl(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasTextInput(
) → bool -
hasUploadedImageFile(
) → bool -
hasUploadedPdfFile(
) → bool -
hasVideoAsset(
) → bool -
hasVideoNetworkUrl(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
whichAudioInput(
) → FFAIAgentRequest_AudioInput -
whichFileInput(
) → FFAIAgentRequest_FileInput -
whichImageInput(
) → FFAIAgentRequest_ImageInput -
whichPdfInput(
) → FFAIAgentRequest_PdfInput -
whichVideoInput(
) → FFAIAgentRequest_VideoInput -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited