FFAction class
- Inheritance
-
- Object
- GeneratedMessage
- FFAction
- Available extensions
Constructors
- FFAction({@Deprecated('This field is deprecated.') FFAction_LegacyTrigger? trigger, @Deprecated('This field is deprecated.') FFSetStateAction? setState, FFDatabaseAction? database, FFLaunchUrlAction? launchUrl, FFAuthAction? auth, FFDrawerAction? drawer, @Deprecated('This field is deprecated.') FFUploadDataSettings? legacyUploadMedia, FFDatePicker? datePicker, FFPageViewAction? pageView, FFBottomSheetAction? bottomSheet, FFAlertDialogAction? alertDialog, FFAlgoliaSearchAction? algoliaSearch, @Deprecated('This field is deprecated.') FFParameter? legacyOutputParameter, FFBraintreeAction? braintree, @Deprecated('This field is deprecated.') FFLottieAnimationAction? lottieAnimation, FFAnimationAction? animation, FFGoogleMapAction? googleMap, @Deprecated('This field is deprecated.') FFConditionalExecution? conditionalExecution, FFSnackBarAction? snackBar, FFBarcodeQrcodeScanner? barcodeScanner, FFTriggerPushNotification? triggerPushNotification, FFExpandImageAction? expandImage, FFRevenueCatAction? revenueCat, FFCustomActionCall? customAction, String? outputVariableName, FFLocalStateUpdate? localStateUpdate, FFChatAction? chatAction, FFStripeAction? stripe, FFWaitAction? waitAction, FFClearTextFieldAction? clearTextFieldAction, FFSetAppLanguageAction? setAppLanguage, FFSetDarkModeSetting? setDarkModeSetting, FFValidateFormAction? validateFormAction, String? actionName, String? key, @Deprecated('This field is deprecated.') bool? legacyHasBeenUpdated, FFFirebaseAnalyticsAction? firebaseAnalyticsAction, FFAdMobAction? admobAction, FFMapLauncherAction? mapLauncherAction, FFSimpleSearchAction? simpleSearchAction, FFGenerateCurrentPageLink? generateCurrentPageLink, FFUploadSignature? uploadSignature, FFClearSignature? clearSignature, FFRefreshDatabaseRequest? refreshDatabaseRequest, FFPlaySound? playSound, FFHapticFeedbackAction? hapticFeedback, FFExecuteCallbackAction? executeCallbackAction, FFBiometricVerification? biometricVerification, FFTimerAction? timer, FFClearSwipeableStackAction? clearSwipeableStackAction, FFSwipeableStackAction? swipeableStack, FFRequestPermissionsAction? requestPermissions, FFSendSMS? sendSMS, FFCallNumber? callNumber, FFSendEmail? sendEmail, FFScrollToPercentage? scrollToPercentage, FFMultiselectWidgetAction? multiselectWidgetAction, FFDeleteData? deleteData, FFStartPeriodic? startPeriodic, FFStopPeriodic? stopPeriodic, FFColorPickerAction? colorPicker, FFHideSnackBarAction? hideSnackBar, FFUploadDataAction? uploadData, FFCopyToClipboard? copyToClipboard, FFRazorpayAction? razorpay, FFStopSound? stopSound, FFClearUploadedDataAction? clearUploadedData, FFResetFormFieldAction? resetFormField, FFSetFormFieldAction? setFormField, FFClearQueryCache? clearQueryCache, FFExecuteActionComponent? executeActionComponent, FFStartAudioRecordAction? startAudioRecord, FFStopAudioRecordAction? stopAudioRecord, FFDisableAction? disableAction, FFTabBarAction? tabBar, FFCustomCloudFunctionCall? customCloudFunctionCall, FFCarouselAction? carousel, bool? nonBlocking, FFOneSignalAction? oneSignal, FFDataTableAction? dataTable, FFWalkthroughAction? walkthrough, FFGeminiAction? gemini, FFUpdateAppBadgeCountAction? updateAppBadgeCount, FFDownloadFileAction? downloadFile, FFAIAgentAction? aiAgent, FFCustomInterfaceMethodCall? customInterfaceMethodCall, FFCancelStreamingResponseSubscriptionAction? cancelStreamingResponseSubscriptionAction, FFSemanticsAnnounceAction? semanticsAnnounceAction, FFUpdateTextScalingFactorAction? updateTextScalingFactorAction, FFCustomCodeCallAction? customCodeCall, FFRebuildAction? rebuild, FFToggleExpandableWidgetAction? toggleExpandableWidget, FFTriggerAppEventAction? triggerAppEventAction, FFAddLocalAppEventHandlerAction? addLocalAppEventHandlerAction, FFCancelLocalAppEventHandlerAction? cancelLocalAppEventHandlerAction, FFSupabaseEdgeFunctionCall? supabaseEdgeFunctionCall})
-
factory
-
FFAction.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFAction.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- actionName ↔ String
-
@doc The name of this action.
getter/setter pair
- addLocalAppEventHandlerAction ↔ FFAddLocalAppEventHandlerAction
-
@doc Add a local app event handler
getter/setter pair
- admobAction ↔ FFAdMobAction
-
@doc AdMob action.
getter/setter pair
- aiAgent ↔ FFAIAgentAction
-
@doc AI Agent action.
getter/setter pair
- alertDialog ↔ FFAlertDialogAction
-
@doc Dialog actions.
getter/setter pair
- algoliaSearch ↔ FFAlgoliaSearchAction
-
@doc Algolia search action.
getter/setter pair
- animation ↔ FFAnimationAction
-
@doc Animation action.
getter/setter pair
- auth ↔ FFAuthAction
-
@doc Authentication actions.
getter/setter pair
- barcodeScanner ↔ FFBarcodeQrcodeScanner
-
@doc Barcode/QR code scanner action.
getter/setter pair
- biometricVerification ↔ FFBiometricVerification
-
@doc Biometric verification action.
getter/setter pair
- bottomSheet ↔ FFBottomSheetAction
-
@doc Actions supported by Bottom Sheets.
getter/setter pair
- braintree ↔ FFBraintreeAction
-
@doc Braintree payment action.
getter/setter pair
- callNumber ↔ FFCallNumber
-
@doc Call number action.
getter/setter pair
- cancelLocalAppEventHandlerAction ↔ FFCancelLocalAppEventHandlerAction
-
@doc Cancel a local app event handler
getter/setter pair
- cancelStreamingResponseSubscriptionAction ↔ FFCancelStreamingResponseSubscriptionAction
-
@doc Cancel Streaming Response Subscription Action
getter/setter pair
- carousel ↔ FFCarouselAction
-
@doc Carousel action.
getter/setter pair
- chatAction ↔ FFChatAction
-
getter/setter pair
- clearQueryCache ↔ FFClearQueryCache
-
getter/setter pair
- clearSignature ↔ FFClearSignature
-
@doc Clear signature action.
getter/setter pair
- clearSwipeableStackAction ↔ FFClearSwipeableStackAction
-
Not implemented.
getter/setter pair
- clearTextFieldAction ↔ FFClearTextFieldAction
-
getter/setter pair
- clearUploadedData ↔ FFClearUploadedDataAction
-
@doc Clear uploaded data action.
getter/setter pair
- colorPicker ↔ FFColorPickerAction
-
@doc Color picker action.
getter/setter pair
- conditionalExecution ↔ FFConditionalExecution
-
getter/setter pair
- copyToClipboard ↔ FFCopyToClipboard
-
@doc Copy to clipboard action.
getter/setter pair
- customAction ↔ FFCustomActionCall
-
getter/setter pair
- customCloudFunctionCall ↔ FFCustomCloudFunctionCall
-
@doc Cloud function call.
getter/setter pair
- customCodeCall ↔ FFCustomCodeCallAction
-
getter/setter pair
- customInterfaceMethodCall ↔ FFCustomInterfaceMethodCall
-
getter/setter pair
- database ↔ FFDatabaseAction
-
@doc Database operations.
getter/setter pair
- dataTable ↔ FFDataTableAction
-
@doc Data table action.
getter/setter pair
- datePicker ↔ FFDatePicker
-
@doc Date picker action.
getter/setter pair
- deleteData ↔ FFDeleteData
-
@doc Delete data action.
getter/setter pair
- disableAction ↔ FFDisableAction
-
@doc A disabled action.
getter/setter pair
- downloadFile ↔ FFDownloadFileAction
-
@doc Download file action.
getter/setter pair
- drawer ↔ FFDrawerAction
-
@doc Actions supported by Drawers.
getter/setter pair
- executeActionComponent ↔ FFExecuteActionComponent
-
@doc Execute action component action.
getter/setter pair
- executeCallbackAction ↔ FFExecuteCallbackAction
-
@doc Execute callback action.
getter/setter pair
- expandImage ↔ FFExpandImageAction
-
@doc Expand image action.
getter/setter pair
- firebaseAnalyticsAction ↔ FFFirebaseAnalyticsAction
-
@doc Firebase Analytics action.
getter/setter pair
- gemini ↔ FFGeminiAction
-
@doc Actions supported by Gemini API.
getter/setter pair
- generateCurrentPageLink ↔ FFGenerateCurrentPageLink
-
@doc Generate current page link action.
getter/setter pair
- googleMap ↔ FFGoogleMapAction
-
@doc Google Map action.
getter/setter pair
- hapticFeedback ↔ FFHapticFeedbackAction
-
@doc Haptic feedback action.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- hideSnackBar ↔ FFHideSnackBarAction
-
@doc Action to hide the SnackBar.
getter/setter pair
- info_ → BuilderInfo
-
no setteroverride
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - key ↔ String
-
@doc Unique key for this action.
getter/setter pair
- launchUrl ↔ FFLaunchUrlAction
-
@doc Launch a URL.
getter/setter pair
- legacyHasBeenUpdated ↔ bool
-
getter/setter pair
- legacyOutputParameter ↔ FFParameter
-
getter/setter pair
- legacyUploadMedia ↔ FFUploadDataSettings
-
getter/setter pair
- localStateUpdate ↔ FFLocalStateUpdate
-
@doc Update app/page/component state action.
getter/setter pair
- lottieAnimation ↔ FFLottieAnimationAction
-
getter/setter pair
- mapLauncherAction ↔ FFMapLauncherAction
-
@doc Map Launcher action.
getter/setter pair
- multiselectWidgetAction ↔ FFMultiselectWidgetAction
-
getter/setter pair
-
@doc Navigation action.
getter/setter pair
- nonBlocking ↔ bool
-
getter/setter pair
- oneSignal ↔ FFOneSignalAction
-
@doc Actions supported by OneSignal integration.
getter/setter pair
- outputVariableName ↔ String
-
@doc The name of the output variable that will be set by this action.
getter/setter pair
- pageView ↔ FFPageViewAction
-
@doc Page view action.
getter/setter pair
- playSound ↔ FFPlaySound
-
@doc Play sound action.
getter/setter pair
- razorpay ↔ FFRazorpayAction
-
@doc Razorpay action.
getter/setter pair
- rebuild ↔ FFRebuildAction
-
getter/setter pair
- refreshDatabaseRequest ↔ FFRefreshDatabaseRequest
-
@doc Refresh a database request.
getter/setter pair
- requestPermissions ↔ FFRequestPermissionsAction
-
@doc Request permissions action.
getter/setter pair
- resetFormField ↔ FFResetFormFieldAction
-
getter/setter pair
- revenueCat ↔ FFRevenueCatAction
-
@doc RevenueCat action.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollToPercentage ↔ FFScrollToPercentage
-
@doc Scroll to percentage action.
getter/setter pair
- semanticsAnnounceAction ↔ FFSemanticsAnnounceAction
-
@doc Announce text to screen readers for accessibility.
getter/setter pair
- sendEmail ↔ FFSendEmail
-
@doc Send email action.
getter/setter pair
- sendSMS ↔ FFSendSMS
-
@doc Send SMS action.
getter/setter pair
- setAppLanguage ↔ FFSetAppLanguageAction
-
@doc Set app language action.
getter/setter pair
- setDarkModeSetting ↔ FFSetDarkModeSetting
-
@doc Set dark mode setting action.
getter/setter pair
- setFormField ↔ FFSetFormFieldAction
-
getter/setter pair
- setState ↔ FFSetStateAction
-
getter/setter pair
-
@doc Share action.
getter/setter pair
- simpleSearchAction ↔ FFSimpleSearchAction
-
@doc Simple search action.
getter/setter pair
- snackBar ↔ FFSnackBarAction
-
@doc SnackBar action.
getter/setter pair
- startAudioRecord ↔ FFStartAudioRecordAction
-
@doc Start audio record action.
getter/setter pair
- startPeriodic ↔ FFStartPeriodic
-
@doc Start periodic action.
getter/setter pair
- stopAudioRecord ↔ FFStopAudioRecordAction
-
@doc Stop audio record action.
getter/setter pair
- stopPeriodic ↔ FFStopPeriodic
-
@doc Stop periodic action.
getter/setter pair
- stopSound ↔ FFStopSound
-
@doc Stop sound action.
getter/setter pair
- stripe ↔ FFStripeAction
-
@doc Stripe payment action.
getter/setter pair
- supabaseEdgeFunctionCall ↔ FFSupabaseEdgeFunctionCall
-
@doc Supabase Edge Function call.
getter/setter pair
- swipeableStack ↔ FFSwipeableStackAction
-
getter/setter pair
- tabBar ↔ FFTabBarAction
-
@doc Tab bar action.
getter/setter pair
- timer ↔ FFTimerAction
-
@doc Timer action.
getter/setter pair
- toggleExpandableWidget ↔ FFToggleExpandableWidgetAction
-
@doc Toggle expandable widget action.
getter/setter pair
- trigger ↔ FFAction_LegacyTrigger
-
getter/setter pair
- triggerAppEventAction ↔ FFTriggerAppEventAction
-
@doc Trigger an app event
getter/setter pair
- triggerPushNotification ↔ FFTriggerPushNotification
-
@doc Action to trigger push notification.
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- updateAppBadgeCount ↔ FFUpdateAppBadgeCountAction
-
@doc Update app badge count action.
getter/setter pair
- updateTextScalingFactorAction ↔ FFUpdateTextScalingFactorAction
-
@doc Update the text scaling factor for accessibility.
getter/setter pair
- uploadData ↔ FFUploadDataAction
-
@doc Upload data action.
getter/setter pair
- uploadSignature ↔ FFUploadSignature
-
@doc Upload signature action.
getter/setter pair
- validateFormAction ↔ FFValidateFormAction
-
getter/setter pair
- waitAction ↔ FFWaitAction
-
@doc Wait action.
getter/setter pair
- walkthrough ↔ FFWalkthroughAction
-
@doc Walkthrough action.
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAction(
) → void -
clearActionName(
) → void -
clearAddLocalAppEventHandlerAction(
) → void -
clearAdmobAction(
) → void -
clearAiAgent(
) → void -
clearAlertDialog(
) → void -
clearAlgoliaSearch(
) → void -
clearAnimation(
) → void -
clearAuth(
) → void -
clearBarcodeScanner(
) → void -
clearBiometricVerification(
) → void -
clearBottomSheet(
) → void -
clearBraintree(
) → void -
clearCallNumber(
) → void -
clearCancelLocalAppEventHandlerAction(
) → void -
clearCancelStreamingResponseSubscriptionAction(
) → void -
clearCarousel(
) → void -
clearChatAction(
) → void -
clearClearQueryCache(
) → void -
clearClearSignature(
) → void -
clearClearSwipeableStackAction(
) → void -
clearClearTextFieldAction(
) → void -
clearClearUploadedData(
) → void -
clearColorPicker(
) → void -
clearConditionalExecution(
) → void -
clearCopyToClipboard(
) → void -
clearCustomAction(
) → void -
clearCustomCloudFunctionCall(
) → void -
clearCustomCodeCall(
) → void -
clearCustomInterfaceMethodCall(
) → void -
clearDatabase(
) → void -
clearDataTable(
) → void -
clearDatePicker(
) → void -
clearDeleteData(
) → void -
clearDisableAction(
) → void -
clearDownloadFile(
) → void -
clearDrawer(
) → void -
clearExecuteActionComponent(
) → void -
clearExecuteCallbackAction(
) → void -
clearExpandImage(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearFirebaseAnalyticsAction(
) → void -
clearGemini(
) → void -
clearGenerateCurrentPageLink(
) → void -
clearGoogleMap(
) → void -
clearHapticFeedback(
) → void -
clearHideSnackBar(
) → void -
clearKey(
) → void -
clearLaunchUrl(
) → void -
clearLegacyHasBeenUpdated(
) → void -
clearLegacyOutputParameter(
) → void -
clearLegacyUploadMedia(
) → void -
clearLocalStateUpdate(
) → void -
clearLottieAnimation(
) → void -
clearMapLauncherAction(
) → void -
clearMultiselectWidgetAction(
) → void -
clearNonBlocking(
) → void -
clearOneSignal(
) → void -
clearOutputVariableName(
) → void -
clearPageView(
) → void -
clearPlaySound(
) → void -
clearRazorpay(
) → void -
clearRebuild(
) → void -
clearRefreshDatabaseRequest(
) → void -
clearRequestPermissions(
) → void -
clearResetFormField(
) → void -
clearRevenueCat(
) → void -
clearScrollToPercentage(
) → void -
clearSemanticsAnnounceAction(
) → void -
clearSendEmail(
) → void -
clearSendSMS(
) → void -
clearSetAppLanguage(
) → void -
clearSetDarkModeSetting(
) → void -
clearSetFormField(
) → void -
clearSetState(
) → void -
clearSimpleSearchAction(
) → void -
clearSnackBar(
) → void -
clearStartAudioRecord(
) → void -
clearStartPeriodic(
) → void -
clearStopAudioRecord(
) → void -
clearStopPeriodic(
) → void -
clearStopSound(
) → void -
clearStripe(
) → void -
clearSupabaseEdgeFunctionCall(
) → void -
clearSwipeableStack(
) → void -
clearTabBar(
) → void -
clearTimer(
) → void -
clearToggleExpandableWidget(
) → void -
clearTrigger(
) → void -
clearTriggerAppEventAction(
) → void -
clearTriggerPushNotification(
) → void -
clearUpdateAppBadgeCount(
) → void -
clearUpdateTextScalingFactorAction(
) → void -
clearUploadData(
) → void -
clearUploadSignature(
) → void -
clearValidateFormAction(
) → void -
clearWaitAction(
) → void -
clearWalkthrough(
) → void -
clone(
) → FFAction -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFAction)) → FFAction -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFAction -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAddLocalAppEventHandlerAction(
) → FFAddLocalAppEventHandlerAction -
ensureAdmobAction(
) → FFAdMobAction -
ensureAiAgent(
) → FFAIAgentAction -
ensureAlertDialog(
) → FFAlertDialogAction -
ensureAlgoliaSearch(
) → FFAlgoliaSearchAction -
ensureAnimation(
) → FFAnimationAction -
ensureAuth(
) → FFAuthAction -
ensureBarcodeScanner(
) → FFBarcodeQrcodeScanner -
ensureBiometricVerification(
) → FFBiometricVerification -
ensureBottomSheet(
) → FFBottomSheetAction -
ensureBraintree(
) → FFBraintreeAction -
ensureCallNumber(
) → FFCallNumber -
ensureCancelLocalAppEventHandlerAction(
) → FFCancelLocalAppEventHandlerAction -
ensureCancelStreamingResponseSubscriptionAction(
) → FFCancelStreamingResponseSubscriptionAction -
ensureCarousel(
) → FFCarouselAction -
ensureChatAction(
) → FFChatAction -
ensureClearQueryCache(
) → FFClearQueryCache -
ensureClearSignature(
) → FFClearSignature -
ensureClearSwipeableStackAction(
) → FFClearSwipeableStackAction -
ensureClearTextFieldAction(
) → FFClearTextFieldAction -
ensureClearUploadedData(
) → FFClearUploadedDataAction -
ensureColorPicker(
) → FFColorPickerAction -
ensureConditionalExecution(
) → FFConditionalExecution -
ensureCopyToClipboard(
) → FFCopyToClipboard -
ensureCustomAction(
) → FFCustomActionCall -
ensureCustomCloudFunctionCall(
) → FFCustomCloudFunctionCall -
ensureCustomCodeCall(
) → FFCustomCodeCallAction -
ensureCustomInterfaceMethodCall(
) → FFCustomInterfaceMethodCall -
ensureDatabase(
) → FFDatabaseAction -
ensureDataTable(
) → FFDataTableAction -
ensureDatePicker(
) → FFDatePicker -
ensureDeleteData(
) → FFDeleteData -
ensureDisableAction(
) → FFDisableAction -
ensureDownloadFile(
) → FFDownloadFileAction -
ensureDrawer(
) → FFDrawerAction -
ensureExecuteActionComponent(
) → FFExecuteActionComponent -
ensureExecuteCallbackAction(
) → FFExecuteCallbackAction -
ensureExpandImage(
) → FFExpandImageAction -
ensureFirebaseAnalyticsAction(
) → FFFirebaseAnalyticsAction -
ensureGemini(
) → FFGeminiAction -
ensureGenerateCurrentPageLink(
) → FFGenerateCurrentPageLink -
ensureGoogleMap(
) → FFGoogleMapAction -
ensureHapticFeedback(
) → FFHapticFeedbackAction -
ensureHideSnackBar(
) → FFHideSnackBarAction -
ensureLaunchUrl(
) → FFLaunchUrlAction -
ensureLegacyOutputParameter(
) → FFParameter -
ensureLegacyUploadMedia(
) → FFUploadDataSettings -
ensureLocalStateUpdate(
) → FFLocalStateUpdate -
ensureLottieAnimation(
) → FFLottieAnimationAction -
ensureMapLauncherAction(
) → FFMapLauncherAction -
ensureMultiselectWidgetAction(
) → FFMultiselectWidgetAction -
ensureOneSignal(
) → FFOneSignalAction -
ensurePageView(
) → FFPageViewAction -
ensurePlaySound(
) → FFPlaySound -
ensureRazorpay(
) → FFRazorpayAction -
ensureRebuild(
) → FFRebuildAction -
ensureRefreshDatabaseRequest(
) → FFRefreshDatabaseRequest -
ensureRequestPermissions(
) → FFRequestPermissionsAction -
ensureResetFormField(
) → FFResetFormFieldAction -
ensureRevenueCat(
) → FFRevenueCatAction -
ensureScrollToPercentage(
) → FFScrollToPercentage -
ensureSemanticsAnnounceAction(
) → FFSemanticsAnnounceAction -
ensureSendEmail(
) → FFSendEmail -
ensureSendSMS(
) → FFSendSMS -
ensureSetAppLanguage(
) → FFSetAppLanguageAction -
ensureSetDarkModeSetting(
) → FFSetDarkModeSetting -
ensureSetFormField(
) → FFSetFormFieldAction -
ensureSetState(
) → FFSetStateAction -
ensureSimpleSearchAction(
) → FFSimpleSearchAction -
ensureSnackBar(
) → FFSnackBarAction -
ensureStartAudioRecord(
) → FFStartAudioRecordAction -
ensureStartPeriodic(
) → FFStartPeriodic -
ensureStopAudioRecord(
) → FFStopAudioRecordAction -
ensureStopPeriodic(
) → FFStopPeriodic -
ensureStopSound(
) → FFStopSound -
ensureStripe(
) → FFStripeAction -
ensureSupabaseEdgeFunctionCall(
) → FFSupabaseEdgeFunctionCall -
ensureSwipeableStack(
) → FFSwipeableStackAction -
ensureTabBar(
) → FFTabBarAction -
ensureTimer(
) → FFTimerAction -
ensureToggleExpandableWidget(
) → FFToggleExpandableWidgetAction -
ensureTriggerAppEventAction(
) → FFTriggerAppEventAction -
ensureTriggerPushNotification(
) → FFTriggerPushNotification -
ensureUpdateAppBadgeCount(
) → FFUpdateAppBadgeCountAction -
ensureUpdateTextScalingFactorAction(
) → FFUpdateTextScalingFactorAction -
ensureUploadData(
) → FFUploadDataAction -
ensureUploadSignature(
) → FFUploadSignature -
ensureValidateFormAction(
) → FFValidateFormAction -
ensureWaitAction(
) → FFWaitAction -
ensureWalkthrough(
) → FFWalkthroughAction -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasActionName(
) → bool -
hasAddLocalAppEventHandlerAction(
) → bool -
hasAdmobAction(
) → bool -
hasAiAgent(
) → bool -
hasAlertDialog(
) → bool -
hasAlgoliaSearch(
) → bool -
hasAnimation(
) → bool -
hasAuth(
) → bool -
hasBarcodeScanner(
) → bool -
hasBiometricVerification(
) → bool -
hasBottomSheet(
) → bool -
hasBraintree(
) → bool -
hasCallNumber(
) → bool -
hasCancelLocalAppEventHandlerAction(
) → bool -
hasCancelStreamingResponseSubscriptionAction(
) → bool -
hasCarousel(
) → bool -
hasChatAction(
) → bool -
hasClearQueryCache(
) → bool -
hasClearSignature(
) → bool -
hasClearSwipeableStackAction(
) → bool -
hasClearTextFieldAction(
) → bool -
hasClearUploadedData(
) → bool -
hasColorPicker(
) → bool -
hasConditionalExecution(
) → bool -
hasCopyToClipboard(
) → bool -
hasCustomAction(
) → bool -
hasCustomCloudFunctionCall(
) → bool -
hasCustomCodeCall(
) → bool -
hasCustomInterfaceMethodCall(
) → bool -
hasDatabase(
) → bool -
hasDataTable(
) → bool -
hasDatePicker(
) → bool -
hasDeleteData(
) → bool -
hasDisableAction(
) → bool -
hasDownloadFile(
) → bool -
hasDrawer(
) → bool -
hasExecuteActionComponent(
) → bool -
hasExecuteCallbackAction(
) → bool -
hasExpandImage(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasFirebaseAnalyticsAction(
) → bool -
hasGemini(
) → bool -
hasGenerateCurrentPageLink(
) → bool -
hasGoogleMap(
) → bool -
hasHapticFeedback(
) → bool -
hasHideSnackBar(
) → bool -
hasKey(
) → bool -
hasLaunchUrl(
) → bool -
hasLegacyHasBeenUpdated(
) → bool -
hasLegacyOutputParameter(
) → bool -
hasLegacyUploadMedia(
) → bool -
hasLocalStateUpdate(
) → bool -
hasLottieAnimation(
) → bool -
hasMapLauncherAction(
) → bool -
hasMultiselectWidgetAction(
) → bool -
hasNonBlocking(
) → bool -
hasOneSignal(
) → bool -
hasOutputVariableName(
) → bool -
hasPageView(
) → bool -
hasPlaySound(
) → bool -
hasRazorpay(
) → bool -
hasRebuild(
) → bool -
hasRefreshDatabaseRequest(
) → bool -
hasRequestPermissions(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasResetFormField(
) → bool -
hasRevenueCat(
) → bool -
hasScrollToPercentage(
) → bool -
hasSemanticsAnnounceAction(
) → bool -
hasSendEmail(
) → bool -
hasSendSMS(
) → bool -
hasSetAppLanguage(
) → bool -
hasSetDarkModeSetting(
) → bool -
hasSetFormField(
) → bool -
hasSetState(
) → bool -
hasSimpleSearchAction(
) → bool -
hasSnackBar(
) → bool -
hasStartAudioRecord(
) → bool -
hasStartPeriodic(
) → bool -
hasStopAudioRecord(
) → bool -
hasStopPeriodic(
) → bool -
hasStopSound(
) → bool -
hasStripe(
) → bool -
hasSupabaseEdgeFunctionCall(
) → bool -
hasSwipeableStack(
) → bool -
hasTabBar(
) → bool -
hasTimer(
) → bool -
hasToggleExpandableWidget(
) → bool -
hasTrigger(
) → bool -
hasTriggerAppEventAction(
) → bool -
hasTriggerPushNotification(
) → bool -
hasUpdateAppBadgeCount(
) → bool -
hasUpdateTextScalingFactorAction(
) → bool -
hasUploadData(
) → bool -
hasUploadSignature(
) → bool -
hasValidateFormAction(
) → bool -
hasWaitAction(
) → bool -
hasWalkthrough(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
whichAction(
) → FFAction_Action -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → FFAction -
getDefault(
) → FFAction