nonBlocking property

  1. @TagNumber(80)
bool get nonBlocking

@doc When toggled off, this action will be "awaited", which means that subsequent actions will not execute until this one is complete. Enabling "Non-Blocking" removes this await, so future actions happen directly after.

Implementation

@$pb.TagNumber(80)
$core.bool get nonBlocking => $_getBF(79);
  1. @TagNumber(80)
set nonBlocking (bool value)

Implementation

@$pb.TagNumber(80)
set nonBlocking($core.bool value) => $_setBool(79, value);