decodeUtf8 property

  1. @TagNumber(7)
bool get decodeUtf8

@doc Whether to force-decode response as UTF-8. This is a common need as not all APIs return the correct header to allow Dart to natively decode as UTF-8.

Implementation

@$pb.TagNumber(7)
$core.bool get decodeUtf8 => $_getBF(6);
  1. @TagNumber(7)
set decodeUtf8 (bool value)

Implementation

@$pb.TagNumber(7)
set decodeUtf8($core.bool value) => $_setBool(6, value);