isPrivateApi property

  1. @TagNumber(4)
bool get isPrivateApi

@doc If true, will deploy a Cloud Function that will make the call @doc directly, allowing sensitive keys to be used here.

Implementation

@$pb.TagNumber(4)
$core.bool get isPrivateApi => $_getBF(3);
  1. @TagNumber(4)
set isPrivateApi (bool value)

Implementation

@$pb.TagNumber(4)
set isPrivateApi($core.bool value) => $_setBool(3, value);