persisted property

  1. @TagNumber(2)
bool get persisted

@doc Whether this app state variable is saved to disk so that it can be loaded when the app is restarted. Otherwise the field will be reset on restart.

Implementation

@$pb.TagNumber(2)
$core.bool get persisted => $_getBF(1);
  1. @TagNumber(2)
set persisted (bool value)

Implementation

@$pb.TagNumber(2)
set persisted($core.bool value) => $_setBool(1, value);