disableAutoNavigate property
@doc By default, certain auth actions will automatically navigate the user upon success. Use this flag to disable and manually manage the navigation logic.
Implementation
@$pb.TagNumber(23)
$core.bool get disableAutoNavigate => $_getBF(22);
Implementation
@$pb.TagNumber(23)
set disableAutoNavigate($core.bool value) => $_setBool(22, value);