useIntrinsicWidth property

  1. @TagNumber(8)
bool get useIntrinsicWidth

@doc If true, the column will be wrapped in an IntrinsicWidth widget, making all children match the width of the widest child.

Implementation

@$pb.TagNumber(8)
$core.bool get useIntrinsicWidth => $_getBF(7);
  1. @TagNumber(8)
set useIntrinsicWidth (bool value)

Implementation

@$pb.TagNumber(8)
set useIntrinsicWidth($core.bool value) => $_setBool(7, value);