FFCountController class
- Inheritance
-
- Object
- GeneratedMessage
- FFCountController
- Available extensions
Constructors
- FFCountController({int? legacyInitialCount, int? displayValue, int? legacyStepSize, int? legacyMinimum, int? legacyMaximum, FFIcon? legacyDecrementIcon, FFIcon? legacyIncrementIcon, FFColor? legacyDisabledColor, FFText? countTextStyle, FFContainer? containerProps, FFPadding? contentPadding, FFIntegerValue? initialCountValue, FFIntegerValue? stepSizeValue, FFIntegerValue? minimumValue, FFIntegerValue? maximumValue, FFColorValue? disabledColorValue, FFIconValue? decrementIconValue, FFIconValue? incrementIconValue})
-
factory
-
FFCountController.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFCountController.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- containerProps ↔ FFContainer
-
getter/setter pair
- contentPadding ↔ FFPadding
-
getter/setter pair
- countTextStyle ↔ FFText
-
getter/setter pair
- decrementIconValue ↔ FFIconValue
-
getter/setter pair
- disabledColorValue ↔ FFColorValue
-
getter/setter pair
- displayValue ↔ int
-
This field is set in the UI Builder, but it's not used in codegen (as of Aug 2024).
We should consider removing it.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- incrementIconValue ↔ FFIconValue
-
getter/setter pair
- info_ → BuilderInfo
-
no setteroverride
- initialCountValue ↔ FFIntegerValue
-
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - legacyDecrementIcon ↔ FFIcon
-
getter/setter pair
- legacyDisabledColor ↔ FFColor
-
getter/setter pair
- legacyIncrementIcon ↔ FFIcon
-
getter/setter pair
- legacyInitialCount ↔ int
-
getter/setter pair
- legacyMaximum ↔ int
-
getter/setter pair
- legacyMinimum ↔ int
-
getter/setter pair
- legacyStepSize ↔ int
-
getter/setter pair
- maximumValue ↔ FFIntegerValue
-
getter/setter pair
- minimumValue ↔ FFIntegerValue
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepSizeValue ↔ FFIntegerValue
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearContainerProps(
) → void -
clearContentPadding(
) → void -
clearCountTextStyle(
) → void -
clearDecrementIconValue(
) → void -
clearDisabledColorValue(
) → void -
clearDisplayValue(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearIncrementIconValue(
) → void -
clearInitialCountValue(
) → void -
clearLegacyDecrementIcon(
) → void -
clearLegacyDisabledColor(
) → void -
clearLegacyIncrementIcon(
) → void -
clearLegacyInitialCount(
) → void -
clearLegacyMaximum(
) → void -
clearLegacyMinimum(
) → void -
clearLegacyStepSize(
) → void -
clearMaximumValue(
) → void -
clearMinimumValue(
) → void -
clearStepSizeValue(
) → void -
clone(
) → FFCountController -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFCountController)) → FFCountController -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFCountController -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureContainerProps(
) → FFContainer -
ensureContentPadding(
) → FFPadding -
ensureCountTextStyle(
) → FFText -
ensureDecrementIconValue(
) → FFIconValue -
ensureDisabledColorValue(
) → FFColorValue -
ensureIncrementIconValue(
) → FFIconValue -
ensureInitialCountValue(
) → FFIntegerValue -
ensureLegacyDecrementIcon(
) → FFIcon -
ensureLegacyDisabledColor(
) → FFColor -
ensureLegacyIncrementIcon(
) → FFIcon -
ensureMaximumValue(
) → FFIntegerValue -
ensureMinimumValue(
) → FFIntegerValue -
ensureStepSizeValue(
) → FFIntegerValue -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasContainerProps(
) → bool -
hasContentPadding(
) → bool -
hasCountTextStyle(
) → bool -
hasDecrementIconValue(
) → bool -
hasDisabledColorValue(
) → bool -
hasDisplayValue(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasIncrementIconValue(
) → bool -
hasInitialCountValue(
) → bool -
hasLegacyDecrementIcon(
) → bool -
hasLegacyDisabledColor(
) → bool -
hasLegacyIncrementIcon(
) → bool -
hasLegacyInitialCount(
) → bool -
hasLegacyMaximum(
) → bool -
hasLegacyMinimum(
) → bool -
hasLegacyStepSize(
) → bool -
hasMaximumValue(
) → bool -
hasMinimumValue(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasStepSizeValue(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited