isGlobal property
@doc Whether to align the dialog with respect to the target widget which triggered the open dialog action.
Implementation
@$pb.TagNumber(8)
$core.bool get isGlobal => $_getBF(7);
@doc Whether to align the dialog with respect to the target widget which triggered the open dialog action.
@$pb.TagNumber(8)
$core.bool get isGlobal => $_getBF(7);