mostRecentInputValue property
@doc Stores the most recent double this value was set to in order to restore after removing a variable.
Implementation
@$pb.TagNumber(3)
$core.double get mostRecentInputValue => $_getN(2);
@doc Stores the most recent double this value was set to in order to restore after removing a variable.
@$pb.TagNumber(3)
$core.double get mostRecentInputValue => $_getN(2);