ignoreChildren property

  1. @TagNumber(4)
bool get ignoreChildren

By default, when we accept a node edit we accept it's new children as well. If this is set to true we will keep the old children on the updated node.

Implementation

@$pb.TagNumber(4)
$core.bool get ignoreChildren => $_getBF(3);
  1. @TagNumber(4)
set ignoreChildren (bool value)

Implementation

@$pb.TagNumber(4)
set ignoreChildren($core.bool value) => $_setBool(3, value);