nodeUpdateTime property

  1. @TagNumber(6)
Int64 get nodeUpdateTime

Used to mark that when a node was updated directly, and did not simply change as a result of an indirect change elsewhere in the project. These edits are given priority even if they occurred slightly before another.

Implementation

@$pb.TagNumber(6)
$fixnum.Int64 get nodeUpdateTime => $_getI64(5);
  1. @TagNumber(6)
set nodeUpdateTime (Int64 value)

Implementation

@$pb.TagNumber(6)
set nodeUpdateTime($fixnum.Int64 value) => $_setInt64(5, value);