uploadVariableNodeKey property

  1. @TagNumber(7)
String get uploadVariableNodeKey

As above, replace when we do state management. For now, this is the key of the node on which there is an upload variable action. Fails if there are none, and there should never be multiple.

Implementation

@$pb.TagNumber(7)
$core.String get uploadVariableNodeKey => $_getSZ(6);
  1. @TagNumber(7)
set uploadVariableNodeKey (String value)

Implementation

@$pb.TagNumber(7)
set uploadVariableNodeKey($core.String value) => $_setString(6, value);