onAuth property
@doc Whether to log an event when a user interacts with authentication in the form of signup, login, logout, reset password, or delete account.
Implementation
@$pb.TagNumber(4)
$core.bool get onAuth => $_getBF(3);
@doc Whether to log an event when a user interacts with authentication in the form of signup, login, logout, reset password, or delete account.
@$pb.TagNumber(4)
$core.bool get onAuth => $_getBF(3);