showBorderAroundRadioButtonAndText property
@doc Controls whether the focus border wraps both the radio button and its text label. If true (default), the focus border will wrap both the radio button and its text label.
Implementation
@$pb.TagNumber(6)
$core.bool get showBorderAroundRadioButtonAndText => $_getBF(5);