wrapInFocusGroup property
@doc Whether to wrap this widget in a FocusTraversalGroup. When enabled, this widget and its descendants will be wrapped in a FocusTraversalGroup, which allows for more granular control over how keyboard focus moves through the UI. Focus can still move between different FocusTraversalGroups based on the focus traversal order.
Implementation
@$pb.TagNumber(1)
$core.bool get wrapInFocusGroup => $_getBF(0);