FFGoogleMap class
- Inheritance
-
- Object
- GeneratedMessage
- FFGoogleMap
- Available extensions
Constructors
- FFGoogleMap({FFLatLng? legacyInitialLocation, @Deprecated('This field is deprecated.') FFMapDocumentMarkers? legacyDocMarkers, @Deprecated('This field is deprecated.') FFMapDocumentMarker? legacySingleDocMarker, FFGoogleMap_FFGoogleMarkerColor? markerColor, FFGoogleMap_FFGoogleMapType? mapType, FFGoogleMap_FFGoogleMapStyle? mapStyle, double? legacyInitialZoom, bool? allowInteraction, bool? allowZoom, bool? showZoomControls, bool? legacyShowLocation, bool? legacyShowCompass, bool? legacyShowMapToolbar, bool? legacyShowTraffic, bool? legacyCenterMapOnMarkerTap, bool? updatePageOnMapMove, FFGoogleMap_FFMarkerType? markerType, @Deprecated('This field is deprecated.') FFMapLatLngMarkers? legacyLatLngMarkers, @Deprecated('This field is deprecated.') FFMapLatLngMarker? legacySingleLatLngMarker, FFGoogleMap_FFMarkerIcon? markerIcon, FFImage? markerImage, FFLatLngValue? initialLocationValue, FFDoubleValue? initialZoomValue, FFBooleanValue? showLocationValue, FFBooleanValue? showCompassValue, FFBooleanValue? showMapToolbarValue, FFBooleanValue? showTrafficValue, FFBooleanValue? centerMapOnMarkerTapValue, FFVariable? docMarkers, FFVariable? singleDocMarker, FFVariable? latLngMarkers, FFVariable? singleLatLngMarker, FFBooleanValue? mapTakesGesturePreference})
-
factory
-
FFGoogleMap.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFGoogleMap.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- allowInteraction ↔ bool
-
Should not be overridable
@doc Whether to allow panning the map.
getter/setter pair
- allowZoom ↔ bool
-
Should not be overridable
@doc Whether to allow zooming on the map.
getter/setter pair
- centerMapOnMarkerTapValue ↔ FFBooleanValue
-
@doc Whether to center the map when marker is tapped.
getter/setter pair
- docMarkers ↔ FFVariable
-
For overrides on Multiple Document markers.
@doc If set, the map will display multiple markers from documents.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setteroverride
- initialLocationValue ↔ FFLatLngValue
-
@doc The initial center location of the map.
getter/setter pair
- initialZoomValue ↔ FFDoubleValue
-
@doc The initial zoom level of the map.
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - latLngMarkers ↔ FFVariable
-
For overrides on Multiple LatLng markers.
@doc If set, the map will display multiple markers from lat/lng values.
getter/setter pair
- legacyCenterMapOnMarkerTap ↔ bool
-
getter/setter pair
- legacyDocMarkers ↔ FFMapDocumentMarkers
-
For overrides on Multiple Document markers.
getter/setter pair
- legacyInitialLocation ↔ FFLatLng
-
getter/setter pair
- legacyInitialZoom ↔ double
-
getter/setter pair
- legacyLatLngMarkers ↔ FFMapLatLngMarkers
-
For overrides on Multiple LatLng markers.
getter/setter pair
- legacyShowCompass ↔ bool
-
getter/setter pair
- legacyShowLocation ↔ bool
-
getter/setter pair
- legacyShowMapToolbar ↔ bool
-
getter/setter pair
- legacyShowTraffic ↔ bool
-
getter/setter pair
- legacySingleDocMarker ↔ FFMapDocumentMarker
-
For overrides on a Single Document marker.
getter/setter pair
- legacySingleLatLngMarker ↔ FFMapLatLngMarker
-
For overrides on a Single LatLng marker.
getter/setter pair
- mapStyle ↔ FFGoogleMap_FFGoogleMapStyle
-
@doc The rendering style of the basemap.
AUBERGINE, RETRO.
getter/setter pair
- mapTakesGesturePreference ↔ FFBooleanValue
-
@doc Whether the map takes gesture preference, such as when
the map is within a scrollable Widget.
getter/setter pair
- mapType ↔ FFGoogleMap_FFGoogleMapType
-
@doc The rendering type of the basemap.
getter/setter pair
- markerColor ↔ FFGoogleMap_FFGoogleMarkerColor
-
@doc (If using default marker icon) the color of the marker.
getter/setter pair
- markerIcon ↔ FFGoogleMap_FFMarkerIcon
-
@doc The icon type of the markers.
getter/setter pair
- markerImage ↔ FFImage
-
@doc (If using image marker icon) the image of the marker.
getter/setter pair
- markerType ↔ FFGoogleMap_FFMarkerType
-
@doc The source type of the markers.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCompassValue ↔ FFBooleanValue
-
@doc Whether to show the compass on the map.
getter/setter pair
- showLocationValue ↔ FFBooleanValue
-
@doc Whether to show the user's location on the map.
getter/setter pair
- showMapToolbarValue ↔ FFBooleanValue
-
@doc Whether to show the map toolbar on the map.
getter/setter pair
- showTrafficValue ↔ FFBooleanValue
-
@doc Whether to show the traffic layer on the map.
getter/setter pair
- showZoomControls ↔ bool
-
Should not be overridable
@doc Whether to show the zoom controls on the map.
getter/setter pair
- singleDocMarker ↔ FFVariable
-
For overrides on a Single Document marker.
@doc If set, the map will display a single marker from the document.
getter/setter pair
- singleLatLngMarker ↔ FFVariable
-
For overrides on a Single LatLng marker.
@doc If set, the map will display a single marker from the lat/lng value.
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- updatePageOnMapMove ↔ bool
-
Should not be overridable
@doc Whether to update page when map is moved.
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAllowInteraction(
) → void -
clearAllowZoom(
) → void -
clearCenterMapOnMarkerTapValue(
) → void -
clearDocMarkers(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearInitialLocationValue(
) → void -
clearInitialZoomValue(
) → void -
clearLatLngMarkers(
) → void -
clearLegacyCenterMapOnMarkerTap(
) → void -
clearLegacyDocMarkers(
) → void -
clearLegacyInitialLocation(
) → void -
clearLegacyInitialZoom(
) → void -
clearLegacyLatLngMarkers(
) → void -
clearLegacyMarkerSource(
) → void -
clearLegacyShowCompass(
) → void -
clearLegacyShowLocation(
) → void -
clearLegacyShowMapToolbar(
) → void -
clearLegacyShowTraffic(
) → void -
clearLegacySingleDocMarker(
) → void -
clearLegacySingleLatLngMarker(
) → void -
clearMapStyle(
) → void -
clearMapTakesGesturePreference(
) → void -
clearMapType(
) → void -
clearMarkerColor(
) → void -
clearMarkerIcon(
) → void -
clearMarkerImage(
) → void -
clearMarkerSource(
) → void -
clearMarkerType(
) → void -
clearShowCompassValue(
) → void -
clearShowLocationValue(
) → void -
clearShowMapToolbarValue(
) → void -
clearShowTrafficValue(
) → void -
clearShowZoomControls(
) → void -
clearSingleDocMarker(
) → void -
clearSingleLatLngMarker(
) → void -
clearUpdatePageOnMapMove(
) → void -
clone(
) → FFGoogleMap -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFGoogleMap)) → FFGoogleMap -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFGoogleMap -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureCenterMapOnMarkerTapValue(
) → FFBooleanValue -
ensureDocMarkers(
) → FFVariable -
ensureInitialLocationValue(
) → FFLatLngValue -
ensureInitialZoomValue(
) → FFDoubleValue -
ensureLatLngMarkers(
) → FFVariable -
ensureLegacyDocMarkers(
) → FFMapDocumentMarkers -
ensureLegacyInitialLocation(
) → FFLatLng -
ensureLegacyLatLngMarkers(
) → FFMapLatLngMarkers -
ensureLegacySingleDocMarker(
) → FFMapDocumentMarker -
ensureLegacySingleLatLngMarker(
) → FFMapLatLngMarker -
ensureMapTakesGesturePreference(
) → FFBooleanValue -
ensureMarkerImage(
) → FFImage -
ensureShowCompassValue(
) → FFBooleanValue -
ensureShowLocationValue(
) → FFBooleanValue -
ensureShowMapToolbarValue(
) → FFBooleanValue -
ensureShowTrafficValue(
) → FFBooleanValue -
ensureSingleDocMarker(
) → FFVariable -
ensureSingleLatLngMarker(
) → FFVariable -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAllowInteraction(
) → bool -
hasAllowZoom(
) → bool -
hasCenterMapOnMarkerTapValue(
) → bool -
hasDocMarkers(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasInitialLocationValue(
) → bool -
hasInitialZoomValue(
) → bool -
hasLatLngMarkers(
) → bool -
hasLegacyCenterMapOnMarkerTap(
) → bool -
hasLegacyDocMarkers(
) → bool -
hasLegacyInitialLocation(
) → bool -
hasLegacyInitialZoom(
) → bool -
hasLegacyLatLngMarkers(
) → bool -
hasLegacyShowCompass(
) → bool -
hasLegacyShowLocation(
) → bool -
hasLegacyShowMapToolbar(
) → bool -
hasLegacyShowTraffic(
) → bool -
hasLegacySingleDocMarker(
) → bool -
hasLegacySingleLatLngMarker(
) → bool -
hasMapStyle(
) → bool -
hasMapTakesGesturePreference(
) → bool -
hasMapType(
) → bool -
hasMarkerColor(
) → bool -
hasMarkerIcon(
) → bool -
hasMarkerImage(
) → bool -
hasMarkerType(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasShowCompassValue(
) → bool -
hasShowLocationValue(
) → bool -
hasShowMapToolbarValue(
) → bool -
hasShowTrafficValue(
) → bool -
hasShowZoomControls(
) → bool -
hasSingleDocMarker(
) → bool -
hasSingleLatLngMarker(
) → bool -
hasUpdatePageOnMapMove(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
whichLegacyMarkerSource(
) → FFGoogleMap_LegacyMarkerSource -
whichMarkerSource(
) → FFGoogleMap_MarkerSource -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → FFGoogleMap -
getDefault(
) → FFGoogleMap