libraryValues property
The values set in the main project when it imports a library that has library_parameters set @doc The list of library values that are set in the project that imports a @doc library
Implementation
@$pb.TagNumber(2)
$pb.PbList<FFLibraryValue> get libraryValues => $_getList(1);