applyStartEndSpace property
@doc If true, the spacing value will also be applied to the start and end of the list.
Implementation
@$pb.TagNumber(2)
$core.bool get applyStartEndSpace => $_getBF(1);
@doc If true, the spacing value will also be applied to the start and end of the list.
@$pb.TagNumber(2)
$core.bool get applyStartEndSpace => $_getBF(1);