widgetDisabledCondition property
@doc When this condition is true, the widget is excluded from keyboard focus traversal and the focus border will not appear.
Implementation
@$pb.TagNumber(34)
FFBooleanValue get widgetDisabledCondition => $_getN(32);
Implementation
@$pb.TagNumber(34)
set widgetDisabledCondition(FFBooleanValue value) => $_setField(34, value);