FFPaginatedDataTable class
- Inheritance
-
- Object
- GeneratedMessage
- FFPaginatedDataTable
- Available extensions
Constructors
- FFPaginatedDataTable({int? legacyNumColumns, int? legacyNumRows, bool? paginated, bool? selectable, bool? legacyHidePaginator, bool? legacyShowFirstLastButtons, FFDimensions? dimensions, FFDim? minWidth, double? legacyHeadingRowHeight, double? legacyDataRowHeight, double? legacyColumnSpacing, FFColor? legacyHeadingRowColor, FFColor? legacyRowColor, FFColor? legacyAlternateRowColor, FFColor? legacySortIconColor, FFBorderRadius? borderRadius, bool? legacyAddHorizontalDivider, FFColor? legacyHorizontalDividerColor, double? legacyHorizontalDividerThickness, bool? legacyAddVerticalDivider, FFColor? legacyVerticalDividerColor, double? legacyVerticalDividerThickness, FFColor? legacyCheckboxUnselectedFillColor, FFColor? legacyCheckboxSelectedFillColor, FFColor? legacyCheckboxUnselectedBorderColor, FFColor? legacyCheckboxSelectedBorderColor, FFColor? legacyCheckboxCheckColor, int? displayNumRows, int? displayNumColumns, bool? legacyAddTopAndBottomDivider, bool? legacyHideDefaultHorizontalDivider, bool? rebuildPageOnSelect, FFIntegerValue? numColumnsValue, FFIntegerValue? numRowsValue, FFBooleanValue? hidePaginatorValue, FFBooleanValue? showFirstLastButtonsValue, FFDoubleValue? headingRowHeightValue, FFDoubleValue? dataRowHeightValue, FFDoubleValue? columnSpacingValue, FFColorValue? headingRowColorValue, FFColorValue? rowColorValue, FFColorValue? alternateRowColorValue, FFColorValue? sortIconColorValue, FFBooleanValue? addHorizontalDividerValue, FFBooleanValue? addTopAndBottomDividerValue, FFBooleanValue? hideDefaultHorizontalDividerValue, FFColorValue? horizontalDividerColorValue, FFDoubleValue? horizontalDividerThicknessValue, FFBooleanValue? addVerticalDividerValue, FFColorValue? verticalDividerColorValue, FFDoubleValue? verticalDividerThicknessValue, FFColorValue? checkboxUnselectedFillColorValue, FFColorValue? checkboxSelectedFillColorValue, FFColorValue? checkboxUnselectedBorderColorValue, FFColorValue? checkboxSelectedBorderColorValue, FFColorValue? checkboxCheckColorValue})
-
factory
-
FFPaginatedDataTable.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFPaginatedDataTable.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- addHorizontalDividerValue ↔ FFBooleanValue
-
getter/setter pair
- addTopAndBottomDividerValue ↔ FFBooleanValue
-
getter/setter pair
- addVerticalDividerValue ↔ FFBooleanValue
-
getter/setter pair
- alternateRowColorValue ↔ FFColorValue
-
getter/setter pair
- borderRadius ↔ FFBorderRadius
-
getter/setter pair
- checkboxCheckColorValue ↔ FFColorValue
-
getter/setter pair
- checkboxSelectedBorderColorValue ↔ FFColorValue
-
getter/setter pair
- checkboxSelectedFillColorValue ↔ FFColorValue
-
getter/setter pair
- checkboxUnselectedBorderColorValue ↔ FFColorValue
-
getter/setter pair
- checkboxUnselectedFillColorValue ↔ FFColorValue
-
getter/setter pair
- columnSpacingValue ↔ FFDoubleValue
-
getter/setter pair
- dataRowHeightValue ↔ FFDoubleValue
-
getter/setter pair
- dimensions ↔ FFDimensions
-
Size and shape options
getter/setter pair
- displayNumColumns ↔ int
-
getter/setter pair
- displayNumRows ↔ int
-
UI Builder options
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- headingRowColorValue ↔ FFColorValue
-
getter/setter pair
- headingRowHeightValue ↔ FFDoubleValue
-
getter/setter pair
- hideDefaultHorizontalDividerValue ↔ FFBooleanValue
-
getter/setter pair
- hidePaginatorValue ↔ FFBooleanValue
-
getter/setter pair
- horizontalDividerColorValue ↔ FFColorValue
-
getter/setter pair
- horizontalDividerThicknessValue ↔ FFDoubleValue
-
getter/setter pair
- info_ → BuilderInfo
-
no setteroverride
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - legacyAddHorizontalDivider ↔ bool
-
getter/setter pair
- legacyAddTopAndBottomDivider ↔ bool
-
getter/setter pair
- legacyAddVerticalDivider ↔ bool
-
getter/setter pair
- legacyAlternateRowColor ↔ FFColor
-
getter/setter pair
- legacyCheckboxCheckColor ↔ FFColor
-
getter/setter pair
- legacyCheckboxSelectedBorderColor ↔ FFColor
-
getter/setter pair
- legacyCheckboxSelectedFillColor ↔ FFColor
-
getter/setter pair
- legacyCheckboxUnselectedBorderColor ↔ FFColor
-
getter/setter pair
- legacyCheckboxUnselectedFillColor ↔ FFColor
-
Checkbox style options
getter/setter pair
- legacyColumnSpacing ↔ double
-
getter/setter pair
- legacyDataRowHeight ↔ double
-
getter/setter pair
- legacyHeadingRowColor ↔ FFColor
-
Style options
getter/setter pair
- legacyHeadingRowHeight ↔ double
-
getter/setter pair
- legacyHideDefaultHorizontalDivider ↔ bool
-
getter/setter pair
- legacyHidePaginator ↔ bool
-
getter/setter pair
- legacyHorizontalDividerColor ↔ FFColor
-
getter/setter pair
- legacyHorizontalDividerThickness ↔ double
-
getter/setter pair
- legacyNumColumns ↔ int
-
getter/setter pair
- legacyNumRows ↔ int
-
getter/setter pair
- legacyRowColor ↔ FFColor
-
getter/setter pair
- legacyShowFirstLastButtons ↔ bool
-
getter/setter pair
- legacySortIconColor ↔ FFColor
-
getter/setter pair
- legacyVerticalDividerColor ↔ FFColor
-
getter/setter pair
- legacyVerticalDividerThickness ↔ double
-
getter/setter pair
- minWidth ↔ FFDim
-
getter/setter pair
- numColumnsValue ↔ FFIntegerValue
-
getter/setter pair
- numRowsValue ↔ FFIntegerValue
-
getter/setter pair
- paginated ↔ bool
-
Functionality options
getter/setter pair
- rebuildPageOnSelect ↔ bool
-
getter/setter pair
- rowColorValue ↔ FFColorValue
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectable ↔ bool
-
getter/setter pair
- showFirstLastButtonsValue ↔ FFBooleanValue
-
getter/setter pair
- sortIconColorValue ↔ FFColorValue
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- verticalDividerColorValue ↔ FFColorValue
-
getter/setter pair
- verticalDividerThicknessValue ↔ FFDoubleValue
-
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAddHorizontalDividerValue(
) → void -
clearAddTopAndBottomDividerValue(
) → void -
clearAddVerticalDividerValue(
) → void -
clearAlternateRowColorValue(
) → void -
clearBorderRadius(
) → void -
clearCheckboxCheckColorValue(
) → void -
clearCheckboxSelectedBorderColorValue(
) → void -
clearCheckboxSelectedFillColorValue(
) → void -
clearCheckboxUnselectedBorderColorValue(
) → void -
clearCheckboxUnselectedFillColorValue(
) → void -
clearColumnSpacingValue(
) → void -
clearDataRowHeightValue(
) → void -
clearDimensions(
) → void -
clearDisplayNumColumns(
) → void -
clearDisplayNumRows(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearHeadingRowColorValue(
) → void -
clearHeadingRowHeightValue(
) → void -
clearHideDefaultHorizontalDividerValue(
) → void -
clearHidePaginatorValue(
) → void -
clearHorizontalDividerColorValue(
) → void -
clearHorizontalDividerThicknessValue(
) → void -
clearLegacyAddHorizontalDivider(
) → void -
clearLegacyAddTopAndBottomDivider(
) → void -
clearLegacyAddVerticalDivider(
) → void -
clearLegacyAlternateRowColor(
) → void -
clearLegacyCheckboxCheckColor(
) → void -
clearLegacyCheckboxSelectedBorderColor(
) → void -
clearLegacyCheckboxSelectedFillColor(
) → void -
clearLegacyCheckboxUnselectedBorderColor(
) → void -
clearLegacyCheckboxUnselectedFillColor(
) → void -
clearLegacyColumnSpacing(
) → void -
clearLegacyDataRowHeight(
) → void -
clearLegacyHeadingRowColor(
) → void -
clearLegacyHeadingRowHeight(
) → void -
clearLegacyHideDefaultHorizontalDivider(
) → void -
clearLegacyHidePaginator(
) → void -
clearLegacyHorizontalDividerColor(
) → void -
clearLegacyHorizontalDividerThickness(
) → void -
clearLegacyNumColumns(
) → void -
clearLegacyNumRows(
) → void -
clearLegacyRowColor(
) → void -
clearLegacyShowFirstLastButtons(
) → void -
clearLegacySortIconColor(
) → void -
clearLegacyVerticalDividerColor(
) → void -
clearLegacyVerticalDividerThickness(
) → void -
clearMinWidth(
) → void -
clearNumColumnsValue(
) → void -
clearNumRowsValue(
) → void -
clearPaginated(
) → void -
clearRebuildPageOnSelect(
) → void -
clearRowColorValue(
) → void -
clearSelectable(
) → void -
clearShowFirstLastButtonsValue(
) → void -
clearSortIconColorValue(
) → void -
clearVerticalDividerColorValue(
) → void -
clearVerticalDividerThicknessValue(
) → void -
clone(
) → FFPaginatedDataTable -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFPaginatedDataTable)) → FFPaginatedDataTable -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFPaginatedDataTable -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAddHorizontalDividerValue(
) → FFBooleanValue -
ensureAddTopAndBottomDividerValue(
) → FFBooleanValue -
ensureAddVerticalDividerValue(
) → FFBooleanValue -
ensureAlternateRowColorValue(
) → FFColorValue -
ensureBorderRadius(
) → FFBorderRadius -
ensureCheckboxCheckColorValue(
) → FFColorValue -
ensureCheckboxSelectedBorderColorValue(
) → FFColorValue -
ensureCheckboxSelectedFillColorValue(
) → FFColorValue -
ensureCheckboxUnselectedBorderColorValue(
) → FFColorValue -
ensureCheckboxUnselectedFillColorValue(
) → FFColorValue -
ensureColumnSpacingValue(
) → FFDoubleValue -
ensureDataRowHeightValue(
) → FFDoubleValue -
ensureDimensions(
) → FFDimensions -
ensureHeadingRowColorValue(
) → FFColorValue -
ensureHeadingRowHeightValue(
) → FFDoubleValue -
ensureHideDefaultHorizontalDividerValue(
) → FFBooleanValue -
ensureHidePaginatorValue(
) → FFBooleanValue -
ensureHorizontalDividerColorValue(
) → FFColorValue -
ensureHorizontalDividerThicknessValue(
) → FFDoubleValue -
ensureLegacyAlternateRowColor(
) → FFColor -
ensureLegacyCheckboxCheckColor(
) → FFColor -
ensureLegacyCheckboxSelectedBorderColor(
) → FFColor -
ensureLegacyCheckboxSelectedFillColor(
) → FFColor -
ensureLegacyCheckboxUnselectedBorderColor(
) → FFColor -
ensureLegacyCheckboxUnselectedFillColor(
) → FFColor -
ensureLegacyHeadingRowColor(
) → FFColor -
ensureLegacyHorizontalDividerColor(
) → FFColor -
ensureLegacyRowColor(
) → FFColor -
ensureLegacySortIconColor(
) → FFColor -
ensureLegacyVerticalDividerColor(
) → FFColor -
ensureMinWidth(
) → FFDim -
ensureNumColumnsValue(
) → FFIntegerValue -
ensureNumRowsValue(
) → FFIntegerValue -
ensureRowColorValue(
) → FFColorValue -
ensureShowFirstLastButtonsValue(
) → FFBooleanValue -
ensureSortIconColorValue(
) → FFColorValue -
ensureVerticalDividerColorValue(
) → FFColorValue -
ensureVerticalDividerThicknessValue(
) → FFDoubleValue -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAddHorizontalDividerValue(
) → bool -
hasAddTopAndBottomDividerValue(
) → bool -
hasAddVerticalDividerValue(
) → bool -
hasAlternateRowColorValue(
) → bool -
hasBorderRadius(
) → bool -
hasCheckboxCheckColorValue(
) → bool -
hasCheckboxSelectedBorderColorValue(
) → bool -
hasCheckboxSelectedFillColorValue(
) → bool -
hasCheckboxUnselectedBorderColorValue(
) → bool -
hasCheckboxUnselectedFillColorValue(
) → bool -
hasColumnSpacingValue(
) → bool -
hasDataRowHeightValue(
) → bool -
hasDimensions(
) → bool -
hasDisplayNumColumns(
) → bool -
hasDisplayNumRows(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasHeadingRowColorValue(
) → bool -
hasHeadingRowHeightValue(
) → bool -
hasHideDefaultHorizontalDividerValue(
) → bool -
hasHidePaginatorValue(
) → bool -
hasHorizontalDividerColorValue(
) → bool -
hasHorizontalDividerThicknessValue(
) → bool -
hasLegacyAddHorizontalDivider(
) → bool -
hasLegacyAddTopAndBottomDivider(
) → bool -
hasLegacyAddVerticalDivider(
) → bool -
hasLegacyAlternateRowColor(
) → bool -
hasLegacyCheckboxCheckColor(
) → bool -
hasLegacyCheckboxSelectedBorderColor(
) → bool -
hasLegacyCheckboxSelectedFillColor(
) → bool -
hasLegacyCheckboxUnselectedBorderColor(
) → bool -
hasLegacyCheckboxUnselectedFillColor(
) → bool -
hasLegacyColumnSpacing(
) → bool -
hasLegacyDataRowHeight(
) → bool -
hasLegacyHeadingRowColor(
) → bool -
hasLegacyHeadingRowHeight(
) → bool -
hasLegacyHideDefaultHorizontalDivider(
) → bool -
hasLegacyHidePaginator(
) → bool -
hasLegacyHorizontalDividerColor(
) → bool -
hasLegacyHorizontalDividerThickness(
) → bool -
hasLegacyNumColumns(
) → bool -
hasLegacyNumRows(
) → bool -
hasLegacyRowColor(
) → bool -
hasLegacyShowFirstLastButtons(
) → bool -
hasLegacySortIconColor(
) → bool -
hasLegacyVerticalDividerColor(
) → bool -
hasLegacyVerticalDividerThickness(
) → bool -
hasMinWidth(
) → bool -
hasNumColumnsValue(
) → bool -
hasNumRowsValue(
) → bool -
hasPaginated(
) → bool -
hasRebuildPageOnSelect(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasRowColorValue(
) → bool -
hasSelectable(
) → bool -
hasShowFirstLastButtonsValue(
) → bool -
hasSortIconColorValue(
) → bool -
hasVerticalDividerColorValue(
) → bool -
hasVerticalDividerThicknessValue(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited