updateContainingClassOnSetState property
Only applicable to components. Determines whether or not to update the containing page or component when this component updates its state.
Implementation
@$pb.TagNumber(4)
$core.bool get updateContainingClassOnSetState => $_getBF(3);