FFPinCode class
- Inheritance
-
- Object
- GeneratedMessage
- FFPinCode
- Available extensions
Constructors
- FFPinCode({int? legacyLength, FFText? textStyle, FFMainAxisAlignment? mainAxisAlignment, bool? legacyEnableActiveFill, double? legacyFieldHeight, double? legacyFieldWidth, double? legacyBorderWidth, FFPinCode_FFPinCodeFieldShape? shape, bool? autoFocus, FFColor? legacyActiveColor, FFColor? legacySelectedColor, FFColor? legacyInactiveColor, bool? showCursor, FFColor? legacyCursorColor, double? legacyBorderRadius, bool? legacyObscureText, String? legacyObscuringCharacter, bool? hintText, String? legacyHintCharacter, bool? autoFill, double? errorTextSpace, FFTextInputType? keyboardType, FFIntegerValue? lengthValue, FFBooleanValue? enableActiveFillValue, FFDoubleValue? fieldHeightValue, FFDoubleValue? fieldWidthValue, FFDoubleValue? borderWidthValue, FFColorValue? activeColorValue, FFColorValue? selectedColorValue, FFColorValue? inactiveColorValue, FFColorValue? cursorColorValue, FFDoubleValue? borderRadiusValue, FFBooleanValue? obscureTextValue, FFStringValue? obscuringCharacterValue, FFStringValue? hintCharacterValue, FFColor? legacyActiveFillColor, FFColorValue? activeFillColorValue, FFColor? legacySelectedFillColor, FFColorValue? selectedFillColorValue, FFColor? legacyInactiveFillColor, FFColorValue? inactiveFillColorValue, FFBooleanValue? blinkWhenObscuringValue, FFIntegerValue? blinkDurationValue})
-
factory
-
FFPinCode.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFPinCode.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- activeColorValue ↔ FFColorValue
-
getter/setter pair
- activeFillColorValue ↔ FFColorValue
-
getter/setter pair
- autoFill ↔ bool
-
Not overridable
getter/setter pair
- autoFocus ↔ bool
-
Not overridable
getter/setter pair
- blinkDurationValue ↔ FFIntegerValue
-
getter/setter pair
- blinkWhenObscuringValue ↔ FFBooleanValue
-
getter/setter pair
- borderRadiusValue ↔ FFDoubleValue
-
getter/setter pair
- borderWidthValue ↔ FFDoubleValue
-
getter/setter pair
- cursorColorValue ↔ FFColorValue
-
getter/setter pair
- enableActiveFillValue ↔ FFBooleanValue
-
getter/setter pair
- errorTextSpace ↔ double
-
Not overridable
getter/setter pair
- fieldHeightValue ↔ FFDoubleValue
-
getter/setter pair
- fieldWidthValue ↔ FFDoubleValue
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- hintCharacterValue ↔ FFStringValue
-
Not overridable at the moment
getter/setter pair
- hintText ↔ bool
-
Not overridable
getter/setter pair
- inactiveColorValue ↔ FFColorValue
-
getter/setter pair
- inactiveFillColorValue ↔ FFColorValue
-
getter/setter pair
- info_ → BuilderInfo
-
no setteroverride
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - keyboardType ↔ FFTextInputType
-
getter/setter pair
- legacyActiveColor ↔ FFColor
-
getter/setter pair
- legacyActiveFillColor ↔ FFColor
-
getter/setter pair
- legacyBorderRadius ↔ double
-
getter/setter pair
- legacyBorderWidth ↔ double
-
getter/setter pair
- legacyCursorColor ↔ FFColor
-
getter/setter pair
- legacyEnableActiveFill ↔ bool
-
getter/setter pair
- legacyFieldHeight ↔ double
-
getter/setter pair
- legacyFieldWidth ↔ double
-
getter/setter pair
- legacyHintCharacter ↔ String
-
getter/setter pair
- legacyInactiveColor ↔ FFColor
-
getter/setter pair
- legacyInactiveFillColor ↔ FFColor
-
getter/setter pair
- legacyLength ↔ int
-
getter/setter pair
- legacyObscureText ↔ bool
-
getter/setter pair
- legacyObscuringCharacter ↔ String
-
getter/setter pair
- legacySelectedColor ↔ FFColor
-
getter/setter pair
- legacySelectedFillColor ↔ FFColor
-
getter/setter pair
- lengthValue ↔ FFIntegerValue
-
getter/setter pair
- mainAxisAlignment ↔ FFMainAxisAlignment
-
getter/setter pair
- obscureTextValue ↔ FFBooleanValue
-
getter/setter pair
- obscuringCharacterValue ↔ FFStringValue
-
Not overridable at the moment
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedColorValue ↔ FFColorValue
-
getter/setter pair
- selectedFillColorValue ↔ FFColorValue
-
getter/setter pair
- shape ↔ FFPinCode_FFPinCodeFieldShape
-
getter/setter pair
- showCursor ↔ bool
-
getter/setter pair
- textStyle ↔ FFText
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearActiveColorValue(
) → void -
clearActiveFillColorValue(
) → void -
clearAutoFill(
) → void -
clearAutoFocus(
) → void -
clearBlinkDurationValue(
) → void -
clearBlinkWhenObscuringValue(
) → void -
clearBorderRadiusValue(
) → void -
clearBorderWidthValue(
) → void -
clearCursorColorValue(
) → void -
clearEnableActiveFillValue(
) → void -
clearErrorTextSpace(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearFieldHeightValue(
) → void -
clearFieldWidthValue(
) → void -
clearHintCharacterValue(
) → void -
clearHintText(
) → void -
clearInactiveColorValue(
) → void -
clearInactiveFillColorValue(
) → void -
clearKeyboardType(
) → void -
clearLegacyActiveColor(
) → void -
clearLegacyActiveFillColor(
) → void -
clearLegacyBorderRadius(
) → void -
clearLegacyBorderWidth(
) → void -
clearLegacyCursorColor(
) → void -
clearLegacyEnableActiveFill(
) → void -
clearLegacyFieldHeight(
) → void -
clearLegacyFieldWidth(
) → void -
clearLegacyHintCharacter(
) → void -
clearLegacyInactiveColor(
) → void -
clearLegacyInactiveFillColor(
) → void -
clearLegacyLength(
) → void -
clearLegacyObscureText(
) → void -
clearLegacyObscuringCharacter(
) → void -
clearLegacySelectedColor(
) → void -
clearLegacySelectedFillColor(
) → void -
clearLengthValue(
) → void -
clearMainAxisAlignment(
) → void -
clearObscureTextValue(
) → void -
clearObscuringCharacterValue(
) → void -
clearSelectedColorValue(
) → void -
clearSelectedFillColorValue(
) → void -
clearShape(
) → void -
clearShowCursor(
) → void -
clearTextStyle(
) → void -
clone(
) → FFPinCode -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFPinCode)) → FFPinCode -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFPinCode -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureActiveColorValue(
) → FFColorValue -
ensureActiveFillColorValue(
) → FFColorValue -
ensureBlinkDurationValue(
) → FFIntegerValue -
ensureBlinkWhenObscuringValue(
) → FFBooleanValue -
ensureBorderRadiusValue(
) → FFDoubleValue -
ensureBorderWidthValue(
) → FFDoubleValue -
ensureCursorColorValue(
) → FFColorValue -
ensureEnableActiveFillValue(
) → FFBooleanValue -
ensureFieldHeightValue(
) → FFDoubleValue -
ensureFieldWidthValue(
) → FFDoubleValue -
ensureHintCharacterValue(
) → FFStringValue -
ensureInactiveColorValue(
) → FFColorValue -
ensureInactiveFillColorValue(
) → FFColorValue -
ensureLegacyActiveColor(
) → FFColor -
ensureLegacyActiveFillColor(
) → FFColor -
ensureLegacyCursorColor(
) → FFColor -
ensureLegacyInactiveColor(
) → FFColor -
ensureLegacyInactiveFillColor(
) → FFColor -
ensureLegacySelectedColor(
) → FFColor -
ensureLegacySelectedFillColor(
) → FFColor -
ensureLengthValue(
) → FFIntegerValue -
ensureObscureTextValue(
) → FFBooleanValue -
ensureObscuringCharacterValue(
) → FFStringValue -
ensureSelectedColorValue(
) → FFColorValue -
ensureSelectedFillColorValue(
) → FFColorValue -
ensureTextStyle(
) → FFText -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasActiveColorValue(
) → bool -
hasActiveFillColorValue(
) → bool -
hasAutoFill(
) → bool -
hasAutoFocus(
) → bool -
hasBlinkDurationValue(
) → bool -
hasBlinkWhenObscuringValue(
) → bool -
hasBorderRadiusValue(
) → bool -
hasBorderWidthValue(
) → bool -
hasCursorColorValue(
) → bool -
hasEnableActiveFillValue(
) → bool -
hasErrorTextSpace(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasFieldHeightValue(
) → bool -
hasFieldWidthValue(
) → bool -
hasHintCharacterValue(
) → bool -
hasHintText(
) → bool -
hasInactiveColorValue(
) → bool -
hasInactiveFillColorValue(
) → bool -
hasKeyboardType(
) → bool -
hasLegacyActiveColor(
) → bool -
hasLegacyActiveFillColor(
) → bool -
hasLegacyBorderRadius(
) → bool -
hasLegacyBorderWidth(
) → bool -
hasLegacyCursorColor(
) → bool -
hasLegacyEnableActiveFill(
) → bool -
hasLegacyFieldHeight(
) → bool -
hasLegacyFieldWidth(
) → bool -
hasLegacyHintCharacter(
) → bool -
hasLegacyInactiveColor(
) → bool -
hasLegacyInactiveFillColor(
) → bool -
hasLegacyLength(
) → bool -
hasLegacyObscureText(
) → bool -
hasLegacyObscuringCharacter(
) → bool -
hasLegacySelectedColor(
) → bool -
hasLegacySelectedFillColor(
) → bool -
hasLengthValue(
) → bool -
hasMainAxisAlignment(
) → bool -
hasObscureTextValue(
) → bool -
hasObscuringCharacterValue(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSelectedColorValue(
) → bool -
hasSelectedFillColorValue(
) → bool -
hasShape(
) → bool -
hasShowCursor(
) → bool -
hasTextStyle(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → FFPinCode -
getDefault(
) → FFPinCode