timeoutMs property

  1. @TagNumber(2)
Int64 get timeoutMs

@doc If it takes longer that the given timeout to settle, then the test will fail (this method will throw an exception).

Implementation

@$pb.TagNumber(2)
$fixnum.Int64 get timeoutMs => $_getI64(1);
  1. @TagNumber(2)
set timeoutMs (Int64 value)

Implementation

@$pb.TagNumber(2)
set timeoutMs($fixnum.Int64 value) => $_setInt64(1, value);