loadDataAfterAppLaunch property
@doc Whether or not to immediately load all plan, purchase, and offering data before the app launches, or instead allow it to load slightly after.
Implementation
@$pb.TagNumber(5)
$core.bool get loadDataAfterAppLaunch => $_getBF(4);