useIntrinsicHeight property

  1. @TagNumber(7)
bool get useIntrinsicHeight

@doc If true, the row will be wrapped in an IntrinsicHeight widget, making all children match the height of the tallest child.

Implementation

@$pb.TagNumber(7)
$core.bool get useIntrinsicHeight => $_getBF(6);
  1. @TagNumber(7)
set useIntrinsicHeight (bool value)

Implementation

@$pb.TagNumber(7)
set useIntrinsicHeight($core.bool value) => $_setBool(6, value);