FFSettings class
- Inheritance
-
- Object
- GeneratedMessage
- FFSettings
- Available extensions
Constructors
-
FFSettings({String? appIconPath, FFSplashImage? splashImage, FFSharing? sharing, FFGoogleMapsApiKeys? googleMapsApiKeys, FFAdMobSettings? admobSettings, FFPaymentSettings? paymentSettings, @Deprecated('This field is deprecated.') FFCodemagicSettings? legacyCodemagicSettings, FFPushNotificationSettings? pushNotificationSettings, FFPermissionsSettings? permissionsSettings, FFPlatformSettings? platformSettings, FFEditMetadata? editMetadata, FFMuxBroadcastApiAccessTokens? muxBroadcastApiAccessTokens, @Deprecated('This field is deprecated.') FFWebSettings? legacyWebSettings, FFDatePickerSettings? datePickerSettings, FFInternationalizationSettings? internationalizationSettings, FFAccessibilitySettings? accessibilitySettings, bool? downloadUnusedAssets, FFAdvancedAppSettings? advancedSettings, String? errorImagePath, Iterable<
MapEntry< ? canvasSizeDefaults, FFOneSignalSettings? oneSignalSettings, FFMaterialThemeSettings? materialThemeSettings, FFGeminiSettings? geminiSettings, FFAndroidAdaptiveIcon? androidAdaptiveIcon, FFCanvasSettings? canvasSettings, FFEnvironmentSettings? environmentSettings, FFLibrarySettings? librarySettings, FFAllWebSettings? allWebSettings, FFAllCodemagicSettings? allCodemagicSettings, bool? checkCustomCodeReferences})String, FFCanvasProps> > -
factory
-
FFSettings.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFSettings.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- accessibilitySettings ↔ FFAccessibilitySettings
-
This isn't accessible from the UI, don't display in YAMLs
getter/setter pair
- admobSettings ↔ FFAdMobSettings
-
getter/setter pair
- advancedSettings ↔ FFAdvancedAppSettings
-
getter/setter pair
- allCodemagicSettings ↔ FFAllCodemagicSettings
-
codemagic settings, keyed by the environment
getter/setter pair
- allWebSettings ↔ FFAllWebSettings
-
@doc Settings for web related settings in the project.
getter/setter pair
- androidAdaptiveIcon ↔ FFAndroidAdaptiveIcon
-
getter/setter pair
- appIconPath ↔ String
-
getter/setter pair
- canvasSettings ↔ FFCanvasSettings
-
getter/setter pair
-
canvasSizeDefaults
→ PbMap<
String, FFCanvasProps> -
Enums are disallowed as map keys, so we use an enum on the Dart side.
no setter
- checkCustomCodeReferences ↔ bool
-
@doc Whether to check for custom code usage when viewing custom code.
getter/setter pair
- datePickerSettings ↔ FFDatePickerSettings
-
getter/setter pair
- downloadUnusedAssets ↔ bool
-
getter/setter pair
- editMetadata ↔ FFEditMetadata
-
getter/setter pair
- environmentSettings ↔ FFEnvironmentSettings
-
@doc Settings for environments in the project.
getter/setter pair
- errorImagePath ↔ String
-
getter/setter pair
- geminiSettings ↔ FFGeminiSettings
-
@doc Settings to enable and configure Gemini into the project.
getter/setter pair
- googleMapsApiKeys ↔ FFGoogleMapsApiKeys
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setteroverride
- internationalizationSettings ↔ FFInternationalizationSettings
-
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - legacyCodemagicSettings ↔ FFCodemagicSettings
-
getter/setter pair
- legacyWebSettings ↔ FFWebSettings
-
getter/setter pair
- librarySettings ↔ FFLibrarySettings
-
@doc Settings to configure/use library values
getter/setter pair
- materialThemeSettings ↔ FFMaterialThemeSettings
-
getter/setter pair
- muxBroadcastApiAccessTokens ↔ FFMuxBroadcastApiAccessTokens
-
getter/setter pair
- oneSignalSettings ↔ FFOneSignalSettings
-
@doc Settings to enable and configure OneSignal in the project.
getter/setter pair
- paymentSettings ↔ FFPaymentSettings
-
getter/setter pair
- permissionsSettings ↔ FFPermissionsSettings
-
getter/setter pair
- platformSettings ↔ FFPlatformSettings
-
getter/setter pair
- pushNotificationSettings ↔ FFPushNotificationSettings
-
@doc Settings for Firebase push notification.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
getter/setter pair
- splashImage ↔ FFSplashImage
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAccessibilitySettings(
) → void -
clearAdmobSettings(
) → void -
clearAdvancedSettings(
) → void -
clearAllCodemagicSettings(
) → void -
clearAllWebSettings(
) → void -
clearAndroidAdaptiveIcon(
) → void -
clearAppIconPath(
) → void -
clearCanvasSettings(
) → void -
clearCheckCustomCodeReferences(
) → void -
clearDatePickerSettings(
) → void -
clearDownloadUnusedAssets(
) → void -
clearEditMetadata(
) → void -
clearEnvironmentSettings(
) → void -
clearErrorImagePath(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearGeminiSettings(
) → void -
clearGoogleMapsApiKeys(
) → void -
clearInternationalizationSettings(
) → void -
clearLegacyCodemagicSettings(
) → void -
clearLegacyWebSettings(
) → void -
clearLibrarySettings(
) → void -
clearMaterialThemeSettings(
) → void -
clearMuxBroadcastApiAccessTokens(
) → void -
clearOneSignalSettings(
) → void -
clearPaymentSettings(
) → void -
clearPermissionsSettings(
) → void -
clearPlatformSettings(
) → void -
clearPushNotificationSettings(
) → void -
clearSharing(
) → void -
clearSplashImage(
) → void -
clone(
) → FFSettings -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFSettings)) → FFSettings -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFSettings -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAccessibilitySettings(
) → FFAccessibilitySettings -
ensureAdmobSettings(
) → FFAdMobSettings -
ensureAdvancedSettings(
) → FFAdvancedAppSettings -
ensureAllCodemagicSettings(
) → FFAllCodemagicSettings -
ensureAllWebSettings(
) → FFAllWebSettings -
ensureAndroidAdaptiveIcon(
) → FFAndroidAdaptiveIcon -
ensureCanvasSettings(
) → FFCanvasSettings -
ensureDatePickerSettings(
) → FFDatePickerSettings -
ensureEditMetadata(
) → FFEditMetadata -
ensureEnvironmentSettings(
) → FFEnvironmentSettings -
ensureGeminiSettings(
) → FFGeminiSettings -
ensureGoogleMapsApiKeys(
) → FFGoogleMapsApiKeys -
ensureInternationalizationSettings(
) → FFInternationalizationSettings -
ensureLegacyCodemagicSettings(
) → FFCodemagicSettings -
ensureLegacyWebSettings(
) → FFWebSettings -
ensureLibrarySettings(
) → FFLibrarySettings -
ensureMaterialThemeSettings(
) → FFMaterialThemeSettings -
ensureMuxBroadcastApiAccessTokens(
) → FFMuxBroadcastApiAccessTokens -
ensureOneSignalSettings(
) → FFOneSignalSettings -
ensurePaymentSettings(
) → FFPaymentSettings -
ensurePermissionsSettings(
) → FFPermissionsSettings -
ensurePlatformSettings(
) → FFPlatformSettings -
ensurePushNotificationSettings(
) → FFPushNotificationSettings -
ensureSharing(
) → FFSharing -
ensureSplashImage(
) → FFSplashImage -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAccessibilitySettings(
) → bool -
hasAdmobSettings(
) → bool -
hasAdvancedSettings(
) → bool -
hasAllCodemagicSettings(
) → bool -
hasAllWebSettings(
) → bool -
hasAndroidAdaptiveIcon(
) → bool -
hasAppIconPath(
) → bool -
hasCanvasSettings(
) → bool -
hasCheckCustomCodeReferences(
) → bool -
hasDatePickerSettings(
) → bool -
hasDownloadUnusedAssets(
) → bool -
hasEditMetadata(
) → bool -
hasEnvironmentSettings(
) → bool -
hasErrorImagePath(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasGeminiSettings(
) → bool -
hasGoogleMapsApiKeys(
) → bool -
hasInternationalizationSettings(
) → bool -
hasLegacyCodemagicSettings(
) → bool -
hasLegacyWebSettings(
) → bool -
hasLibrarySettings(
) → bool -
hasMaterialThemeSettings(
) → bool -
hasMuxBroadcastApiAccessTokens(
) → bool -
hasOneSignalSettings(
) → bool -
hasPaymentSettings(
) → bool -
hasPermissionsSettings(
) → bool -
hasPlatformSettings(
) → bool -
hasPushNotificationSettings(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSharing(
) → bool -
hasSplashImage(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → FFSettings -
getDefault(
) → FFSettings