FFShaderProperties class
- Inheritance
-
- Object
- GeneratedMessage
- FFShaderProperties
- Available extensions
Constructors
-
FFShaderProperties({FFStringValue? pathValue, FFSourceType? source, FFShaderMode? shaderMode, FFShaderPresetType? presetType, Iterable<
FFShaderParam> ? params, FFColorValue? backgroundColorValue, FFShaderAnimationMode? animationMode, FFBooleanValue? cacheValue, FFBooleanValue? interactiveValue, FFVariable? animationVariable, FFCurve? animationCurve, FFDoubleValue? animationDurationValue, FFDoubleValue? animationDelayValue, FFDoubleValue? timeValue, FFBooleanValue? persistTapsValue, FFBooleanValue? animationLoopValue, FFBooleanValue? animationReverseValue, FFBooleanValue? animationInvertValue, FFDoubleValue? animationRangeStartValue, FFDoubleValue? animationRangeEndValue, bool? animateParams, FFCurve? paramsAnimationCurve, FFDoubleValue? paramsAnimationDurationValue, FFCurve? tapAnimationCurve, FFDoubleValue? tapAnimationDurationValue, FFDoubleValue? tapAnimationDelayValue, FFBooleanValue? tapAnimationReverseValue, FFBooleanValue? tapAnimationInvertValue, FFDoubleValue? tapAnimationRangeStartValue, FFDoubleValue? tapAnimationRangeEndValue, Iterable<FFDoubleValue> ? customUniformValues}) -
factory
-
FFShaderProperties.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFShaderProperties.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- animateParams ↔ bool
-
Implicit param animation (smooth transitions when ShaderParams change).
getter/setter pair
- animationCurve ↔ FFCurve
-
getter/setter pair
- animationDelayValue ↔ FFDoubleValue
-
getter/setter pair
- animationDurationValue ↔ FFDoubleValue
-
getter/setter pair
- animationInvertValue ↔ FFBooleanValue
-
getter/setter pair
- animationLoopValue ↔ FFBooleanValue
-
getter/setter pair
- animationMode ↔ FFShaderAnimationMode
-
getter/setter pair
- animationRangeEndValue ↔ FFDoubleValue
-
getter/setter pair
- animationRangeStartValue ↔ FFDoubleValue
-
getter/setter pair
- animationReverseValue ↔ FFBooleanValue
-
getter/setter pair
- animationVariable ↔ FFVariable
-
getter/setter pair
- backgroundColorValue ↔ FFColorValue
-
getter/setter pair
- cacheValue ↔ FFBooleanValue
-
getter/setter pair
-
customUniformValues
→ PbList<
FFDoubleValue> -
Custom mode: uniform values with variable binding support.
no setter
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setteroverride
- interactiveValue ↔ FFBooleanValue
-
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited -
params
→ PbList<
FFShaderParam> -
no setter
- paramsAnimationCurve ↔ FFCurve
-
getter/setter pair
- paramsAnimationDurationValue ↔ FFDoubleValue
-
getter/setter pair
- pathValue ↔ FFStringValue
-
@doc Path to the shader (.frag) asset file (custom mode).
getter/setter pair
- persistTapsValue ↔ FFBooleanValue
-
Interactive widgets: persistTaps
getter/setter pair
- presetType ↔ FFShaderPresetType
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shaderMode ↔ FFShaderMode
-
getter/setter pair
- source ↔ FFSourceType
-
@doc Source of the shader. Currently only ASSET is supported.
getter/setter pair
- tapAnimationCurve ↔ FFCurve
-
Tap animation config (per-tap animation on interactive shaders)
getter/setter pair
- tapAnimationDelayValue ↔ FFDoubleValue
-
getter/setter pair
- tapAnimationDurationValue ↔ FFDoubleValue
-
getter/setter pair
- tapAnimationInvertValue ↔ FFBooleanValue
-
getter/setter pair
- tapAnimationRangeEndValue ↔ FFDoubleValue
-
getter/setter pair
- tapAnimationRangeStartValue ↔ FFDoubleValue
-
getter/setter pair
- tapAnimationReverseValue ↔ FFBooleanValue
-
getter/setter pair
- timeValue ↔ FFDoubleValue
-
Implicit mode: external time value
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAnimateParams(
) → void -
clearAnimationCurve(
) → void -
clearAnimationDelayValue(
) → void -
clearAnimationDurationValue(
) → void -
clearAnimationInvertValue(
) → void -
clearAnimationLoopValue(
) → void -
clearAnimationMode(
) → void -
clearAnimationRangeEndValue(
) → void -
clearAnimationRangeStartValue(
) → void -
clearAnimationReverseValue(
) → void -
clearAnimationVariable(
) → void -
clearBackgroundColorValue(
) → void -
clearCacheValue(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearInteractiveValue(
) → void -
clearParamsAnimationCurve(
) → void -
clearParamsAnimationDurationValue(
) → void -
clearPathValue(
) → void -
clearPersistTapsValue(
) → void -
clearPresetType(
) → void -
clearShaderMode(
) → void -
clearSource(
) → void -
clearTapAnimationCurve(
) → void -
clearTapAnimationDelayValue(
) → void -
clearTapAnimationDurationValue(
) → void -
clearTapAnimationInvertValue(
) → void -
clearTapAnimationRangeEndValue(
) → void -
clearTapAnimationRangeStartValue(
) → void -
clearTapAnimationReverseValue(
) → void -
clearTimeValue(
) → void -
clone(
) → FFShaderProperties -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFShaderProperties)) → FFShaderProperties -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFShaderProperties -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAnimationDelayValue(
) → FFDoubleValue -
ensureAnimationDurationValue(
) → FFDoubleValue -
ensureAnimationInvertValue(
) → FFBooleanValue -
ensureAnimationLoopValue(
) → FFBooleanValue -
ensureAnimationRangeEndValue(
) → FFDoubleValue -
ensureAnimationRangeStartValue(
) → FFDoubleValue -
ensureAnimationReverseValue(
) → FFBooleanValue -
ensureAnimationVariable(
) → FFVariable -
ensureBackgroundColorValue(
) → FFColorValue -
ensureCacheValue(
) → FFBooleanValue -
ensureInteractiveValue(
) → FFBooleanValue -
ensureParamsAnimationDurationValue(
) → FFDoubleValue -
ensurePathValue(
) → FFStringValue -
ensurePersistTapsValue(
) → FFBooleanValue -
ensureTapAnimationDelayValue(
) → FFDoubleValue -
ensureTapAnimationDurationValue(
) → FFDoubleValue -
ensureTapAnimationInvertValue(
) → FFBooleanValue -
ensureTapAnimationRangeEndValue(
) → FFDoubleValue -
ensureTapAnimationRangeStartValue(
) → FFDoubleValue -
ensureTapAnimationReverseValue(
) → FFBooleanValue -
ensureTimeValue(
) → FFDoubleValue -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAnimateParams(
) → bool -
hasAnimationCurve(
) → bool -
hasAnimationDelayValue(
) → bool -
hasAnimationDurationValue(
) → bool -
hasAnimationInvertValue(
) → bool -
hasAnimationLoopValue(
) → bool -
hasAnimationMode(
) → bool -
hasAnimationRangeEndValue(
) → bool -
hasAnimationRangeStartValue(
) → bool -
hasAnimationReverseValue(
) → bool -
hasAnimationVariable(
) → bool -
hasBackgroundColorValue(
) → bool -
hasCacheValue(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasInteractiveValue(
) → bool -
hasParamsAnimationCurve(
) → bool -
hasParamsAnimationDurationValue(
) → bool -
hasPathValue(
) → bool -
hasPersistTapsValue(
) → bool -
hasPresetType(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasShaderMode(
) → bool -
hasSource(
) → bool -
hasTapAnimationCurve(
) → bool -
hasTapAnimationDelayValue(
) → bool -
hasTapAnimationDurationValue(
) → bool -
hasTapAnimationInvertValue(
) → bool -
hasTapAnimationRangeEndValue(
) → bool -
hasTapAnimationRangeStartValue(
) → bool -
hasTapAnimationReverseValue(
) → bool -
hasTimeValue(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited