flexValue property
@doc The flex value of the spacer, which dictates how much space it takes up relative to the other widgets in the Row/Column/Flex.
Implementation
@$pb.TagNumber(2)
FFIntegerValue get flexValue => $_getN(1);
Implementation
@$pb.TagNumber(2)
set flexValue(FFIntegerValue value) => $_setField(2, value);