streamSubscriptionKey property
@doc A unique key to identify this stream subscription. This can be used to cancel the subscription later.
Implementation
@$pb.TagNumber(4)
FFValue get streamSubscriptionKey => $_getN(3);
@doc A unique key to identify this stream subscription. This can be used to cancel the subscription later.
@$pb.TagNumber(4)
FFValue get streamSubscriptionKey => $_getN(3);