FFTabBar class

Inheritance
Available extensions

Constructors

FFTabBar({bool? legacyScrollable, FFColor? legacyIndicatorColor, double? legacyIndicatorWeight, FFColor? legacyLabelColor, FFColor? legacyUnselectedLabelColor, FFPadding? labelPadding, int? legacyInitialIndex, FFText? labelStyle, bool? keepTabStateAlive, bool? legacyPreventSwipeToSwitchTabs, FFAlignment? tabAlignment, bool? legacyTabOnBottom, FFTabBar_TabBarStyle? tabBarStyle, FFColor? legacyBackgroundColor, FFColor? legacyUnselectedBackgroundColor, double? legacyBorderWidth, FFColor? legacyBorderColor, FFColor? legacyUnselectedBorderColor, FFPadding? buttonMargin, double? legacyBorderRadius, double? legacyElevation, FFPadding? tabbarMargin, FFText? unselectedLabelStyle, FFBooleanValue? scrollableValue, FFColorValue? indicatorColorValue, FFDoubleValue? indicatorWeightValue, FFColorValue? labelColorValue, FFColorValue? unselectedLabelColorValue, FFIntegerValue? initialIndexValue, FFBooleanValue? preventSwipeToSwitchTabsValue, FFBooleanValue? tabOnBottomValue, FFColorValue? backgroundColorValue, FFColorValue? unselectedBackgroundColorValue, FFDoubleValue? borderWidthValue, FFColorValue? borderColorValue, FFColorValue? unselectedBorderColorValue, FFDoubleValue? borderRadiusValue, FFDoubleValue? elevationValue})
factory
FFTabBar.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FFTabBar.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

backgroundColorValue FFColorValue
getter/setter pair
borderColorValue FFColorValue
getter/setter pair
borderRadiusValue FFDoubleValue
getter/setter pair
borderWidthValue FFDoubleValue
getter/setter pair
buttonMargin FFPadding
getter/setter pair
elevationValue FFDoubleValue
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
indicatorColorValue FFColorValue
getter/setter pair
indicatorWeightValue FFDoubleValue
getter/setter pair
info_ BuilderInfo
no setteroverride
initialIndexValue FFIntegerValue
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
keepTabStateAlive bool
getter/setter pair
labelColorValue FFColorValue
getter/setter pair
labelPadding FFPadding
getter/setter pair
labelStyle FFText
getter/setter pair
legacyBackgroundColor FFColor
getter/setter pair
legacyBorderColor FFColor
getter/setter pair
legacyBorderRadius double
getter/setter pair
legacyBorderWidth double
getter/setter pair
legacyElevation double
getter/setter pair
legacyIndicatorColor FFColor
getter/setter pair
legacyIndicatorWeight double
getter/setter pair
legacyInitialIndex int
getter/setter pair
legacyLabelColor FFColor
getter/setter pair
legacyPreventSwipeToSwitchTabs bool
getter/setter pair
legacyScrollable bool
getter/setter pair
legacyTabOnBottom bool
getter/setter pair
legacyUnselectedBackgroundColor FFColor
getter/setter pair
legacyUnselectedBorderColor FFColor
getter/setter pair
legacyUnselectedLabelColor FFColor
getter/setter pair
preventSwipeToSwitchTabsValue FFBooleanValue
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollableValue FFBooleanValue
getter/setter pair
tabAlignment FFAlignment
getter/setter pair
tabbarMargin FFPadding
getter/setter pair
tabBarStyle FFTabBar_TabBarStyle
getter/setter pair
tabOnBottomValue FFBooleanValue
getter/setter pair
unknownFields UnknownFieldSet
no setterinherited
unselectedBackgroundColorValue FFColorValue
getter/setter pair
unselectedBorderColorValue FFColorValue
getter/setter pair
unselectedLabelColorValue FFColorValue
getter/setter pair
unselectedLabelStyle FFText
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBackgroundColorValue() → void
clearBorderColorValue() → void
clearBorderRadiusValue() → void
clearBorderWidthValue() → void
clearButtonMargin() → void
clearElevationValue() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIndicatorColorValue() → void
clearIndicatorWeightValue() → void
clearInitialIndexValue() → void
clearKeepTabStateAlive() → void
clearLabelColorValue() → void
clearLabelPadding() → void
clearLabelStyle() → void
clearLegacyBackgroundColor() → void
clearLegacyBorderColor() → void
clearLegacyBorderRadius() → void
clearLegacyBorderWidth() → void
clearLegacyElevation() → void
clearLegacyIndicatorColor() → void
clearLegacyIndicatorWeight() → void
clearLegacyInitialIndex() → void
clearLegacyLabelColor() → void
clearLegacyPreventSwipeToSwitchTabs() → void
clearLegacyScrollable() → void
clearLegacyTabOnBottom() → void
clearLegacyUnselectedBackgroundColor() → void
clearLegacyUnselectedBorderColor() → void
clearLegacyUnselectedLabelColor() → void
clearPreventSwipeToSwitchTabsValue() → void
clearScrollableValue() → void
clearTabAlignment() → void
clearTabbarMargin() → void
clearTabBarStyle() → void
clearTabOnBottomValue() → void
clearUnselectedBackgroundColorValue() → void
clearUnselectedBorderColorValue() → void
clearUnselectedLabelColorValue() → void
clearUnselectedLabelStyle() → void
clone() FFTabBar
Creates a deep copy of the fields in this message.
override
copyWith(void updates(FFTabBar)) FFTabBar
Apply updates to a copy of this message.
override
createEmptyInstance() FFTabBar
Creates an empty instance of the same message type as this.
override
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureBackgroundColorValue() FFColorValue
ensureBorderColorValue() FFColorValue
ensureBorderRadiusValue() FFDoubleValue
ensureBorderWidthValue() FFDoubleValue
ensureButtonMargin() FFPadding
ensureElevationValue() FFDoubleValue
ensureIndicatorColorValue() FFColorValue
ensureIndicatorWeightValue() FFDoubleValue
ensureInitialIndexValue() FFIntegerValue
ensureLabelColorValue() FFColorValue
ensureLabelPadding() FFPadding
ensureLabelStyle() FFText
ensureLegacyBackgroundColor() FFColor
ensureLegacyBorderColor() FFColor
ensureLegacyIndicatorColor() FFColor
ensureLegacyLabelColor() FFColor
ensureLegacyUnselectedBackgroundColor() FFColor
ensureLegacyUnselectedBorderColor() FFColor
ensureLegacyUnselectedLabelColor() FFColor
ensurePreventSwipeToSwitchTabsValue() FFBooleanValue
ensureScrollableValue() FFBooleanValue
ensureTabAlignment() FFAlignment
ensureTabbarMargin() FFPadding
ensureTabOnBottomValue() FFBooleanValue
ensureUnselectedBackgroundColorValue() FFColorValue
ensureUnselectedBorderColorValue() FFColorValue
ensureUnselectedLabelColorValue() FFColorValue
ensureUnselectedLabelStyle() FFText
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
fromCompressedSerializedBuffer(List<int> buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

fromCompressedSerializedBufferString(String buffer, [int recursionLimit = 512]) → void

Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension

getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasBackgroundColorValue() bool
hasBorderColorValue() bool
hasBorderRadiusValue() bool
hasBorderWidthValue() bool
hasButtonMargin() bool
hasElevationValue() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasIndicatorColorValue() bool
hasIndicatorWeightValue() bool
hasInitialIndexValue() bool
hasKeepTabStateAlive() bool
hasLabelColorValue() bool
hasLabelPadding() bool
hasLabelStyle() bool
hasLegacyBackgroundColor() bool
hasLegacyBorderColor() bool
hasLegacyBorderRadius() bool
hasLegacyBorderWidth() bool
hasLegacyElevation() bool
hasLegacyIndicatorColor() bool
hasLegacyIndicatorWeight() bool
hasLegacyInitialIndex() bool
hasLegacyLabelColor() bool
hasLegacyPreventSwipeToSwitchTabs() bool
hasLegacyScrollable() bool
hasLegacyTabOnBottom() bool
hasLegacyUnselectedBackgroundColor() bool
hasLegacyUnselectedBorderColor() bool
hasLegacyUnselectedLabelColor() bool
hasPreventSwipeToSwitchTabsValue() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasScrollableValue() bool
hasTabAlignment() bool
hasTabbarMargin() bool
hasTabBarStyle() bool
hasTabOnBottomValue() bool
hasUnselectedBackgroundColorValue() bool
hasUnselectedBorderColorValue() bool
hasUnselectedLabelColorValue() bool
hasUnselectedLabelStyle() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
toTextFormat() String

Available on GeneratedMessage, provided by the TextFormatExtension extension

Returns a TextFormat String representation of this message.
writeTextFormat(StringSink sink) → void

Available on GeneratedMessage, provided by the TextFormatExtension extension

Writes a TextFormat String representation of this message to sink.
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() FFTabBar
getDefault() FFTabBar