FFTextField class
- Inheritance
-
- Object
- GeneratedMessage
- FFTextField
- Available extensions
Constructors
-
FFTextField({FFText? textStyle, FFInputDecoration? inputDecoration, int? legacyMaxLines, bool? passwordField, @Deprecated('This field is deprecated.') String? legacyInitialText, FFTextInputType? keyboardType, bool? showClearButton, FFIcon? legacyLeadingIcon, FFIcon? legacyTrailingIcon, bool? localStateValue, @Deprecated('This field is deprecated.') FFTextInputValidation? validation, bool? setStateOnChanged, double? legacyDebounceTime, FFText? initialText, bool? legacyReadOnly, bool? legacyAutofocus, FFDim? width, bool? autocomplete, @Deprecated('This field is deprecated.') Iterable<
FFText> ? legacyOptions, FFText? optionTextStyle, FFText? optionSubstringStyle, FFColor? legacyOptionBackgroundColor, FFColor? legacyOptionHighlightColor, double? legacyOptionElevation, FFDim? optionsOverlayHeight, int? legacyMinLines, FFTextFieldMask? mask, FFTextFieldFilter? filter, FFTextField_AutoFillHints? autoFillHint, FFTextField_Capitalization? capitalization, FFColor? legacyCursorColor, FFTextField_SubmitType? submitType, int? legacyMaxLength, FFTextField_MaxLengthEnforcement? maxLengthEnforcement, bool? hideMaxLengthCounter, bool? setStateOnFocusChanged, FFIntegerValue? maxLinesValue, FFIntegerValue? minLinesValue, FFDoubleValue? debounceTimeValue, FFBooleanValue? readOnlyValue, FFBooleanValue? autofocusValue, FFDoubleValue? optionElevationValue, FFColorValue? cursorColorValue, FFIntegerValue? maxLengthValue, FFIconValue? leadingIconValue, FFIconValue? trailingIconValue, bool? blockShortcutIntents, FFColorValue? optionBackgroundColorValue, FFColorValue? optionHighlightColorValue, FFTextOptionsValue? options, FFBooleanValue? enableInteractiveSelection, FFBooleanValue? enabledValue, FFBooleanValue? passwordIconAllowKeyboardTraversal}) -
factory
-
FFTextField.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- FFTextField.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- autocomplete ↔ bool
-
Not overridable
getter/setter pair
- autoFillHint ↔ FFTextField_AutoFillHints
-
getter/setter pair
- autofocusValue ↔ FFBooleanValue
-
getter/setter pair
- blockShortcutIntents ↔ bool
-
Not overridable
@doc If set, shortcuts are blocked when the text field is focused.
getter/setter pair
- capitalization ↔ FFTextField_Capitalization
-
getter/setter pair
- cursorColorValue ↔ FFColorValue
-
getter/setter pair
- debounceTimeValue ↔ FFDoubleValue
-
getter/setter pair
- enabledValue ↔ FFBooleanValue
-
getter/setter pair
- enableInteractiveSelection ↔ FFBooleanValue
-
getter/setter pair
- filter ↔ FFTextFieldFilter
-
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- hideMaxLengthCounter ↔ bool
-
Not overridable
getter/setter pair
- info_ → BuilderInfo
-
no setteroverride
- initialText ↔ FFText
-
getter/setter pair
- inputDecoration ↔ FFInputDecoration
-
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - keyboardType ↔ FFTextInputType
-
getter/setter pair
- leadingIconValue ↔ FFIconValue
-
getter/setter pair
- legacyAutofocus ↔ bool
-
getter/setter pair
- legacyCursorColor ↔ FFColor
-
getter/setter pair
- legacyDebounceTime ↔ double
-
Actually has to be int. Only int allowed in property editor.
getter/setter pair
- legacyInitialText ↔ String
-
getter/setter pair
- legacyLeadingIcon ↔ FFIcon
-
getter/setter pair
- legacyMaxLength ↔ int
-
getter/setter pair
- legacyMaxLines ↔ int
-
getter/setter pair
- legacyMinLines ↔ int
-
getter/setter pair
- legacyOptionBackgroundColor ↔ FFColor
-
getter/setter pair
- legacyOptionElevation ↔ double
-
getter/setter pair
- legacyOptionHighlightColor ↔ FFColor
-
getter/setter pair
-
legacyOptions
→ PbList<
FFText> -
no setter
- legacyReadOnly ↔ bool
-
getter/setter pair
- legacyTrailingIcon ↔ FFIcon
-
getter/setter pair
- localStateValue ↔ bool
-
Not overridable (used only for UI Builder)
getter/setter pair
- mask ↔ FFTextFieldMask
-
getter/setter pair
- maxLengthEnforcement ↔ FFTextField_MaxLengthEnforcement
-
getter/setter pair
- maxLengthValue ↔ FFIntegerValue
-
getter/setter pair
- maxLinesValue ↔ FFIntegerValue
-
getter/setter pair
- minLinesValue ↔ FFIntegerValue
-
getter/setter pair
- optionBackgroundColorValue ↔ FFColorValue
-
getter/setter pair
- optionElevationValue ↔ FFDoubleValue
-
getter/setter pair
- optionHighlightColorValue ↔ FFColorValue
-
getter/setter pair
- options ↔ FFTextOptionsValue
-
getter/setter pair
- optionsOverlayHeight ↔ FFDim
-
getter/setter pair
- optionSubstringStyle ↔ FFText
-
getter/setter pair
- optionTextStyle ↔ FFText
-
getter/setter pair
- passwordField ↔ bool
-
Not overridable
getter/setter pair
- passwordIconAllowKeyboardTraversal ↔ FFBooleanValue
-
getter/setter pair
- readOnlyValue ↔ FFBooleanValue
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setStateOnChanged ↔ bool
-
Not overridable
getter/setter pair
- setStateOnFocusChanged ↔ bool
-
Not overridable
getter/setter pair
- showClearButton ↔ bool
-
Not overridable
getter/setter pair
- submitType ↔ FFTextField_SubmitType
-
getter/setter pair
- textStyle ↔ FFText
-
getter/setter pair
- trailingIconValue ↔ FFIconValue
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- validation ↔ FFTextInputValidation
-
Deprecated in favor of FFFormFieldValidation.
getter/setter pair
- width ↔ FFDim
-
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAutocomplete(
) → void -
clearAutoFillHint(
) → void -
clearAutofocusValue(
) → void -
clearBlockShortcutIntents(
) → void -
clearCapitalization(
) → void -
clearCursorColorValue(
) → void -
clearDebounceTimeValue(
) → void -
clearEnabledValue(
) → void -
clearEnableInteractiveSelection(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearFilter(
) → void -
clearHideMaxLengthCounter(
) → void -
clearInitialText(
) → void -
clearInputDecoration(
) → void -
clearKeyboardType(
) → void -
clearLeadingIconValue(
) → void -
clearLegacyAutofocus(
) → void -
clearLegacyCursorColor(
) → void -
clearLegacyDebounceTime(
) → void -
clearLegacyInitialText(
) → void -
clearLegacyLeadingIcon(
) → void -
clearLegacyMaxLength(
) → void -
clearLegacyMaxLines(
) → void -
clearLegacyMinLines(
) → void -
clearLegacyOptionBackgroundColor(
) → void -
clearLegacyOptionElevation(
) → void -
clearLegacyOptionHighlightColor(
) → void -
clearLegacyReadOnly(
) → void -
clearLegacyTrailingIcon(
) → void -
clearLocalStateValue(
) → void -
clearMask(
) → void -
clearMaxLengthEnforcement(
) → void -
clearMaxLengthValue(
) → void -
clearMaxLinesValue(
) → void -
clearMinLinesValue(
) → void -
clearOptionBackgroundColorValue(
) → void -
clearOptionElevationValue(
) → void -
clearOptionHighlightColorValue(
) → void -
clearOptions(
) → void -
clearOptionsOverlayHeight(
) → void -
clearOptionSubstringStyle(
) → void -
clearOptionTextStyle(
) → void -
clearPasswordField(
) → void -
clearPasswordIconAllowKeyboardTraversal(
) → void -
clearReadOnlyValue(
) → void -
clearSetStateOnChanged(
) → void -
clearSetStateOnFocusChanged(
) → void -
clearShowClearButton(
) → void -
clearSubmitType(
) → void -
clearTextStyle(
) → void -
clearTrailingIconValue(
) → void -
clearValidation(
) → void -
clearWidth(
) → void -
clone(
) → FFTextField -
Creates a deep copy of the fields in this message.
override
-
copyWith(
void updates(FFTextField)) → FFTextField -
Apply
updatesto a copy of this message.override -
createEmptyInstance(
) → FFTextField -
Creates an empty instance of the same message type as this.
override
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAutofocusValue(
) → FFBooleanValue -
ensureCursorColorValue(
) → FFColorValue -
ensureDebounceTimeValue(
) → FFDoubleValue -
ensureEnabledValue(
) → FFBooleanValue -
ensureEnableInteractiveSelection(
) → FFBooleanValue -
ensureFilter(
) → FFTextFieldFilter -
ensureInitialText(
) → FFText -
ensureInputDecoration(
) → FFInputDecoration -
ensureLeadingIconValue(
) → FFIconValue -
ensureLegacyCursorColor(
) → FFColor -
ensureLegacyLeadingIcon(
) → FFIcon -
ensureLegacyOptionBackgroundColor(
) → FFColor -
ensureLegacyOptionHighlightColor(
) → FFColor -
ensureLegacyTrailingIcon(
) → FFIcon -
ensureMask(
) → FFTextFieldMask -
ensureMaxLengthValue(
) → FFIntegerValue -
ensureMaxLinesValue(
) → FFIntegerValue -
ensureMinLinesValue(
) → FFIntegerValue -
ensureOptionBackgroundColorValue(
) → FFColorValue -
ensureOptionElevationValue(
) → FFDoubleValue -
ensureOptionHighlightColorValue(
) → FFColorValue -
ensureOptions(
) → FFTextOptionsValue -
ensureOptionsOverlayHeight(
) → FFDim -
ensureOptionSubstringStyle(
) → FFText -
ensureOptionTextStyle(
) → FFText -
ensurePasswordIconAllowKeyboardTraversal(
) → FFBooleanValue -
ensureReadOnlyValue(
) → FFBooleanValue -
ensureTextStyle(
) → FFText -
ensureTrailingIconValue(
) → FFIconValue -
ensureValidation(
) → FFTextInputValidation -
ensureWidth(
) → FFDim -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
fromCompressedSerializedBuffer(
List< int> buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
fromCompressedSerializedBufferString(
String buffer, [int recursionLimit = 512]) → void -
Available on GeneratedMessage, provided by the SchemaCompressedSerializationExtensions extension
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAutocomplete(
) → bool -
hasAutoFillHint(
) → bool -
hasAutofocusValue(
) → bool -
hasBlockShortcutIntents(
) → bool -
hasCapitalization(
) → bool -
hasCursorColorValue(
) → bool -
hasDebounceTimeValue(
) → bool -
hasEnabledValue(
) → bool -
hasEnableInteractiveSelection(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasFilter(
) → bool -
hasHideMaxLengthCounter(
) → bool -
hasInitialText(
) → bool -
hasInputDecoration(
) → bool -
hasKeyboardType(
) → bool -
hasLeadingIconValue(
) → bool -
hasLegacyAutofocus(
) → bool -
hasLegacyCursorColor(
) → bool -
hasLegacyDebounceTime(
) → bool -
hasLegacyInitialText(
) → bool -
hasLegacyLeadingIcon(
) → bool -
hasLegacyMaxLength(
) → bool -
hasLegacyMaxLines(
) → bool -
hasLegacyMinLines(
) → bool -
hasLegacyOptionBackgroundColor(
) → bool -
hasLegacyOptionElevation(
) → bool -
hasLegacyOptionHighlightColor(
) → bool -
hasLegacyReadOnly(
) → bool -
hasLegacyTrailingIcon(
) → bool -
hasLocalStateValue(
) → bool -
hasMask(
) → bool -
hasMaxLengthEnforcement(
) → bool -
hasMaxLengthValue(
) → bool -
hasMaxLinesValue(
) → bool -
hasMinLinesValue(
) → bool -
hasOptionBackgroundColorValue(
) → bool -
hasOptionElevationValue(
) → bool -
hasOptionHighlightColorValue(
) → bool -
hasOptions(
) → bool -
hasOptionsOverlayHeight(
) → bool -
hasOptionSubstringStyle(
) → bool -
hasOptionTextStyle(
) → bool -
hasPasswordField(
) → bool -
hasPasswordIconAllowKeyboardTraversal(
) → bool -
hasReadOnlyValue(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSetStateOnChanged(
) → bool -
hasSetStateOnFocusChanged(
) → bool -
hasShowClearButton(
) → bool -
hasSubmitType(
) → bool -
hasTextStyle(
) → bool -
hasTrailingIconValue(
) → bool -
hasValidation(
) → bool -
hasWidth(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
-
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described by GeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
toTextFormat(
) → String -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Returns a TextFormat String representation of this message. -
writeTextFormat(
StringSink sink) → void -
Available on GeneratedMessage, provided by the TextFormatExtension extension
Writes a TextFormat String representation of this message tosink. -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
-
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → FFTextField -
getDefault(
) → FFTextField