batchFirestoreWrites property
@doc Whether to execute all Firestore write operations as a single batch. A batch of writes completes atomically and can write to multiple documents. The batch is written at the end of the entire action chain execution.
Learn more about Firestore batches: https://firebase.google.com/docs/firestore/manage-data/transactions#batched-writes
Implementation
@$pb.TagNumber(4)
$core.bool get batchFirestoreWrites => $_getBF(3);