legacyActionComponentKey property
The key of the action component associated with this variable. This should only be used for other actions inside of an action component.
Implementation
@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(15)
$core.String get legacyActionComponentKey => $_getSZ(14);
Implementation
@$core.Deprecated('This field is deprecated.')
@$pb.TagNumber(15)
set legacyActionComponentKey($core.String value) => $_setString(14, value);