themeOverrides property
Properties in a widget theme that should be overridden by this node's values We can add a repeated theme_overrides_overrides that keep track of the override properties in a widget theme that should be overridden by this node's override properties. But I don't think the use case is very strong
Implementation
@$pb.TagNumber(90)
$pb.PbList<FFPropertyOverride> get themeOverrides => $_getList(88);