schema/gen/flutterflow.pbenum library
Classes
- AIMessage_Role
- AIModelRequestOptions_RequestType
- AIModelResponseOptions_ResponseType
- FFAccessDocumentField_DocumentProperty
- FFAccessGooglePlaceField_GooglePlaceField
- FFAction_LegacyTrigger
- FFActionInputVariable_ActionInput
- FFActionTriggerType
- FFAdMobSettings_MaxAdContentRating
- FFAgent_FFAgentStatus
- FFAlgoliaLocation_LocationSource
- FFAnimation_Trigger
- FFAnimationAction_FFAnimationActionType
- FFAnimationAction_FFWidgetAnimationAction_ActionType
- FFApiEndpoint_BodyType
- FFApiEndpoint_CallType
- FFApiResponseField_ResponseField
- FFApiResponseType
- FFAppBar_TemplateType
- FFAppEvent_FFAppEventScope
- FFAppStorePrivacyManifestSettings_ActiveKeyboardsApi
- FFAppStorePrivacyManifestSettings_DiskSpaceApi
- FFAppStorePrivacyManifestSettings_FileTimestampApi
- FFAppStorePrivacyManifestSettings_SystemBootTimeApi
- FFAppStorePrivacyManifestSettings_UserDefaultsApi
- FFAspectRatioPreset
- FFAudio_FFAudioType
- FFAudioPlayer_PlayInBackground
- FFAuthAction_ActionType
- FFAuthProvider
- FFAuthVariable_AuthProperty
- FFAxis
- FFAxisDirection
- FFBarcode_BarcodeType
- FFBarcode_BarcodeTypeCategory
- FFBaseDataType
- FFBorderRadius_BorderRadiusType
- FFBoxFit
- FFBoxShape
- FFBraintreePaymentConfig_BraintreePaymentType
- FFButton_FFButtonIconPosition
- FFCarouselAction_ActionType
- FFChart_ChartType
- FFChartData_DataSourceType
- FFChartLabelFormatInfo_LabelFormatType
- FFChatAction_ChatActionType
- FFChatPage_TimeDisplaySetting
- FFCheckboxDensity
- FFClip
- FFCodemagicGooglePlayStoreSettings_GooglePlayTrack
- FFColor_ThemeColor
- FFCombineConditions_LogicalOperator
- FFCondition_Relation
- FFConstantsVariable_ConstantValue
- FFCrossAxisAlignment
- FFCurve
- FFCustomCloudFunctionResponseField_ResponseField
- FFCustomFile_Action_Type
- FFCustomFile_Hook_Type
- FFCustomFile_Type
- @doc The type of custom file.
- FFDatabaseRequestManagerSettings_ManagerScope
- Whether the request is managed / cached at the app or widget class level.
- FFDataTableAction_ControlPageType
- FFDatePicker_DateTimePickerType
- FFDesignTokenVariable_TokenType
- FFDividerLineStyle
- FFDrawerAction_ActionType
- FFDynamicComponentAccess_AccessType
- FFExpandable_HeaderAlignment
- FFExpanded_ExpandedType
- FFFirebaseAppCheckConfig_AndroidProvider
- FFFirebaseAppCheckConfig_AppleProvider
- FFFirestoreAggregation_AggregationType
- FFFirestoreFilter_Relation
- TODO: Extend these with more types.
- FFFirestoreSchemaValidation_Mode
- Using enum instead of bool in anticipation that we can have more options in how it will run.
- FFFontWeight
- FFForm_AutovalidateMode
- FFFormFieldActionRebuildType
- @doc Defines the types of rebuild that can be performed, when a form field is reset or set.
- FFGenUIBackendType
- FFGlobalPropertiesVariable_GlobalProperty
- FFGoogleMap_FFGoogleMapStyle
- FFGoogleMap_FFGoogleMapType
- FFGoogleMap_FFGoogleMarkerColor
- FFGoogleMap_FFMarkerIcon
- FFGoogleMap_FFMarkerType
- FFGradient_FFGradientType
- FFHapticFeedbackAction_FFFeedbackType
- FFHideSnackBarAction_HideScope
- FFImage_FFImageFormat
- FFImage_FFImageType
- FFIndicatorPosition
- FFInputDecoration_InputBorderType
- FFInternationalizationVariable_VariableType
- FFListItemAtIndex_IndexType
- FFLoadingIndicator_IndicatorType
- FFLocalStateUpdate_UpdateType
- FFLottieAnimationType
- FFMainAxisAlignment
- FFMapLauncherAction_MapType
- FFMouseRegion_FFMouseCursor
- FFMultiselectWidgetAction_ActionType
- FFMuxBroadcast_FFMuxBroadcastAudioChannel
- FFMuxBroadcast_FFMuxBroadcastLatencyMode
- FFMuxBroadcast_FFMuxBroadcastResolution
- FFNumberFormat_DecimalType
- FFNumberFormat_FormatType
- FFOverrideSourceType
- FFOverrideVariableSource
- TODO: Eventually add STATE as a type.
- FFPadding_PaddingType
- FFPageViewAction_ActionType
- FFPermissionType
- FFPieChart_SectionLabelType
- FFPinCode_FFPinCodeFieldShape
- FFPostgresFilter_ExactEquality
- FFPostgresFilter_Relation
- FFPostgresFlavor
- FFProgressBar_FFProgressBarShape
- FFProject_LegacyNullSafety
- TODO: remove once null-safety migration is completed. Use enum instead of boolean to distinguish users who did not specify the value vs those who explicitly opted out.
- FFProjectWalkthroughStep_ContentAlignment
- FFProjectWalkthroughStep_FocusShape
- FFProjectWalkthroughStep_SkipAlignment
- FFPushNotificationData_Status
- FFPushNotificationData_TargetAudience
- FFRadioButton_FFRadioButtonPosition
- FFRandomName_NameType
- FFRebuildAction_UpdateType
- FFResponseStreamMessageField_ResponseField
- FFRevenueCatGetOfferingAttributeReducer_OfferingAttribute
- FFRevenueCatGetPackageAttributeReducer_PackageAttribute
- FFRevenueCatVariable_VariableType
- FFRiveSimpleAnimationType
- FFSetDarkModeSetting_DarkModeSetting
- FFSetFormFieldAction_FormFieldInfo_CursorPosition
- FFShaderAnimationAction_ActionType
- FFShaderAnimationMode
- FFShaderMode
- FFShaderPresetType
- FFSourceType
- FFStateVariableType
- FFStaticMap_FFStaticMapStyle
- FFStripePaymentSheetOptions_PaymentSheetTheme
- FFSwipeableStack_SwipeDirectionType
- FFSwipeableStackAction_SwipeActionType
- FFTabBar_TabBarStyle
- FFTabBarAction_ActionType
- FFText_LegacyOverflowReplacement
- FFText_OverflowReplacement
- FFText_ThemeStyle
- FFTextAlign
- FFTextField_AutoFillHints
- FFTextField_Capitalization
- FFTextField_MaxLengthEnforcement
- FFTextField_SubmitType
- FFTextGradient_FFGradientDirection
- FFTextGradient_FFGradientType
- FFTextInputType
- FFTimer_FFTimerFormat
- FFTimer_FFTimerType
- FFTimerAction_ActionType
- FFTooltip_TriggerMode
- FFUpdateFieldValue_FieldValue
- FFUploadDataDestination
- FFUploadDataSettings_FileType
- FFUploadDataSettings_Source
- FFVariableSource
- FFVerticalDirection
- FFVideoPlayer_FFVideoType
- FFWebBuildSettings_CORSProxyStrategy
- FFWebSettings_WebOrientation
- FFWidgetProperties_PlatformType
- Used for widgets that may differ in style depending on the platform.
- FFWidgetPropertyType
- FFWidgetStateVariable_ActionVariableType
- If the variable comes from an action on a widget, stores the action type.
- FFWidgetType
- FFWrapAlignment
- FFWrapCrossAlignment
- TimeUnitType